import * as constructs from 'constructs';
import * as cdk from '../../core';
import * as cfn_parse from '../../core/lib/helpers-internal';
/**
 * Properties for defining a `CfnAnalysis`
 *
 * @struct
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
 */
export interface CfnAnalysisProps {
    /**
     * The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-analysisid
     */
    readonly analysisId: string;
    /**
     * The ID of the AWS account where you are creating an analysis.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-awsaccountid
     */
    readonly awsAccountId: string;
    /**
     * A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon QuickSight console.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-name
     */
    readonly name: string;
    /**
     * `AWS::QuickSight::Analysis.Definition`
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-definition
     */
    readonly definition?: CfnAnalysis.AnalysisDefinitionProperty | cdk.IResolvable;
    /**
     * The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-parameters
     */
    readonly parameters?: CfnAnalysis.ParametersProperty | cdk.IResolvable;
    /**
     * A structure that describes the principals and the resource-level permissions on an analysis. You can use the `Permissions` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).
     *
     * To specify no permissions, omit `Permissions` .
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-permissions
     */
    readonly permissions?: Array<CfnAnalysis.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets.
     *
     * Either a `SourceEntity` or a `Definition` must be provided in order for the request to be valid.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sourceentity
     */
    readonly sourceEntity?: CfnAnalysis.AnalysisSourceEntityProperty | cdk.IResolvable;
    /**
     * `AWS::QuickSight::Analysis.Status`
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-status
     */
    readonly status?: string;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-tags
     */
    readonly tags?: cdk.CfnTag[];
    /**
     * The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon QuickSight console, make sure that you have access to it.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-themearn
     */
    readonly themeArn?: string;
}
/**
 * A CloudFormation `AWS::QuickSight::Analysis`
 *
 * Creates an analysis in Amazon QuickSight.
 *
 * @cloudformationResource AWS::QuickSight::Analysis
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html
 */
export declare class CfnAnalysis extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "AWS::QuickSight::Analysis";
    /**
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnAnalysis;
    /**
     * The Amazon Resource Name (ARN) of the analysis.
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     *
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The ARNs of the datasets of the analysis.
     * @cloudformationAttribute DataSetArns
     */
    readonly attrDataSetArns: string[];
    /**
     *
     * @cloudformationAttribute Errors
     */
    readonly attrErrors: cdk.IResolvable;
    /**
     * The time that the analysis was last updated.
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     *
     * @cloudformationAttribute Sheets
     */
    readonly attrSheets: cdk.IResolvable;
    /**
     * The ID for the analysis that you're creating. This ID displays in the URL of the analysis.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-analysisid
     */
    analysisId: string;
    /**
     * The ID of the AWS account where you are creating an analysis.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-awsaccountid
     */
    awsAccountId: string;
    /**
     * A descriptive name for the analysis that you're creating. This name displays for the analysis in the Amazon QuickSight console.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-name
     */
    name: string;
    /**
     * `AWS::QuickSight::Analysis.Definition`
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-definition
     */
    definition: CfnAnalysis.AnalysisDefinitionProperty | cdk.IResolvable | undefined;
    /**
     * The parameter names and override values that you want to use. An analysis can have any parameter type, and some parameters might accept multiple values.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-parameters
     */
    parameters: CfnAnalysis.ParametersProperty | cdk.IResolvable | undefined;
    /**
     * A structure that describes the principals and the resource-level permissions on an analysis. You can use the `Permissions` structure to grant permissions by providing a list of AWS Identity and Access Management (IAM) action information for each principal listed by Amazon Resource Name (ARN).
     *
     * To specify no permissions, omit `Permissions` .
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-permissions
     */
    permissions: Array<CfnAnalysis.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * A source entity to use for the analysis that you're creating. This metadata structure contains details that describe a source template and one or more datasets.
     *
     * Either a `SourceEntity` or a `Definition` must be provided in order for the request to be valid.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-sourceentity
     */
    sourceEntity: CfnAnalysis.AnalysisSourceEntityProperty | cdk.IResolvable | undefined;
    /**
     * `AWS::QuickSight::Analysis.Status`
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-status
     */
    status: string | undefined;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the analysis.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-tags
     */
    readonly tags: cdk.TagManager;
    /**
     * The ARN for the theme to apply to the analysis that you're creating. To see the theme in the Amazon QuickSight console, make sure that you have access to it.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-analysis.html#cfn-quicksight-analysis-themearn
     */
    themeArn: string | undefined;
    /**
     * Create a new `AWS::QuickSight::Analysis`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnAnalysisProps);
    /**
     * Examines the CloudFormation resource and discloses attributes.
     *
     * @param inspector - tree inspector to collect and process attributes
     *
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected get cfnProperties(): {
        [key: string]: any;
    };
    protected renderProperties(props: {
        [key: string]: any;
    }): {
        [key: string]: any;
    };
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html
     */
    interface AggregationFunctionProperty {
        /**
         * `CfnAnalysis.AggregationFunctionProperty.CategoricalAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-categoricalaggregationfunction
         */
        readonly categoricalAggregationFunction?: string;
        /**
         * `CfnAnalysis.AggregationFunctionProperty.DateAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-dateaggregationfunction
         */
        readonly dateAggregationFunction?: string;
        /**
         * `CfnAnalysis.AggregationFunctionProperty.NumericalAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationfunction.html#cfn-quicksight-analysis-aggregationfunction-numericalaggregationfunction
         */
        readonly numericalAggregationFunction?: CfnAnalysis.NumericalAggregationFunctionProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html
     */
    interface AggregationSortConfigurationProperty {
        /**
         * `CfnAnalysis.AggregationSortConfigurationProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-aggregationfunction
         */
        readonly aggregationFunction: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AggregationSortConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AggregationSortConfigurationProperty.SortDirection`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-aggregationsortconfiguration.html#cfn-quicksight-analysis-aggregationsortconfiguration-sortdirection
         */
        readonly sortDirection: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html
     */
    interface AnalysisDefaultsProperty {
        /**
         * `CfnAnalysis.AnalysisDefaultsProperty.DefaultNewSheetConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefaults.html#cfn-quicksight-analysis-analysisdefaults-defaultnewsheetconfiguration
         */
        readonly defaultNewSheetConfiguration: CfnAnalysis.DefaultNewSheetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html
     */
    interface AnalysisDefinitionProperty {
        /**
         * `CfnAnalysis.AnalysisDefinitionProperty.AnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-analysisdefaults
         */
        readonly analysisDefaults?: CfnAnalysis.AnalysisDefaultsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AnalysisDefinitionProperty.CalculatedFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-calculatedfields
         */
        readonly calculatedFields?: Array<CfnAnalysis.CalculatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.AnalysisDefinitionProperty.ColumnConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-columnconfigurations
         */
        readonly columnConfigurations?: Array<CfnAnalysis.ColumnConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.AnalysisDefinitionProperty.DataSetIdentifierDeclarations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-datasetidentifierdeclarations
         */
        readonly dataSetIdentifierDeclarations: Array<CfnAnalysis.DataSetIdentifierDeclarationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.AnalysisDefinitionProperty.FilterGroups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-filtergroups
         */
        readonly filterGroups?: Array<CfnAnalysis.FilterGroupProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.AnalysisDefinitionProperty.ParameterDeclarations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-parameterdeclarations
         */
        readonly parameterDeclarations?: Array<CfnAnalysis.ParameterDeclarationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.AnalysisDefinitionProperty.Sheets`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysisdefinition.html#cfn-quicksight-analysis-analysisdefinition-sheets
         */
        readonly sheets?: Array<CfnAnalysis.SheetDefinitionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     * Analysis error.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html
     */
    interface AnalysisErrorProperty {
        /**
         * The message associated with the analysis error.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-message
         */
        readonly message?: string;
        /**
         * The type of the analysis error.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-type
         */
        readonly type?: string;
        /**
         * `CfnAnalysis.AnalysisErrorProperty.ViolatedEntities`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysiserror.html#cfn-quicksight-analysis-analysiserror-violatedentities
         */
        readonly violatedEntities?: Array<CfnAnalysis.EntityProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     * The source entity of an analysis.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html
     */
    interface AnalysisSourceEntityProperty {
        /**
         * The source template for the source entity of the analysis.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourceentity.html#cfn-quicksight-analysis-analysissourceentity-sourcetemplate
         */
        readonly sourceTemplate?: CfnAnalysis.AnalysisSourceTemplateProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     * The source template of an analysis.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html
     */
    interface AnalysisSourceTemplateProperty {
        /**
         * The Amazon Resource Name (ARN) of the source template of an analysis.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-arn
         */
        readonly arn: string;
        /**
         * The dataset references of the source template of an analysis.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-analysissourcetemplate.html#cfn-quicksight-analysis-analysissourcetemplate-datasetreferences
         */
        readonly dataSetReferences: Array<CfnAnalysis.DataSetReferenceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html
     */
    interface AnchorDateConfigurationProperty {
        /**
         * `CfnAnalysis.AnchorDateConfigurationProperty.AnchorOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-anchoroption
         */
        readonly anchorOption?: string;
        /**
         * `CfnAnalysis.AnchorDateConfigurationProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-anchordateconfiguration.html#cfn-quicksight-analysis-anchordateconfiguration-parametername
         */
        readonly parameterName?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html
     */
    interface ArcAxisConfigurationProperty {
        /**
         * `CfnAnalysis.ArcAxisConfigurationProperty.Range`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-range
         */
        readonly range?: CfnAnalysis.ArcAxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ArcAxisConfigurationProperty.ReserveRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisconfiguration.html#cfn-quicksight-analysis-arcaxisconfiguration-reserverange
         */
        readonly reserveRange?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html
     */
    interface ArcAxisDisplayRangeProperty {
        /**
         * `CfnAnalysis.ArcAxisDisplayRangeProperty.Max`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-max
         */
        readonly max?: number;
        /**
         * `CfnAnalysis.ArcAxisDisplayRangeProperty.Min`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcaxisdisplayrange.html#cfn-quicksight-analysis-arcaxisdisplayrange-min
         */
        readonly min?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html
     */
    interface ArcConfigurationProperty {
        /**
         * `CfnAnalysis.ArcConfigurationProperty.ArcAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcangle
         */
        readonly arcAngle?: number;
        /**
         * `CfnAnalysis.ArcConfigurationProperty.ArcThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcconfiguration.html#cfn-quicksight-analysis-arcconfiguration-arcthickness
         */
        readonly arcThickness?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html
     */
    interface ArcOptionsProperty {
        /**
         * `CfnAnalysis.ArcOptionsProperty.ArcThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-arcoptions.html#cfn-quicksight-analysis-arcoptions-arcthickness
         */
        readonly arcThickness?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html
     */
    interface AxisDataOptionsProperty {
        /**
         * `CfnAnalysis.AxisDataOptionsProperty.DateAxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-dateaxisoptions
         */
        readonly dateAxisOptions?: CfnAnalysis.DateAxisOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AxisDataOptionsProperty.NumericAxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdataoptions.html#cfn-quicksight-analysis-axisdataoptions-numericaxisoptions
         */
        readonly numericAxisOptions?: CfnAnalysis.NumericAxisOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html
     */
    interface AxisDisplayMinMaxRangeProperty {
        /**
         * `CfnAnalysis.AxisDisplayMinMaxRangeProperty.Maximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-maximum
         */
        readonly maximum?: number;
        /**
         * `CfnAnalysis.AxisDisplayMinMaxRangeProperty.Minimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayminmaxrange.html#cfn-quicksight-analysis-axisdisplayminmaxrange-minimum
         */
        readonly minimum?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html
     */
    interface AxisDisplayOptionsProperty {
        /**
         * `CfnAnalysis.AxisDisplayOptionsProperty.AxisLineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axislinevisibility
         */
        readonly axisLineVisibility?: string;
        /**
         * `CfnAnalysis.AxisDisplayOptionsProperty.AxisOffset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-axisoffset
         */
        readonly axisOffset?: string;
        /**
         * `CfnAnalysis.AxisDisplayOptionsProperty.DataOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-dataoptions
         */
        readonly dataOptions?: CfnAnalysis.AxisDataOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AxisDisplayOptionsProperty.GridLineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-gridlinevisibility
         */
        readonly gridLineVisibility?: string;
        /**
         * `CfnAnalysis.AxisDisplayOptionsProperty.ScrollbarOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-scrollbaroptions
         */
        readonly scrollbarOptions?: CfnAnalysis.ScrollBarOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AxisDisplayOptionsProperty.TickLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayoptions.html#cfn-quicksight-analysis-axisdisplayoptions-ticklabeloptions
         */
        readonly tickLabelOptions?: CfnAnalysis.AxisTickLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html
     */
    interface AxisDisplayRangeProperty {
        /**
         * `CfnAnalysis.AxisDisplayRangeProperty.DataDriven`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-datadriven
         */
        readonly dataDriven?: any | cdk.IResolvable;
        /**
         * `CfnAnalysis.AxisDisplayRangeProperty.MinMax`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisdisplayrange.html#cfn-quicksight-analysis-axisdisplayrange-minmax
         */
        readonly minMax?: CfnAnalysis.AxisDisplayMinMaxRangeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html
     */
    interface AxisLabelOptionsProperty {
        /**
         * `CfnAnalysis.AxisLabelOptionsProperty.ApplyTo`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-applyto
         */
        readonly applyTo?: CfnAnalysis.AxisLabelReferenceOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AxisLabelOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnAnalysis.AxisLabelOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabeloptions.html#cfn-quicksight-analysis-axislabeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html
     */
    interface AxisLabelReferenceOptionsProperty {
        /**
         * `CfnAnalysis.AxisLabelReferenceOptionsProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AxisLabelReferenceOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislabelreferenceoptions.html#cfn-quicksight-analysis-axislabelreferenceoptions-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html
     */
    interface AxisLinearScaleProperty {
        /**
         * `CfnAnalysis.AxisLinearScaleProperty.StepCount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepcount
         */
        readonly stepCount?: number;
        /**
         * `CfnAnalysis.AxisLinearScaleProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislinearscale.html#cfn-quicksight-analysis-axislinearscale-stepsize
         */
        readonly stepSize?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html
     */
    interface AxisLogarithmicScaleProperty {
        /**
         * `CfnAnalysis.AxisLogarithmicScaleProperty.Base`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axislogarithmicscale.html#cfn-quicksight-analysis-axislogarithmicscale-base
         */
        readonly base?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html
     */
    interface AxisScaleProperty {
        /**
         * `CfnAnalysis.AxisScaleProperty.Linear`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-linear
         */
        readonly linear?: CfnAnalysis.AxisLinearScaleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AxisScaleProperty.Logarithmic`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisscale.html#cfn-quicksight-analysis-axisscale-logarithmic
         */
        readonly logarithmic?: CfnAnalysis.AxisLogarithmicScaleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html
     */
    interface AxisTickLabelOptionsProperty {
        /**
         * `CfnAnalysis.AxisTickLabelOptionsProperty.LabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-labeloptions
         */
        readonly labelOptions?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.AxisTickLabelOptionsProperty.RotationAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-axisticklabeloptions.html#cfn-quicksight-analysis-axisticklabeloptions-rotationangle
         */
        readonly rotationAngle?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html
     */
    interface BarChartAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.BarChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartaggregatedfieldwells.html#cfn-quicksight-analysis-barchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html
     */
    interface BarChartConfigurationProperty {
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.BarsArrangement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnAnalysis.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.BarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.Orientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-orientation
         */
        readonly orientation?: string;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnAnalysis.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnAnalysis.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.BarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.ValueAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valueaxis
         */
        readonly valueAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartconfiguration.html#cfn-quicksight-analysis-barchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html
     */
    interface BarChartFieldWellsProperty {
        /**
         * `CfnAnalysis.BarChartFieldWellsProperty.BarChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartfieldwells.html#cfn-quicksight-analysis-barchartfieldwells-barchartaggregatedfieldwells
         */
        readonly barChartAggregatedFieldWells?: CfnAnalysis.BarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html
     */
    interface BarChartSortConfigurationProperty {
        /**
         * `CfnAnalysis.BarChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartsortconfiguration.html#cfn-quicksight-analysis-barchartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html
     */
    interface BarChartVisualProperty {
        /**
         * `CfnAnalysis.BarChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.BarChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BarChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-barchartvisual.html#cfn-quicksight-analysis-barchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html
     */
    interface BinCountOptionsProperty {
        /**
         * `CfnAnalysis.BinCountOptionsProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bincountoptions.html#cfn-quicksight-analysis-bincountoptions-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html
     */
    interface BinWidthOptionsProperty {
        /**
         * `CfnAnalysis.BinWidthOptionsProperty.BinCountLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-bincountlimit
         */
        readonly binCountLimit?: number;
        /**
         * `CfnAnalysis.BinWidthOptionsProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-binwidthoptions.html#cfn-quicksight-analysis-binwidthoptions-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html
     */
    interface BodySectionConfigurationProperty {
        /**
         * `CfnAnalysis.BodySectionConfigurationProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-content
         */
        readonly content: CfnAnalysis.BodySectionContentProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BodySectionConfigurationProperty.PageBreakConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-pagebreakconfiguration
         */
        readonly pageBreakConfiguration?: CfnAnalysis.SectionPageBreakConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BodySectionConfigurationProperty.SectionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * `CfnAnalysis.BodySectionConfigurationProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectionconfiguration.html#cfn-quicksight-analysis-bodysectionconfiguration-style
         */
        readonly style?: CfnAnalysis.SectionStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html
     */
    interface BodySectionContentProperty {
        /**
         * `CfnAnalysis.BodySectionContentProperty.Layout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-bodysectioncontent.html#cfn-quicksight-analysis-bodysectioncontent-layout
         */
        readonly layout?: CfnAnalysis.SectionLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html
     */
    interface BoxPlotAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.BoxPlotAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotaggregatedfieldwells.html#cfn-quicksight-analysis-boxplotaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html
     */
    interface BoxPlotChartConfigurationProperty {
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.BoxPlotOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-boxplotoptions
         */
        readonly boxPlotOptions?: CfnAnalysis.BoxPlotOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.BoxPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnAnalysis.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.BoxPlotSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotchartconfiguration.html#cfn-quicksight-analysis-boxplotchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html
     */
    interface BoxPlotFieldWellsProperty {
        /**
         * `CfnAnalysis.BoxPlotFieldWellsProperty.BoxPlotAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotfieldwells.html#cfn-quicksight-analysis-boxplotfieldwells-boxplotaggregatedfieldwells
         */
        readonly boxPlotAggregatedFieldWells?: CfnAnalysis.BoxPlotAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html
     */
    interface BoxPlotOptionsProperty {
        /**
         * `CfnAnalysis.BoxPlotOptionsProperty.AllDataPointsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-alldatapointsvisibility
         */
        readonly allDataPointsVisibility?: string;
        /**
         * `CfnAnalysis.BoxPlotOptionsProperty.OutlierVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-outliervisibility
         */
        readonly outlierVisibility?: string;
        /**
         * `CfnAnalysis.BoxPlotOptionsProperty.StyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotoptions.html#cfn-quicksight-analysis-boxplotoptions-styleoptions
         */
        readonly styleOptions?: CfnAnalysis.BoxPlotStyleOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html
     */
    interface BoxPlotSortConfigurationProperty {
        /**
         * `CfnAnalysis.BoxPlotSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotSortConfigurationProperty.PaginationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotsortconfiguration.html#cfn-quicksight-analysis-boxplotsortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: CfnAnalysis.PaginationConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html
     */
    interface BoxPlotStyleOptionsProperty {
        /**
         * `CfnAnalysis.BoxPlotStyleOptionsProperty.FillStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotstyleoptions.html#cfn-quicksight-analysis-boxplotstyleoptions-fillstyle
         */
        readonly fillStyle?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html
     */
    interface BoxPlotVisualProperty {
        /**
         * `CfnAnalysis.BoxPlotVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.BoxPlotChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.BoxPlotVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-boxplotvisual.html#cfn-quicksight-analysis-boxplotvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html
     */
    interface CalculatedFieldProperty {
        /**
         * `CfnAnalysis.CalculatedFieldProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnAnalysis.CalculatedFieldProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-expression
         */
        readonly expression: string;
        /**
         * `CfnAnalysis.CalculatedFieldProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedfield.html#cfn-quicksight-analysis-calculatedfield-name
         */
        readonly name: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html
     */
    interface CalculatedMeasureFieldProperty {
        /**
         * `CfnAnalysis.CalculatedMeasureFieldProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-expression
         */
        readonly expression: string;
        /**
         * `CfnAnalysis.CalculatedMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-calculatedmeasurefield.html#cfn-quicksight-analysis-calculatedmeasurefield-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html
     */
    interface CascadingControlConfigurationProperty {
        /**
         * `CfnAnalysis.CascadingControlConfigurationProperty.SourceControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolconfiguration.html#cfn-quicksight-analysis-cascadingcontrolconfiguration-sourcecontrols
         */
        readonly sourceControls?: Array<CfnAnalysis.CascadingControlSourceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html
     */
    interface CascadingControlSourceProperty {
        /**
         * `CfnAnalysis.CascadingControlSourceProperty.ColumnToMatch`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-columntomatch
         */
        readonly columnToMatch?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CascadingControlSourceProperty.SourceSheetControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-cascadingcontrolsource.html#cfn-quicksight-analysis-cascadingcontrolsource-sourcesheetcontrolid
         */
        readonly sourceSheetControlId?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html
     */
    interface CategoricalDimensionFieldProperty {
        /**
         * `CfnAnalysis.CategoricalDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CategoricalDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.CategoricalDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.StringFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CategoricalDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricaldimensionfield.html#cfn-quicksight-analysis-categoricaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html
     */
    interface CategoricalMeasureFieldProperty {
        /**
         * `CfnAnalysis.CategoricalMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * `CfnAnalysis.CategoricalMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CategoricalMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.CategoricalMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoricalmeasurefield.html#cfn-quicksight-analysis-categoricalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.StringFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html
     */
    interface CategoryDrillDownFilterProperty {
        /**
         * `CfnAnalysis.CategoryDrillDownFilterProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-categoryvalues
         */
        readonly categoryValues: string[];
        /**
         * `CfnAnalysis.CategoryDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categorydrilldownfilter.html#cfn-quicksight-analysis-categorydrilldownfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html
     */
    interface CategoryFilterProperty {
        /**
         * `CfnAnalysis.CategoryFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CategoryFilterProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-configuration
         */
        readonly configuration: CfnAnalysis.CategoryFilterConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CategoryFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilter.html#cfn-quicksight-analysis-categoryfilter-filterid
         */
        readonly filterId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html
     */
    interface CategoryFilterConfigurationProperty {
        /**
         * `CfnAnalysis.CategoryFilterConfigurationProperty.CustomFilterConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterconfiguration
         */
        readonly customFilterConfiguration?: CfnAnalysis.CustomFilterConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CategoryFilterConfigurationProperty.CustomFilterListConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-customfilterlistconfiguration
         */
        readonly customFilterListConfiguration?: CfnAnalysis.CustomFilterListConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CategoryFilterConfigurationProperty.FilterListConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-categoryfilterconfiguration.html#cfn-quicksight-analysis-categoryfilterconfiguration-filterlistconfiguration
         */
        readonly filterListConfiguration?: CfnAnalysis.FilterListConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html
     */
    interface ChartAxisLabelOptionsProperty {
        /**
         * `CfnAnalysis.ChartAxisLabelOptionsProperty.AxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-axislabeloptions
         */
        readonly axisLabelOptions?: Array<CfnAnalysis.AxisLabelOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ChartAxisLabelOptionsProperty.SortIconVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-sorticonvisibility
         */
        readonly sortIconVisibility?: string;
        /**
         * `CfnAnalysis.ChartAxisLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-chartaxislabeloptions.html#cfn-quicksight-analysis-chartaxislabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html
     */
    interface ClusterMarkerProperty {
        /**
         * `CfnAnalysis.ClusterMarkerProperty.SimpleClusterMarker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarker.html#cfn-quicksight-analysis-clustermarker-simpleclustermarker
         */
        readonly simpleClusterMarker?: CfnAnalysis.SimpleClusterMarkerProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html
     */
    interface ClusterMarkerConfigurationProperty {
        /**
         * `CfnAnalysis.ClusterMarkerConfigurationProperty.ClusterMarker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-clustermarkerconfiguration.html#cfn-quicksight-analysis-clustermarkerconfiguration-clustermarker
         */
        readonly clusterMarker?: CfnAnalysis.ClusterMarkerProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html
     */
    interface ColorScaleProperty {
        /**
         * `CfnAnalysis.ColorScaleProperty.ColorFillType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colorfilltype
         */
        readonly colorFillType: string;
        /**
         * `CfnAnalysis.ColorScaleProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-colors
         */
        readonly colors: Array<CfnAnalysis.DataColorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColorScaleProperty.NullValueColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorscale.html#cfn-quicksight-analysis-colorscale-nullvaluecolor
         */
        readonly nullValueColor?: CfnAnalysis.DataColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html
     */
    interface ColorsConfigurationProperty {
        /**
         * `CfnAnalysis.ColorsConfigurationProperty.CustomColors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-colorsconfiguration.html#cfn-quicksight-analysis-colorsconfiguration-customcolors
         */
        readonly customColors?: Array<CfnAnalysis.CustomColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html
     */
    interface ColumnConfigurationProperty {
        /**
         * `CfnAnalysis.ColumnConfigurationProperty.ColorsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-colorsconfiguration
         */
        readonly colorsConfiguration?: CfnAnalysis.ColorsConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColumnConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColumnConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.FormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColumnConfigurationProperty.Role`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnconfiguration.html#cfn-quicksight-analysis-columnconfiguration-role
         */
        readonly role?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html
     */
    interface ColumnHierarchyProperty {
        /**
         * `CfnAnalysis.ColumnHierarchyProperty.DateTimeHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-datetimehierarchy
         */
        readonly dateTimeHierarchy?: CfnAnalysis.DateTimeHierarchyProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColumnHierarchyProperty.ExplicitHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-explicithierarchy
         */
        readonly explicitHierarchy?: CfnAnalysis.ExplicitHierarchyProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColumnHierarchyProperty.PredefinedHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnhierarchy.html#cfn-quicksight-analysis-columnhierarchy-predefinedhierarchy
         */
        readonly predefinedHierarchy?: CfnAnalysis.PredefinedHierarchyProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html
     */
    interface ColumnIdentifierProperty {
        /**
         * `CfnAnalysis.ColumnIdentifierProperty.ColumnName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-columnname
         */
        readonly columnName: string;
        /**
         * `CfnAnalysis.ColumnIdentifierProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnidentifier.html#cfn-quicksight-analysis-columnidentifier-datasetidentifier
         */
        readonly dataSetIdentifier: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html
     */
    interface ColumnSortProperty {
        /**
         * `CfnAnalysis.ColumnSortProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-aggregationfunction
         */
        readonly aggregationFunction?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColumnSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-direction
         */
        readonly direction: string;
        /**
         * `CfnAnalysis.ColumnSortProperty.SortBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columnsort.html#cfn-quicksight-analysis-columnsort-sortby
         */
        readonly sortBy: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html
     */
    interface ColumnTooltipItemProperty {
        /**
         * `CfnAnalysis.ColumnTooltipItemProperty.Aggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-aggregation
         */
        readonly aggregation?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColumnTooltipItemProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ColumnTooltipItemProperty.Label`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-label
         */
        readonly label?: string;
        /**
         * `CfnAnalysis.ColumnTooltipItemProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-columntooltipitem.html#cfn-quicksight-analysis-columntooltipitem-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html
     */
    interface ComboChartAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.ComboChartAggregatedFieldWellsProperty.BarValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-barvalues
         */
        readonly barValues?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartAggregatedFieldWellsProperty.LineValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartaggregatedfieldwells.html#cfn-quicksight-analysis-combochartaggregatedfieldwells-linevalues
         */
        readonly lineValues?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html
     */
    interface ComboChartConfigurationProperty {
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.BarDataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-bardatalabels
         */
        readonly barDataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.BarsArrangement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.ComboChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.LineDataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-linedatalabels
         */
        readonly lineDataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnAnalysis.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.SecondaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.SecondaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.ComboChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartconfiguration.html#cfn-quicksight-analysis-combochartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html
     */
    interface ComboChartFieldWellsProperty {
        /**
         * `CfnAnalysis.ComboChartFieldWellsProperty.ComboChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartfieldwells.html#cfn-quicksight-analysis-combochartfieldwells-combochartaggregatedfieldwells
         */
        readonly comboChartAggregatedFieldWells?: CfnAnalysis.ComboChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html
     */
    interface ComboChartSortConfigurationProperty {
        /**
         * `CfnAnalysis.ComboChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartsortconfiguration.html#cfn-quicksight-analysis-combochartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html
     */
    interface ComboChartVisualProperty {
        /**
         * `CfnAnalysis.ComboChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.ComboChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComboChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-combochartvisual.html#cfn-quicksight-analysis-combochartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html
     */
    interface ComparisonConfigurationProperty {
        /**
         * `CfnAnalysis.ComparisonConfigurationProperty.ComparisonFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonformat
         */
        readonly comparisonFormat?: CfnAnalysis.ComparisonFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComparisonConfigurationProperty.ComparisonMethod`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonconfiguration.html#cfn-quicksight-analysis-comparisonconfiguration-comparisonmethod
         */
        readonly comparisonMethod?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html
     */
    interface ComparisonFormatConfigurationProperty {
        /**
         * `CfnAnalysis.ComparisonFormatConfigurationProperty.NumberDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: CfnAnalysis.NumberDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComparisonFormatConfigurationProperty.PercentageDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-comparisonformatconfiguration.html#cfn-quicksight-analysis-comparisonformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: CfnAnalysis.PercentageDisplayFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html
     */
    interface ComputationProperty {
        /**
         * `CfnAnalysis.ComputationProperty.Forecast`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-forecast
         */
        readonly forecast?: CfnAnalysis.ForecastComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.GrowthRate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-growthrate
         */
        readonly growthRate?: CfnAnalysis.GrowthRateComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.MaximumMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-maximumminimum
         */
        readonly maximumMinimum?: CfnAnalysis.MaximumMinimumComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.MetricComparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-metriccomparison
         */
        readonly metricComparison?: CfnAnalysis.MetricComparisonComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.PeriodOverPeriod`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodoverperiod
         */
        readonly periodOverPeriod?: CfnAnalysis.PeriodOverPeriodComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.PeriodToDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-periodtodate
         */
        readonly periodToDate?: CfnAnalysis.PeriodToDateComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.TopBottomMovers`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottommovers
         */
        readonly topBottomMovers?: CfnAnalysis.TopBottomMoversComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.TopBottomRanked`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-topbottomranked
         */
        readonly topBottomRanked?: CfnAnalysis.TopBottomRankedComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.TotalAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-totalaggregation
         */
        readonly totalAggregation?: CfnAnalysis.TotalAggregationComputationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ComputationProperty.UniqueValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-computation.html#cfn-quicksight-analysis-computation-uniquevalues
         */
        readonly uniqueValues?: CfnAnalysis.UniqueValuesComputationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html
     */
    interface ConditionalFormattingColorProperty {
        /**
         * `CfnAnalysis.ConditionalFormattingColorProperty.Gradient`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-gradient
         */
        readonly gradient?: CfnAnalysis.ConditionalFormattingGradientColorProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ConditionalFormattingColorProperty.Solid`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcolor.html#cfn-quicksight-analysis-conditionalformattingcolor-solid
         */
        readonly solid?: CfnAnalysis.ConditionalFormattingSolidColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html
     */
    interface ConditionalFormattingCustomIconConditionProperty {
        /**
         * `CfnAnalysis.ConditionalFormattingCustomIconConditionProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-color
         */
        readonly color?: string;
        /**
         * `CfnAnalysis.ConditionalFormattingCustomIconConditionProperty.DisplayConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-displayconfiguration
         */
        readonly displayConfiguration?: CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ConditionalFormattingCustomIconConditionProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-expression
         */
        readonly expression: string;
        /**
         * `CfnAnalysis.ConditionalFormattingCustomIconConditionProperty.IconOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconcondition.html#cfn-quicksight-analysis-conditionalformattingcustomiconcondition-iconoptions
         */
        readonly iconOptions: CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html
     */
    interface ConditionalFormattingCustomIconOptionsProperty {
        /**
         * `CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-icon
         */
        readonly icon?: string;
        /**
         * `CfnAnalysis.ConditionalFormattingCustomIconOptionsProperty.UnicodeIcon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingcustomiconoptions.html#cfn-quicksight-analysis-conditionalformattingcustomiconoptions-unicodeicon
         */
        readonly unicodeIcon?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html
     */
    interface ConditionalFormattingGradientColorProperty {
        /**
         * `CfnAnalysis.ConditionalFormattingGradientColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-color
         */
        readonly color: CfnAnalysis.GradientColorProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ConditionalFormattingGradientColorProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattinggradientcolor.html#cfn-quicksight-analysis-conditionalformattinggradientcolor-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html
     */
    interface ConditionalFormattingIconProperty {
        /**
         * `CfnAnalysis.ConditionalFormattingIconProperty.CustomCondition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-customcondition
         */
        readonly customCondition?: CfnAnalysis.ConditionalFormattingCustomIconConditionProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ConditionalFormattingIconProperty.IconSet`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicon.html#cfn-quicksight-analysis-conditionalformattingicon-iconset
         */
        readonly iconSet?: CfnAnalysis.ConditionalFormattingIconSetProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html
     */
    interface ConditionalFormattingIconDisplayConfigurationProperty {
        /**
         * `CfnAnalysis.ConditionalFormattingIconDisplayConfigurationProperty.IconDisplayOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-analysis-conditionalformattingicondisplayconfiguration-icondisplayoption
         */
        readonly iconDisplayOption?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html
     */
    interface ConditionalFormattingIconSetProperty {
        /**
         * `CfnAnalysis.ConditionalFormattingIconSetProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-expression
         */
        readonly expression: string;
        /**
         * `CfnAnalysis.ConditionalFormattingIconSetProperty.IconSetType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingiconset.html#cfn-quicksight-analysis-conditionalformattingiconset-iconsettype
         */
        readonly iconSetType?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html
     */
    interface ConditionalFormattingSolidColorProperty {
        /**
         * `CfnAnalysis.ConditionalFormattingSolidColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-color
         */
        readonly color?: string;
        /**
         * `CfnAnalysis.ConditionalFormattingSolidColorProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-conditionalformattingsolidcolor.html#cfn-quicksight-analysis-conditionalformattingsolidcolor-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html
     */
    interface ContributionAnalysisDefaultProperty {
        /**
         * `CfnAnalysis.ContributionAnalysisDefaultProperty.ContributorDimensions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-contributordimensions
         */
        readonly contributorDimensions: Array<CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ContributionAnalysisDefaultProperty.MeasureFieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-contributionanalysisdefault.html#cfn-quicksight-analysis-contributionanalysisdefault-measurefieldid
         */
        readonly measureFieldId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html
     */
    interface CurrencyDisplayFormatConfigurationProperty {
        /**
         * `CfnAnalysis.CurrencyDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnAnalysis.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CurrencyDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnAnalysis.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CurrencyDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnAnalysis.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CurrencyDisplayFormatConfigurationProperty.NumberScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * `CfnAnalysis.CurrencyDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnAnalysis.CurrencyDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnAnalysis.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CurrencyDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
        /**
         * `CfnAnalysis.CurrencyDisplayFormatConfigurationProperty.Symbol`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-currencydisplayformatconfiguration.html#cfn-quicksight-analysis-currencydisplayformatconfiguration-symbol
         */
        readonly symbol?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html
     */
    interface CustomActionFilterOperationProperty {
        /**
         * `CfnAnalysis.CustomActionFilterOperationProperty.SelectedFieldsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-selectedfieldsconfiguration
         */
        readonly selectedFieldsConfiguration: CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CustomActionFilterOperationProperty.TargetVisualsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionfilteroperation.html#cfn-quicksight-analysis-customactionfilteroperation-targetvisualsconfiguration
         */
        readonly targetVisualsConfiguration: CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html
     */
    interface CustomActionNavigationOperationProperty {
        /**
         * `CfnAnalysis.CustomActionNavigationOperationProperty.LocalNavigationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionnavigationoperation.html#cfn-quicksight-analysis-customactionnavigationoperation-localnavigationconfiguration
         */
        readonly localNavigationConfiguration?: CfnAnalysis.LocalNavigationConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html
     */
    interface CustomActionSetParametersOperationProperty {
        /**
         * `CfnAnalysis.CustomActionSetParametersOperationProperty.ParameterValueConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionsetparametersoperation.html#cfn-quicksight-analysis-customactionsetparametersoperation-parametervalueconfigurations
         */
        readonly parameterValueConfigurations: Array<CfnAnalysis.SetParameterValueConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html
     */
    interface CustomActionURLOperationProperty {
        /**
         * `CfnAnalysis.CustomActionURLOperationProperty.URLTarget`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltarget
         */
        readonly urlTarget: string;
        /**
         * `CfnAnalysis.CustomActionURLOperationProperty.URLTemplate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customactionurloperation.html#cfn-quicksight-analysis-customactionurloperation-urltemplate
         */
        readonly urlTemplate: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html
     */
    interface CustomColorProperty {
        /**
         * `CfnAnalysis.CustomColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-color
         */
        readonly color: string;
        /**
         * `CfnAnalysis.CustomColorProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnAnalysis.CustomColorProperty.SpecialValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcolor.html#cfn-quicksight-analysis-customcolor-specialvalue
         */
        readonly specialValue?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html
     */
    interface CustomContentConfigurationProperty {
        /**
         * `CfnAnalysis.CustomContentConfigurationProperty.ContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenttype
         */
        readonly contentType?: string;
        /**
         * `CfnAnalysis.CustomContentConfigurationProperty.ContentUrl`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-contenturl
         */
        readonly contentUrl?: string;
        /**
         * `CfnAnalysis.CustomContentConfigurationProperty.ImageScaling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentconfiguration.html#cfn-quicksight-analysis-customcontentconfiguration-imagescaling
         */
        readonly imageScaling?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html
     */
    interface CustomContentVisualProperty {
        /**
         * `CfnAnalysis.CustomContentVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.CustomContentVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.CustomContentConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CustomContentVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnAnalysis.CustomContentVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CustomContentVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CustomContentVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customcontentvisual.html#cfn-quicksight-analysis-customcontentvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html
     */
    interface CustomFilterConfigurationProperty {
        /**
         * `CfnAnalysis.CustomFilterConfigurationProperty.CategoryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-categoryvalue
         */
        readonly categoryValue?: string;
        /**
         * `CfnAnalysis.CustomFilterConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnAnalysis.CustomFilterConfigurationProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnAnalysis.CustomFilterConfigurationProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnAnalysis.CustomFilterConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterconfiguration.html#cfn-quicksight-analysis-customfilterconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html
     */
    interface CustomFilterListConfigurationProperty {
        /**
         * `CfnAnalysis.CustomFilterListConfigurationProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: string[];
        /**
         * `CfnAnalysis.CustomFilterListConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnAnalysis.CustomFilterListConfigurationProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnAnalysis.CustomFilterListConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customfilterlistconfiguration.html#cfn-quicksight-analysis-customfilterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html
     */
    interface CustomNarrativeOptionsProperty {
        /**
         * `CfnAnalysis.CustomNarrativeOptionsProperty.Narrative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customnarrativeoptions.html#cfn-quicksight-analysis-customnarrativeoptions-narrative
         */
        readonly narrative: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html
     */
    interface CustomParameterValuesProperty {
        /**
         * `CfnAnalysis.CustomParameterValuesProperty.DateTimeValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-datetimevalues
         */
        readonly dateTimeValues?: string[];
        /**
         * `CfnAnalysis.CustomParameterValuesProperty.DecimalValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-decimalvalues
         */
        readonly decimalValues?: number[] | cdk.IResolvable;
        /**
         * `CfnAnalysis.CustomParameterValuesProperty.IntegerValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-integervalues
         */
        readonly integerValues?: number[] | cdk.IResolvable;
        /**
         * `CfnAnalysis.CustomParameterValuesProperty.StringValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customparametervalues.html#cfn-quicksight-analysis-customparametervalues-stringvalues
         */
        readonly stringValues?: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html
     */
    interface CustomValuesConfigurationProperty {
        /**
         * `CfnAnalysis.CustomValuesConfigurationProperty.CustomValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-customvalues
         */
        readonly customValues: CfnAnalysis.CustomParameterValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.CustomValuesConfigurationProperty.IncludeNullValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-customvaluesconfiguration.html#cfn-quicksight-analysis-customvaluesconfiguration-includenullvalue
         */
        readonly includeNullValue?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html
     */
    interface DataBarsOptionsProperty {
        /**
         * `CfnAnalysis.DataBarsOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.DataBarsOptionsProperty.NegativeColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-negativecolor
         */
        readonly negativeColor?: string;
        /**
         * `CfnAnalysis.DataBarsOptionsProperty.PositiveColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-databarsoptions.html#cfn-quicksight-analysis-databarsoptions-positivecolor
         */
        readonly positiveColor?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html
     */
    interface DataColorProperty {
        /**
         * `CfnAnalysis.DataColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-color
         */
        readonly color?: string;
        /**
         * `CfnAnalysis.DataColorProperty.DataValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datacolor.html#cfn-quicksight-analysis-datacolor-datavalue
         */
        readonly dataValue?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html
     */
    interface DataFieldSeriesItemProperty {
        /**
         * `CfnAnalysis.DataFieldSeriesItemProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * `CfnAnalysis.DataFieldSeriesItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.DataFieldSeriesItemProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnAnalysis.DataFieldSeriesItemProperty.Settings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datafieldseriesitem.html#cfn-quicksight-analysis-datafieldseriesitem-settings
         */
        readonly settings?: CfnAnalysis.LineChartSeriesSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html
     */
    interface DataLabelOptionsProperty {
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.CategoryLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.DataLabelTypes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-datalabeltypes
         */
        readonly dataLabelTypes?: Array<CfnAnalysis.DataLabelTypeProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.LabelColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.LabelContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelcontent
         */
        readonly labelContent?: string;
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.LabelFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.MeasureLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.Overlap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-overlap
         */
        readonly overlap?: string;
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-position
         */
        readonly position?: string;
        /**
         * `CfnAnalysis.DataLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeloptions.html#cfn-quicksight-analysis-datalabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html
     */
    interface DataLabelTypeProperty {
        /**
         * `CfnAnalysis.DataLabelTypeProperty.DataPathLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-datapathlabeltype
         */
        readonly dataPathLabelType?: CfnAnalysis.DataPathLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DataLabelTypeProperty.FieldLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-fieldlabeltype
         */
        readonly fieldLabelType?: CfnAnalysis.FieldLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DataLabelTypeProperty.MaximumLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-maximumlabeltype
         */
        readonly maximumLabelType?: CfnAnalysis.MaximumLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DataLabelTypeProperty.MinimumLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-minimumlabeltype
         */
        readonly minimumLabelType?: CfnAnalysis.MinimumLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DataLabelTypeProperty.RangeEndsLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datalabeltype.html#cfn-quicksight-analysis-datalabeltype-rangeendslabeltype
         */
        readonly rangeEndsLabelType?: CfnAnalysis.RangeEndsLabelTypeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html
     */
    interface DataPathColorProperty {
        /**
         * `CfnAnalysis.DataPathColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-color
         */
        readonly color: string;
        /**
         * `CfnAnalysis.DataPathColorProperty.Element`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-element
         */
        readonly element: CfnAnalysis.DataPathValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DataPathColorProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathcolor.html#cfn-quicksight-analysis-datapathcolor-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html
     */
    interface DataPathLabelTypeProperty {
        /**
         * `CfnAnalysis.DataPathLabelTypeProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * `CfnAnalysis.DataPathLabelTypeProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnAnalysis.DataPathLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathlabeltype.html#cfn-quicksight-analysis-datapathlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html
     */
    interface DataPathSortProperty {
        /**
         * `CfnAnalysis.DataPathSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-direction
         */
        readonly direction: string;
        /**
         * `CfnAnalysis.DataPathSortProperty.SortPaths`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathsort.html#cfn-quicksight-analysis-datapathsort-sortpaths
         */
        readonly sortPaths: Array<CfnAnalysis.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html
     */
    interface DataPathValueProperty {
        /**
         * `CfnAnalysis.DataPathValueProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.DataPathValueProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datapathvalue.html#cfn-quicksight-analysis-datapathvalue-fieldvalue
         */
        readonly fieldValue: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html
     */
    interface DataSetIdentifierDeclarationProperty {
        /**
         * `CfnAnalysis.DataSetIdentifierDeclarationProperty.DataSetArn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * `CfnAnalysis.DataSetIdentifierDeclarationProperty.Identifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetidentifierdeclaration.html#cfn-quicksight-analysis-datasetidentifierdeclaration-identifier
         */
        readonly identifier: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     * Dataset reference.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html
     */
    interface DataSetReferenceProperty {
        /**
         * Dataset Amazon Resource Name (ARN).
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * Dataset placeholder.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datasetreference.html#cfn-quicksight-analysis-datasetreference-datasetplaceholder
         */
        readonly dataSetPlaceholder: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html
     */
    interface DateAxisOptionsProperty {
        /**
         * `CfnAnalysis.DateAxisOptionsProperty.MissingDateVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dateaxisoptions.html#cfn-quicksight-analysis-dateaxisoptions-missingdatevisibility
         */
        readonly missingDateVisibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html
     */
    interface DateDimensionFieldProperty {
        /**
         * `CfnAnalysis.DateDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateDimensionFieldProperty.DateGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-dategranularity
         */
        readonly dateGranularity?: string;
        /**
         * `CfnAnalysis.DateDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.DateDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datedimensionfield.html#cfn-quicksight-analysis-datedimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html
     */
    interface DateMeasureFieldProperty {
        /**
         * `CfnAnalysis.DateMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * `CfnAnalysis.DateMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.DateMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datemeasurefield.html#cfn-quicksight-analysis-datemeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.DateTimeFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html
     */
    interface DateTimeDefaultValuesProperty {
        /**
         * `CfnAnalysis.DateTimeDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnAnalysis.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateTimeDefaultValuesProperty.RollingDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-rollingdate
         */
        readonly rollingDate?: CfnAnalysis.RollingDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateTimeDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimedefaultvalues.html#cfn-quicksight-analysis-datetimedefaultvalues-staticvalues
         */
        readonly staticValues?: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html
     */
    interface DateTimeFormatConfigurationProperty {
        /**
         * `CfnAnalysis.DateTimeFormatConfigurationProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnAnalysis.DateTimeFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnAnalysis.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateTimeFormatConfigurationProperty.NumericFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeformatconfiguration.html#cfn-quicksight-analysis-datetimeformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: CfnAnalysis.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html
     */
    interface DateTimeHierarchyProperty {
        /**
         * `CfnAnalysis.DateTimeHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnAnalysis.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateTimeHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimehierarchy.html#cfn-quicksight-analysis-datetimehierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     * A date-time parameter.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html
     */
    interface DateTimeParameterProperty {
        /**
         * A display name for the date-time parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-name
         */
        readonly name: string;
        /**
         * The values for the date-time parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameter.html#cfn-quicksight-analysis-datetimeparameter-values
         */
        readonly values: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html
     */
    interface DateTimeParameterDeclarationProperty {
        /**
         * `CfnAnalysis.DateTimeParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnAnalysis.DateTimeDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateTimeParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnAnalysis.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.DateTimeParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnAnalysis.DateTimeParameterDeclarationProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * `CfnAnalysis.DateTimeParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimeparameterdeclaration.html#cfn-quicksight-analysis-datetimeparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html
     */
    interface DateTimePickerControlDisplayOptionsProperty {
        /**
         * `CfnAnalysis.DateTimePickerControlDisplayOptionsProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnAnalysis.DateTimePickerControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimepickercontroldisplayoptions.html#cfn-quicksight-analysis-datetimepickercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html
     */
    interface DateTimeValueWhenUnsetConfigurationProperty {
        /**
         * `CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * `CfnAnalysis.DateTimeValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-analysis-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html
     */
    interface DecimalDefaultValuesProperty {
        /**
         * `CfnAnalysis.DecimalDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnAnalysis.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DecimalDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimaldefaultvalues.html#cfn-quicksight-analysis-decimaldefaultvalues-staticvalues
         */
        readonly staticValues?: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     * A decimal parameter.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html
     */
    interface DecimalParameterProperty {
        /**
         * A display name for the decimal parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-name
         */
        readonly name: string;
        /**
         * The values for the decimal parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameter.html#cfn-quicksight-analysis-decimalparameter-values
         */
        readonly values: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html
     */
    interface DecimalParameterDeclarationProperty {
        /**
         * `CfnAnalysis.DecimalParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnAnalysis.DecimalDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DecimalParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnAnalysis.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.DecimalParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnAnalysis.DecimalParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnAnalysis.DecimalParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalparameterdeclaration.html#cfn-quicksight-analysis-decimalparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html
     */
    interface DecimalPlacesConfigurationProperty {
        /**
         * `CfnAnalysis.DecimalPlacesConfigurationProperty.DecimalPlaces`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalplacesconfiguration.html#cfn-quicksight-analysis-decimalplacesconfiguration-decimalplaces
         */
        readonly decimalPlaces: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html
     */
    interface DecimalValueWhenUnsetConfigurationProperty {
        /**
         * `CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * `CfnAnalysis.DecimalValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html
     */
    interface DefaultFreeFormLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultfreeformlayoutconfiguration.html#cfn-quicksight-analysis-defaultfreeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html
     */
    interface DefaultGridLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.DefaultGridLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultgridlayoutconfiguration.html#cfn-quicksight-analysis-defaultgridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnAnalysis.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html
     */
    interface DefaultInteractiveLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty.FreeForm`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-freeform
         */
        readonly freeForm?: CfnAnalysis.DefaultFreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty.Grid`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultinteractivelayoutconfiguration.html#cfn-quicksight-analysis-defaultinteractivelayoutconfiguration-grid
         */
        readonly grid?: CfnAnalysis.DefaultGridLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html
     */
    interface DefaultNewSheetConfigurationProperty {
        /**
         * `CfnAnalysis.DefaultNewSheetConfigurationProperty.InteractiveLayoutConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-interactivelayoutconfiguration
         */
        readonly interactiveLayoutConfiguration?: CfnAnalysis.DefaultInteractiveLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DefaultNewSheetConfigurationProperty.PaginatedLayoutConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-paginatedlayoutconfiguration
         */
        readonly paginatedLayoutConfiguration?: CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DefaultNewSheetConfigurationProperty.SheetContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultnewsheetconfiguration.html#cfn-quicksight-analysis-defaultnewsheetconfiguration-sheetcontenttype
         */
        readonly sheetContentType?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html
     */
    interface DefaultPaginatedLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.DefaultPaginatedLayoutConfigurationProperty.SectionBased`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-analysis-defaultpaginatedlayoutconfiguration-sectionbased
         */
        readonly sectionBased?: CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html
     */
    interface DefaultSectionBasedLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.DefaultSectionBasedLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-defaultsectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html
     */
    interface DestinationParameterValueConfigurationProperty {
        /**
         * `CfnAnalysis.DestinationParameterValueConfigurationProperty.CustomValuesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-customvaluesconfiguration
         */
        readonly customValuesConfiguration?: CfnAnalysis.CustomValuesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DestinationParameterValueConfigurationProperty.SelectAllValueOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-selectallvalueoptions
         */
        readonly selectAllValueOptions?: string;
        /**
         * `CfnAnalysis.DestinationParameterValueConfigurationProperty.SourceField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourcefield
         */
        readonly sourceField?: string;
        /**
         * `CfnAnalysis.DestinationParameterValueConfigurationProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-destinationparametervalueconfiguration.html#cfn-quicksight-analysis-destinationparametervalueconfiguration-sourceparametername
         */
        readonly sourceParameterName?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html
     */
    interface DimensionFieldProperty {
        /**
         * `CfnAnalysis.DimensionFieldProperty.CategoricalDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-categoricaldimensionfield
         */
        readonly categoricalDimensionField?: CfnAnalysis.CategoricalDimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DimensionFieldProperty.DateDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-datedimensionfield
         */
        readonly dateDimensionField?: CfnAnalysis.DateDimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DimensionFieldProperty.NumericalDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dimensionfield.html#cfn-quicksight-analysis-dimensionfield-numericaldimensionfield
         */
        readonly numericalDimensionField?: CfnAnalysis.NumericalDimensionFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html
     */
    interface DonutCenterOptionsProperty {
        /**
         * `CfnAnalysis.DonutCenterOptionsProperty.LabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutcenteroptions.html#cfn-quicksight-analysis-donutcenteroptions-labelvisibility
         */
        readonly labelVisibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html
     */
    interface DonutOptionsProperty {
        /**
         * `CfnAnalysis.DonutOptionsProperty.ArcOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-arcoptions
         */
        readonly arcOptions?: CfnAnalysis.ArcOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DonutOptionsProperty.DonutCenterOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-donutoptions.html#cfn-quicksight-analysis-donutoptions-donutcenteroptions
         */
        readonly donutCenterOptions?: CfnAnalysis.DonutCenterOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html
     */
    interface DrillDownFilterProperty {
        /**
         * `CfnAnalysis.DrillDownFilterProperty.CategoryFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-categoryfilter
         */
        readonly categoryFilter?: CfnAnalysis.CategoryDrillDownFilterProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DrillDownFilterProperty.NumericEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-numericequalityfilter
         */
        readonly numericEqualityFilter?: CfnAnalysis.NumericEqualityDrillDownFilterProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DrillDownFilterProperty.TimeRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-drilldownfilter.html#cfn-quicksight-analysis-drilldownfilter-timerangefilter
         */
        readonly timeRangeFilter?: CfnAnalysis.TimeRangeDrillDownFilterProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html
     */
    interface DropDownControlDisplayOptionsProperty {
        /**
         * `CfnAnalysis.DropDownControlDisplayOptionsProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: CfnAnalysis.ListControlSelectAllOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DropDownControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dropdowncontroldisplayoptions.html#cfn-quicksight-analysis-dropdowncontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html
     */
    interface DynamicDefaultValueProperty {
        /**
         * `CfnAnalysis.DynamicDefaultValueProperty.DefaultValueColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-defaultvaluecolumn
         */
        readonly defaultValueColumn: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DynamicDefaultValueProperty.GroupNameColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-groupnamecolumn
         */
        readonly groupNameColumn?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.DynamicDefaultValueProperty.UserNameColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-dynamicdefaultvalue.html#cfn-quicksight-analysis-dynamicdefaultvalue-usernamecolumn
         */
        readonly userNameColumn?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html
     */
    interface EmptyVisualProperty {
        /**
         * `CfnAnalysis.EmptyVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.EmptyVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnAnalysis.EmptyVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-emptyvisual.html#cfn-quicksight-analysis-emptyvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html
     */
    interface EntityProperty {
        /**
         * `CfnAnalysis.EntityProperty.Path`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-entity.html#cfn-quicksight-analysis-entity-path
         */
        readonly path?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html
     */
    interface ExcludePeriodConfigurationProperty {
        /**
         * `CfnAnalysis.ExcludePeriodConfigurationProperty.Amount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-amount
         */
        readonly amount: number;
        /**
         * `CfnAnalysis.ExcludePeriodConfigurationProperty.Granularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-granularity
         */
        readonly granularity: string;
        /**
         * `CfnAnalysis.ExcludePeriodConfigurationProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-excludeperiodconfiguration.html#cfn-quicksight-analysis-excludeperiodconfiguration-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html
     */
    interface ExplicitHierarchyProperty {
        /**
         * `CfnAnalysis.ExplicitHierarchyProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-columns
         */
        readonly columns: Array<CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ExplicitHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnAnalysis.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ExplicitHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-explicithierarchy.html#cfn-quicksight-analysis-explicithierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html
     */
    interface FieldBasedTooltipProperty {
        /**
         * `CfnAnalysis.FieldBasedTooltipProperty.AggregationVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-aggregationvisibility
         */
        readonly aggregationVisibility?: string;
        /**
         * `CfnAnalysis.FieldBasedTooltipProperty.TooltipFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltipfields
         */
        readonly tooltipFields?: Array<CfnAnalysis.TooltipItemProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FieldBasedTooltipProperty.TooltipTitleType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldbasedtooltip.html#cfn-quicksight-analysis-fieldbasedtooltip-tooltiptitletype
         */
        readonly tooltipTitleType?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html
     */
    interface FieldLabelTypeProperty {
        /**
         * `CfnAnalysis.FieldLabelTypeProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * `CfnAnalysis.FieldLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldlabeltype.html#cfn-quicksight-analysis-fieldlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html
     */
    interface FieldSeriesItemProperty {
        /**
         * `CfnAnalysis.FieldSeriesItemProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * `CfnAnalysis.FieldSeriesItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.FieldSeriesItemProperty.Settings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldseriesitem.html#cfn-quicksight-analysis-fieldseriesitem-settings
         */
        readonly settings?: CfnAnalysis.LineChartSeriesSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html
     */
    interface FieldSortProperty {
        /**
         * `CfnAnalysis.FieldSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-direction
         */
        readonly direction: string;
        /**
         * `CfnAnalysis.FieldSortProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsort.html#cfn-quicksight-analysis-fieldsort-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html
     */
    interface FieldSortOptionsProperty {
        /**
         * `CfnAnalysis.FieldSortOptionsProperty.ColumnSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-columnsort
         */
        readonly columnSort?: CfnAnalysis.ColumnSortProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FieldSortOptionsProperty.FieldSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldsortoptions.html#cfn-quicksight-analysis-fieldsortoptions-fieldsort
         */
        readonly fieldSort?: CfnAnalysis.FieldSortProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html
     */
    interface FieldTooltipItemProperty {
        /**
         * `CfnAnalysis.FieldTooltipItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.FieldTooltipItemProperty.Label`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-label
         */
        readonly label?: string;
        /**
         * `CfnAnalysis.FieldTooltipItemProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fieldtooltipitem.html#cfn-quicksight-analysis-fieldtooltipitem-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html
     */
    interface FilledMapAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.FilledMapAggregatedFieldWellsProperty.Geospatial`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapaggregatedfieldwells.html#cfn-quicksight-analysis-filledmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html
     */
    interface FilledMapConditionalFormattingProperty {
        /**
         * `CfnAnalysis.FilledMapConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformatting.html#cfn-quicksight-analysis-filledmapconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions: Array<CfnAnalysis.FilledMapConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html
     */
    interface FilledMapConditionalFormattingOptionProperty {
        /**
         * `CfnAnalysis.FilledMapConditionalFormattingOptionProperty.Shape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconditionalformattingoption.html#cfn-quicksight-analysis-filledmapconditionalformattingoption-shape
         */
        readonly shape: CfnAnalysis.FilledMapShapeConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html
     */
    interface FilledMapConfigurationProperty {
        /**
         * `CfnAnalysis.FilledMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.FilledMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapConfigurationProperty.MapStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnAnalysis.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.FilledMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapConfigurationProperty.WindowOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapconfiguration.html#cfn-quicksight-analysis-filledmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnAnalysis.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html
     */
    interface FilledMapFieldWellsProperty {
        /**
         * `CfnAnalysis.FilledMapFieldWellsProperty.FilledMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapfieldwells.html#cfn-quicksight-analysis-filledmapfieldwells-filledmapaggregatedfieldwells
         */
        readonly filledMapAggregatedFieldWells?: CfnAnalysis.FilledMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html
     */
    interface FilledMapShapeConditionalFormattingProperty {
        /**
         * `CfnAnalysis.FilledMapShapeConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.FilledMapShapeConditionalFormattingProperty.Format`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapshapeconditionalformatting.html#cfn-quicksight-analysis-filledmapshapeconditionalformatting-format
         */
        readonly format?: CfnAnalysis.ShapeConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html
     */
    interface FilledMapSortConfigurationProperty {
        /**
         * `CfnAnalysis.FilledMapSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapsortconfiguration.html#cfn-quicksight-analysis-filledmapsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html
     */
    interface FilledMapVisualProperty {
        /**
         * `CfnAnalysis.FilledMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.FilledMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnAnalysis.FilledMapConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilledMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filledmapvisual.html#cfn-quicksight-analysis-filledmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html
     */
    interface FilterProperty {
        /**
         * `CfnAnalysis.FilterProperty.CategoryFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-categoryfilter
         */
        readonly categoryFilter?: CfnAnalysis.CategoryFilterProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterProperty.NumericEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericequalityfilter
         */
        readonly numericEqualityFilter?: CfnAnalysis.NumericEqualityFilterProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterProperty.NumericRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-numericrangefilter
         */
        readonly numericRangeFilter?: CfnAnalysis.NumericRangeFilterProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterProperty.RelativeDatesFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-relativedatesfilter
         */
        readonly relativeDatesFilter?: CfnAnalysis.RelativeDatesFilterProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterProperty.TimeEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timeequalityfilter
         */
        readonly timeEqualityFilter?: CfnAnalysis.TimeEqualityFilterProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterProperty.TimeRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-timerangefilter
         */
        readonly timeRangeFilter?: CfnAnalysis.TimeRangeFilterProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterProperty.TopBottomFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filter.html#cfn-quicksight-analysis-filter-topbottomfilter
         */
        readonly topBottomFilter?: CfnAnalysis.TopBottomFilterProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html
     */
    interface FilterControlProperty {
        /**
         * `CfnAnalysis.FilterControlProperty.DateTimePicker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnAnalysis.FilterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterControlProperty.Dropdown`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-dropdown
         */
        readonly dropdown?: CfnAnalysis.FilterDropDownControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterControlProperty.List`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-list
         */
        readonly list?: CfnAnalysis.FilterListControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterControlProperty.RelativeDateTime`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-relativedatetime
         */
        readonly relativeDateTime?: CfnAnalysis.FilterRelativeDateTimeControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterControlProperty.Slider`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-slider
         */
        readonly slider?: CfnAnalysis.FilterSliderControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterControlProperty.TextArea`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textarea
         */
        readonly textArea?: CfnAnalysis.FilterTextAreaControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterControlProperty.TextField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtercontrol.html#cfn-quicksight-analysis-filtercontrol-textfield
         */
        readonly textField?: CfnAnalysis.FilterTextFieldControlProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html
     */
    interface FilterDateTimePickerControlProperty {
        /**
         * `CfnAnalysis.FilterDateTimePickerControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterDateTimePickerControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnAnalysis.FilterDateTimePickerControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnAnalysis.FilterDateTimePickerControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-title
         */
        readonly title: string;
        /**
         * `CfnAnalysis.FilterDateTimePickerControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdatetimepickercontrol.html#cfn-quicksight-analysis-filterdatetimepickercontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html
     */
    interface FilterDropDownControlProperty {
        /**
         * `CfnAnalysis.FilterDropDownControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnAnalysis.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterDropDownControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterDropDownControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnAnalysis.FilterDropDownControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnAnalysis.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterDropDownControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnAnalysis.FilterDropDownControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * `CfnAnalysis.FilterDropDownControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterdropdowncontrol.html#cfn-quicksight-analysis-filterdropdowncontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html
     */
    interface FilterGroupProperty {
        /**
         * `CfnAnalysis.FilterGroupProperty.CrossDataset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-crossdataset
         */
        readonly crossDataset: string;
        /**
         * `CfnAnalysis.FilterGroupProperty.FilterGroupId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filtergroupid
         */
        readonly filterGroupId: string;
        /**
         * `CfnAnalysis.FilterGroupProperty.Filters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-filters
         */
        readonly filters: Array<CfnAnalysis.FilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterGroupProperty.ScopeConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-scopeconfiguration
         */
        readonly scopeConfiguration: CfnAnalysis.FilterScopeConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterGroupProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtergroup.html#cfn-quicksight-analysis-filtergroup-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html
     */
    interface FilterListConfigurationProperty {
        /**
         * `CfnAnalysis.FilterListConfigurationProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: string[];
        /**
         * `CfnAnalysis.FilterListConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnAnalysis.FilterListConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistconfiguration.html#cfn-quicksight-analysis-filterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html
     */
    interface FilterListControlProperty {
        /**
         * `CfnAnalysis.FilterListControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnAnalysis.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterListControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.ListControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterListControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnAnalysis.FilterListControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnAnalysis.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterListControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnAnalysis.FilterListControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-title
         */
        readonly title: string;
        /**
         * `CfnAnalysis.FilterListControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterlistcontrol.html#cfn-quicksight-analysis-filterlistcontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html
     */
    interface FilterOperationSelectedFieldsConfigurationProperty {
        /**
         * `CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfieldoptions
         */
        readonly selectedFieldOptions?: string;
        /**
         * `CfnAnalysis.FilterOperationSelectedFieldsConfigurationProperty.SelectedFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-analysis-filteroperationselectedfieldsconfiguration-selectedfields
         */
        readonly selectedFields?: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html
     */
    interface FilterOperationTargetVisualsConfigurationProperty {
        /**
         * `CfnAnalysis.FilterOperationTargetVisualsConfigurationProperty.SameSheetTargetVisualConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-analysis-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
         */
        readonly sameSheetTargetVisualConfiguration?: CfnAnalysis.SameSheetTargetVisualConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html
     */
    interface FilterRelativeDateTimeControlProperty {
        /**
         * `CfnAnalysis.FilterRelativeDateTimeControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterRelativeDateTimeControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnAnalysis.FilterRelativeDateTimeControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnAnalysis.FilterRelativeDateTimeControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterrelativedatetimecontrol.html#cfn-quicksight-analysis-filterrelativedatetimecontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html
     */
    interface FilterScopeConfigurationProperty {
        /**
         * `CfnAnalysis.FilterScopeConfigurationProperty.SelectedSheets`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterscopeconfiguration.html#cfn-quicksight-analysis-filterscopeconfiguration-selectedsheets
         */
        readonly selectedSheets?: CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html
     */
    interface FilterSelectableValuesProperty {
        /**
         * `CfnAnalysis.FilterSelectableValuesProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterselectablevalues.html#cfn-quicksight-analysis-filterselectablevalues-values
         */
        readonly values?: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html
     */
    interface FilterSliderControlProperty {
        /**
         * `CfnAnalysis.FilterSliderControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.SliderControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterSliderControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnAnalysis.FilterSliderControlProperty.MaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * `CfnAnalysis.FilterSliderControlProperty.MinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * `CfnAnalysis.FilterSliderControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnAnalysis.FilterSliderControlProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * `CfnAnalysis.FilterSliderControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-title
         */
        readonly title: string;
        /**
         * `CfnAnalysis.FilterSliderControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filterslidercontrol.html#cfn-quicksight-analysis-filterslidercontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html
     */
    interface FilterTextAreaControlProperty {
        /**
         * `CfnAnalysis.FilterTextAreaControlProperty.Delimiter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * `CfnAnalysis.FilterTextAreaControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.TextAreaControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterTextAreaControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnAnalysis.FilterTextAreaControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnAnalysis.FilterTextAreaControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextareacontrol.html#cfn-quicksight-analysis-filtertextareacontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html
     */
    interface FilterTextFieldControlProperty {
        /**
         * `CfnAnalysis.FilterTextFieldControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.TextFieldControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FilterTextFieldControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnAnalysis.FilterTextFieldControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnAnalysis.FilterTextFieldControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-filtertextfieldcontrol.html#cfn-quicksight-analysis-filtertextfieldcontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html
     */
    interface FontConfigurationProperty {
        /**
         * `CfnAnalysis.FontConfigurationProperty.FontColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * `CfnAnalysis.FontConfigurationProperty.FontDecoration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontdecoration
         */
        readonly fontDecoration?: string;
        /**
         * `CfnAnalysis.FontConfigurationProperty.FontSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontsize
         */
        readonly fontSize?: CfnAnalysis.FontSizeProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FontConfigurationProperty.FontStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontstyle
         */
        readonly fontStyle?: string;
        /**
         * `CfnAnalysis.FontConfigurationProperty.FontWeight`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontconfiguration.html#cfn-quicksight-analysis-fontconfiguration-fontweight
         */
        readonly fontWeight?: CfnAnalysis.FontWeightProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html
     */
    interface FontSizeProperty {
        /**
         * `CfnAnalysis.FontSizeProperty.Relative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontsize.html#cfn-quicksight-analysis-fontsize-relative
         */
        readonly relative?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html
     */
    interface FontWeightProperty {
        /**
         * `CfnAnalysis.FontWeightProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-fontweight.html#cfn-quicksight-analysis-fontweight-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html
     */
    interface ForecastComputationProperty {
        /**
         * `CfnAnalysis.ForecastComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.ForecastComputationProperty.CustomSeasonalityValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-customseasonalityvalue
         */
        readonly customSeasonalityValue?: number;
        /**
         * `CfnAnalysis.ForecastComputationProperty.LowerBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * `CfnAnalysis.ForecastComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.ForecastComputationProperty.PeriodsBackward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * `CfnAnalysis.ForecastComputationProperty.PeriodsForward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * `CfnAnalysis.ForecastComputationProperty.PredictionInterval`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * `CfnAnalysis.ForecastComputationProperty.Seasonality`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-seasonality
         */
        readonly seasonality?: string;
        /**
         * `CfnAnalysis.ForecastComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-time
         */
        readonly time: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ForecastComputationProperty.UpperBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-upperboundary
         */
        readonly upperBoundary?: number;
        /**
         * `CfnAnalysis.ForecastComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastcomputation.html#cfn-quicksight-analysis-forecastcomputation-value
         */
        readonly value?: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html
     */
    interface ForecastConfigurationProperty {
        /**
         * `CfnAnalysis.ForecastConfigurationProperty.ForecastProperties`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-forecastproperties
         */
        readonly forecastProperties?: CfnAnalysis.TimeBasedForecastPropertiesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ForecastConfigurationProperty.Scenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastconfiguration.html#cfn-quicksight-analysis-forecastconfiguration-scenario
         */
        readonly scenario?: CfnAnalysis.ForecastScenarioProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html
     */
    interface ForecastScenarioProperty {
        /**
         * `CfnAnalysis.ForecastScenarioProperty.WhatIfPointScenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifpointscenario
         */
        readonly whatIfPointScenario?: CfnAnalysis.WhatIfPointScenarioProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ForecastScenarioProperty.WhatIfRangeScenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-forecastscenario.html#cfn-quicksight-analysis-forecastscenario-whatifrangescenario
         */
        readonly whatIfRangeScenario?: CfnAnalysis.WhatIfRangeScenarioProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html
     */
    interface FormatConfigurationProperty {
        /**
         * `CfnAnalysis.FormatConfigurationProperty.DateTimeFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-datetimeformatconfiguration
         */
        readonly dateTimeFormatConfiguration?: CfnAnalysis.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FormatConfigurationProperty.NumberFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-numberformatconfiguration
         */
        readonly numberFormatConfiguration?: CfnAnalysis.NumberFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FormatConfigurationProperty.StringFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-formatconfiguration.html#cfn-quicksight-analysis-formatconfiguration-stringformatconfiguration
         */
        readonly stringFormatConfiguration?: CfnAnalysis.StringFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html
     */
    interface FreeFormLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty.ScreenCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutcanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html
     */
    interface FreeFormLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.FreeFormLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnAnalysis.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FreeFormLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutconfiguration.html#cfn-quicksight-analysis-freeformlayoutconfiguration-elements
         */
        readonly elements: Array<CfnAnalysis.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html
     */
    interface FreeFormLayoutElementProperty {
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.BackgroundStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-backgroundstyle
         */
        readonly backgroundStyle?: CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.BorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-borderstyle
         */
        readonly borderStyle?: CfnAnalysis.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.ElementId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.ElementType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-height
         */
        readonly height: string;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.LoadingAnimation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-loadinganimation
         */
        readonly loadingAnimation?: CfnAnalysis.LoadingAnimationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.RenderingRules`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-renderingrules
         */
        readonly renderingRules?: Array<CfnAnalysis.SheetElementRenderingRuleProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.SelectedBorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-selectedborderstyle
         */
        readonly selectedBorderStyle?: CfnAnalysis.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-width
         */
        readonly width: string;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.XAxisLocation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-xaxislocation
         */
        readonly xAxisLocation: string;
        /**
         * `CfnAnalysis.FreeFormLayoutElementProperty.YAxisLocation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelement.html#cfn-quicksight-analysis-freeformlayoutelement-yaxislocation
         */
        readonly yAxisLocation: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html
     */
    interface FreeFormLayoutElementBackgroundStyleProperty {
        /**
         * `CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-color
         */
        readonly color?: string;
        /**
         * `CfnAnalysis.FreeFormLayoutElementBackgroundStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-analysis-freeformlayoutelementbackgroundstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html
     */
    interface FreeFormLayoutElementBorderStyleProperty {
        /**
         * `CfnAnalysis.FreeFormLayoutElementBorderStyleProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-color
         */
        readonly color?: string;
        /**
         * `CfnAnalysis.FreeFormLayoutElementBorderStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutelementborderstyle.html#cfn-quicksight-analysis-freeformlayoutelementborderstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html
     */
    interface FreeFormLayoutScreenCanvasSizeOptionsProperty {
        /**
         * `CfnAnalysis.FreeFormLayoutScreenCanvasSizeOptionsProperty.OptimizedViewPortWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html
     */
    interface FreeFormSectionLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.FreeFormSectionLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-freeformsectionlayoutconfiguration.html#cfn-quicksight-analysis-freeformsectionlayoutconfiguration-elements
         */
        readonly elements: Array<CfnAnalysis.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html
     */
    interface FunnelChartAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.FunnelChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartaggregatedfieldwells.html#cfn-quicksight-analysis-funnelchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html
     */
    interface FunnelChartConfigurationProperty {
        /**
         * `CfnAnalysis.FunnelChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartConfigurationProperty.DataLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-datalabeloptions
         */
        readonly dataLabelOptions?: CfnAnalysis.FunnelChartDataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.FunnelChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.FunnelChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartconfiguration.html#cfn-quicksight-analysis-funnelchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html
     */
    interface FunnelChartDataLabelOptionsProperty {
        /**
         * `CfnAnalysis.FunnelChartDataLabelOptionsProperty.CategoryLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * `CfnAnalysis.FunnelChartDataLabelOptionsProperty.LabelColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * `CfnAnalysis.FunnelChartDataLabelOptionsProperty.LabelFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartDataLabelOptionsProperty.MeasureDataLabelStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measuredatalabelstyle
         */
        readonly measureDataLabelStyle?: string;
        /**
         * `CfnAnalysis.FunnelChartDataLabelOptionsProperty.MeasureLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * `CfnAnalysis.FunnelChartDataLabelOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-position
         */
        readonly position?: string;
        /**
         * `CfnAnalysis.FunnelChartDataLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartdatalabeloptions.html#cfn-quicksight-analysis-funnelchartdatalabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html
     */
    interface FunnelChartFieldWellsProperty {
        /**
         * `CfnAnalysis.FunnelChartFieldWellsProperty.FunnelChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartfieldwells.html#cfn-quicksight-analysis-funnelchartfieldwells-funnelchartaggregatedfieldwells
         */
        readonly funnelChartAggregatedFieldWells?: CfnAnalysis.FunnelChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html
     */
    interface FunnelChartSortConfigurationProperty {
        /**
         * `CfnAnalysis.FunnelChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartsortconfiguration.html#cfn-quicksight-analysis-funnelchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html
     */
    interface FunnelChartVisualProperty {
        /**
         * `CfnAnalysis.FunnelChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.FunnelChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.FunnelChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-funnelchartvisual.html#cfn-quicksight-analysis-funnelchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html
     */
    interface GaugeChartArcConditionalFormattingProperty {
        /**
         * `CfnAnalysis.GaugeChartArcConditionalFormattingProperty.ForegroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartarcconditionalformatting.html#cfn-quicksight-analysis-gaugechartarcconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html
     */
    interface GaugeChartConditionalFormattingProperty {
        /**
         * `CfnAnalysis.GaugeChartConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformatting.html#cfn-quicksight-analysis-gaugechartconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnAnalysis.GaugeChartConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html
     */
    interface GaugeChartConditionalFormattingOptionProperty {
        /**
         * `CfnAnalysis.GaugeChartConditionalFormattingOptionProperty.Arc`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-arc
         */
        readonly arc?: CfnAnalysis.GaugeChartArcConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartConditionalFormattingOptionProperty.PrimaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconditionalformattingoption.html#cfn-quicksight-analysis-gaugechartconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html
     */
    interface GaugeChartConfigurationProperty {
        /**
         * `CfnAnalysis.GaugeChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.GaugeChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartConfigurationProperty.GaugeChartOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-gaugechartoptions
         */
        readonly gaugeChartOptions?: CfnAnalysis.GaugeChartOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartConfigurationProperty.TooltipOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-tooltipoptions
         */
        readonly tooltipOptions?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartconfiguration.html#cfn-quicksight-analysis-gaugechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html
     */
    interface GaugeChartFieldWellsProperty {
        /**
         * `CfnAnalysis.GaugeChartFieldWellsProperty.TargetValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-targetvalues
         */
        readonly targetValues?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartfieldwells.html#cfn-quicksight-analysis-gaugechartfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html
     */
    interface GaugeChartOptionsProperty {
        /**
         * `CfnAnalysis.GaugeChartOptionsProperty.Arc`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arc
         */
        readonly arc?: CfnAnalysis.ArcConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartOptionsProperty.ArcAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-arcaxis
         */
        readonly arcAxis?: CfnAnalysis.ArcAxisConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartOptionsProperty.Comparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-comparison
         */
        readonly comparison?: CfnAnalysis.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartOptionsProperty.PrimaryValueDisplayType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * `CfnAnalysis.GaugeChartOptionsProperty.PrimaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartoptions.html#cfn-quicksight-analysis-gaugechartoptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html
     */
    interface GaugeChartPrimaryValueConditionalFormattingProperty {
        /**
         * `CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnAnalysis.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartPrimaryValueConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-gaugechartprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html
     */
    interface GaugeChartVisualProperty {
        /**
         * `CfnAnalysis.GaugeChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.GaugeChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnAnalysis.GaugeChartConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GaugeChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gaugechartvisual.html#cfn-quicksight-analysis-gaugechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html
     */
    interface GeospatialCoordinateBoundsProperty {
        /**
         * `CfnAnalysis.GeospatialCoordinateBoundsProperty.East`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-east
         */
        readonly east: number;
        /**
         * `CfnAnalysis.GeospatialCoordinateBoundsProperty.North`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-north
         */
        readonly north: number;
        /**
         * `CfnAnalysis.GeospatialCoordinateBoundsProperty.South`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-south
         */
        readonly south: number;
        /**
         * `CfnAnalysis.GeospatialCoordinateBoundsProperty.West`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialcoordinatebounds.html#cfn-quicksight-analysis-geospatialcoordinatebounds-west
         */
        readonly west: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html
     */
    interface GeospatialMapAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty.Geospatial`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapaggregatedfieldwells.html#cfn-quicksight-analysis-geospatialmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html
     */
    interface GeospatialMapConfigurationProperty {
        /**
         * `CfnAnalysis.GeospatialMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.GeospatialMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapConfigurationProperty.MapStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnAnalysis.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapConfigurationProperty.PointStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-pointstyleoptions
         */
        readonly pointStyleOptions?: CfnAnalysis.GeospatialPointStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapConfigurationProperty.WindowOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapconfiguration.html#cfn-quicksight-analysis-geospatialmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnAnalysis.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html
     */
    interface GeospatialMapFieldWellsProperty {
        /**
         * `CfnAnalysis.GeospatialMapFieldWellsProperty.GeospatialMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapfieldwells.html#cfn-quicksight-analysis-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
         */
        readonly geospatialMapAggregatedFieldWells?: CfnAnalysis.GeospatialMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html
     */
    interface GeospatialMapStyleOptionsProperty {
        /**
         * `CfnAnalysis.GeospatialMapStyleOptionsProperty.BaseMapStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapstyleoptions.html#cfn-quicksight-analysis-geospatialmapstyleoptions-basemapstyle
         */
        readonly baseMapStyle?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html
     */
    interface GeospatialMapVisualProperty {
        /**
         * `CfnAnalysis.GeospatialMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.GeospatialMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialmapvisual.html#cfn-quicksight-analysis-geospatialmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html
     */
    interface GeospatialPointStyleOptionsProperty {
        /**
         * `CfnAnalysis.GeospatialPointStyleOptionsProperty.ClusterMarkerConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-clustermarkerconfiguration
         */
        readonly clusterMarkerConfiguration?: CfnAnalysis.ClusterMarkerConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialPointStyleOptionsProperty.SelectedPointStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialpointstyleoptions.html#cfn-quicksight-analysis-geospatialpointstyleoptions-selectedpointstyle
         */
        readonly selectedPointStyle?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html
     */
    interface GeospatialWindowOptionsProperty {
        /**
         * `CfnAnalysis.GeospatialWindowOptionsProperty.Bounds`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-bounds
         */
        readonly bounds?: CfnAnalysis.GeospatialCoordinateBoundsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GeospatialWindowOptionsProperty.MapZoomMode`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-geospatialwindowoptions.html#cfn-quicksight-analysis-geospatialwindowoptions-mapzoommode
         */
        readonly mapZoomMode?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html
     */
    interface GlobalTableBorderOptionsProperty {
        /**
         * `CfnAnalysis.GlobalTableBorderOptionsProperty.SideSpecificBorder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-sidespecificborder
         */
        readonly sideSpecificBorder?: CfnAnalysis.TableSideBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GlobalTableBorderOptionsProperty.UniformBorder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-globaltableborderoptions.html#cfn-quicksight-analysis-globaltableborderoptions-uniformborder
         */
        readonly uniformBorder?: CfnAnalysis.TableBorderOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html
     */
    interface GradientColorProperty {
        /**
         * `CfnAnalysis.GradientColorProperty.Stops`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientcolor.html#cfn-quicksight-analysis-gradientcolor-stops
         */
        readonly stops?: Array<CfnAnalysis.GradientStopProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html
     */
    interface GradientStopProperty {
        /**
         * `CfnAnalysis.GradientStopProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-color
         */
        readonly color?: string;
        /**
         * `CfnAnalysis.GradientStopProperty.DataValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-datavalue
         */
        readonly dataValue?: number;
        /**
         * `CfnAnalysis.GradientStopProperty.GradientOffset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gradientstop.html#cfn-quicksight-analysis-gradientstop-gradientoffset
         */
        readonly gradientOffset: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html
     */
    interface GridLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnAnalysis.GridLayoutCanvasSizeOptionsProperty.ScreenCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutcanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html
     */
    interface GridLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.GridLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnAnalysis.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GridLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutconfiguration.html#cfn-quicksight-analysis-gridlayoutconfiguration-elements
         */
        readonly elements: Array<CfnAnalysis.GridLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html
     */
    interface GridLayoutElementProperty {
        /**
         * `CfnAnalysis.GridLayoutElementProperty.ColumnIndex`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnindex
         */
        readonly columnIndex?: number;
        /**
         * `CfnAnalysis.GridLayoutElementProperty.ColumnSpan`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-columnspan
         */
        readonly columnSpan: number;
        /**
         * `CfnAnalysis.GridLayoutElementProperty.ElementId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * `CfnAnalysis.GridLayoutElementProperty.ElementType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * `CfnAnalysis.GridLayoutElementProperty.RowIndex`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowindex
         */
        readonly rowIndex?: number;
        /**
         * `CfnAnalysis.GridLayoutElementProperty.RowSpan`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutelement.html#cfn-quicksight-analysis-gridlayoutelement-rowspan
         */
        readonly rowSpan: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html
     */
    interface GridLayoutScreenCanvasSizeOptionsProperty {
        /**
         * `CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty.OptimizedViewPortWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth?: string;
        /**
         * `CfnAnalysis.GridLayoutScreenCanvasSizeOptionsProperty.ResizeOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-analysis-gridlayoutscreencanvassizeoptions-resizeoption
         */
        readonly resizeOption: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html
     */
    interface GrowthRateComputationProperty {
        /**
         * `CfnAnalysis.GrowthRateComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.GrowthRateComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.GrowthRateComputationProperty.PeriodSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-periodsize
         */
        readonly periodSize?: number;
        /**
         * `CfnAnalysis.GrowthRateComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-time
         */
        readonly time: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.GrowthRateComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-growthratecomputation.html#cfn-quicksight-analysis-growthratecomputation-value
         */
        readonly value?: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html
     */
    interface HeaderFooterSectionConfigurationProperty {
        /**
         * `CfnAnalysis.HeaderFooterSectionConfigurationProperty.Layout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-layout
         */
        readonly layout: CfnAnalysis.SectionLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeaderFooterSectionConfigurationProperty.SectionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * `CfnAnalysis.HeaderFooterSectionConfigurationProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-headerfootersectionconfiguration.html#cfn-quicksight-analysis-headerfootersectionconfiguration-style
         */
        readonly style?: CfnAnalysis.SectionStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html
     */
    interface HeatMapAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.HeatMapAggregatedFieldWellsProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapAggregatedFieldWellsProperty.Rows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapaggregatedfieldwells.html#cfn-quicksight-analysis-heatmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html
     */
    interface HeatMapConfigurationProperty {
        /**
         * `CfnAnalysis.HeatMapConfigurationProperty.ColorScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-colorscale
         */
        readonly colorScale?: CfnAnalysis.ColorScaleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapConfigurationProperty.ColumnLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-columnlabeloptions
         */
        readonly columnLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.HeatMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapConfigurationProperty.RowLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-rowlabeloptions
         */
        readonly rowLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.HeatMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapconfiguration.html#cfn-quicksight-analysis-heatmapconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html
     */
    interface HeatMapFieldWellsProperty {
        /**
         * `CfnAnalysis.HeatMapFieldWellsProperty.HeatMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapfieldwells.html#cfn-quicksight-analysis-heatmapfieldwells-heatmapaggregatedfieldwells
         */
        readonly heatMapAggregatedFieldWells?: CfnAnalysis.HeatMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html
     */
    interface HeatMapSortConfigurationProperty {
        /**
         * `CfnAnalysis.HeatMapSortConfigurationProperty.HeatMapColumnItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
         */
        readonly heatMapColumnItemsLimitConfiguration?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapSortConfigurationProperty.HeatMapColumnSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmapcolumnsort
         */
        readonly heatMapColumnSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapSortConfigurationProperty.HeatMapRowItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
         */
        readonly heatMapRowItemsLimitConfiguration?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapSortConfigurationProperty.HeatMapRowSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapsortconfiguration.html#cfn-quicksight-analysis-heatmapsortconfiguration-heatmaprowsort
         */
        readonly heatMapRowSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html
     */
    interface HeatMapVisualProperty {
        /**
         * `CfnAnalysis.HeatMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.HeatMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HeatMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-heatmapvisual.html#cfn-quicksight-analysis-heatmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html
     */
    interface HistogramAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.HistogramAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramaggregatedfieldwells.html#cfn-quicksight-analysis-histogramaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html
     */
    interface HistogramBinOptionsProperty {
        /**
         * `CfnAnalysis.HistogramBinOptionsProperty.BinCount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-bincount
         */
        readonly binCount?: CfnAnalysis.BinCountOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramBinOptionsProperty.BinWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-binwidth
         */
        readonly binWidth?: CfnAnalysis.BinWidthOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramBinOptionsProperty.SelectedBinType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-selectedbintype
         */
        readonly selectedBinType?: string;
        /**
         * `CfnAnalysis.HistogramBinOptionsProperty.StartValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogrambinoptions.html#cfn-quicksight-analysis-histogrambinoptions-startvalue
         */
        readonly startValue?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html
     */
    interface HistogramConfigurationProperty {
        /**
         * `CfnAnalysis.HistogramConfigurationProperty.BinOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-binoptions
         */
        readonly binOptions?: CfnAnalysis.HistogramBinOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.HistogramFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramConfigurationProperty.YAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramconfiguration.html#cfn-quicksight-analysis-histogramconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html
     */
    interface HistogramFieldWellsProperty {
        /**
         * `CfnAnalysis.HistogramFieldWellsProperty.HistogramAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramfieldwells.html#cfn-quicksight-analysis-histogramfieldwells-histogramaggregatedfieldwells
         */
        readonly histogramAggregatedFieldWells?: CfnAnalysis.HistogramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html
     */
    interface HistogramVisualProperty {
        /**
         * `CfnAnalysis.HistogramVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.HistogramConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.HistogramVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-histogramvisual.html#cfn-quicksight-analysis-histogramvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html
     */
    interface InsightConfigurationProperty {
        /**
         * `CfnAnalysis.InsightConfigurationProperty.Computations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-computations
         */
        readonly computations?: Array<CfnAnalysis.ComputationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.InsightConfigurationProperty.CustomNarrative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightconfiguration.html#cfn-quicksight-analysis-insightconfiguration-customnarrative
         */
        readonly customNarrative?: CfnAnalysis.CustomNarrativeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html
     */
    interface InsightVisualProperty {
        /**
         * `CfnAnalysis.InsightVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.InsightVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnAnalysis.InsightVisualProperty.InsightConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-insightconfiguration
         */
        readonly insightConfiguration?: CfnAnalysis.InsightConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.InsightVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.InsightVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.InsightVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-insightvisual.html#cfn-quicksight-analysis-insightvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html
     */
    interface IntegerDefaultValuesProperty {
        /**
         * `CfnAnalysis.IntegerDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnAnalysis.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.IntegerDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerdefaultvalues.html#cfn-quicksight-analysis-integerdefaultvalues-staticvalues
         */
        readonly staticValues?: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     * An integer parameter.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html
     */
    interface IntegerParameterProperty {
        /**
         * The name of the integer parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-name
         */
        readonly name: string;
        /**
         * The values for the integer parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameter.html#cfn-quicksight-analysis-integerparameter-values
         */
        readonly values: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html
     */
    interface IntegerParameterDeclarationProperty {
        /**
         * `CfnAnalysis.IntegerParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnAnalysis.IntegerDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.IntegerParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnAnalysis.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.IntegerParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnAnalysis.IntegerParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnAnalysis.IntegerParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integerparameterdeclaration.html#cfn-quicksight-analysis-integerparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html
     */
    interface IntegerValueWhenUnsetConfigurationProperty {
        /**
         * `CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * `CfnAnalysis.IntegerValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-integervaluewhenunsetconfiguration.html#cfn-quicksight-analysis-integervaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html
     */
    interface ItemsLimitConfigurationProperty {
        /**
         * `CfnAnalysis.ItemsLimitConfigurationProperty.ItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-itemslimit
         */
        readonly itemsLimit?: number;
        /**
         * `CfnAnalysis.ItemsLimitConfigurationProperty.OtherCategories`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-itemslimitconfiguration.html#cfn-quicksight-analysis-itemslimitconfiguration-othercategories
         */
        readonly otherCategories?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html
     */
    interface KPIConditionalFormattingProperty {
        /**
         * `CfnAnalysis.KPIConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformatting.html#cfn-quicksight-analysis-kpiconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnAnalysis.KPIConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html
     */
    interface KPIConditionalFormattingOptionProperty {
        /**
         * `CfnAnalysis.KPIConditionalFormattingOptionProperty.PrimaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIConditionalFormattingOptionProperty.ProgressBar`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconditionalformattingoption.html#cfn-quicksight-analysis-kpiconditionalformattingoption-progressbar
         */
        readonly progressBar?: CfnAnalysis.KPIProgressBarConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html
     */
    interface KPIConfigurationProperty {
        /**
         * `CfnAnalysis.KPIConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.KPIFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIConfigurationProperty.KPIOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-kpioptions
         */
        readonly kpiOptions?: CfnAnalysis.KPIOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiconfiguration.html#cfn-quicksight-analysis-kpiconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.KPISortConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html
     */
    interface KPIFieldWellsProperty {
        /**
         * `CfnAnalysis.KPIFieldWellsProperty.TargetValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-targetvalues
         */
        readonly targetValues?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIFieldWellsProperty.TrendGroups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-trendgroups
         */
        readonly trendGroups?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpifieldwells.html#cfn-quicksight-analysis-kpifieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html
     */
    interface KPIOptionsProperty {
        /**
         * `CfnAnalysis.KPIOptionsProperty.Comparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-comparison
         */
        readonly comparison?: CfnAnalysis.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIOptionsProperty.PrimaryValueDisplayType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * `CfnAnalysis.KPIOptionsProperty.PrimaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIOptionsProperty.ProgressBar`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-progressbar
         */
        readonly progressBar?: CfnAnalysis.ProgressBarOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIOptionsProperty.SecondaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvalue
         */
        readonly secondaryValue?: CfnAnalysis.SecondaryValueOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIOptionsProperty.SecondaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-secondaryvaluefontconfiguration
         */
        readonly secondaryValueFontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIOptionsProperty.TrendArrows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpioptions.html#cfn-quicksight-analysis-kpioptions-trendarrows
         */
        readonly trendArrows?: CfnAnalysis.TrendArrowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html
     */
    interface KPIPrimaryValueConditionalFormattingProperty {
        /**
         * `CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnAnalysis.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIPrimaryValueConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-analysis-kpiprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html
     */
    interface KPIProgressBarConditionalFormattingProperty {
        /**
         * `CfnAnalysis.KPIProgressBarConditionalFormattingProperty.ForegroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpiprogressbarconditionalformatting.html#cfn-quicksight-analysis-kpiprogressbarconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html
     */
    interface KPISortConfigurationProperty {
        /**
         * `CfnAnalysis.KPISortConfigurationProperty.TrendGroupSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpisortconfiguration.html#cfn-quicksight-analysis-kpisortconfiguration-trendgroupsort
         */
        readonly trendGroupSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html
     */
    interface KPIVisualProperty {
        /**
         * `CfnAnalysis.KPIVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.KPIConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnAnalysis.KPIConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.KPIVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-kpivisual.html#cfn-quicksight-analysis-kpivisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html
     */
    interface LabelOptionsProperty {
        /**
         * `CfnAnalysis.LabelOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnAnalysis.LabelOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-labeloptions.html#cfn-quicksight-analysis-labeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html
     */
    interface LayoutProperty {
        /**
         * `CfnAnalysis.LayoutProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layout.html#cfn-quicksight-analysis-layout-configuration
         */
        readonly configuration: CfnAnalysis.LayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html
     */
    interface LayoutConfigurationProperty {
        /**
         * `CfnAnalysis.LayoutConfigurationProperty.FreeFormLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-freeformlayout
         */
        readonly freeFormLayout?: CfnAnalysis.FreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LayoutConfigurationProperty.GridLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnAnalysis.GridLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LayoutConfigurationProperty.SectionBasedLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-layoutconfiguration.html#cfn-quicksight-analysis-layoutconfiguration-sectionbasedlayout
         */
        readonly sectionBasedLayout?: CfnAnalysis.SectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html
     */
    interface LegendOptionsProperty {
        /**
         * `CfnAnalysis.LegendOptionsProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-height
         */
        readonly height?: string;
        /**
         * `CfnAnalysis.LegendOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-position
         */
        readonly position?: string;
        /**
         * `CfnAnalysis.LegendOptionsProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-title
         */
        readonly title?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LegendOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnAnalysis.LegendOptionsProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-legendoptions.html#cfn-quicksight-analysis-legendoptions-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html
     */
    interface LineChartAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.LineChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartaggregatedfieldwells.html#cfn-quicksight-analysis-linechartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html
     */
    interface LineChartConfigurationProperty {
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnAnalysis.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.DefaultSeriesSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-defaultseriessettings
         */
        readonly defaultSeriesSettings?: CfnAnalysis.LineChartDefaultSeriesSettingsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.LineChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.ForecastConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-forecastconfigurations
         */
        readonly forecastConfigurations?: Array<CfnAnalysis.ForecastConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnAnalysis.LineSeriesAxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnAnalysis.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.SecondaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnAnalysis.LineSeriesAxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.SecondaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.Series`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-series
         */
        readonly series?: Array<CfnAnalysis.SeriesItemProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnAnalysis.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.LineChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-type
         */
        readonly type?: string;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartconfiguration.html#cfn-quicksight-analysis-linechartconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html
     */
    interface LineChartDefaultSeriesSettingsProperty {
        /**
         * `CfnAnalysis.LineChartDefaultSeriesSettingsProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * `CfnAnalysis.LineChartDefaultSeriesSettingsProperty.LineStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: CfnAnalysis.LineChartLineStyleSettingsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartDefaultSeriesSettingsProperty.MarkerStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartdefaultseriessettings.html#cfn-quicksight-analysis-linechartdefaultseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: CfnAnalysis.LineChartMarkerStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html
     */
    interface LineChartFieldWellsProperty {
        /**
         * `CfnAnalysis.LineChartFieldWellsProperty.LineChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartfieldwells.html#cfn-quicksight-analysis-linechartfieldwells-linechartaggregatedfieldwells
         */
        readonly lineChartAggregatedFieldWells?: CfnAnalysis.LineChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html
     */
    interface LineChartLineStyleSettingsProperty {
        /**
         * `CfnAnalysis.LineChartLineStyleSettingsProperty.LineInterpolation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-lineinterpolation
         */
        readonly lineInterpolation?: string;
        /**
         * `CfnAnalysis.LineChartLineStyleSettingsProperty.LineStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linestyle
         */
        readonly lineStyle?: string;
        /**
         * `CfnAnalysis.LineChartLineStyleSettingsProperty.LineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linevisibility
         */
        readonly lineVisibility?: string;
        /**
         * `CfnAnalysis.LineChartLineStyleSettingsProperty.LineWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartlinestylesettings.html#cfn-quicksight-analysis-linechartlinestylesettings-linewidth
         */
        readonly lineWidth?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html
     */
    interface LineChartMarkerStyleSettingsProperty {
        /**
         * `CfnAnalysis.LineChartMarkerStyleSettingsProperty.MarkerColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markercolor
         */
        readonly markerColor?: string;
        /**
         * `CfnAnalysis.LineChartMarkerStyleSettingsProperty.MarkerShape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markershape
         */
        readonly markerShape?: string;
        /**
         * `CfnAnalysis.LineChartMarkerStyleSettingsProperty.MarkerSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markersize
         */
        readonly markerSize?: string;
        /**
         * `CfnAnalysis.LineChartMarkerStyleSettingsProperty.MarkerVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartmarkerstylesettings.html#cfn-quicksight-analysis-linechartmarkerstylesettings-markervisibility
         */
        readonly markerVisibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html
     */
    interface LineChartSeriesSettingsProperty {
        /**
         * `CfnAnalysis.LineChartSeriesSettingsProperty.LineStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: CfnAnalysis.LineChartLineStyleSettingsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartSeriesSettingsProperty.MarkerStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartseriessettings.html#cfn-quicksight-analysis-linechartseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: CfnAnalysis.LineChartMarkerStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html
     */
    interface LineChartSortConfigurationProperty {
        /**
         * `CfnAnalysis.LineChartSortConfigurationProperty.CategoryItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categoryitemslimitconfiguration
         */
        readonly categoryItemsLimitConfiguration?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartSortConfigurationProperty.ColorItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-coloritemslimitconfiguration
         */
        readonly colorItemsLimitConfiguration?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartsortconfiguration.html#cfn-quicksight-analysis-linechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html
     */
    interface LineChartVisualProperty {
        /**
         * `CfnAnalysis.LineChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.LineChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-linechartvisual.html#cfn-quicksight-analysis-linechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html
     */
    interface LineSeriesAxisDisplayOptionsProperty {
        /**
         * `CfnAnalysis.LineSeriesAxisDisplayOptionsProperty.AxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-axisoptions
         */
        readonly axisOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.LineSeriesAxisDisplayOptionsProperty.MissingDataConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-lineseriesaxisdisplayoptions.html#cfn-quicksight-analysis-lineseriesaxisdisplayoptions-missingdataconfigurations
         */
        readonly missingDataConfigurations?: Array<CfnAnalysis.MissingDataConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html
     */
    interface ListControlDisplayOptionsProperty {
        /**
         * `CfnAnalysis.ListControlDisplayOptionsProperty.SearchOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-searchoptions
         */
        readonly searchOptions?: CfnAnalysis.ListControlSearchOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ListControlDisplayOptionsProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: CfnAnalysis.ListControlSelectAllOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ListControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontroldisplayoptions.html#cfn-quicksight-analysis-listcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html
     */
    interface ListControlSearchOptionsProperty {
        /**
         * `CfnAnalysis.ListControlSearchOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolsearchoptions.html#cfn-quicksight-analysis-listcontrolsearchoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html
     */
    interface ListControlSelectAllOptionsProperty {
        /**
         * `CfnAnalysis.ListControlSelectAllOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-listcontrolselectalloptions.html#cfn-quicksight-analysis-listcontrolselectalloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html
     */
    interface LoadingAnimationProperty {
        /**
         * `CfnAnalysis.LoadingAnimationProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-loadinganimation.html#cfn-quicksight-analysis-loadinganimation-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html
     */
    interface LocalNavigationConfigurationProperty {
        /**
         * `CfnAnalysis.LocalNavigationConfigurationProperty.TargetSheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-localnavigationconfiguration.html#cfn-quicksight-analysis-localnavigationconfiguration-targetsheetid
         */
        readonly targetSheetId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html
     */
    interface LongFormatTextProperty {
        /**
         * `CfnAnalysis.LongFormatTextProperty.PlainText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * `CfnAnalysis.LongFormatTextProperty.RichText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-longformattext.html#cfn-quicksight-analysis-longformattext-richtext
         */
        readonly richText?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html
     */
    interface MappedDataSetParameterProperty {
        /**
         * `CfnAnalysis.MappedDataSetParameterProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnAnalysis.MappedDataSetParameterProperty.DataSetParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-mappeddatasetparameter.html#cfn-quicksight-analysis-mappeddatasetparameter-datasetparametername
         */
        readonly dataSetParameterName: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html
     */
    interface MaximumLabelTypeProperty {
        /**
         * `CfnAnalysis.MaximumLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumlabeltype.html#cfn-quicksight-analysis-maximumlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html
     */
    interface MaximumMinimumComputationProperty {
        /**
         * `CfnAnalysis.MaximumMinimumComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.MaximumMinimumComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.MaximumMinimumComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-time
         */
        readonly time: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.MaximumMinimumComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-type
         */
        readonly type: string;
        /**
         * `CfnAnalysis.MaximumMinimumComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-maximumminimumcomputation.html#cfn-quicksight-analysis-maximumminimumcomputation-value
         */
        readonly value?: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html
     */
    interface MeasureFieldProperty {
        /**
         * `CfnAnalysis.MeasureFieldProperty.CalculatedMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-calculatedmeasurefield
         */
        readonly calculatedMeasureField?: CfnAnalysis.CalculatedMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.MeasureFieldProperty.CategoricalMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-categoricalmeasurefield
         */
        readonly categoricalMeasureField?: CfnAnalysis.CategoricalMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.MeasureFieldProperty.DateMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-datemeasurefield
         */
        readonly dateMeasureField?: CfnAnalysis.DateMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.MeasureFieldProperty.NumericalMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-measurefield.html#cfn-quicksight-analysis-measurefield-numericalmeasurefield
         */
        readonly numericalMeasureField?: CfnAnalysis.NumericalMeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html
     */
    interface MetricComparisonComputationProperty {
        /**
         * `CfnAnalysis.MetricComparisonComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.MetricComparisonComputationProperty.FromValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-fromvalue
         */
        readonly fromValue: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.MetricComparisonComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.MetricComparisonComputationProperty.TargetValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-targetvalue
         */
        readonly targetValue: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.MetricComparisonComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-metriccomparisoncomputation.html#cfn-quicksight-analysis-metriccomparisoncomputation-time
         */
        readonly time: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html
     */
    interface MinimumLabelTypeProperty {
        /**
         * `CfnAnalysis.MinimumLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-minimumlabeltype.html#cfn-quicksight-analysis-minimumlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html
     */
    interface MissingDataConfigurationProperty {
        /**
         * `CfnAnalysis.MissingDataConfigurationProperty.TreatmentOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-missingdataconfiguration.html#cfn-quicksight-analysis-missingdataconfiguration-treatmentoption
         */
        readonly treatmentOption?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html
     */
    interface NegativeValueConfigurationProperty {
        /**
         * `CfnAnalysis.NegativeValueConfigurationProperty.DisplayMode`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-negativevalueconfiguration.html#cfn-quicksight-analysis-negativevalueconfiguration-displaymode
         */
        readonly displayMode: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html
     */
    interface NullValueFormatConfigurationProperty {
        /**
         * `CfnAnalysis.NullValueFormatConfigurationProperty.NullString`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-nullvalueformatconfiguration.html#cfn-quicksight-analysis-nullvalueformatconfiguration-nullstring
         */
        readonly nullString: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html
     */
    interface NumberDisplayFormatConfigurationProperty {
        /**
         * `CfnAnalysis.NumberDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnAnalysis.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumberDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnAnalysis.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumberDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnAnalysis.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumberDisplayFormatConfigurationProperty.NumberScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * `CfnAnalysis.NumberDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnAnalysis.NumberDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnAnalysis.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumberDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberdisplayformatconfiguration.html#cfn-quicksight-analysis-numberdisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html
     */
    interface NumberFormatConfigurationProperty {
        /**
         * `CfnAnalysis.NumberFormatConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numberformatconfiguration.html#cfn-quicksight-analysis-numberformatconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html
     */
    interface NumericAxisOptionsProperty {
        /**
         * `CfnAnalysis.NumericAxisOptionsProperty.Range`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-range
         */
        readonly range?: CfnAnalysis.AxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericAxisOptionsProperty.Scale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaxisoptions.html#cfn-quicksight-analysis-numericaxisoptions-scale
         */
        readonly scale?: CfnAnalysis.AxisScaleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html
     */
    interface NumericEqualityDrillDownFilterProperty {
        /**
         * `CfnAnalysis.NumericEqualityDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericEqualityDrillDownFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalitydrilldownfilter.html#cfn-quicksight-analysis-numericequalitydrilldownfilter-value
         */
        readonly value: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html
     */
    interface NumericEqualityFilterProperty {
        /**
         * `CfnAnalysis.NumericEqualityFilterProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericEqualityFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericEqualityFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnAnalysis.NumericEqualityFilterProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnAnalysis.NumericEqualityFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnAnalysis.NumericEqualityFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnAnalysis.NumericEqualityFilterProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-selectalloptions
         */
        readonly selectAllOptions?: string;
        /**
         * `CfnAnalysis.NumericEqualityFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericequalityfilter.html#cfn-quicksight-analysis-numericequalityfilter-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html
     */
    interface NumericFormatConfigurationProperty {
        /**
         * `CfnAnalysis.NumericFormatConfigurationProperty.CurrencyDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-currencydisplayformatconfiguration
         */
        readonly currencyDisplayFormatConfiguration?: CfnAnalysis.CurrencyDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericFormatConfigurationProperty.NumberDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: CfnAnalysis.NumberDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericFormatConfigurationProperty.PercentageDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericformatconfiguration.html#cfn-quicksight-analysis-numericformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: CfnAnalysis.PercentageDisplayFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html
     */
    interface NumericRangeFilterProperty {
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.IncludeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.IncludeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.RangeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangemaximum
         */
        readonly rangeMaximum?: CfnAnalysis.NumericRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.RangeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-rangeminimum
         */
        readonly rangeMinimum?: CfnAnalysis.NumericRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericRangeFilterProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefilter.html#cfn-quicksight-analysis-numericrangefilter-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html
     */
    interface NumericRangeFilterValueProperty {
        /**
         * `CfnAnalysis.NumericRangeFilterValueProperty.Parameter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * `CfnAnalysis.NumericRangeFilterValueProperty.StaticValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericrangefiltervalue.html#cfn-quicksight-analysis-numericrangefiltervalue-staticvalue
         */
        readonly staticValue?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html
     */
    interface NumericSeparatorConfigurationProperty {
        /**
         * `CfnAnalysis.NumericSeparatorConfigurationProperty.DecimalSeparator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-decimalseparator
         */
        readonly decimalSeparator?: string;
        /**
         * `CfnAnalysis.NumericSeparatorConfigurationProperty.ThousandsSeparator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericseparatorconfiguration.html#cfn-quicksight-analysis-numericseparatorconfiguration-thousandsseparator
         */
        readonly thousandsSeparator?: CfnAnalysis.ThousandSeparatorOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html
     */
    interface NumericalAggregationFunctionProperty {
        /**
         * `CfnAnalysis.NumericalAggregationFunctionProperty.PercentileAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-percentileaggregation
         */
        readonly percentileAggregation?: CfnAnalysis.PercentileAggregationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericalAggregationFunctionProperty.SimpleNumericalAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalaggregationfunction.html#cfn-quicksight-analysis-numericalaggregationfunction-simplenumericalaggregation
         */
        readonly simpleNumericalAggregation?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html
     */
    interface NumericalDimensionFieldProperty {
        /**
         * `CfnAnalysis.NumericalDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericalDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.NumericalDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.NumberFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericalDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericaldimensionfield.html#cfn-quicksight-analysis-numericaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html
     */
    interface NumericalMeasureFieldProperty {
        /**
         * `CfnAnalysis.NumericalMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: CfnAnalysis.NumericalAggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericalMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.NumericalMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.NumericalMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-numericalmeasurefield.html#cfn-quicksight-analysis-numericalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.NumberFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html
     */
    interface PaginationConfigurationProperty {
        /**
         * `CfnAnalysis.PaginationConfigurationProperty.PageNumber`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagenumber
         */
        readonly pageNumber: number;
        /**
         * `CfnAnalysis.PaginationConfigurationProperty.PageSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paginationconfiguration.html#cfn-quicksight-analysis-paginationconfiguration-pagesize
         */
        readonly pageSize: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html
     */
    interface PanelConfigurationProperty {
        /**
         * `CfnAnalysis.PanelConfigurationProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * `CfnAnalysis.PanelConfigurationProperty.BackgroundVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-backgroundvisibility
         */
        readonly backgroundVisibility?: string;
        /**
         * `CfnAnalysis.PanelConfigurationProperty.BorderColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordercolor
         */
        readonly borderColor?: string;
        /**
         * `CfnAnalysis.PanelConfigurationProperty.BorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderstyle
         */
        readonly borderStyle?: string;
        /**
         * `CfnAnalysis.PanelConfigurationProperty.BorderThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-borderthickness
         */
        readonly borderThickness?: string;
        /**
         * `CfnAnalysis.PanelConfigurationProperty.BorderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-bordervisibility
         */
        readonly borderVisibility?: string;
        /**
         * `CfnAnalysis.PanelConfigurationProperty.GutterSpacing`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-gutterspacing
         */
        readonly gutterSpacing?: string;
        /**
         * `CfnAnalysis.PanelConfigurationProperty.GutterVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-guttervisibility
         */
        readonly gutterVisibility?: string;
        /**
         * `CfnAnalysis.PanelConfigurationProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-panelconfiguration.html#cfn-quicksight-analysis-panelconfiguration-title
         */
        readonly title?: CfnAnalysis.PanelTitleOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html
     */
    interface PanelTitleOptionsProperty {
        /**
         * `CfnAnalysis.PanelTitleOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PanelTitleOptionsProperty.HorizontalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * `CfnAnalysis.PanelTitleOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-paneltitleoptions.html#cfn-quicksight-analysis-paneltitleoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html
     */
    interface ParameterControlProperty {
        /**
         * `CfnAnalysis.ParameterControlProperty.DateTimePicker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnAnalysis.ParameterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterControlProperty.Dropdown`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-dropdown
         */
        readonly dropdown?: CfnAnalysis.ParameterDropDownControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterControlProperty.List`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-list
         */
        readonly list?: CfnAnalysis.ParameterListControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterControlProperty.Slider`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-slider
         */
        readonly slider?: CfnAnalysis.ParameterSliderControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterControlProperty.TextArea`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textarea
         */
        readonly textArea?: CfnAnalysis.ParameterTextAreaControlProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterControlProperty.TextField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametercontrol.html#cfn-quicksight-analysis-parametercontrol-textfield
         */
        readonly textField?: CfnAnalysis.ParameterTextFieldControlProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html
     */
    interface ParameterDateTimePickerControlProperty {
        /**
         * `CfnAnalysis.ParameterDateTimePickerControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterDateTimePickerControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnAnalysis.ParameterDateTimePickerControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnAnalysis.ParameterDateTimePickerControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdatetimepickercontrol.html#cfn-quicksight-analysis-parameterdatetimepickercontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html
     */
    interface ParameterDeclarationProperty {
        /**
         * `CfnAnalysis.ParameterDeclarationProperty.DateTimeParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-datetimeparameterdeclaration
         */
        readonly dateTimeParameterDeclaration?: CfnAnalysis.DateTimeParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterDeclarationProperty.DecimalParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-decimalparameterdeclaration
         */
        readonly decimalParameterDeclaration?: CfnAnalysis.DecimalParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterDeclarationProperty.IntegerParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-integerparameterdeclaration
         */
        readonly integerParameterDeclaration?: CfnAnalysis.IntegerParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterDeclarationProperty.StringParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdeclaration.html#cfn-quicksight-analysis-parameterdeclaration-stringparameterdeclaration
         */
        readonly stringParameterDeclaration?: CfnAnalysis.StringParameterDeclarationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html
     */
    interface ParameterDropDownControlProperty {
        /**
         * `CfnAnalysis.ParameterDropDownControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnAnalysis.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterDropDownControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterDropDownControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnAnalysis.ParameterDropDownControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnAnalysis.ParameterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterDropDownControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnAnalysis.ParameterDropDownControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * `CfnAnalysis.ParameterDropDownControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterdropdowncontrol.html#cfn-quicksight-analysis-parameterdropdowncontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html
     */
    interface ParameterListControlProperty {
        /**
         * `CfnAnalysis.ParameterListControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnAnalysis.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterListControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.ListControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterListControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnAnalysis.ParameterListControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnAnalysis.ParameterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterListControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnAnalysis.ParameterListControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-title
         */
        readonly title: string;
        /**
         * `CfnAnalysis.ParameterListControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterlistcontrol.html#cfn-quicksight-analysis-parameterlistcontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html
     */
    interface ParameterSelectableValuesProperty {
        /**
         * `CfnAnalysis.ParameterSelectableValuesProperty.LinkToDataSetColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-linktodatasetcolumn
         */
        readonly linkToDataSetColumn?: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterSelectableValuesProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterselectablevalues.html#cfn-quicksight-analysis-parameterselectablevalues-values
         */
        readonly values?: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html
     */
    interface ParameterSliderControlProperty {
        /**
         * `CfnAnalysis.ParameterSliderControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.SliderControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterSliderControlProperty.MaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * `CfnAnalysis.ParameterSliderControlProperty.MinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * `CfnAnalysis.ParameterSliderControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnAnalysis.ParameterSliderControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnAnalysis.ParameterSliderControlProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * `CfnAnalysis.ParameterSliderControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameterslidercontrol.html#cfn-quicksight-analysis-parameterslidercontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html
     */
    interface ParameterTextAreaControlProperty {
        /**
         * `CfnAnalysis.ParameterTextAreaControlProperty.Delimiter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * `CfnAnalysis.ParameterTextAreaControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.TextAreaControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterTextAreaControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnAnalysis.ParameterTextAreaControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnAnalysis.ParameterTextAreaControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextareacontrol.html#cfn-quicksight-analysis-parametertextareacontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html
     */
    interface ParameterTextFieldControlProperty {
        /**
         * `CfnAnalysis.ParameterTextFieldControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: CfnAnalysis.TextFieldControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ParameterTextFieldControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnAnalysis.ParameterTextFieldControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnAnalysis.ParameterTextFieldControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parametertextfieldcontrol.html#cfn-quicksight-analysis-parametertextfieldcontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     * A list of Amazon QuickSight parameters and the list's override values.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html
     */
    interface ParametersProperty {
        /**
         * The parameters that have a data type of date-time.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-datetimeparameters
         */
        readonly dateTimeParameters?: Array<CfnAnalysis.DateTimeParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of decimal.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-decimalparameters
         */
        readonly decimalParameters?: Array<CfnAnalysis.DecimalParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of integer.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-integerparameters
         */
        readonly integerParameters?: Array<CfnAnalysis.IntegerParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of string.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-parameters.html#cfn-quicksight-analysis-parameters-stringparameters
         */
        readonly stringParameters?: Array<CfnAnalysis.StringParameterProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html
     */
    interface PercentVisibleRangeProperty {
        /**
         * `CfnAnalysis.PercentVisibleRangeProperty.From`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-from
         */
        readonly from?: number;
        /**
         * `CfnAnalysis.PercentVisibleRangeProperty.To`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentvisiblerange.html#cfn-quicksight-analysis-percentvisiblerange-to
         */
        readonly to?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html
     */
    interface PercentageDisplayFormatConfigurationProperty {
        /**
         * `CfnAnalysis.PercentageDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnAnalysis.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PercentageDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnAnalysis.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PercentageDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnAnalysis.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PercentageDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnAnalysis.PercentageDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnAnalysis.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PercentageDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentagedisplayformatconfiguration.html#cfn-quicksight-analysis-percentagedisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html
     */
    interface PercentileAggregationProperty {
        /**
         * `CfnAnalysis.PercentileAggregationProperty.PercentileValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-percentileaggregation.html#cfn-quicksight-analysis-percentileaggregation-percentilevalue
         */
        readonly percentileValue?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html
     */
    interface PeriodOverPeriodComputationProperty {
        /**
         * `CfnAnalysis.PeriodOverPeriodComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.PeriodOverPeriodComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.PeriodOverPeriodComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-time
         */
        readonly time: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PeriodOverPeriodComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodoverperiodcomputation.html#cfn-quicksight-analysis-periodoverperiodcomputation-value
         */
        readonly value?: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html
     */
    interface PeriodToDateComputationProperty {
        /**
         * `CfnAnalysis.PeriodToDateComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.PeriodToDateComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.PeriodToDateComputationProperty.PeriodTimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-periodtimegranularity
         */
        readonly periodTimeGranularity?: string;
        /**
         * `CfnAnalysis.PeriodToDateComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-time
         */
        readonly time: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PeriodToDateComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-periodtodatecomputation.html#cfn-quicksight-analysis-periodtodatecomputation-value
         */
        readonly value?: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html
     */
    interface PieChartAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.PieChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartaggregatedfieldwells.html#cfn-quicksight-analysis-piechartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html
     */
    interface PieChartConfigurationProperty {
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnAnalysis.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.DonutOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-donutoptions
         */
        readonly donutOptions?: CfnAnalysis.DonutOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.PieChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnAnalysis.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.PieChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartconfiguration.html#cfn-quicksight-analysis-piechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html
     */
    interface PieChartFieldWellsProperty {
        /**
         * `CfnAnalysis.PieChartFieldWellsProperty.PieChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartfieldwells.html#cfn-quicksight-analysis-piechartfieldwells-piechartaggregatedfieldwells
         */
        readonly pieChartAggregatedFieldWells?: CfnAnalysis.PieChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html
     */
    interface PieChartSortConfigurationProperty {
        /**
         * `CfnAnalysis.PieChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartsortconfiguration.html#cfn-quicksight-analysis-piechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html
     */
    interface PieChartVisualProperty {
        /**
         * `CfnAnalysis.PieChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.PieChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PieChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-piechartvisual.html#cfn-quicksight-analysis-piechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html
     */
    interface PivotFieldSortOptionsProperty {
        /**
         * `CfnAnalysis.PivotFieldSortOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.PivotFieldSortOptionsProperty.SortBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivotfieldsortoptions.html#cfn-quicksight-analysis-pivotfieldsortoptions-sortby
         */
        readonly sortBy: CfnAnalysis.PivotTableSortByProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html
     */
    interface PivotTableAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.PivotTableAggregatedFieldWellsProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableAggregatedFieldWellsProperty.Rows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableaggregatedfieldwells.html#cfn-quicksight-analysis-pivottableaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html
     */
    interface PivotTableCellConditionalFormattingProperty {
        /**
         * `CfnAnalysis.PivotTableCellConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.PivotTableCellConditionalFormattingProperty.Scope`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-scope
         */
        readonly scope?: CfnAnalysis.PivotTableConditionalFormattingScopeProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableCellConditionalFormattingProperty.TextFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablecellconditionalformatting.html#cfn-quicksight-analysis-pivottablecellconditionalformatting-textformat
         */
        readonly textFormat?: CfnAnalysis.TextConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html
     */
    interface PivotTableConditionalFormattingProperty {
        /**
         * `CfnAnalysis.PivotTableConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformatting.html#cfn-quicksight-analysis-pivottableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnAnalysis.PivotTableConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html
     */
    interface PivotTableConditionalFormattingOptionProperty {
        /**
         * `CfnAnalysis.PivotTableConditionalFormattingOptionProperty.Cell`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingoption.html#cfn-quicksight-analysis-pivottableconditionalformattingoption-cell
         */
        readonly cell?: CfnAnalysis.PivotTableCellConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html
     */
    interface PivotTableConditionalFormattingScopeProperty {
        /**
         * `CfnAnalysis.PivotTableConditionalFormattingScopeProperty.Role`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconditionalformattingscope.html#cfn-quicksight-analysis-pivottableconditionalformattingscope-role
         */
        readonly role?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html
     */
    interface PivotTableConfigurationProperty {
        /**
         * `CfnAnalysis.PivotTableConfigurationProperty.FieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldoptions
         */
        readonly fieldOptions?: CfnAnalysis.PivotTableFieldOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.PivotTableFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableConfigurationProperty.PaginatedReportOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: CfnAnalysis.PivotTablePaginatedReportOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.PivotTableSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableConfigurationProperty.TableOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-tableoptions
         */
        readonly tableOptions?: CfnAnalysis.PivotTableOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableConfigurationProperty.TotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableconfiguration.html#cfn-quicksight-analysis-pivottableconfiguration-totaloptions
         */
        readonly totalOptions?: CfnAnalysis.PivotTableTotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html
     */
    interface PivotTableDataPathOptionProperty {
        /**
         * `CfnAnalysis.PivotTableDataPathOptionProperty.DataPathList`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-datapathlist
         */
        readonly dataPathList: Array<CfnAnalysis.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableDataPathOptionProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabledatapathoption.html#cfn-quicksight-analysis-pivottabledatapathoption-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html
     */
    interface PivotTableFieldOptionProperty {
        /**
         * `CfnAnalysis.PivotTableFieldOptionProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnAnalysis.PivotTableFieldOptionProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.PivotTableFieldOptionProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoption.html#cfn-quicksight-analysis-pivottablefieldoption-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html
     */
    interface PivotTableFieldOptionsProperty {
        /**
         * `CfnAnalysis.PivotTableFieldOptionsProperty.DataPathOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-datapathoptions
         */
        readonly dataPathOptions?: Array<CfnAnalysis.PivotTableDataPathOptionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableFieldOptionsProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldoptions.html#cfn-quicksight-analysis-pivottablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<CfnAnalysis.PivotTableFieldOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html
     */
    interface PivotTableFieldSubtotalOptionsProperty {
        /**
         * `CfnAnalysis.PivotTableFieldSubtotalOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldsubtotaloptions.html#cfn-quicksight-analysis-pivottablefieldsubtotaloptions-fieldid
         */
        readonly fieldId?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html
     */
    interface PivotTableFieldWellsProperty {
        /**
         * `CfnAnalysis.PivotTableFieldWellsProperty.PivotTableAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablefieldwells.html#cfn-quicksight-analysis-pivottablefieldwells-pivottableaggregatedfieldwells
         */
        readonly pivotTableAggregatedFieldWells?: CfnAnalysis.PivotTableAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html
     */
    interface PivotTableOptionsProperty {
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.CellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-cellstyle
         */
        readonly cellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.ColumnHeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnheaderstyle
         */
        readonly columnHeaderStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.ColumnNamesVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-columnnamesvisibility
         */
        readonly columnNamesVisibility?: string;
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.MetricPlacement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-metricplacement
         */
        readonly metricPlacement?: string;
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.RowAlternateColorOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: CfnAnalysis.RowAlternateColorOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.RowFieldNamesStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowfieldnamesstyle
         */
        readonly rowFieldNamesStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.RowHeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-rowheaderstyle
         */
        readonly rowHeaderStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.SingleMetricVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-singlemetricvisibility
         */
        readonly singleMetricVisibility?: string;
        /**
         * `CfnAnalysis.PivotTableOptionsProperty.ToggleButtonsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottableoptions.html#cfn-quicksight-analysis-pivottableoptions-togglebuttonsvisibility
         */
        readonly toggleButtonsVisibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html
     */
    interface PivotTablePaginatedReportOptionsProperty {
        /**
         * `CfnAnalysis.PivotTablePaginatedReportOptionsProperty.OverflowColumnHeaderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * `CfnAnalysis.PivotTablePaginatedReportOptionsProperty.VerticalOverflowVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablepaginatedreportoptions.html#cfn-quicksight-analysis-pivottablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html
     */
    interface PivotTableSortByProperty {
        /**
         * `CfnAnalysis.PivotTableSortByProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-column
         */
        readonly column?: CfnAnalysis.ColumnSortProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableSortByProperty.DataPath`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-datapath
         */
        readonly dataPath?: CfnAnalysis.DataPathSortProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableSortByProperty.Field`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortby.html#cfn-quicksight-analysis-pivottablesortby-field
         */
        readonly field?: CfnAnalysis.FieldSortProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html
     */
    interface PivotTableSortConfigurationProperty {
        /**
         * `CfnAnalysis.PivotTableSortConfigurationProperty.FieldSortOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablesortconfiguration.html#cfn-quicksight-analysis-pivottablesortconfiguration-fieldsortoptions
         */
        readonly fieldSortOptions?: Array<CfnAnalysis.PivotFieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html
     */
    interface PivotTableTotalOptionsProperty {
        /**
         * `CfnAnalysis.PivotTableTotalOptionsProperty.ColumnSubtotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columnsubtotaloptions
         */
        readonly columnSubtotalOptions?: CfnAnalysis.SubtotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableTotalOptionsProperty.ColumnTotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-columntotaloptions
         */
        readonly columnTotalOptions?: CfnAnalysis.PivotTotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableTotalOptionsProperty.RowSubtotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowsubtotaloptions
         */
        readonly rowSubtotalOptions?: CfnAnalysis.SubtotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableTotalOptionsProperty.RowTotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottabletotaloptions.html#cfn-quicksight-analysis-pivottabletotaloptions-rowtotaloptions
         */
        readonly rowTotalOptions?: CfnAnalysis.PivotTotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html
     */
    interface PivotTableVisualProperty {
        /**
         * `CfnAnalysis.PivotTableVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.PivotTableConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnAnalysis.PivotTableConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTableVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottablevisual.html#cfn-quicksight-analysis-pivottablevisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html
     */
    interface PivotTotalOptionsProperty {
        /**
         * `CfnAnalysis.PivotTotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnAnalysis.PivotTotalOptionsProperty.MetricHeaderCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTotalOptionsProperty.Placement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-placement
         */
        readonly placement?: string;
        /**
         * `CfnAnalysis.PivotTotalOptionsProperty.ScrollStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * `CfnAnalysis.PivotTotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.PivotTotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * `CfnAnalysis.PivotTotalOptionsProperty.ValueCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-pivottotaloptions.html#cfn-quicksight-analysis-pivottotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html
     */
    interface PredefinedHierarchyProperty {
        /**
         * `CfnAnalysis.PredefinedHierarchyProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-columns
         */
        readonly columns: Array<CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PredefinedHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnAnalysis.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.PredefinedHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-predefinedhierarchy.html#cfn-quicksight-analysis-predefinedhierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html
     */
    interface ProgressBarOptionsProperty {
        /**
         * `CfnAnalysis.ProgressBarOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-progressbaroptions.html#cfn-quicksight-analysis-progressbaroptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html
     */
    interface RadarChartAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.RadarChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartAggregatedFieldWellsProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-color
         */
        readonly color?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartaggregatedfieldwells.html#cfn-quicksight-analysis-radarchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html
     */
    interface RadarChartAreaStyleSettingsProperty {
        /**
         * `CfnAnalysis.RadarChartAreaStyleSettingsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartareastylesettings.html#cfn-quicksight-analysis-radarchartareastylesettings-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html
     */
    interface RadarChartConfigurationProperty {
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.AlternateBandColorsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandcolorsvisibility
         */
        readonly alternateBandColorsVisibility?: string;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.AlternateBandEvenColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandevencolor
         */
        readonly alternateBandEvenColor?: string;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.AlternateBandOddColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-alternatebandoddcolor
         */
        readonly alternateBandOddColor?: string;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.BaseSeriesSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-baseseriessettings
         */
        readonly baseSeriesSettings?: CfnAnalysis.RadarChartSeriesSettingsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.ColorAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-coloraxis
         */
        readonly colorAxis?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.RadarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.Shape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-shape
         */
        readonly shape?: string;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.RadarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.StartAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-startangle
         */
        readonly startAngle?: number;
        /**
         * `CfnAnalysis.RadarChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartconfiguration.html#cfn-quicksight-analysis-radarchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html
     */
    interface RadarChartFieldWellsProperty {
        /**
         * `CfnAnalysis.RadarChartFieldWellsProperty.RadarChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartfieldwells.html#cfn-quicksight-analysis-radarchartfieldwells-radarchartaggregatedfieldwells
         */
        readonly radarChartAggregatedFieldWells?: CfnAnalysis.RadarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html
     */
    interface RadarChartSeriesSettingsProperty {
        /**
         * `CfnAnalysis.RadarChartSeriesSettingsProperty.AreaStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartseriessettings.html#cfn-quicksight-analysis-radarchartseriessettings-areastylesettings
         */
        readonly areaStyleSettings?: CfnAnalysis.RadarChartAreaStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html
     */
    interface RadarChartSortConfigurationProperty {
        /**
         * `CfnAnalysis.RadarChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartsortconfiguration.html#cfn-quicksight-analysis-radarchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html
     */
    interface RadarChartVisualProperty {
        /**
         * `CfnAnalysis.RadarChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.RadarChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RadarChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-radarchartvisual.html#cfn-quicksight-analysis-radarchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html
     */
    interface RangeEndsLabelTypeProperty {
        /**
         * `CfnAnalysis.RangeEndsLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rangeendslabeltype.html#cfn-quicksight-analysis-rangeendslabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html
     */
    interface ReferenceLineProperty {
        /**
         * `CfnAnalysis.ReferenceLineProperty.DataConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-dataconfiguration
         */
        readonly dataConfiguration: CfnAnalysis.ReferenceLineDataConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineProperty.LabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-labelconfiguration
         */
        readonly labelConfiguration?: CfnAnalysis.ReferenceLineLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-status
         */
        readonly status?: string;
        /**
         * `CfnAnalysis.ReferenceLineProperty.StyleConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referenceline.html#cfn-quicksight-analysis-referenceline-styleconfiguration
         */
        readonly styleConfiguration?: CfnAnalysis.ReferenceLineStyleConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html
     */
    interface ReferenceLineCustomLabelConfigurationProperty {
        /**
         * `CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinecustomlabelconfiguration.html#cfn-quicksight-analysis-referencelinecustomlabelconfiguration-customlabel
         */
        readonly customLabel: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html
     */
    interface ReferenceLineDataConfigurationProperty {
        /**
         * `CfnAnalysis.ReferenceLineDataConfigurationProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * `CfnAnalysis.ReferenceLineDataConfigurationProperty.DynamicConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-dynamicconfiguration
         */
        readonly dynamicConfiguration?: CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineDataConfigurationProperty.StaticConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedataconfiguration.html#cfn-quicksight-analysis-referencelinedataconfiguration-staticconfiguration
         */
        readonly staticConfiguration?: CfnAnalysis.ReferenceLineStaticDataConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html
     */
    interface ReferenceLineDynamicDataConfigurationProperty {
        /**
         * `CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty.Calculation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-calculation
         */
        readonly calculation: CfnAnalysis.NumericalAggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineDynamicDataConfigurationProperty.MeasureAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinedynamicdataconfiguration.html#cfn-quicksight-analysis-referencelinedynamicdataconfiguration-measureaggregationfunction
         */
        readonly measureAggregationFunction: CfnAnalysis.AggregationFunctionProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html
     */
    interface ReferenceLineLabelConfigurationProperty {
        /**
         * `CfnAnalysis.ReferenceLineLabelConfigurationProperty.CustomLabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-customlabelconfiguration
         */
        readonly customLabelConfiguration?: CfnAnalysis.ReferenceLineCustomLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineLabelConfigurationProperty.FontColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * `CfnAnalysis.ReferenceLineLabelConfigurationProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineLabelConfigurationProperty.HorizontalPosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-horizontalposition
         */
        readonly horizontalPosition?: string;
        /**
         * `CfnAnalysis.ReferenceLineLabelConfigurationProperty.ValueLabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-valuelabelconfiguration
         */
        readonly valueLabelConfiguration?: CfnAnalysis.ReferenceLineValueLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineLabelConfigurationProperty.VerticalPosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinelabelconfiguration.html#cfn-quicksight-analysis-referencelinelabelconfiguration-verticalposition
         */
        readonly verticalPosition?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html
     */
    interface ReferenceLineStaticDataConfigurationProperty {
        /**
         * `CfnAnalysis.ReferenceLineStaticDataConfigurationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestaticdataconfiguration.html#cfn-quicksight-analysis-referencelinestaticdataconfiguration-value
         */
        readonly value: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html
     */
    interface ReferenceLineStyleConfigurationProperty {
        /**
         * `CfnAnalysis.ReferenceLineStyleConfigurationProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-color
         */
        readonly color?: string;
        /**
         * `CfnAnalysis.ReferenceLineStyleConfigurationProperty.Pattern`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinestyleconfiguration.html#cfn-quicksight-analysis-referencelinestyleconfiguration-pattern
         */
        readonly pattern?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html
     */
    interface ReferenceLineValueLabelConfigurationProperty {
        /**
         * `CfnAnalysis.ReferenceLineValueLabelConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.NumericFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ReferenceLineValueLabelConfigurationProperty.RelativePosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-referencelinevaluelabelconfiguration.html#cfn-quicksight-analysis-referencelinevaluelabelconfiguration-relativeposition
         */
        readonly relativePosition?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html
     */
    interface RelativeDateTimeControlDisplayOptionsProperty {
        /**
         * `CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnAnalysis.RelativeDateTimeControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatetimecontroldisplayoptions.html#cfn-quicksight-analysis-relativedatetimecontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html
     */
    interface RelativeDatesFilterProperty {
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.AnchorDateConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-anchordateconfiguration
         */
        readonly anchorDateConfiguration: CfnAnalysis.AnchorDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.ExcludePeriodConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnAnalysis.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.MinimumGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-minimumgranularity
         */
        readonly minimumGranularity?: string;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.RelativeDateType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatetype
         */
        readonly relativeDateType: string;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.RelativeDateValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-relativedatevalue
         */
        readonly relativeDateValue?: number;
        /**
         * `CfnAnalysis.RelativeDatesFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-relativedatesfilter.html#cfn-quicksight-analysis-relativedatesfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-actions
         */
        readonly actions: string[];
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-principal
         */
        readonly principal: string;
        /**
         * `CfnAnalysis.ResourcePermissionProperty.Resource`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-resourcepermission.html#cfn-quicksight-analysis-resourcepermission-resource
         */
        readonly resource?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html
     */
    interface RollingDateConfigurationProperty {
        /**
         * `CfnAnalysis.RollingDateConfigurationProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-datasetidentifier
         */
        readonly dataSetIdentifier?: string;
        /**
         * `CfnAnalysis.RollingDateConfigurationProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rollingdateconfiguration.html#cfn-quicksight-analysis-rollingdateconfiguration-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html
     */
    interface RowAlternateColorOptionsProperty {
        /**
         * `CfnAnalysis.RowAlternateColorOptionsProperty.RowAlternateColors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-rowalternatecolors
         */
        readonly rowAlternateColors?: string[];
        /**
         * `CfnAnalysis.RowAlternateColorOptionsProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-rowalternatecoloroptions.html#cfn-quicksight-analysis-rowalternatecoloroptions-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html
     */
    interface SameSheetTargetVisualConfigurationProperty {
        /**
         * `CfnAnalysis.SameSheetTargetVisualConfigurationProperty.TargetVisualOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisualoptions
         */
        readonly targetVisualOptions?: string;
        /**
         * `CfnAnalysis.SameSheetTargetVisualConfigurationProperty.TargetVisuals`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-samesheettargetvisualconfiguration.html#cfn-quicksight-analysis-samesheettargetvisualconfiguration-targetvisuals
         */
        readonly targetVisuals?: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html
     */
    interface SankeyDiagramAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty.Destination`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-destination
         */
        readonly destination?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty.Source`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-source
         */
        readonly source?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty.Weight`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-analysis-sankeydiagramaggregatedfieldwells-weight
         */
        readonly weight?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html
     */
    interface SankeyDiagramChartConfigurationProperty {
        /**
         * `CfnAnalysis.SankeyDiagramChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.SankeyDiagramFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramchartconfiguration.html#cfn-quicksight-analysis-sankeydiagramchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.SankeyDiagramSortConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html
     */
    interface SankeyDiagramFieldWellsProperty {
        /**
         * `CfnAnalysis.SankeyDiagramFieldWellsProperty.SankeyDiagramAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramfieldwells.html#cfn-quicksight-analysis-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
         */
        readonly sankeyDiagramAggregatedFieldWells?: CfnAnalysis.SankeyDiagramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html
     */
    interface SankeyDiagramSortConfigurationProperty {
        /**
         * `CfnAnalysis.SankeyDiagramSortConfigurationProperty.DestinationItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-destinationitemslimit
         */
        readonly destinationItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramSortConfigurationProperty.SourceItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-sourceitemslimit
         */
        readonly sourceItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramSortConfigurationProperty.WeightSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramsortconfiguration.html#cfn-quicksight-analysis-sankeydiagramsortconfiguration-weightsort
         */
        readonly weightSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html
     */
    interface SankeyDiagramVisualProperty {
        /**
         * `CfnAnalysis.SankeyDiagramVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.SankeyDiagramChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SankeyDiagramVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sankeydiagramvisual.html#cfn-quicksight-analysis-sankeydiagramvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html
     */
    interface ScatterPlotCategoricallyAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-category
         */
        readonly category?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-size
         */
        readonly size?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty.XAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty.YAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotcategoricallyaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html
     */
    interface ScatterPlotConfigurationProperty {
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.ScatterPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.YAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotConfigurationProperty.YAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotconfiguration.html#cfn-quicksight-analysis-scatterplotconfiguration-yaxislabeloptions
         */
        readonly yAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html
     */
    interface ScatterPlotFieldWellsProperty {
        /**
         * `CfnAnalysis.ScatterPlotFieldWellsProperty.ScatterPlotCategoricallyAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
         */
        readonly scatterPlotCategoricallyAggregatedFieldWells?: CfnAnalysis.ScatterPlotCategoricallyAggregatedFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotFieldWellsProperty.ScatterPlotUnaggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotfieldwells.html#cfn-quicksight-analysis-scatterplotfieldwells-scatterplotunaggregatedfieldwells
         */
        readonly scatterPlotUnaggregatedFieldWells?: CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html
     */
    interface ScatterPlotUnaggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-size
         */
        readonly size?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty.XAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotUnaggregatedFieldWellsProperty.YAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotunaggregatedfieldwells.html#cfn-quicksight-analysis-scatterplotunaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html
     */
    interface ScatterPlotVisualProperty {
        /**
         * `CfnAnalysis.ScatterPlotVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.ScatterPlotConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.ScatterPlotVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scatterplotvisual.html#cfn-quicksight-analysis-scatterplotvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html
     */
    interface ScrollBarOptionsProperty {
        /**
         * `CfnAnalysis.ScrollBarOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnAnalysis.ScrollBarOptionsProperty.VisibleRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-scrollbaroptions.html#cfn-quicksight-analysis-scrollbaroptions-visiblerange
         */
        readonly visibleRange?: CfnAnalysis.VisibleRangeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html
     */
    interface SecondaryValueOptionsProperty {
        /**
         * `CfnAnalysis.SecondaryValueOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-secondaryvalueoptions.html#cfn-quicksight-analysis-secondaryvalueoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html
     */
    interface SectionAfterPageBreakProperty {
        /**
         * `CfnAnalysis.SectionAfterPageBreakProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionafterpagebreak.html#cfn-quicksight-analysis-sectionafterpagebreak-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html
     */
    interface SectionBasedLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty.PaperCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
         */
        readonly paperCanvasSizeOptions?: CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html
     */
    interface SectionBasedLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.SectionBasedLayoutConfigurationProperty.BodySections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-bodysections
         */
        readonly bodySections: Array<CfnAnalysis.BodySectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SectionBasedLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnAnalysis.SectionBasedLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SectionBasedLayoutConfigurationProperty.FooterSections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-footersections
         */
        readonly footerSections: Array<CfnAnalysis.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SectionBasedLayoutConfigurationProperty.HeaderSections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutconfiguration.html#cfn-quicksight-analysis-sectionbasedlayoutconfiguration-headersections
         */
        readonly headerSections: Array<CfnAnalysis.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html
     */
    interface SectionBasedLayoutPaperCanvasSizeOptionsProperty {
        /**
         * `CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperMargin`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papermargin
         */
        readonly paperMargin?: CfnAnalysis.SpacingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperOrientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-paperorientation
         */
        readonly paperOrientation?: string;
        /**
         * `CfnAnalysis.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-analysis-sectionbasedlayoutpapercanvassizeoptions-papersize
         */
        readonly paperSize?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html
     */
    interface SectionLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.SectionLayoutConfigurationProperty.FreeFormLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionlayoutconfiguration.html#cfn-quicksight-analysis-sectionlayoutconfiguration-freeformlayout
         */
        readonly freeFormLayout: CfnAnalysis.FreeFormSectionLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html
     */
    interface SectionPageBreakConfigurationProperty {
        /**
         * `CfnAnalysis.SectionPageBreakConfigurationProperty.After`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionpagebreakconfiguration.html#cfn-quicksight-analysis-sectionpagebreakconfiguration-after
         */
        readonly after?: CfnAnalysis.SectionAfterPageBreakProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html
     */
    interface SectionStyleProperty {
        /**
         * `CfnAnalysis.SectionStyleProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-height
         */
        readonly height?: string;
        /**
         * `CfnAnalysis.SectionStyleProperty.Padding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sectionstyle.html#cfn-quicksight-analysis-sectionstyle-padding
         */
        readonly padding?: CfnAnalysis.SpacingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html
     */
    interface SelectedSheetsFilterScopeConfigurationProperty {
        /**
         * `CfnAnalysis.SelectedSheetsFilterScopeConfigurationProperty.SheetVisualScopingConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-analysis-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
         */
        readonly sheetVisualScopingConfigurations?: Array<CfnAnalysis.SheetVisualScopingConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html
     */
    interface SeriesItemProperty {
        /**
         * `CfnAnalysis.SeriesItemProperty.DataFieldSeriesItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-datafieldseriesitem
         */
        readonly dataFieldSeriesItem?: CfnAnalysis.DataFieldSeriesItemProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SeriesItemProperty.FieldSeriesItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-seriesitem.html#cfn-quicksight-analysis-seriesitem-fieldseriesitem
         */
        readonly fieldSeriesItem?: CfnAnalysis.FieldSeriesItemProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html
     */
    interface SetParameterValueConfigurationProperty {
        /**
         * `CfnAnalysis.SetParameterValueConfigurationProperty.DestinationParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-destinationparametername
         */
        readonly destinationParameterName: string;
        /**
         * `CfnAnalysis.SetParameterValueConfigurationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-setparametervalueconfiguration.html#cfn-quicksight-analysis-setparametervalueconfiguration-value
         */
        readonly value: CfnAnalysis.DestinationParameterValueConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html
     */
    interface ShapeConditionalFormatProperty {
        /**
         * `CfnAnalysis.ShapeConditionalFormatProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shapeconditionalformat.html#cfn-quicksight-analysis-shapeconditionalformat-backgroundcolor
         */
        readonly backgroundColor: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     * A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight. Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html
     */
    interface SheetProperty {
        /**
         * The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-name
         */
        readonly name?: string;
        /**
         * The unique identifier associated with a sheet.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheet.html#cfn-quicksight-analysis-sheet-sheetid
         */
        readonly sheetId?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html
     */
    interface SheetControlLayoutProperty {
        /**
         * `CfnAnalysis.SheetControlLayoutProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayout.html#cfn-quicksight-analysis-sheetcontrollayout-configuration
         */
        readonly configuration: CfnAnalysis.SheetControlLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html
     */
    interface SheetControlLayoutConfigurationProperty {
        /**
         * `CfnAnalysis.SheetControlLayoutConfigurationProperty.GridLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetcontrollayoutconfiguration.html#cfn-quicksight-analysis-sheetcontrollayoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnAnalysis.GridLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html
     */
    interface SheetDefinitionProperty {
        /**
         * `CfnAnalysis.SheetDefinitionProperty.ContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-contenttype
         */
        readonly contentType?: string;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.Description`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-description
         */
        readonly description?: string;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.FilterControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-filtercontrols
         */
        readonly filterControls?: Array<CfnAnalysis.FilterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.Layouts`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-layouts
         */
        readonly layouts?: Array<CfnAnalysis.LayoutProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.ParameterControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-parametercontrols
         */
        readonly parameterControls?: Array<CfnAnalysis.ParameterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.SheetControlLayouts`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetcontrollayouts
         */
        readonly sheetControlLayouts?: Array<CfnAnalysis.SheetControlLayoutProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.SheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-sheetid
         */
        readonly sheetId: string;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.TextBoxes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-textboxes
         */
        readonly textBoxes?: Array<CfnAnalysis.SheetTextBoxProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-title
         */
        readonly title?: string;
        /**
         * `CfnAnalysis.SheetDefinitionProperty.Visuals`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetdefinition.html#cfn-quicksight-analysis-sheetdefinition-visuals
         */
        readonly visuals?: Array<CfnAnalysis.VisualProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html
     */
    interface SheetElementConfigurationOverridesProperty {
        /**
         * `CfnAnalysis.SheetElementConfigurationOverridesProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementconfigurationoverrides.html#cfn-quicksight-analysis-sheetelementconfigurationoverrides-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html
     */
    interface SheetElementRenderingRuleProperty {
        /**
         * `CfnAnalysis.SheetElementRenderingRuleProperty.ConfigurationOverrides`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-configurationoverrides
         */
        readonly configurationOverrides: CfnAnalysis.SheetElementConfigurationOverridesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SheetElementRenderingRuleProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetelementrenderingrule.html#cfn-quicksight-analysis-sheetelementrenderingrule-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html
     */
    interface SheetTextBoxProperty {
        /**
         * `CfnAnalysis.SheetTextBoxProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-content
         */
        readonly content?: string;
        /**
         * `CfnAnalysis.SheetTextBoxProperty.SheetTextBoxId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheettextbox.html#cfn-quicksight-analysis-sheettextbox-sheettextboxid
         */
        readonly sheetTextBoxId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html
     */
    interface SheetVisualScopingConfigurationProperty {
        /**
         * `CfnAnalysis.SheetVisualScopingConfigurationProperty.Scope`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-scope
         */
        readonly scope: string;
        /**
         * `CfnAnalysis.SheetVisualScopingConfigurationProperty.SheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-sheetid
         */
        readonly sheetId: string;
        /**
         * `CfnAnalysis.SheetVisualScopingConfigurationProperty.VisualIds`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-sheetvisualscopingconfiguration.html#cfn-quicksight-analysis-sheetvisualscopingconfiguration-visualids
         */
        readonly visualIds?: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html
     */
    interface ShortFormatTextProperty {
        /**
         * `CfnAnalysis.ShortFormatTextProperty.PlainText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * `CfnAnalysis.ShortFormatTextProperty.RichText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-shortformattext.html#cfn-quicksight-analysis-shortformattext-richtext
         */
        readonly richText?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html
     */
    interface SimpleClusterMarkerProperty {
        /**
         * `CfnAnalysis.SimpleClusterMarkerProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-simpleclustermarker.html#cfn-quicksight-analysis-simpleclustermarker-color
         */
        readonly color?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html
     */
    interface SliderControlDisplayOptionsProperty {
        /**
         * `CfnAnalysis.SliderControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-slidercontroldisplayoptions.html#cfn-quicksight-analysis-slidercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html
     */
    interface SmallMultiplesOptionsProperty {
        /**
         * `CfnAnalysis.SmallMultiplesOptionsProperty.MaxVisibleColumns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblecolumns
         */
        readonly maxVisibleColumns?: number;
        /**
         * `CfnAnalysis.SmallMultiplesOptionsProperty.MaxVisibleRows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-maxvisiblerows
         */
        readonly maxVisibleRows?: number;
        /**
         * `CfnAnalysis.SmallMultiplesOptionsProperty.PanelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-smallmultiplesoptions.html#cfn-quicksight-analysis-smallmultiplesoptions-panelconfiguration
         */
        readonly panelConfiguration?: CfnAnalysis.PanelConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html
     */
    interface SpacingProperty {
        /**
         * `CfnAnalysis.SpacingProperty.Bottom`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-bottom
         */
        readonly bottom?: string;
        /**
         * `CfnAnalysis.SpacingProperty.Left`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-left
         */
        readonly left?: string;
        /**
         * `CfnAnalysis.SpacingProperty.Right`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-right
         */
        readonly right?: string;
        /**
         * `CfnAnalysis.SpacingProperty.Top`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-spacing.html#cfn-quicksight-analysis-spacing-top
         */
        readonly top?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html
     */
    interface StringDefaultValuesProperty {
        /**
         * `CfnAnalysis.StringDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnAnalysis.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.StringDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringdefaultvalues.html#cfn-quicksight-analysis-stringdefaultvalues-staticvalues
         */
        readonly staticValues?: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html
     */
    interface StringFormatConfigurationProperty {
        /**
         * `CfnAnalysis.StringFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnAnalysis.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.StringFormatConfigurationProperty.NumericFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringformatconfiguration.html#cfn-quicksight-analysis-stringformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: CfnAnalysis.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     * A string parameter.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html
     */
    interface StringParameterProperty {
        /**
         * A display name for a string parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-name
         */
        readonly name: string;
        /**
         * The values of a string parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameter.html#cfn-quicksight-analysis-stringparameter-values
         */
        readonly values: string[];
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html
     */
    interface StringParameterDeclarationProperty {
        /**
         * `CfnAnalysis.StringParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnAnalysis.StringDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.StringParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnAnalysis.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.StringParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnAnalysis.StringParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnAnalysis.StringParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringparameterdeclaration.html#cfn-quicksight-analysis-stringparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnAnalysis.StringValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html
     */
    interface StringValueWhenUnsetConfigurationProperty {
        /**
         * `CfnAnalysis.StringValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * `CfnAnalysis.StringValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-stringvaluewhenunsetconfiguration.html#cfn-quicksight-analysis-stringvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html
     */
    interface SubtotalOptionsProperty {
        /**
         * `CfnAnalysis.SubtotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnAnalysis.SubtotalOptionsProperty.FieldLevel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldlevel
         */
        readonly fieldLevel?: string;
        /**
         * `CfnAnalysis.SubtotalOptionsProperty.FieldLevelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-fieldleveloptions
         */
        readonly fieldLevelOptions?: Array<CfnAnalysis.PivotTableFieldSubtotalOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.SubtotalOptionsProperty.MetricHeaderCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SubtotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.SubtotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * `CfnAnalysis.SubtotalOptionsProperty.ValueCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-subtotaloptions.html#cfn-quicksight-analysis-subtotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html
     */
    interface TableAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.TableAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableaggregatedfieldwells.html#cfn-quicksight-analysis-tableaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html
     */
    interface TableBorderOptionsProperty {
        /**
         * `CfnAnalysis.TableBorderOptionsProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-color
         */
        readonly color?: string;
        /**
         * `CfnAnalysis.TableBorderOptionsProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-style
         */
        readonly style?: string;
        /**
         * `CfnAnalysis.TableBorderOptionsProperty.Thickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableborderoptions.html#cfn-quicksight-analysis-tableborderoptions-thickness
         */
        readonly thickness?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html
     */
    interface TableCellConditionalFormattingProperty {
        /**
         * `CfnAnalysis.TableCellConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.TableCellConditionalFormattingProperty.TextFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellconditionalformatting.html#cfn-quicksight-analysis-tablecellconditionalformatting-textformat
         */
        readonly textFormat?: CfnAnalysis.TextConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html
     */
    interface TableCellImageSizingConfigurationProperty {
        /**
         * `CfnAnalysis.TableCellImageSizingConfigurationProperty.TableCellImageScalingConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellimagesizingconfiguration.html#cfn-quicksight-analysis-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
         */
        readonly tableCellImageScalingConfiguration?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html
     */
    interface TableCellStyleProperty {
        /**
         * `CfnAnalysis.TableCellStyleProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * `CfnAnalysis.TableCellStyleProperty.Border`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-border
         */
        readonly border?: CfnAnalysis.GlobalTableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableCellStyleProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-fontconfiguration
         */
        readonly fontConfiguration?: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableCellStyleProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-height
         */
        readonly height?: number;
        /**
         * `CfnAnalysis.TableCellStyleProperty.HorizontalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * `CfnAnalysis.TableCellStyleProperty.TextWrap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-textwrap
         */
        readonly textWrap?: string;
        /**
         * `CfnAnalysis.TableCellStyleProperty.VerticalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-verticaltextalignment
         */
        readonly verticalTextAlignment?: string;
        /**
         * `CfnAnalysis.TableCellStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablecellstyle.html#cfn-quicksight-analysis-tablecellstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html
     */
    interface TableConditionalFormattingProperty {
        /**
         * `CfnAnalysis.TableConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformatting.html#cfn-quicksight-analysis-tableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnAnalysis.TableConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html
     */
    interface TableConditionalFormattingOptionProperty {
        /**
         * `CfnAnalysis.TableConditionalFormattingOptionProperty.Cell`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-cell
         */
        readonly cell?: CfnAnalysis.TableCellConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableConditionalFormattingOptionProperty.Row`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconditionalformattingoption.html#cfn-quicksight-analysis-tableconditionalformattingoption-row
         */
        readonly row?: CfnAnalysis.TableRowConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html
     */
    interface TableConfigurationProperty {
        /**
         * `CfnAnalysis.TableConfigurationProperty.FieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldoptions
         */
        readonly fieldOptions?: CfnAnalysis.TableFieldOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.TableFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableConfigurationProperty.PaginatedReportOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: CfnAnalysis.TablePaginatedReportOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.TableSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableConfigurationProperty.TableInlineVisualizations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableinlinevisualizations
         */
        readonly tableInlineVisualizations?: Array<CfnAnalysis.TableInlineVisualizationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableConfigurationProperty.TableOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-tableoptions
         */
        readonly tableOptions?: CfnAnalysis.TableOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableConfigurationProperty.TotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableconfiguration.html#cfn-quicksight-analysis-tableconfiguration-totaloptions
         */
        readonly totalOptions?: CfnAnalysis.TotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html
     */
    interface TableFieldCustomIconContentProperty {
        /**
         * `CfnAnalysis.TableFieldCustomIconContentProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomiconcontent.html#cfn-quicksight-analysis-tablefieldcustomiconcontent-icon
         */
        readonly icon?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html
     */
    interface TableFieldCustomTextContentProperty {
        /**
         * `CfnAnalysis.TableFieldCustomTextContentProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-fontconfiguration
         */
        readonly fontConfiguration: CfnAnalysis.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableFieldCustomTextContentProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldcustomtextcontent.html#cfn-quicksight-analysis-tablefieldcustomtextcontent-value
         */
        readonly value?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html
     */
    interface TableFieldImageConfigurationProperty {
        /**
         * `CfnAnalysis.TableFieldImageConfigurationProperty.SizingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldimageconfiguration.html#cfn-quicksight-analysis-tablefieldimageconfiguration-sizingoptions
         */
        readonly sizingOptions?: CfnAnalysis.TableCellImageSizingConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html
     */
    interface TableFieldLinkConfigurationProperty {
        /**
         * `CfnAnalysis.TableFieldLinkConfigurationProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-content
         */
        readonly content: CfnAnalysis.TableFieldLinkContentConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableFieldLinkConfigurationProperty.Target`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkconfiguration.html#cfn-quicksight-analysis-tablefieldlinkconfiguration-target
         */
        readonly target: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html
     */
    interface TableFieldLinkContentConfigurationProperty {
        /**
         * `CfnAnalysis.TableFieldLinkContentConfigurationProperty.CustomIconContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customiconcontent
         */
        readonly customIconContent?: CfnAnalysis.TableFieldCustomIconContentProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableFieldLinkContentConfigurationProperty.CustomTextContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldlinkcontentconfiguration.html#cfn-quicksight-analysis-tablefieldlinkcontentconfiguration-customtextcontent
         */
        readonly customTextContent?: CfnAnalysis.TableFieldCustomTextContentProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html
     */
    interface TableFieldOptionProperty {
        /**
         * `CfnAnalysis.TableFieldOptionProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnAnalysis.TableFieldOptionProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.TableFieldOptionProperty.URLStyling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-urlstyling
         */
        readonly urlStyling?: CfnAnalysis.TableFieldURLConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableFieldOptionProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnAnalysis.TableFieldOptionProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoption.html#cfn-quicksight-analysis-tablefieldoption-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html
     */
    interface TableFieldOptionsProperty {
        /**
         * `CfnAnalysis.TableFieldOptionsProperty.Order`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-order
         */
        readonly order?: string[];
        /**
         * `CfnAnalysis.TableFieldOptionsProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldoptions.html#cfn-quicksight-analysis-tablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<CfnAnalysis.TableFieldOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html
     */
    interface TableFieldURLConfigurationProperty {
        /**
         * `CfnAnalysis.TableFieldURLConfigurationProperty.ImageConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-imageconfiguration
         */
        readonly imageConfiguration?: CfnAnalysis.TableFieldImageConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableFieldURLConfigurationProperty.LinkConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldurlconfiguration.html#cfn-quicksight-analysis-tablefieldurlconfiguration-linkconfiguration
         */
        readonly linkConfiguration?: CfnAnalysis.TableFieldLinkConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html
     */
    interface TableFieldWellsProperty {
        /**
         * `CfnAnalysis.TableFieldWellsProperty.TableAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableaggregatedfieldwells
         */
        readonly tableAggregatedFieldWells?: CfnAnalysis.TableAggregatedFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableFieldWellsProperty.TableUnaggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablefieldwells.html#cfn-quicksight-analysis-tablefieldwells-tableunaggregatedfieldwells
         */
        readonly tableUnaggregatedFieldWells?: CfnAnalysis.TableUnaggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html
     */
    interface TableInlineVisualizationProperty {
        /**
         * `CfnAnalysis.TableInlineVisualizationProperty.DataBars`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableinlinevisualization.html#cfn-quicksight-analysis-tableinlinevisualization-databars
         */
        readonly dataBars?: CfnAnalysis.DataBarsOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html
     */
    interface TableOptionsProperty {
        /**
         * `CfnAnalysis.TableOptionsProperty.CellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-cellstyle
         */
        readonly cellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableOptionsProperty.HeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-headerstyle
         */
        readonly headerStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableOptionsProperty.Orientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-orientation
         */
        readonly orientation?: string;
        /**
         * `CfnAnalysis.TableOptionsProperty.RowAlternateColorOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableoptions.html#cfn-quicksight-analysis-tableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: CfnAnalysis.RowAlternateColorOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html
     */
    interface TablePaginatedReportOptionsProperty {
        /**
         * `CfnAnalysis.TablePaginatedReportOptionsProperty.OverflowColumnHeaderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * `CfnAnalysis.TablePaginatedReportOptionsProperty.VerticalOverflowVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablepaginatedreportoptions.html#cfn-quicksight-analysis-tablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html
     */
    interface TableRowConditionalFormattingProperty {
        /**
         * `CfnAnalysis.TableRowConditionalFormattingProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-backgroundcolor
         */
        readonly backgroundColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableRowConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablerowconditionalformatting.html#cfn-quicksight-analysis-tablerowconditionalformatting-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html
     */
    interface TableSideBorderOptionsProperty {
        /**
         * `CfnAnalysis.TableSideBorderOptionsProperty.Bottom`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-bottom
         */
        readonly bottom?: CfnAnalysis.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableSideBorderOptionsProperty.InnerHorizontal`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innerhorizontal
         */
        readonly innerHorizontal?: CfnAnalysis.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableSideBorderOptionsProperty.InnerVertical`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-innervertical
         */
        readonly innerVertical?: CfnAnalysis.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableSideBorderOptionsProperty.Left`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-left
         */
        readonly left?: CfnAnalysis.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableSideBorderOptionsProperty.Right`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-right
         */
        readonly right?: CfnAnalysis.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableSideBorderOptionsProperty.Top`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesideborderoptions.html#cfn-quicksight-analysis-tablesideborderoptions-top
         */
        readonly top?: CfnAnalysis.TableBorderOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html
     */
    interface TableSortConfigurationProperty {
        /**
         * `CfnAnalysis.TableSortConfigurationProperty.PaginationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: CfnAnalysis.PaginationConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableSortConfigurationProperty.RowSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablesortconfiguration.html#cfn-quicksight-analysis-tablesortconfiguration-rowsort
         */
        readonly rowSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html
     */
    interface TableUnaggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.TableUnaggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tableunaggregatedfieldwells.html#cfn-quicksight-analysis-tableunaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.UnaggregatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html
     */
    interface TableVisualProperty {
        /**
         * `CfnAnalysis.TableVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.TableConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnAnalysis.TableConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TableVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tablevisual.html#cfn-quicksight-analysis-tablevisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html
     */
    interface TextAreaControlDisplayOptionsProperty {
        /**
         * `CfnAnalysis.TextAreaControlDisplayOptionsProperty.PlaceholderOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: CfnAnalysis.TextControlPlaceholderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TextAreaControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textareacontroldisplayoptions.html#cfn-quicksight-analysis-textareacontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html
     */
    interface TextConditionalFormatProperty {
        /**
         * `CfnAnalysis.TextConditionalFormatProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-backgroundcolor
         */
        readonly backgroundColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TextConditionalFormatProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-icon
         */
        readonly icon?: CfnAnalysis.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TextConditionalFormatProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textconditionalformat.html#cfn-quicksight-analysis-textconditionalformat-textcolor
         */
        readonly textColor?: CfnAnalysis.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html
     */
    interface TextControlPlaceholderOptionsProperty {
        /**
         * `CfnAnalysis.TextControlPlaceholderOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textcontrolplaceholderoptions.html#cfn-quicksight-analysis-textcontrolplaceholderoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html
     */
    interface TextFieldControlDisplayOptionsProperty {
        /**
         * `CfnAnalysis.TextFieldControlDisplayOptionsProperty.PlaceholderOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: CfnAnalysis.TextControlPlaceholderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TextFieldControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-textfieldcontroldisplayoptions.html#cfn-quicksight-analysis-textfieldcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnAnalysis.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html
     */
    interface ThousandSeparatorOptionsProperty {
        /**
         * `CfnAnalysis.ThousandSeparatorOptionsProperty.Symbol`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-symbol
         */
        readonly symbol?: string;
        /**
         * `CfnAnalysis.ThousandSeparatorOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-thousandseparatoroptions.html#cfn-quicksight-analysis-thousandseparatoroptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html
     */
    interface TimeBasedForecastPropertiesProperty {
        /**
         * `CfnAnalysis.TimeBasedForecastPropertiesProperty.LowerBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * `CfnAnalysis.TimeBasedForecastPropertiesProperty.PeriodsBackward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * `CfnAnalysis.TimeBasedForecastPropertiesProperty.PeriodsForward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * `CfnAnalysis.TimeBasedForecastPropertiesProperty.PredictionInterval`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * `CfnAnalysis.TimeBasedForecastPropertiesProperty.Seasonality`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-seasonality
         */
        readonly seasonality?: number;
        /**
         * `CfnAnalysis.TimeBasedForecastPropertiesProperty.UpperBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timebasedforecastproperties.html#cfn-quicksight-analysis-timebasedforecastproperties-upperboundary
         */
        readonly upperBoundary?: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html
     */
    interface TimeEqualityFilterProperty {
        /**
         * `CfnAnalysis.TimeEqualityFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeEqualityFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnAnalysis.TimeEqualityFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnAnalysis.TimeEqualityFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * `CfnAnalysis.TimeEqualityFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timeequalityfilter.html#cfn-quicksight-analysis-timeequalityfilter-value
         */
        readonly value?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html
     */
    interface TimeRangeDrillDownFilterProperty {
        /**
         * `CfnAnalysis.TimeRangeDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeRangeDrillDownFilterProperty.RangeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangemaximum
         */
        readonly rangeMaximum: string;
        /**
         * `CfnAnalysis.TimeRangeDrillDownFilterProperty.RangeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-rangeminimum
         */
        readonly rangeMinimum: string;
        /**
         * `CfnAnalysis.TimeRangeDrillDownFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangedrilldownfilter.html#cfn-quicksight-analysis-timerangedrilldownfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html
     */
    interface TimeRangeFilterProperty {
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.ExcludePeriodConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnAnalysis.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.IncludeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.IncludeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.RangeMaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangemaximumvalue
         */
        readonly rangeMaximumValue?: CfnAnalysis.TimeRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.RangeMinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-rangeminimumvalue
         */
        readonly rangeMinimumValue?: CfnAnalysis.TimeRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeRangeFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefilter.html#cfn-quicksight-analysis-timerangefilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html
     */
    interface TimeRangeFilterValueProperty {
        /**
         * `CfnAnalysis.TimeRangeFilterValueProperty.Parameter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * `CfnAnalysis.TimeRangeFilterValueProperty.RollingDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-rollingdate
         */
        readonly rollingDate?: CfnAnalysis.RollingDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TimeRangeFilterValueProperty.StaticValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-timerangefiltervalue.html#cfn-quicksight-analysis-timerangefiltervalue-staticvalue
         */
        readonly staticValue?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html
     */
    interface TooltipItemProperty {
        /**
         * `CfnAnalysis.TooltipItemProperty.ColumnTooltipItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-columntooltipitem
         */
        readonly columnTooltipItem?: CfnAnalysis.ColumnTooltipItemProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TooltipItemProperty.FieldTooltipItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipitem.html#cfn-quicksight-analysis-tooltipitem-fieldtooltipitem
         */
        readonly fieldTooltipItem?: CfnAnalysis.FieldTooltipItemProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html
     */
    interface TooltipOptionsProperty {
        /**
         * `CfnAnalysis.TooltipOptionsProperty.FieldBasedTooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-fieldbasedtooltip
         */
        readonly fieldBasedTooltip?: CfnAnalysis.FieldBasedTooltipProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TooltipOptionsProperty.SelectedTooltipType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-selectedtooltiptype
         */
        readonly selectedTooltipType?: string;
        /**
         * `CfnAnalysis.TooltipOptionsProperty.TooltipVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-tooltipoptions.html#cfn-quicksight-analysis-tooltipoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html
     */
    interface TopBottomFilterProperty {
        /**
         * `CfnAnalysis.TopBottomFilterProperty.AggregationSortConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-aggregationsortconfigurations
         */
        readonly aggregationSortConfigurations: Array<CfnAnalysis.AggregationSortConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.TopBottomFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TopBottomFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnAnalysis.TopBottomFilterProperty.Limit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-limit
         */
        readonly limit?: number;
        /**
         * `CfnAnalysis.TopBottomFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnAnalysis.TopBottomFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomfilter.html#cfn-quicksight-analysis-topbottomfilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html
     */
    interface TopBottomMoversComputationProperty {
        /**
         * `CfnAnalysis.TopBottomMoversComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-category
         */
        readonly category: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TopBottomMoversComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.TopBottomMoversComputationProperty.MoverSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-moversize
         */
        readonly moverSize?: number;
        /**
         * `CfnAnalysis.TopBottomMoversComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.TopBottomMoversComputationProperty.SortOrder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-sortorder
         */
        readonly sortOrder?: string;
        /**
         * `CfnAnalysis.TopBottomMoversComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-time
         */
        readonly time: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TopBottomMoversComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-type
         */
        readonly type: string;
        /**
         * `CfnAnalysis.TopBottomMoversComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottommoverscomputation.html#cfn-quicksight-analysis-topbottommoverscomputation-value
         */
        readonly value?: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html
     */
    interface TopBottomRankedComputationProperty {
        /**
         * `CfnAnalysis.TopBottomRankedComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-category
         */
        readonly category: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TopBottomRankedComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.TopBottomRankedComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.TopBottomRankedComputationProperty.ResultSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-resultsize
         */
        readonly resultSize?: number;
        /**
         * `CfnAnalysis.TopBottomRankedComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-type
         */
        readonly type: string;
        /**
         * `CfnAnalysis.TopBottomRankedComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-topbottomrankedcomputation.html#cfn-quicksight-analysis-topbottomrankedcomputation-value
         */
        readonly value?: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html
     */
    interface TotalAggregationComputationProperty {
        /**
         * `CfnAnalysis.TotalAggregationComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.TotalAggregationComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnAnalysis.TotalAggregationComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totalaggregationcomputation.html#cfn-quicksight-analysis-totalaggregationcomputation-value
         */
        readonly value: CfnAnalysis.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html
     */
    interface TotalOptionsProperty {
        /**
         * `CfnAnalysis.TotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnAnalysis.TotalOptionsProperty.Placement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-placement
         */
        readonly placement?: string;
        /**
         * `CfnAnalysis.TotalOptionsProperty.ScrollStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * `CfnAnalysis.TotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnAnalysis.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-totaloptions.html#cfn-quicksight-analysis-totaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html
     */
    interface TreeMapAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.TreeMapAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapAggregatedFieldWellsProperty.Groups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-groups
         */
        readonly groups?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapAggregatedFieldWellsProperty.Sizes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapaggregatedfieldwells.html#cfn-quicksight-analysis-treemapaggregatedfieldwells-sizes
         */
        readonly sizes?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html
     */
    interface TreeMapConfigurationProperty {
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.ColorScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-colorscale
         */
        readonly colorScale?: CfnAnalysis.ColorScaleProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.TreeMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.GroupLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-grouplabeloptions
         */
        readonly groupLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.SizeLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sizelabeloptions
         */
        readonly sizeLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.TreeMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapconfiguration.html#cfn-quicksight-analysis-treemapconfiguration-tooltip
         */
        readonly tooltip?: CfnAnalysis.TooltipOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html
     */
    interface TreeMapFieldWellsProperty {
        /**
         * `CfnAnalysis.TreeMapFieldWellsProperty.TreeMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapfieldwells.html#cfn-quicksight-analysis-treemapfieldwells-treemapaggregatedfieldwells
         */
        readonly treeMapAggregatedFieldWells?: CfnAnalysis.TreeMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html
     */
    interface TreeMapSortConfigurationProperty {
        /**
         * `CfnAnalysis.TreeMapSortConfigurationProperty.TreeMapGroupItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapgroupitemslimitconfiguration
         */
        readonly treeMapGroupItemsLimitConfiguration?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapSortConfigurationProperty.TreeMapSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapsortconfiguration.html#cfn-quicksight-analysis-treemapsortconfiguration-treemapsort
         */
        readonly treeMapSort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html
     */
    interface TreeMapVisualProperty {
        /**
         * `CfnAnalysis.TreeMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.TreeMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.TreeMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-treemapvisual.html#cfn-quicksight-analysis-treemapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html
     */
    interface TrendArrowOptionsProperty {
        /**
         * `CfnAnalysis.TrendArrowOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-trendarrowoptions.html#cfn-quicksight-analysis-trendarrowoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html
     */
    interface UnaggregatedFieldProperty {
        /**
         * `CfnAnalysis.UnaggregatedFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-column
         */
        readonly column: CfnAnalysis.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.UnaggregatedFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnAnalysis.UnaggregatedFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-unaggregatedfield.html#cfn-quicksight-analysis-unaggregatedfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnAnalysis.FormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html
     */
    interface UniqueValuesComputationProperty {
        /**
         * `CfnAnalysis.UniqueValuesComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-category
         */
        readonly category: CfnAnalysis.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.UniqueValuesComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnAnalysis.UniqueValuesComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-uniquevaluescomputation.html#cfn-quicksight-analysis-uniquevaluescomputation-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html
     */
    interface VisibleRangeOptionsProperty {
        /**
         * `CfnAnalysis.VisibleRangeOptionsProperty.PercentRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visiblerangeoptions.html#cfn-quicksight-analysis-visiblerangeoptions-percentrange
         */
        readonly percentRange?: CfnAnalysis.PercentVisibleRangeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html
     */
    interface VisualProperty {
        /**
         * `CfnAnalysis.VisualProperty.BarChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-barchartvisual
         */
        readonly barChartVisual?: CfnAnalysis.BarChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.BoxPlotVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-boxplotvisual
         */
        readonly boxPlotVisual?: CfnAnalysis.BoxPlotVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.ComboChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-combochartvisual
         */
        readonly comboChartVisual?: CfnAnalysis.ComboChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.CustomContentVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-customcontentvisual
         */
        readonly customContentVisual?: CfnAnalysis.CustomContentVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.EmptyVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-emptyvisual
         */
        readonly emptyVisual?: CfnAnalysis.EmptyVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.FilledMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-filledmapvisual
         */
        readonly filledMapVisual?: CfnAnalysis.FilledMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.FunnelChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-funnelchartvisual
         */
        readonly funnelChartVisual?: CfnAnalysis.FunnelChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.GaugeChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-gaugechartvisual
         */
        readonly gaugeChartVisual?: CfnAnalysis.GaugeChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.GeospatialMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-geospatialmapvisual
         */
        readonly geospatialMapVisual?: CfnAnalysis.GeospatialMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.HeatMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-heatmapvisual
         */
        readonly heatMapVisual?: CfnAnalysis.HeatMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.HistogramVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-histogramvisual
         */
        readonly histogramVisual?: CfnAnalysis.HistogramVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.InsightVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-insightvisual
         */
        readonly insightVisual?: CfnAnalysis.InsightVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.KPIVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-kpivisual
         */
        readonly kpiVisual?: CfnAnalysis.KPIVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.LineChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-linechartvisual
         */
        readonly lineChartVisual?: CfnAnalysis.LineChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.PieChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-piechartvisual
         */
        readonly pieChartVisual?: CfnAnalysis.PieChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.PivotTableVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-pivottablevisual
         */
        readonly pivotTableVisual?: CfnAnalysis.PivotTableVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.RadarChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-radarchartvisual
         */
        readonly radarChartVisual?: CfnAnalysis.RadarChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.SankeyDiagramVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-sankeydiagramvisual
         */
        readonly sankeyDiagramVisual?: CfnAnalysis.SankeyDiagramVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.ScatterPlotVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-scatterplotvisual
         */
        readonly scatterPlotVisual?: CfnAnalysis.ScatterPlotVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.TableVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-tablevisual
         */
        readonly tableVisual?: CfnAnalysis.TableVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.TreeMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-treemapvisual
         */
        readonly treeMapVisual?: CfnAnalysis.TreeMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.WaterfallVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-waterfallvisual
         */
        readonly waterfallVisual?: CfnAnalysis.WaterfallVisualProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualProperty.WordCloudVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visual.html#cfn-quicksight-analysis-visual-wordcloudvisual
         */
        readonly wordCloudVisual?: CfnAnalysis.WordCloudVisualProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html
     */
    interface VisualCustomActionProperty {
        /**
         * `CfnAnalysis.VisualCustomActionProperty.ActionOperations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-actionoperations
         */
        readonly actionOperations: Array<CfnAnalysis.VisualCustomActionOperationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualCustomActionProperty.CustomActionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-customactionid
         */
        readonly customActionId: string;
        /**
         * `CfnAnalysis.VisualCustomActionProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-name
         */
        readonly name: string;
        /**
         * `CfnAnalysis.VisualCustomActionProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-status
         */
        readonly status?: string;
        /**
         * `CfnAnalysis.VisualCustomActionProperty.Trigger`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomaction.html#cfn-quicksight-analysis-visualcustomaction-trigger
         */
        readonly trigger: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html
     */
    interface VisualCustomActionOperationProperty {
        /**
         * `CfnAnalysis.VisualCustomActionOperationProperty.FilterOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-filteroperation
         */
        readonly filterOperation?: CfnAnalysis.CustomActionFilterOperationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualCustomActionOperationProperty.NavigationOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-navigationoperation
         */
        readonly navigationOperation?: CfnAnalysis.CustomActionNavigationOperationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualCustomActionOperationProperty.SetParametersOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-setparametersoperation
         */
        readonly setParametersOperation?: CfnAnalysis.CustomActionSetParametersOperationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualCustomActionOperationProperty.URLOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualcustomactionoperation.html#cfn-quicksight-analysis-visualcustomactionoperation-urloperation
         */
        readonly urlOperation?: CfnAnalysis.CustomActionURLOperationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html
     */
    interface VisualPaletteProperty {
        /**
         * `CfnAnalysis.VisualPaletteProperty.ChartColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-chartcolor
         */
        readonly chartColor?: string;
        /**
         * `CfnAnalysis.VisualPaletteProperty.ColorMap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualpalette.html#cfn-quicksight-analysis-visualpalette-colormap
         */
        readonly colorMap?: Array<CfnAnalysis.DataPathColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html
     */
    interface VisualSubtitleLabelOptionsProperty {
        /**
         * `CfnAnalysis.VisualSubtitleLabelOptionsProperty.FormatText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-formattext
         */
        readonly formatText?: CfnAnalysis.LongFormatTextProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualSubtitleLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualsubtitlelabeloptions.html#cfn-quicksight-analysis-visualsubtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html
     */
    interface VisualTitleLabelOptionsProperty {
        /**
         * `CfnAnalysis.VisualTitleLabelOptionsProperty.FormatText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-formattext
         */
        readonly formatText?: CfnAnalysis.ShortFormatTextProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.VisualTitleLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-visualtitlelabeloptions.html#cfn-quicksight-analysis-visualtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html
     */
    interface WaterfallChartAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty.Breakdowns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-breakdowns
         */
        readonly breakdowns?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty.Categories`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-categories
         */
        readonly categories?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartaggregatedfieldwells.html#cfn-quicksight-analysis-waterfallchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html
     */
    interface WaterfallChartConfigurationProperty {
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.CategoryAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxisdisplayoptions
         */
        readonly categoryAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.CategoryAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-categoryaxislabeloptions
         */
        readonly categoryAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnAnalysis.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.WaterfallChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-legend
         */
        readonly legend?: CfnAnalysis.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnAnalysis.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.WaterfallChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnAnalysis.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartConfigurationProperty.WaterfallChartOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartconfiguration.html#cfn-quicksight-analysis-waterfallchartconfiguration-waterfallchartoptions
         */
        readonly waterfallChartOptions?: CfnAnalysis.WaterfallChartOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html
     */
    interface WaterfallChartFieldWellsProperty {
        /**
         * `CfnAnalysis.WaterfallChartFieldWellsProperty.WaterfallChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartfieldwells.html#cfn-quicksight-analysis-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
         */
        readonly waterfallChartAggregatedFieldWells?: CfnAnalysis.WaterfallChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html
     */
    interface WaterfallChartOptionsProperty {
        /**
         * `CfnAnalysis.WaterfallChartOptionsProperty.TotalBarLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartoptions.html#cfn-quicksight-analysis-waterfallchartoptions-totalbarlabel
         */
        readonly totalBarLabel?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html
     */
    interface WaterfallChartSortConfigurationProperty {
        /**
         * `CfnAnalysis.WaterfallChartSortConfigurationProperty.BreakdownItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-breakdownitemslimit
         */
        readonly breakdownItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallchartsortconfiguration.html#cfn-quicksight-analysis-waterfallchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html
     */
    interface WaterfallVisualProperty {
        /**
         * `CfnAnalysis.WaterfallVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.WaterfallChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WaterfallVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-waterfallvisual.html#cfn-quicksight-analysis-waterfallvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html
     */
    interface WhatIfPointScenarioProperty {
        /**
         * `CfnAnalysis.WhatIfPointScenarioProperty.Date`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-date
         */
        readonly date: string;
        /**
         * `CfnAnalysis.WhatIfPointScenarioProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifpointscenario.html#cfn-quicksight-analysis-whatifpointscenario-value
         */
        readonly value: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html
     */
    interface WhatIfRangeScenarioProperty {
        /**
         * `CfnAnalysis.WhatIfRangeScenarioProperty.EndDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-enddate
         */
        readonly endDate: string;
        /**
         * `CfnAnalysis.WhatIfRangeScenarioProperty.StartDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-startdate
         */
        readonly startDate: string;
        /**
         * `CfnAnalysis.WhatIfRangeScenarioProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-whatifrangescenario.html#cfn-quicksight-analysis-whatifrangescenario-value
         */
        readonly value: number;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html
     */
    interface WordCloudAggregatedFieldWellsProperty {
        /**
         * `CfnAnalysis.WordCloudAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnAnalysis.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudAggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudaggregatedfieldwells.html#cfn-quicksight-analysis-wordcloudaggregatedfieldwells-size
         */
        readonly size?: Array<CfnAnalysis.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html
     */
    interface WordCloudChartConfigurationProperty {
        /**
         * `CfnAnalysis.WordCloudChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnAnalysis.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnAnalysis.WordCloudFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnAnalysis.WordCloudSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudChartConfigurationProperty.WordCloudOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudchartconfiguration.html#cfn-quicksight-analysis-wordcloudchartconfiguration-wordcloudoptions
         */
        readonly wordCloudOptions?: CfnAnalysis.WordCloudOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html
     */
    interface WordCloudFieldWellsProperty {
        /**
         * `CfnAnalysis.WordCloudFieldWellsProperty.WordCloudAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudfieldwells.html#cfn-quicksight-analysis-wordcloudfieldwells-wordcloudaggregatedfieldwells
         */
        readonly wordCloudAggregatedFieldWells?: CfnAnalysis.WordCloudAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html
     */
    interface WordCloudOptionsProperty {
        /**
         * `CfnAnalysis.WordCloudOptionsProperty.CloudLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-cloudlayout
         */
        readonly cloudLayout?: string;
        /**
         * `CfnAnalysis.WordCloudOptionsProperty.MaximumStringLength`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-maximumstringlength
         */
        readonly maximumStringLength?: number;
        /**
         * `CfnAnalysis.WordCloudOptionsProperty.WordCasing`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordcasing
         */
        readonly wordCasing?: string;
        /**
         * `CfnAnalysis.WordCloudOptionsProperty.WordOrientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordorientation
         */
        readonly wordOrientation?: string;
        /**
         * `CfnAnalysis.WordCloudOptionsProperty.WordPadding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordpadding
         */
        readonly wordPadding?: string;
        /**
         * `CfnAnalysis.WordCloudOptionsProperty.WordScaling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudoptions.html#cfn-quicksight-analysis-wordcloudoptions-wordscaling
         */
        readonly wordScaling?: string;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html
     */
    interface WordCloudSortConfigurationProperty {
        /**
         * `CfnAnalysis.WordCloudSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnAnalysis.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudsortconfiguration.html#cfn-quicksight-analysis-wordcloudsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnAnalysis.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnAnalysis {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html
     */
    interface WordCloudVisualProperty {
        /**
         * `CfnAnalysis.WordCloudVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-actions
         */
        readonly actions?: Array<CfnAnalysis.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnAnalysis.WordCloudChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnAnalysis.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-subtitle
         */
        readonly subtitle?: CfnAnalysis.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-title
         */
        readonly title?: CfnAnalysis.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnAnalysis.WordCloudVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-analysis-wordcloudvisual.html#cfn-quicksight-analysis-wordcloudvisual-visualid
         */
        readonly visualId: string;
    }
}
/**
 * Properties for defining a `CfnDashboard`
 *
 * @struct
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
 */
export interface CfnDashboardProps {
    /**
     * The ID of the AWS account where you want to create the dashboard.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-awsaccountid
     */
    readonly awsAccountId: string;
    /**
     * The ID for the dashboard, also added to the IAM policy.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardid
     */
    readonly dashboardId: string;
    /**
     * The display name of the dashboard.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-name
     */
    readonly name: string;
    /**
     * Options for publishing the dashboard when you create it:
     *
     * - `AvailabilityStatus` for `AdHocFilteringOption` - This status can be either `ENABLED` or `DISABLED` . When this is set to `DISABLED` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is `ENABLED` by default.
     * - `AvailabilityStatus` for `ExportToCSVOption` - This status can be either `ENABLED` or `DISABLED` . The visual option to export data to .CSV format isn't enabled when this is set to `DISABLED` . This option is `ENABLED` by default.
     * - `VisibilityState` for `SheetControlsOption` - This visibility state can be either `COLLAPSED` or `EXPANDED` . This option is `COLLAPSED` by default.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardpublishoptions
     */
    readonly dashboardPublishOptions?: CfnDashboard.DashboardPublishOptionsProperty | cdk.IResolvable;
    /**
     * `AWS::QuickSight::Dashboard.Definition`
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-definition
     */
    readonly definition?: CfnDashboard.DashboardVersionDefinitionProperty | cdk.IResolvable;
    /**
     * The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-parameters
     */
    readonly parameters?: CfnDashboard.ParametersProperty | cdk.IResolvable;
    /**
     * A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.
     *
     * To specify no permissions, omit the permissions list.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-permissions
     */
    readonly permissions?: Array<CfnDashboard.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The entity that you are using as a source when you create the dashboard. In `SourceEntity` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a `SourceTemplate` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the `CreateTemplate` API operation. For `SourceTemplate` , specify the Amazon Resource Name (ARN) of the source template. The `SourceTemplate` ARN can contain any AWS account; and any QuickSight-supported AWS Region .
     *
     * Use the `DataSetReferences` entity within `SourceTemplate` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-sourceentity
     */
    readonly sourceEntity?: CfnDashboard.DashboardSourceEntityProperty | cdk.IResolvable;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-tags
     */
    readonly tags?: cdk.CfnTag[];
    /**
     * The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-themearn
     */
    readonly themeArn?: string;
    /**
     * A description for the first version of the dashboard being created.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-versiondescription
     */
    readonly versionDescription?: string;
}
/**
 * A CloudFormation `AWS::QuickSight::Dashboard`
 *
 * Creates a dashboard from a template. To first create a template, see the `CreateTemplate` API operation.
 *
 * A dashboard is an entity in Amazon QuickSight that identifies Amazon QuickSight reports, created from analyses. You can share Amazon QuickSight dashboards. With the right permissions, you can create scheduled email reports from them. If you have the correct permissions, you can create a dashboard from a template that exists in a different AWS account .
 *
 * @cloudformationResource AWS::QuickSight::Dashboard
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html
 */
export declare class CfnDashboard extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "AWS::QuickSight::Dashboard";
    /**
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDashboard;
    /**
     * The Amazon Resource Name (ARN) of the dashboard.
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time this dashboard version was created.
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time that the dashboard was last published.
     * @cloudformationAttribute LastPublishedTime
     */
    readonly attrLastPublishedTime: string;
    /**
     * The time that the dashboard was last updated.
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     *
     * @cloudformationAttribute Version.Arn
     */
    readonly attrVersionArn: string;
    /**
     *
     * @cloudformationAttribute Version.CreatedTime
     */
    readonly attrVersionCreatedTime: string;
    /**
     *
     * @cloudformationAttribute Version.DataSetArns
     */
    readonly attrVersionDataSetArns: string[];
    /**
     *
     * @cloudformationAttribute Version.Description
     */
    readonly attrVersionDescription: string;
    /**
     *
     * @cloudformationAttribute Version.Errors
     */
    readonly attrVersionErrors: cdk.IResolvable;
    /**
     *
     * @cloudformationAttribute Version.Sheets
     */
    readonly attrVersionSheets: cdk.IResolvable;
    /**
     *
     * @cloudformationAttribute Version.SourceEntityArn
     */
    readonly attrVersionSourceEntityArn: string;
    /**
     *
     * @cloudformationAttribute Version.Status
     */
    readonly attrVersionStatus: string;
    /**
     *
     * @cloudformationAttribute Version.ThemeArn
     */
    readonly attrVersionThemeArn: string;
    /**
     *
     * @cloudformationAttribute Version.VersionNumber
     */
    readonly attrVersionVersionNumber: cdk.IResolvable;
    /**
     * The ID of the AWS account where you want to create the dashboard.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-awsaccountid
     */
    awsAccountId: string;
    /**
     * The ID for the dashboard, also added to the IAM policy.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardid
     */
    dashboardId: string;
    /**
     * The display name of the dashboard.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-name
     */
    name: string;
    /**
     * Options for publishing the dashboard when you create it:
     *
     * - `AvailabilityStatus` for `AdHocFilteringOption` - This status can be either `ENABLED` or `DISABLED` . When this is set to `DISABLED` , Amazon QuickSight disables the left filter pane on the published dashboard, which can be used for ad hoc (one-time) filtering. This option is `ENABLED` by default.
     * - `AvailabilityStatus` for `ExportToCSVOption` - This status can be either `ENABLED` or `DISABLED` . The visual option to export data to .CSV format isn't enabled when this is set to `DISABLED` . This option is `ENABLED` by default.
     * - `VisibilityState` for `SheetControlsOption` - This visibility state can be either `COLLAPSED` or `EXPANDED` . This option is `COLLAPSED` by default.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-dashboardpublishoptions
     */
    dashboardPublishOptions: CfnDashboard.DashboardPublishOptionsProperty | cdk.IResolvable | undefined;
    /**
     * `AWS::QuickSight::Dashboard.Definition`
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-definition
     */
    definition: CfnDashboard.DashboardVersionDefinitionProperty | cdk.IResolvable | undefined;
    /**
     * The parameters for the creation of the dashboard, which you want to use to override the default settings. A dashboard can have any type of parameters, and some parameters might accept multiple values.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-parameters
     */
    parameters: CfnDashboard.ParametersProperty | cdk.IResolvable | undefined;
    /**
     * A structure that contains the permissions of the dashboard. You can use this structure for granting permissions by providing a list of IAM action information for each principal ARN.
     *
     * To specify no permissions, omit the permissions list.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-permissions
     */
    permissions: Array<CfnDashboard.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * The entity that you are using as a source when you create the dashboard. In `SourceEntity` , you specify the type of object that you want to use. You can only create a dashboard from a template, so you use a `SourceTemplate` entity. If you need to create a dashboard from an analysis, first convert the analysis to a template by using the `CreateTemplate` API operation. For `SourceTemplate` , specify the Amazon Resource Name (ARN) of the source template. The `SourceTemplate` ARN can contain any AWS account; and any QuickSight-supported AWS Region .
     *
     * Use the `DataSetReferences` entity within `SourceTemplate` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-sourceentity
     */
    sourceEntity: CfnDashboard.DashboardSourceEntityProperty | cdk.IResolvable | undefined;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the dashboard.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-tags
     */
    readonly tags: cdk.TagManager;
    /**
     * The Amazon Resource Name (ARN) of the theme that is being used for this dashboard. If you add a value for this field, it overrides the value that is used in the source entity. The theme ARN must exist in the same AWS account where you create the dashboard.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-themearn
     */
    themeArn: string | undefined;
    /**
     * A description for the first version of the dashboard being created.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dashboard.html#cfn-quicksight-dashboard-versiondescription
     */
    versionDescription: string | undefined;
    /**
     * Create a new `AWS::QuickSight::Dashboard`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnDashboardProps);
    /**
     * Examines the CloudFormation resource and discloses attributes.
     *
     * @param inspector - tree inspector to collect and process attributes
     *
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected get cfnProperties(): {
        [key: string]: any;
    };
    protected renderProperties(props: {
        [key: string]: any;
    }): {
        [key: string]: any;
    };
}
export declare namespace CfnDashboard {
    /**
     * An ad hoc (one-time) filtering option.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html
     */
    interface AdHocFilteringOptionProperty {
        /**
         * Availability status.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-adhocfilteringoption.html#cfn-quicksight-dashboard-adhocfilteringoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html
     */
    interface AggregationFunctionProperty {
        /**
         * `CfnDashboard.AggregationFunctionProperty.CategoricalAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-categoricalaggregationfunction
         */
        readonly categoricalAggregationFunction?: string;
        /**
         * `CfnDashboard.AggregationFunctionProperty.DateAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-dateaggregationfunction
         */
        readonly dateAggregationFunction?: string;
        /**
         * `CfnDashboard.AggregationFunctionProperty.NumericalAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationfunction.html#cfn-quicksight-dashboard-aggregationfunction-numericalaggregationfunction
         */
        readonly numericalAggregationFunction?: CfnDashboard.NumericalAggregationFunctionProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html
     */
    interface AggregationSortConfigurationProperty {
        /**
         * `CfnDashboard.AggregationSortConfigurationProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-aggregationfunction
         */
        readonly aggregationFunction: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AggregationSortConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AggregationSortConfigurationProperty.SortDirection`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-aggregationsortconfiguration.html#cfn-quicksight-dashboard-aggregationsortconfiguration-sortdirection
         */
        readonly sortDirection: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html
     */
    interface AnalysisDefaultsProperty {
        /**
         * `CfnDashboard.AnalysisDefaultsProperty.DefaultNewSheetConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-analysisdefaults.html#cfn-quicksight-dashboard-analysisdefaults-defaultnewsheetconfiguration
         */
        readonly defaultNewSheetConfiguration: CfnDashboard.DefaultNewSheetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html
     */
    interface AnchorDateConfigurationProperty {
        /**
         * `CfnDashboard.AnchorDateConfigurationProperty.AnchorOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-anchoroption
         */
        readonly anchorOption?: string;
        /**
         * `CfnDashboard.AnchorDateConfigurationProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-anchordateconfiguration.html#cfn-quicksight-dashboard-anchordateconfiguration-parametername
         */
        readonly parameterName?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html
     */
    interface ArcAxisConfigurationProperty {
        /**
         * `CfnDashboard.ArcAxisConfigurationProperty.Range`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-range
         */
        readonly range?: CfnDashboard.ArcAxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ArcAxisConfigurationProperty.ReserveRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisconfiguration.html#cfn-quicksight-dashboard-arcaxisconfiguration-reserverange
         */
        readonly reserveRange?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html
     */
    interface ArcAxisDisplayRangeProperty {
        /**
         * `CfnDashboard.ArcAxisDisplayRangeProperty.Max`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-max
         */
        readonly max?: number;
        /**
         * `CfnDashboard.ArcAxisDisplayRangeProperty.Min`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcaxisdisplayrange.html#cfn-quicksight-dashboard-arcaxisdisplayrange-min
         */
        readonly min?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html
     */
    interface ArcConfigurationProperty {
        /**
         * `CfnDashboard.ArcConfigurationProperty.ArcAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcangle
         */
        readonly arcAngle?: number;
        /**
         * `CfnDashboard.ArcConfigurationProperty.ArcThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcconfiguration.html#cfn-quicksight-dashboard-arcconfiguration-arcthickness
         */
        readonly arcThickness?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html
     */
    interface ArcOptionsProperty {
        /**
         * `CfnDashboard.ArcOptionsProperty.ArcThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-arcoptions.html#cfn-quicksight-dashboard-arcoptions-arcthickness
         */
        readonly arcThickness?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html
     */
    interface AxisDataOptionsProperty {
        /**
         * `CfnDashboard.AxisDataOptionsProperty.DateAxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-dateaxisoptions
         */
        readonly dateAxisOptions?: CfnDashboard.DateAxisOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AxisDataOptionsProperty.NumericAxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdataoptions.html#cfn-quicksight-dashboard-axisdataoptions-numericaxisoptions
         */
        readonly numericAxisOptions?: CfnDashboard.NumericAxisOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html
     */
    interface AxisDisplayMinMaxRangeProperty {
        /**
         * `CfnDashboard.AxisDisplayMinMaxRangeProperty.Maximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-maximum
         */
        readonly maximum?: number;
        /**
         * `CfnDashboard.AxisDisplayMinMaxRangeProperty.Minimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayminmaxrange.html#cfn-quicksight-dashboard-axisdisplayminmaxrange-minimum
         */
        readonly minimum?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html
     */
    interface AxisDisplayOptionsProperty {
        /**
         * `CfnDashboard.AxisDisplayOptionsProperty.AxisLineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axislinevisibility
         */
        readonly axisLineVisibility?: string;
        /**
         * `CfnDashboard.AxisDisplayOptionsProperty.AxisOffset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-axisoffset
         */
        readonly axisOffset?: string;
        /**
         * `CfnDashboard.AxisDisplayOptionsProperty.DataOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-dataoptions
         */
        readonly dataOptions?: CfnDashboard.AxisDataOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AxisDisplayOptionsProperty.GridLineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-gridlinevisibility
         */
        readonly gridLineVisibility?: string;
        /**
         * `CfnDashboard.AxisDisplayOptionsProperty.ScrollbarOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-scrollbaroptions
         */
        readonly scrollbarOptions?: CfnDashboard.ScrollBarOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AxisDisplayOptionsProperty.TickLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayoptions.html#cfn-quicksight-dashboard-axisdisplayoptions-ticklabeloptions
         */
        readonly tickLabelOptions?: CfnDashboard.AxisTickLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html
     */
    interface AxisDisplayRangeProperty {
        /**
         * `CfnDashboard.AxisDisplayRangeProperty.DataDriven`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-datadriven
         */
        readonly dataDriven?: any | cdk.IResolvable;
        /**
         * `CfnDashboard.AxisDisplayRangeProperty.MinMax`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisdisplayrange.html#cfn-quicksight-dashboard-axisdisplayrange-minmax
         */
        readonly minMax?: CfnDashboard.AxisDisplayMinMaxRangeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html
     */
    interface AxisLabelOptionsProperty {
        /**
         * `CfnDashboard.AxisLabelOptionsProperty.ApplyTo`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-applyto
         */
        readonly applyTo?: CfnDashboard.AxisLabelReferenceOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AxisLabelOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnDashboard.AxisLabelOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabeloptions.html#cfn-quicksight-dashboard-axislabeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html
     */
    interface AxisLabelReferenceOptionsProperty {
        /**
         * `CfnDashboard.AxisLabelReferenceOptionsProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AxisLabelReferenceOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislabelreferenceoptions.html#cfn-quicksight-dashboard-axislabelreferenceoptions-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html
     */
    interface AxisLinearScaleProperty {
        /**
         * `CfnDashboard.AxisLinearScaleProperty.StepCount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepcount
         */
        readonly stepCount?: number;
        /**
         * `CfnDashboard.AxisLinearScaleProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislinearscale.html#cfn-quicksight-dashboard-axislinearscale-stepsize
         */
        readonly stepSize?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html
     */
    interface AxisLogarithmicScaleProperty {
        /**
         * `CfnDashboard.AxisLogarithmicScaleProperty.Base`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axislogarithmicscale.html#cfn-quicksight-dashboard-axislogarithmicscale-base
         */
        readonly base?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html
     */
    interface AxisScaleProperty {
        /**
         * `CfnDashboard.AxisScaleProperty.Linear`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-linear
         */
        readonly linear?: CfnDashboard.AxisLinearScaleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AxisScaleProperty.Logarithmic`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisscale.html#cfn-quicksight-dashboard-axisscale-logarithmic
         */
        readonly logarithmic?: CfnDashboard.AxisLogarithmicScaleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html
     */
    interface AxisTickLabelOptionsProperty {
        /**
         * `CfnDashboard.AxisTickLabelOptionsProperty.LabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-labeloptions
         */
        readonly labelOptions?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.AxisTickLabelOptionsProperty.RotationAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-axisticklabeloptions.html#cfn-quicksight-dashboard-axisticklabeloptions-rotationangle
         */
        readonly rotationAngle?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html
     */
    interface BarChartAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.BarChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartaggregatedfieldwells.html#cfn-quicksight-dashboard-barchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html
     */
    interface BarChartConfigurationProperty {
        /**
         * `CfnDashboard.BarChartConfigurationProperty.BarsArrangement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnDashboard.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.BarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.Orientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-orientation
         */
        readonly orientation?: string;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnDashboard.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnDashboard.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.BarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.ValueAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valueaxis
         */
        readonly valueAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartconfiguration.html#cfn-quicksight-dashboard-barchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html
     */
    interface BarChartFieldWellsProperty {
        /**
         * `CfnDashboard.BarChartFieldWellsProperty.BarChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartfieldwells.html#cfn-quicksight-dashboard-barchartfieldwells-barchartaggregatedfieldwells
         */
        readonly barChartAggregatedFieldWells?: CfnDashboard.BarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html
     */
    interface BarChartSortConfigurationProperty {
        /**
         * `CfnDashboard.BarChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartsortconfiguration.html#cfn-quicksight-dashboard-barchartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html
     */
    interface BarChartVisualProperty {
        /**
         * `CfnDashboard.BarChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.BarChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BarChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-barchartvisual.html#cfn-quicksight-dashboard-barchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html
     */
    interface BinCountOptionsProperty {
        /**
         * `CfnDashboard.BinCountOptionsProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bincountoptions.html#cfn-quicksight-dashboard-bincountoptions-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html
     */
    interface BinWidthOptionsProperty {
        /**
         * `CfnDashboard.BinWidthOptionsProperty.BinCountLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-bincountlimit
         */
        readonly binCountLimit?: number;
        /**
         * `CfnDashboard.BinWidthOptionsProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-binwidthoptions.html#cfn-quicksight-dashboard-binwidthoptions-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html
     */
    interface BodySectionConfigurationProperty {
        /**
         * `CfnDashboard.BodySectionConfigurationProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-content
         */
        readonly content: CfnDashboard.BodySectionContentProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BodySectionConfigurationProperty.PageBreakConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-pagebreakconfiguration
         */
        readonly pageBreakConfiguration?: CfnDashboard.SectionPageBreakConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BodySectionConfigurationProperty.SectionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * `CfnDashboard.BodySectionConfigurationProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectionconfiguration.html#cfn-quicksight-dashboard-bodysectionconfiguration-style
         */
        readonly style?: CfnDashboard.SectionStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html
     */
    interface BodySectionContentProperty {
        /**
         * `CfnDashboard.BodySectionContentProperty.Layout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-bodysectioncontent.html#cfn-quicksight-dashboard-bodysectioncontent-layout
         */
        readonly layout?: CfnDashboard.SectionLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html
     */
    interface BoxPlotAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.BoxPlotAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotaggregatedfieldwells.html#cfn-quicksight-dashboard-boxplotaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html
     */
    interface BoxPlotChartConfigurationProperty {
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.BoxPlotOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-boxplotoptions
         */
        readonly boxPlotOptions?: CfnDashboard.BoxPlotOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.BoxPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnDashboard.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.BoxPlotSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotchartconfiguration.html#cfn-quicksight-dashboard-boxplotchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html
     */
    interface BoxPlotFieldWellsProperty {
        /**
         * `CfnDashboard.BoxPlotFieldWellsProperty.BoxPlotAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotfieldwells.html#cfn-quicksight-dashboard-boxplotfieldwells-boxplotaggregatedfieldwells
         */
        readonly boxPlotAggregatedFieldWells?: CfnDashboard.BoxPlotAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html
     */
    interface BoxPlotOptionsProperty {
        /**
         * `CfnDashboard.BoxPlotOptionsProperty.AllDataPointsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-alldatapointsvisibility
         */
        readonly allDataPointsVisibility?: string;
        /**
         * `CfnDashboard.BoxPlotOptionsProperty.OutlierVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-outliervisibility
         */
        readonly outlierVisibility?: string;
        /**
         * `CfnDashboard.BoxPlotOptionsProperty.StyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotoptions.html#cfn-quicksight-dashboard-boxplotoptions-styleoptions
         */
        readonly styleOptions?: CfnDashboard.BoxPlotStyleOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html
     */
    interface BoxPlotSortConfigurationProperty {
        /**
         * `CfnDashboard.BoxPlotSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotSortConfigurationProperty.PaginationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotsortconfiguration.html#cfn-quicksight-dashboard-boxplotsortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: CfnDashboard.PaginationConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html
     */
    interface BoxPlotStyleOptionsProperty {
        /**
         * `CfnDashboard.BoxPlotStyleOptionsProperty.FillStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotstyleoptions.html#cfn-quicksight-dashboard-boxplotstyleoptions-fillstyle
         */
        readonly fillStyle?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html
     */
    interface BoxPlotVisualProperty {
        /**
         * `CfnDashboard.BoxPlotVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.BoxPlotChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.BoxPlotVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-boxplotvisual.html#cfn-quicksight-dashboard-boxplotvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html
     */
    interface CalculatedFieldProperty {
        /**
         * `CfnDashboard.CalculatedFieldProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnDashboard.CalculatedFieldProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-expression
         */
        readonly expression: string;
        /**
         * `CfnDashboard.CalculatedFieldProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedfield.html#cfn-quicksight-dashboard-calculatedfield-name
         */
        readonly name: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html
     */
    interface CalculatedMeasureFieldProperty {
        /**
         * `CfnDashboard.CalculatedMeasureFieldProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-expression
         */
        readonly expression: string;
        /**
         * `CfnDashboard.CalculatedMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-calculatedmeasurefield.html#cfn-quicksight-dashboard-calculatedmeasurefield-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html
     */
    interface CascadingControlConfigurationProperty {
        /**
         * `CfnDashboard.CascadingControlConfigurationProperty.SourceControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolconfiguration.html#cfn-quicksight-dashboard-cascadingcontrolconfiguration-sourcecontrols
         */
        readonly sourceControls?: Array<CfnDashboard.CascadingControlSourceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html
     */
    interface CascadingControlSourceProperty {
        /**
         * `CfnDashboard.CascadingControlSourceProperty.ColumnToMatch`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-columntomatch
         */
        readonly columnToMatch?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CascadingControlSourceProperty.SourceSheetControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-cascadingcontrolsource.html#cfn-quicksight-dashboard-cascadingcontrolsource-sourcesheetcontrolid
         */
        readonly sourceSheetControlId?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html
     */
    interface CategoricalDimensionFieldProperty {
        /**
         * `CfnDashboard.CategoricalDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CategoricalDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.CategoricalDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.StringFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CategoricalDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricaldimensionfield.html#cfn-quicksight-dashboard-categoricaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html
     */
    interface CategoricalMeasureFieldProperty {
        /**
         * `CfnDashboard.CategoricalMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * `CfnDashboard.CategoricalMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CategoricalMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.CategoricalMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoricalmeasurefield.html#cfn-quicksight-dashboard-categoricalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.StringFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html
     */
    interface CategoryDrillDownFilterProperty {
        /**
         * `CfnDashboard.CategoryDrillDownFilterProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-categoryvalues
         */
        readonly categoryValues: string[];
        /**
         * `CfnDashboard.CategoryDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categorydrilldownfilter.html#cfn-quicksight-dashboard-categorydrilldownfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html
     */
    interface CategoryFilterProperty {
        /**
         * `CfnDashboard.CategoryFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CategoryFilterProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-configuration
         */
        readonly configuration: CfnDashboard.CategoryFilterConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CategoryFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilter.html#cfn-quicksight-dashboard-categoryfilter-filterid
         */
        readonly filterId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html
     */
    interface CategoryFilterConfigurationProperty {
        /**
         * `CfnDashboard.CategoryFilterConfigurationProperty.CustomFilterConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterconfiguration
         */
        readonly customFilterConfiguration?: CfnDashboard.CustomFilterConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CategoryFilterConfigurationProperty.CustomFilterListConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-customfilterlistconfiguration
         */
        readonly customFilterListConfiguration?: CfnDashboard.CustomFilterListConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CategoryFilterConfigurationProperty.FilterListConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-categoryfilterconfiguration.html#cfn-quicksight-dashboard-categoryfilterconfiguration-filterlistconfiguration
         */
        readonly filterListConfiguration?: CfnDashboard.FilterListConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html
     */
    interface ChartAxisLabelOptionsProperty {
        /**
         * `CfnDashboard.ChartAxisLabelOptionsProperty.AxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-axislabeloptions
         */
        readonly axisLabelOptions?: Array<CfnDashboard.AxisLabelOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ChartAxisLabelOptionsProperty.SortIconVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-sorticonvisibility
         */
        readonly sortIconVisibility?: string;
        /**
         * `CfnDashboard.ChartAxisLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-chartaxislabeloptions.html#cfn-quicksight-dashboard-chartaxislabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html
     */
    interface ClusterMarkerProperty {
        /**
         * `CfnDashboard.ClusterMarkerProperty.SimpleClusterMarker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarker.html#cfn-quicksight-dashboard-clustermarker-simpleclustermarker
         */
        readonly simpleClusterMarker?: CfnDashboard.SimpleClusterMarkerProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html
     */
    interface ClusterMarkerConfigurationProperty {
        /**
         * `CfnDashboard.ClusterMarkerConfigurationProperty.ClusterMarker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-clustermarkerconfiguration.html#cfn-quicksight-dashboard-clustermarkerconfiguration-clustermarker
         */
        readonly clusterMarker?: CfnDashboard.ClusterMarkerProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html
     */
    interface ColorScaleProperty {
        /**
         * `CfnDashboard.ColorScaleProperty.ColorFillType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colorfilltype
         */
        readonly colorFillType: string;
        /**
         * `CfnDashboard.ColorScaleProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-colors
         */
        readonly colors: Array<CfnDashboard.DataColorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ColorScaleProperty.NullValueColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorscale.html#cfn-quicksight-dashboard-colorscale-nullvaluecolor
         */
        readonly nullValueColor?: CfnDashboard.DataColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html
     */
    interface ColorsConfigurationProperty {
        /**
         * `CfnDashboard.ColorsConfigurationProperty.CustomColors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-colorsconfiguration.html#cfn-quicksight-dashboard-colorsconfiguration-customcolors
         */
        readonly customColors?: Array<CfnDashboard.CustomColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html
     */
    interface ColumnConfigurationProperty {
        /**
         * `CfnDashboard.ColumnConfigurationProperty.ColorsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-colorsconfiguration
         */
        readonly colorsConfiguration?: CfnDashboard.ColorsConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ColumnConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ColumnConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.FormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ColumnConfigurationProperty.Role`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnconfiguration.html#cfn-quicksight-dashboard-columnconfiguration-role
         */
        readonly role?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html
     */
    interface ColumnHierarchyProperty {
        /**
         * `CfnDashboard.ColumnHierarchyProperty.DateTimeHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-datetimehierarchy
         */
        readonly dateTimeHierarchy?: CfnDashboard.DateTimeHierarchyProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ColumnHierarchyProperty.ExplicitHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-explicithierarchy
         */
        readonly explicitHierarchy?: CfnDashboard.ExplicitHierarchyProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ColumnHierarchyProperty.PredefinedHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnhierarchy.html#cfn-quicksight-dashboard-columnhierarchy-predefinedhierarchy
         */
        readonly predefinedHierarchy?: CfnDashboard.PredefinedHierarchyProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html
     */
    interface ColumnIdentifierProperty {
        /**
         * `CfnDashboard.ColumnIdentifierProperty.ColumnName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-columnname
         */
        readonly columnName: string;
        /**
         * `CfnDashboard.ColumnIdentifierProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnidentifier.html#cfn-quicksight-dashboard-columnidentifier-datasetidentifier
         */
        readonly dataSetIdentifier: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html
     */
    interface ColumnSortProperty {
        /**
         * `CfnDashboard.ColumnSortProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-aggregationfunction
         */
        readonly aggregationFunction?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ColumnSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-direction
         */
        readonly direction: string;
        /**
         * `CfnDashboard.ColumnSortProperty.SortBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columnsort.html#cfn-quicksight-dashboard-columnsort-sortby
         */
        readonly sortBy: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html
     */
    interface ColumnTooltipItemProperty {
        /**
         * `CfnDashboard.ColumnTooltipItemProperty.Aggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-aggregation
         */
        readonly aggregation?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ColumnTooltipItemProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ColumnTooltipItemProperty.Label`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-label
         */
        readonly label?: string;
        /**
         * `CfnDashboard.ColumnTooltipItemProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-columntooltipitem.html#cfn-quicksight-dashboard-columntooltipitem-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html
     */
    interface ComboChartAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.ComboChartAggregatedFieldWellsProperty.BarValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-barvalues
         */
        readonly barValues?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartAggregatedFieldWellsProperty.LineValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartaggregatedfieldwells.html#cfn-quicksight-dashboard-combochartaggregatedfieldwells-linevalues
         */
        readonly lineValues?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html
     */
    interface ComboChartConfigurationProperty {
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.BarDataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-bardatalabels
         */
        readonly barDataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.BarsArrangement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.ComboChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.LineDataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-linedatalabels
         */
        readonly lineDataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnDashboard.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.SecondaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.SecondaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.ComboChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartconfiguration.html#cfn-quicksight-dashboard-combochartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html
     */
    interface ComboChartFieldWellsProperty {
        /**
         * `CfnDashboard.ComboChartFieldWellsProperty.ComboChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartfieldwells.html#cfn-quicksight-dashboard-combochartfieldwells-combochartaggregatedfieldwells
         */
        readonly comboChartAggregatedFieldWells?: CfnDashboard.ComboChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html
     */
    interface ComboChartSortConfigurationProperty {
        /**
         * `CfnDashboard.ComboChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartsortconfiguration.html#cfn-quicksight-dashboard-combochartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html
     */
    interface ComboChartVisualProperty {
        /**
         * `CfnDashboard.ComboChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.ComboChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComboChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-combochartvisual.html#cfn-quicksight-dashboard-combochartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html
     */
    interface ComparisonConfigurationProperty {
        /**
         * `CfnDashboard.ComparisonConfigurationProperty.ComparisonFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonformat
         */
        readonly comparisonFormat?: CfnDashboard.ComparisonFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComparisonConfigurationProperty.ComparisonMethod`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonconfiguration.html#cfn-quicksight-dashboard-comparisonconfiguration-comparisonmethod
         */
        readonly comparisonMethod?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html
     */
    interface ComparisonFormatConfigurationProperty {
        /**
         * `CfnDashboard.ComparisonFormatConfigurationProperty.NumberDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: CfnDashboard.NumberDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComparisonFormatConfigurationProperty.PercentageDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-comparisonformatconfiguration.html#cfn-quicksight-dashboard-comparisonformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: CfnDashboard.PercentageDisplayFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html
     */
    interface ComputationProperty {
        /**
         * `CfnDashboard.ComputationProperty.Forecast`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-forecast
         */
        readonly forecast?: CfnDashboard.ForecastComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.GrowthRate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-growthrate
         */
        readonly growthRate?: CfnDashboard.GrowthRateComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.MaximumMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-maximumminimum
         */
        readonly maximumMinimum?: CfnDashboard.MaximumMinimumComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.MetricComparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-metriccomparison
         */
        readonly metricComparison?: CfnDashboard.MetricComparisonComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.PeriodOverPeriod`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodoverperiod
         */
        readonly periodOverPeriod?: CfnDashboard.PeriodOverPeriodComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.PeriodToDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-periodtodate
         */
        readonly periodToDate?: CfnDashboard.PeriodToDateComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.TopBottomMovers`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottommovers
         */
        readonly topBottomMovers?: CfnDashboard.TopBottomMoversComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.TopBottomRanked`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-topbottomranked
         */
        readonly topBottomRanked?: CfnDashboard.TopBottomRankedComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.TotalAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-totalaggregation
         */
        readonly totalAggregation?: CfnDashboard.TotalAggregationComputationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ComputationProperty.UniqueValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-computation.html#cfn-quicksight-dashboard-computation-uniquevalues
         */
        readonly uniqueValues?: CfnDashboard.UniqueValuesComputationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html
     */
    interface ConditionalFormattingColorProperty {
        /**
         * `CfnDashboard.ConditionalFormattingColorProperty.Gradient`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-gradient
         */
        readonly gradient?: CfnDashboard.ConditionalFormattingGradientColorProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ConditionalFormattingColorProperty.Solid`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcolor.html#cfn-quicksight-dashboard-conditionalformattingcolor-solid
         */
        readonly solid?: CfnDashboard.ConditionalFormattingSolidColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html
     */
    interface ConditionalFormattingCustomIconConditionProperty {
        /**
         * `CfnDashboard.ConditionalFormattingCustomIconConditionProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-color
         */
        readonly color?: string;
        /**
         * `CfnDashboard.ConditionalFormattingCustomIconConditionProperty.DisplayConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-displayconfiguration
         */
        readonly displayConfiguration?: CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ConditionalFormattingCustomIconConditionProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-expression
         */
        readonly expression: string;
        /**
         * `CfnDashboard.ConditionalFormattingCustomIconConditionProperty.IconOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconcondition.html#cfn-quicksight-dashboard-conditionalformattingcustomiconcondition-iconoptions
         */
        readonly iconOptions: CfnDashboard.ConditionalFormattingCustomIconOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html
     */
    interface ConditionalFormattingCustomIconOptionsProperty {
        /**
         * `CfnDashboard.ConditionalFormattingCustomIconOptionsProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-icon
         */
        readonly icon?: string;
        /**
         * `CfnDashboard.ConditionalFormattingCustomIconOptionsProperty.UnicodeIcon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingcustomiconoptions.html#cfn-quicksight-dashboard-conditionalformattingcustomiconoptions-unicodeicon
         */
        readonly unicodeIcon?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html
     */
    interface ConditionalFormattingGradientColorProperty {
        /**
         * `CfnDashboard.ConditionalFormattingGradientColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-color
         */
        readonly color: CfnDashboard.GradientColorProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ConditionalFormattingGradientColorProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattinggradientcolor.html#cfn-quicksight-dashboard-conditionalformattinggradientcolor-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html
     */
    interface ConditionalFormattingIconProperty {
        /**
         * `CfnDashboard.ConditionalFormattingIconProperty.CustomCondition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-customcondition
         */
        readonly customCondition?: CfnDashboard.ConditionalFormattingCustomIconConditionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ConditionalFormattingIconProperty.IconSet`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicon.html#cfn-quicksight-dashboard-conditionalformattingicon-iconset
         */
        readonly iconSet?: CfnDashboard.ConditionalFormattingIconSetProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html
     */
    interface ConditionalFormattingIconDisplayConfigurationProperty {
        /**
         * `CfnDashboard.ConditionalFormattingIconDisplayConfigurationProperty.IconDisplayOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-dashboard-conditionalformattingicondisplayconfiguration-icondisplayoption
         */
        readonly iconDisplayOption?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html
     */
    interface ConditionalFormattingIconSetProperty {
        /**
         * `CfnDashboard.ConditionalFormattingIconSetProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-expression
         */
        readonly expression: string;
        /**
         * `CfnDashboard.ConditionalFormattingIconSetProperty.IconSetType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingiconset.html#cfn-quicksight-dashboard-conditionalformattingiconset-iconsettype
         */
        readonly iconSetType?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html
     */
    interface ConditionalFormattingSolidColorProperty {
        /**
         * `CfnDashboard.ConditionalFormattingSolidColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-color
         */
        readonly color?: string;
        /**
         * `CfnDashboard.ConditionalFormattingSolidColorProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-conditionalformattingsolidcolor.html#cfn-quicksight-dashboard-conditionalformattingsolidcolor-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html
     */
    interface ContributionAnalysisDefaultProperty {
        /**
         * `CfnDashboard.ContributionAnalysisDefaultProperty.ContributorDimensions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-contributordimensions
         */
        readonly contributorDimensions: Array<CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ContributionAnalysisDefaultProperty.MeasureFieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-contributionanalysisdefault.html#cfn-quicksight-dashboard-contributionanalysisdefault-measurefieldid
         */
        readonly measureFieldId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html
     */
    interface CurrencyDisplayFormatConfigurationProperty {
        /**
         * `CfnDashboard.CurrencyDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnDashboard.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CurrencyDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnDashboard.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CurrencyDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnDashboard.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CurrencyDisplayFormatConfigurationProperty.NumberScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * `CfnDashboard.CurrencyDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnDashboard.CurrencyDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnDashboard.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CurrencyDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
        /**
         * `CfnDashboard.CurrencyDisplayFormatConfigurationProperty.Symbol`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-currencydisplayformatconfiguration.html#cfn-quicksight-dashboard-currencydisplayformatconfiguration-symbol
         */
        readonly symbol?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html
     */
    interface CustomActionFilterOperationProperty {
        /**
         * `CfnDashboard.CustomActionFilterOperationProperty.SelectedFieldsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-selectedfieldsconfiguration
         */
        readonly selectedFieldsConfiguration: CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CustomActionFilterOperationProperty.TargetVisualsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionfilteroperation.html#cfn-quicksight-dashboard-customactionfilteroperation-targetvisualsconfiguration
         */
        readonly targetVisualsConfiguration: CfnDashboard.FilterOperationTargetVisualsConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html
     */
    interface CustomActionNavigationOperationProperty {
        /**
         * `CfnDashboard.CustomActionNavigationOperationProperty.LocalNavigationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionnavigationoperation.html#cfn-quicksight-dashboard-customactionnavigationoperation-localnavigationconfiguration
         */
        readonly localNavigationConfiguration?: CfnDashboard.LocalNavigationConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html
     */
    interface CustomActionSetParametersOperationProperty {
        /**
         * `CfnDashboard.CustomActionSetParametersOperationProperty.ParameterValueConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionsetparametersoperation.html#cfn-quicksight-dashboard-customactionsetparametersoperation-parametervalueconfigurations
         */
        readonly parameterValueConfigurations: Array<CfnDashboard.SetParameterValueConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html
     */
    interface CustomActionURLOperationProperty {
        /**
         * `CfnDashboard.CustomActionURLOperationProperty.URLTarget`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltarget
         */
        readonly urlTarget: string;
        /**
         * `CfnDashboard.CustomActionURLOperationProperty.URLTemplate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customactionurloperation.html#cfn-quicksight-dashboard-customactionurloperation-urltemplate
         */
        readonly urlTemplate: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html
     */
    interface CustomColorProperty {
        /**
         * `CfnDashboard.CustomColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-color
         */
        readonly color: string;
        /**
         * `CfnDashboard.CustomColorProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnDashboard.CustomColorProperty.SpecialValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcolor.html#cfn-quicksight-dashboard-customcolor-specialvalue
         */
        readonly specialValue?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html
     */
    interface CustomContentConfigurationProperty {
        /**
         * `CfnDashboard.CustomContentConfigurationProperty.ContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenttype
         */
        readonly contentType?: string;
        /**
         * `CfnDashboard.CustomContentConfigurationProperty.ContentUrl`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-contenturl
         */
        readonly contentUrl?: string;
        /**
         * `CfnDashboard.CustomContentConfigurationProperty.ImageScaling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentconfiguration.html#cfn-quicksight-dashboard-customcontentconfiguration-imagescaling
         */
        readonly imageScaling?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html
     */
    interface CustomContentVisualProperty {
        /**
         * `CfnDashboard.CustomContentVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.CustomContentVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.CustomContentConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CustomContentVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnDashboard.CustomContentVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CustomContentVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CustomContentVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customcontentvisual.html#cfn-quicksight-dashboard-customcontentvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html
     */
    interface CustomFilterConfigurationProperty {
        /**
         * `CfnDashboard.CustomFilterConfigurationProperty.CategoryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-categoryvalue
         */
        readonly categoryValue?: string;
        /**
         * `CfnDashboard.CustomFilterConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnDashboard.CustomFilterConfigurationProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnDashboard.CustomFilterConfigurationProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnDashboard.CustomFilterConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterconfiguration.html#cfn-quicksight-dashboard-customfilterconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html
     */
    interface CustomFilterListConfigurationProperty {
        /**
         * `CfnDashboard.CustomFilterListConfigurationProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: string[];
        /**
         * `CfnDashboard.CustomFilterListConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnDashboard.CustomFilterListConfigurationProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnDashboard.CustomFilterListConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customfilterlistconfiguration.html#cfn-quicksight-dashboard-customfilterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html
     */
    interface CustomNarrativeOptionsProperty {
        /**
         * `CfnDashboard.CustomNarrativeOptionsProperty.Narrative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customnarrativeoptions.html#cfn-quicksight-dashboard-customnarrativeoptions-narrative
         */
        readonly narrative: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html
     */
    interface CustomParameterValuesProperty {
        /**
         * `CfnDashboard.CustomParameterValuesProperty.DateTimeValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-datetimevalues
         */
        readonly dateTimeValues?: string[];
        /**
         * `CfnDashboard.CustomParameterValuesProperty.DecimalValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-decimalvalues
         */
        readonly decimalValues?: number[] | cdk.IResolvable;
        /**
         * `CfnDashboard.CustomParameterValuesProperty.IntegerValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-integervalues
         */
        readonly integerValues?: number[] | cdk.IResolvable;
        /**
         * `CfnDashboard.CustomParameterValuesProperty.StringValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customparametervalues.html#cfn-quicksight-dashboard-customparametervalues-stringvalues
         */
        readonly stringValues?: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html
     */
    interface CustomValuesConfigurationProperty {
        /**
         * `CfnDashboard.CustomValuesConfigurationProperty.CustomValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-customvalues
         */
        readonly customValues: CfnDashboard.CustomParameterValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.CustomValuesConfigurationProperty.IncludeNullValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-customvaluesconfiguration.html#cfn-quicksight-dashboard-customvaluesconfiguration-includenullvalue
         */
        readonly includeNullValue?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * Dashboard error.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html
     */
    interface DashboardErrorProperty {
        /**
         * Message.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-message
         */
        readonly message?: string;
        /**
         * Type.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-type
         */
        readonly type?: string;
        /**
         * `CfnDashboard.DashboardErrorProperty.ViolatedEntities`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboarderror.html#cfn-quicksight-dashboard-dashboarderror-violatedentities
         */
        readonly violatedEntities?: Array<CfnDashboard.EntityProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * Dashboard publish options.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html
     */
    interface DashboardPublishOptionsProperty {
        /**
         * Ad hoc (one-time) filtering option.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-adhocfilteringoption
         */
        readonly adHocFilteringOption?: CfnDashboard.AdHocFilteringOptionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardPublishOptionsProperty.DataPointDrillUpDownOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointdrillupdownoption
         */
        readonly dataPointDrillUpDownOption?: CfnDashboard.DataPointDrillUpDownOptionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardPublishOptionsProperty.DataPointMenuLabelOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointmenulabeloption
         */
        readonly dataPointMenuLabelOption?: CfnDashboard.DataPointMenuLabelOptionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardPublishOptionsProperty.DataPointTooltipOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-datapointtooltipoption
         */
        readonly dataPointTooltipOption?: CfnDashboard.DataPointTooltipOptionProperty | cdk.IResolvable;
        /**
         * Export to .csv option.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exporttocsvoption
         */
        readonly exportToCsvOption?: CfnDashboard.ExportToCSVOptionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardPublishOptionsProperty.ExportWithHiddenFieldsOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-exportwithhiddenfieldsoption
         */
        readonly exportWithHiddenFieldsOption?: CfnDashboard.ExportWithHiddenFieldsOptionProperty | cdk.IResolvable;
        /**
         * Sheet controls option.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetcontrolsoption
         */
        readonly sheetControlsOption?: CfnDashboard.SheetControlsOptionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardPublishOptionsProperty.SheetLayoutElementMaximizationOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-sheetlayoutelementmaximizationoption
         */
        readonly sheetLayoutElementMaximizationOption?: CfnDashboard.SheetLayoutElementMaximizationOptionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardPublishOptionsProperty.VisualAxisSortOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualaxissortoption
         */
        readonly visualAxisSortOption?: CfnDashboard.VisualAxisSortOptionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardPublishOptionsProperty.VisualMenuOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualmenuoption
         */
        readonly visualMenuOption?: CfnDashboard.VisualMenuOptionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardPublishOptionsProperty.VisualPublishOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardpublishoptions.html#cfn-quicksight-dashboard-dashboardpublishoptions-visualpublishoptions
         */
        readonly visualPublishOptions?: CfnDashboard.DashboardVisualPublishOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * Dashboard source entity.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html
     */
    interface DashboardSourceEntityProperty {
        /**
         * Source template.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourceentity.html#cfn-quicksight-dashboard-dashboardsourceentity-sourcetemplate
         */
        readonly sourceTemplate?: CfnDashboard.DashboardSourceTemplateProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * Dashboard source template.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html
     */
    interface DashboardSourceTemplateProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-arn
         */
        readonly arn: string;
        /**
         * Dataset references.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardsourcetemplate.html#cfn-quicksight-dashboard-dashboardsourcetemplate-datasetreferences
         */
        readonly dataSetReferences: Array<CfnDashboard.DataSetReferenceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * Dashboard version.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html
     */
    interface DashboardVersionProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-arn
         */
        readonly arn?: string;
        /**
         * The time that this dashboard version was created.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-createdtime
         */
        readonly createdTime?: string;
        /**
         * The Amazon Resource Numbers (ARNs) for the datasets that are associated with this version of the dashboard.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-datasetarns
         */
        readonly dataSetArns?: string[];
        /**
         * Description.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-description
         */
        readonly description?: string;
        /**
         * Errors associated with this dashboard version.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-errors
         */
        readonly errors?: Array<CfnDashboard.DashboardErrorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A list of the associated sheets with the unique identifier and name of each sheet.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sheets
         */
        readonly sheets?: Array<CfnDashboard.SheetProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Source entity ARN.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-sourceentityarn
         */
        readonly sourceEntityArn?: string;
        /**
         * The HTTP status of the request.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-status
         */
        readonly status?: string;
        /**
         * The ARN of the theme associated with a version of the dashboard.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-themearn
         */
        readonly themeArn?: string;
        /**
         * Version number for this version of the dashboard.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversion.html#cfn-quicksight-dashboard-dashboardversion-versionnumber
         */
        readonly versionNumber?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html
     */
    interface DashboardVersionDefinitionProperty {
        /**
         * `CfnDashboard.DashboardVersionDefinitionProperty.AnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-analysisdefaults
         */
        readonly analysisDefaults?: CfnDashboard.AnalysisDefaultsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardVersionDefinitionProperty.CalculatedFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-calculatedfields
         */
        readonly calculatedFields?: Array<CfnDashboard.CalculatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardVersionDefinitionProperty.ColumnConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-columnconfigurations
         */
        readonly columnConfigurations?: Array<CfnDashboard.ColumnConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardVersionDefinitionProperty.DataSetIdentifierDeclarations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-datasetidentifierdeclarations
         */
        readonly dataSetIdentifierDeclarations: Array<CfnDashboard.DataSetIdentifierDeclarationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardVersionDefinitionProperty.FilterGroups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-filtergroups
         */
        readonly filterGroups?: Array<CfnDashboard.FilterGroupProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardVersionDefinitionProperty.ParameterDeclarations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-parameterdeclarations
         */
        readonly parameterDeclarations?: Array<CfnDashboard.ParameterDeclarationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DashboardVersionDefinitionProperty.Sheets`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardversiondefinition.html#cfn-quicksight-dashboard-dashboardversiondefinition-sheets
         */
        readonly sheets?: Array<CfnDashboard.SheetDefinitionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html
     */
    interface DashboardVisualPublishOptionsProperty {
        /**
         * `CfnDashboard.DashboardVisualPublishOptionsProperty.ExportHiddenFieldsOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dashboardvisualpublishoptions.html#cfn-quicksight-dashboard-dashboardvisualpublishoptions-exporthiddenfieldsoption
         */
        readonly exportHiddenFieldsOption?: CfnDashboard.ExportHiddenFieldsOptionProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html
     */
    interface DataBarsOptionsProperty {
        /**
         * `CfnDashboard.DataBarsOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.DataBarsOptionsProperty.NegativeColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-negativecolor
         */
        readonly negativeColor?: string;
        /**
         * `CfnDashboard.DataBarsOptionsProperty.PositiveColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-databarsoptions.html#cfn-quicksight-dashboard-databarsoptions-positivecolor
         */
        readonly positiveColor?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html
     */
    interface DataColorProperty {
        /**
         * `CfnDashboard.DataColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-color
         */
        readonly color?: string;
        /**
         * `CfnDashboard.DataColorProperty.DataValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datacolor.html#cfn-quicksight-dashboard-datacolor-datavalue
         */
        readonly dataValue?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html
     */
    interface DataFieldSeriesItemProperty {
        /**
         * `CfnDashboard.DataFieldSeriesItemProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * `CfnDashboard.DataFieldSeriesItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.DataFieldSeriesItemProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnDashboard.DataFieldSeriesItemProperty.Settings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datafieldseriesitem.html#cfn-quicksight-dashboard-datafieldseriesitem-settings
         */
        readonly settings?: CfnDashboard.LineChartSeriesSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html
     */
    interface DataLabelOptionsProperty {
        /**
         * `CfnDashboard.DataLabelOptionsProperty.CategoryLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * `CfnDashboard.DataLabelOptionsProperty.DataLabelTypes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-datalabeltypes
         */
        readonly dataLabelTypes?: Array<CfnDashboard.DataLabelTypeProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DataLabelOptionsProperty.LabelColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * `CfnDashboard.DataLabelOptionsProperty.LabelContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelcontent
         */
        readonly labelContent?: string;
        /**
         * `CfnDashboard.DataLabelOptionsProperty.LabelFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DataLabelOptionsProperty.MeasureLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * `CfnDashboard.DataLabelOptionsProperty.Overlap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-overlap
         */
        readonly overlap?: string;
        /**
         * `CfnDashboard.DataLabelOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-position
         */
        readonly position?: string;
        /**
         * `CfnDashboard.DataLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeloptions.html#cfn-quicksight-dashboard-datalabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html
     */
    interface DataLabelTypeProperty {
        /**
         * `CfnDashboard.DataLabelTypeProperty.DataPathLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-datapathlabeltype
         */
        readonly dataPathLabelType?: CfnDashboard.DataPathLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DataLabelTypeProperty.FieldLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-fieldlabeltype
         */
        readonly fieldLabelType?: CfnDashboard.FieldLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DataLabelTypeProperty.MaximumLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-maximumlabeltype
         */
        readonly maximumLabelType?: CfnDashboard.MaximumLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DataLabelTypeProperty.MinimumLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-minimumlabeltype
         */
        readonly minimumLabelType?: CfnDashboard.MinimumLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DataLabelTypeProperty.RangeEndsLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datalabeltype.html#cfn-quicksight-dashboard-datalabeltype-rangeendslabeltype
         */
        readonly rangeEndsLabelType?: CfnDashboard.RangeEndsLabelTypeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html
     */
    interface DataPathColorProperty {
        /**
         * `CfnDashboard.DataPathColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-color
         */
        readonly color: string;
        /**
         * `CfnDashboard.DataPathColorProperty.Element`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-element
         */
        readonly element: CfnDashboard.DataPathValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DataPathColorProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathcolor.html#cfn-quicksight-dashboard-datapathcolor-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html
     */
    interface DataPathLabelTypeProperty {
        /**
         * `CfnDashboard.DataPathLabelTypeProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * `CfnDashboard.DataPathLabelTypeProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnDashboard.DataPathLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathlabeltype.html#cfn-quicksight-dashboard-datapathlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html
     */
    interface DataPathSortProperty {
        /**
         * `CfnDashboard.DataPathSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-direction
         */
        readonly direction: string;
        /**
         * `CfnDashboard.DataPathSortProperty.SortPaths`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathsort.html#cfn-quicksight-dashboard-datapathsort-sortpaths
         */
        readonly sortPaths: Array<CfnDashboard.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html
     */
    interface DataPathValueProperty {
        /**
         * `CfnDashboard.DataPathValueProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.DataPathValueProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapathvalue.html#cfn-quicksight-dashboard-datapathvalue-fieldvalue
         */
        readonly fieldValue: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html
     */
    interface DataPointDrillUpDownOptionProperty {
        /**
         * `CfnDashboard.DataPointDrillUpDownOptionProperty.AvailabilityStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointdrillupdownoption.html#cfn-quicksight-dashboard-datapointdrillupdownoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html
     */
    interface DataPointMenuLabelOptionProperty {
        /**
         * `CfnDashboard.DataPointMenuLabelOptionProperty.AvailabilityStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointmenulabeloption.html#cfn-quicksight-dashboard-datapointmenulabeloption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html
     */
    interface DataPointTooltipOptionProperty {
        /**
         * `CfnDashboard.DataPointTooltipOptionProperty.AvailabilityStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datapointtooltipoption.html#cfn-quicksight-dashboard-datapointtooltipoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html
     */
    interface DataSetIdentifierDeclarationProperty {
        /**
         * `CfnDashboard.DataSetIdentifierDeclarationProperty.DataSetArn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * `CfnDashboard.DataSetIdentifierDeclarationProperty.Identifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetidentifierdeclaration.html#cfn-quicksight-dashboard-datasetidentifierdeclaration-identifier
         */
        readonly identifier: string;
    }
}
export declare namespace CfnDashboard {
    /**
     * Dataset reference.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html
     */
    interface DataSetReferenceProperty {
        /**
         * Dataset Amazon Resource Name (ARN).
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * Dataset placeholder.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datasetreference.html#cfn-quicksight-dashboard-datasetreference-datasetplaceholder
         */
        readonly dataSetPlaceholder: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html
     */
    interface DateAxisOptionsProperty {
        /**
         * `CfnDashboard.DateAxisOptionsProperty.MissingDateVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dateaxisoptions.html#cfn-quicksight-dashboard-dateaxisoptions-missingdatevisibility
         */
        readonly missingDateVisibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html
     */
    interface DateDimensionFieldProperty {
        /**
         * `CfnDashboard.DateDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DateDimensionFieldProperty.DateGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-dategranularity
         */
        readonly dateGranularity?: string;
        /**
         * `CfnDashboard.DateDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.DateDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DateDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datedimensionfield.html#cfn-quicksight-dashboard-datedimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html
     */
    interface DateMeasureFieldProperty {
        /**
         * `CfnDashboard.DateMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * `CfnDashboard.DateMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DateMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.DateMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datemeasurefield.html#cfn-quicksight-dashboard-datemeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.DateTimeFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html
     */
    interface DateTimeDefaultValuesProperty {
        /**
         * `CfnDashboard.DateTimeDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnDashboard.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DateTimeDefaultValuesProperty.RollingDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-rollingdate
         */
        readonly rollingDate?: CfnDashboard.RollingDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DateTimeDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimedefaultvalues.html#cfn-quicksight-dashboard-datetimedefaultvalues-staticvalues
         */
        readonly staticValues?: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html
     */
    interface DateTimeFormatConfigurationProperty {
        /**
         * `CfnDashboard.DateTimeFormatConfigurationProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnDashboard.DateTimeFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnDashboard.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DateTimeFormatConfigurationProperty.NumericFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeformatconfiguration.html#cfn-quicksight-dashboard-datetimeformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: CfnDashboard.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html
     */
    interface DateTimeHierarchyProperty {
        /**
         * `CfnDashboard.DateTimeHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnDashboard.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DateTimeHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimehierarchy.html#cfn-quicksight-dashboard-datetimehierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     * A date-time parameter.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html
     */
    interface DateTimeParameterProperty {
        /**
         * A display name for the date-time parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-name
         */
        readonly name: string;
        /**
         * The values for the date-time parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameter.html#cfn-quicksight-dashboard-datetimeparameter-values
         */
        readonly values: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html
     */
    interface DateTimeParameterDeclarationProperty {
        /**
         * `CfnDashboard.DateTimeParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnDashboard.DateTimeDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DateTimeParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnDashboard.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DateTimeParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnDashboard.DateTimeParameterDeclarationProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * `CfnDashboard.DateTimeParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimeparameterdeclaration.html#cfn-quicksight-dashboard-datetimeparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html
     */
    interface DateTimePickerControlDisplayOptionsProperty {
        /**
         * `CfnDashboard.DateTimePickerControlDisplayOptionsProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnDashboard.DateTimePickerControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimepickercontroldisplayoptions.html#cfn-quicksight-dashboard-datetimepickercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html
     */
    interface DateTimeValueWhenUnsetConfigurationProperty {
        /**
         * `CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * `CfnDashboard.DateTimeValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html
     */
    interface DecimalDefaultValuesProperty {
        /**
         * `CfnDashboard.DecimalDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnDashboard.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DecimalDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimaldefaultvalues.html#cfn-quicksight-dashboard-decimaldefaultvalues-staticvalues
         */
        readonly staticValues?: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * A decimal parameter.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html
     */
    interface DecimalParameterProperty {
        /**
         * A display name for the decimal parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-name
         */
        readonly name: string;
        /**
         * The values for the decimal parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameter.html#cfn-quicksight-dashboard-decimalparameter-values
         */
        readonly values: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html
     */
    interface DecimalParameterDeclarationProperty {
        /**
         * `CfnDashboard.DecimalParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnDashboard.DecimalDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DecimalParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnDashboard.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.DecimalParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnDashboard.DecimalParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnDashboard.DecimalParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalparameterdeclaration.html#cfn-quicksight-dashboard-decimalparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnDashboard.DecimalValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html
     */
    interface DecimalPlacesConfigurationProperty {
        /**
         * `CfnDashboard.DecimalPlacesConfigurationProperty.DecimalPlaces`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalplacesconfiguration.html#cfn-quicksight-dashboard-decimalplacesconfiguration-decimalplaces
         */
        readonly decimalPlaces: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html
     */
    interface DecimalValueWhenUnsetConfigurationProperty {
        /**
         * `CfnDashboard.DecimalValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * `CfnDashboard.DecimalValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html
     */
    interface DefaultFreeFormLayoutConfigurationProperty {
        /**
         * `CfnDashboard.DefaultFreeFormLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultfreeformlayoutconfiguration.html#cfn-quicksight-dashboard-defaultfreeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html
     */
    interface DefaultGridLayoutConfigurationProperty {
        /**
         * `CfnDashboard.DefaultGridLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultgridlayoutconfiguration.html#cfn-quicksight-dashboard-defaultgridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnDashboard.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html
     */
    interface DefaultInteractiveLayoutConfigurationProperty {
        /**
         * `CfnDashboard.DefaultInteractiveLayoutConfigurationProperty.FreeForm`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-freeform
         */
        readonly freeForm?: CfnDashboard.DefaultFreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DefaultInteractiveLayoutConfigurationProperty.Grid`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultinteractivelayoutconfiguration.html#cfn-quicksight-dashboard-defaultinteractivelayoutconfiguration-grid
         */
        readonly grid?: CfnDashboard.DefaultGridLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html
     */
    interface DefaultNewSheetConfigurationProperty {
        /**
         * `CfnDashboard.DefaultNewSheetConfigurationProperty.InteractiveLayoutConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-interactivelayoutconfiguration
         */
        readonly interactiveLayoutConfiguration?: CfnDashboard.DefaultInteractiveLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DefaultNewSheetConfigurationProperty.PaginatedLayoutConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-paginatedlayoutconfiguration
         */
        readonly paginatedLayoutConfiguration?: CfnDashboard.DefaultPaginatedLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DefaultNewSheetConfigurationProperty.SheetContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultnewsheetconfiguration.html#cfn-quicksight-dashboard-defaultnewsheetconfiguration-sheetcontenttype
         */
        readonly sheetContentType?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html
     */
    interface DefaultPaginatedLayoutConfigurationProperty {
        /**
         * `CfnDashboard.DefaultPaginatedLayoutConfigurationProperty.SectionBased`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultpaginatedlayoutconfiguration-sectionbased
         */
        readonly sectionBased?: CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html
     */
    interface DefaultSectionBasedLayoutConfigurationProperty {
        /**
         * `CfnDashboard.DefaultSectionBasedLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-defaultsectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html
     */
    interface DestinationParameterValueConfigurationProperty {
        /**
         * `CfnDashboard.DestinationParameterValueConfigurationProperty.CustomValuesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-customvaluesconfiguration
         */
        readonly customValuesConfiguration?: CfnDashboard.CustomValuesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DestinationParameterValueConfigurationProperty.SelectAllValueOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-selectallvalueoptions
         */
        readonly selectAllValueOptions?: string;
        /**
         * `CfnDashboard.DestinationParameterValueConfigurationProperty.SourceField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourcefield
         */
        readonly sourceField?: string;
        /**
         * `CfnDashboard.DestinationParameterValueConfigurationProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-destinationparametervalueconfiguration.html#cfn-quicksight-dashboard-destinationparametervalueconfiguration-sourceparametername
         */
        readonly sourceParameterName?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html
     */
    interface DimensionFieldProperty {
        /**
         * `CfnDashboard.DimensionFieldProperty.CategoricalDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-categoricaldimensionfield
         */
        readonly categoricalDimensionField?: CfnDashboard.CategoricalDimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DimensionFieldProperty.DateDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-datedimensionfield
         */
        readonly dateDimensionField?: CfnDashboard.DateDimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DimensionFieldProperty.NumericalDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dimensionfield.html#cfn-quicksight-dashboard-dimensionfield-numericaldimensionfield
         */
        readonly numericalDimensionField?: CfnDashboard.NumericalDimensionFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html
     */
    interface DonutCenterOptionsProperty {
        /**
         * `CfnDashboard.DonutCenterOptionsProperty.LabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutcenteroptions.html#cfn-quicksight-dashboard-donutcenteroptions-labelvisibility
         */
        readonly labelVisibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html
     */
    interface DonutOptionsProperty {
        /**
         * `CfnDashboard.DonutOptionsProperty.ArcOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-arcoptions
         */
        readonly arcOptions?: CfnDashboard.ArcOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DonutOptionsProperty.DonutCenterOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-donutoptions.html#cfn-quicksight-dashboard-donutoptions-donutcenteroptions
         */
        readonly donutCenterOptions?: CfnDashboard.DonutCenterOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html
     */
    interface DrillDownFilterProperty {
        /**
         * `CfnDashboard.DrillDownFilterProperty.CategoryFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-categoryfilter
         */
        readonly categoryFilter?: CfnDashboard.CategoryDrillDownFilterProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DrillDownFilterProperty.NumericEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-numericequalityfilter
         */
        readonly numericEqualityFilter?: CfnDashboard.NumericEqualityDrillDownFilterProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DrillDownFilterProperty.TimeRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-drilldownfilter.html#cfn-quicksight-dashboard-drilldownfilter-timerangefilter
         */
        readonly timeRangeFilter?: CfnDashboard.TimeRangeDrillDownFilterProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html
     */
    interface DropDownControlDisplayOptionsProperty {
        /**
         * `CfnDashboard.DropDownControlDisplayOptionsProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: CfnDashboard.ListControlSelectAllOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DropDownControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dropdowncontroldisplayoptions.html#cfn-quicksight-dashboard-dropdowncontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html
     */
    interface DynamicDefaultValueProperty {
        /**
         * `CfnDashboard.DynamicDefaultValueProperty.DefaultValueColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-defaultvaluecolumn
         */
        readonly defaultValueColumn: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DynamicDefaultValueProperty.GroupNameColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-groupnamecolumn
         */
        readonly groupNameColumn?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.DynamicDefaultValueProperty.UserNameColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-dynamicdefaultvalue.html#cfn-quicksight-dashboard-dynamicdefaultvalue-usernamecolumn
         */
        readonly userNameColumn?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html
     */
    interface EmptyVisualProperty {
        /**
         * `CfnDashboard.EmptyVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.EmptyVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnDashboard.EmptyVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-emptyvisual.html#cfn-quicksight-dashboard-emptyvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html
     */
    interface EntityProperty {
        /**
         * `CfnDashboard.EntityProperty.Path`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-entity.html#cfn-quicksight-dashboard-entity-path
         */
        readonly path?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html
     */
    interface ExcludePeriodConfigurationProperty {
        /**
         * `CfnDashboard.ExcludePeriodConfigurationProperty.Amount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-amount
         */
        readonly amount: number;
        /**
         * `CfnDashboard.ExcludePeriodConfigurationProperty.Granularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-granularity
         */
        readonly granularity: string;
        /**
         * `CfnDashboard.ExcludePeriodConfigurationProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-excludeperiodconfiguration.html#cfn-quicksight-dashboard-excludeperiodconfiguration-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html
     */
    interface ExplicitHierarchyProperty {
        /**
         * `CfnDashboard.ExplicitHierarchyProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-columns
         */
        readonly columns: Array<CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ExplicitHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnDashboard.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ExplicitHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-explicithierarchy.html#cfn-quicksight-dashboard-explicithierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html
     */
    interface ExportHiddenFieldsOptionProperty {
        /**
         * `CfnDashboard.ExportHiddenFieldsOptionProperty.AvailabilityStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporthiddenfieldsoption.html#cfn-quicksight-dashboard-exporthiddenfieldsoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     * Export to .csv option.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html
     */
    interface ExportToCSVOptionProperty {
        /**
         * Availability status.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exporttocsvoption.html#cfn-quicksight-dashboard-exporttocsvoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html
     */
    interface ExportWithHiddenFieldsOptionProperty {
        /**
         * `CfnDashboard.ExportWithHiddenFieldsOptionProperty.AvailabilityStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-exportwithhiddenfieldsoption.html#cfn-quicksight-dashboard-exportwithhiddenfieldsoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html
     */
    interface FieldBasedTooltipProperty {
        /**
         * `CfnDashboard.FieldBasedTooltipProperty.AggregationVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-aggregationvisibility
         */
        readonly aggregationVisibility?: string;
        /**
         * `CfnDashboard.FieldBasedTooltipProperty.TooltipFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltipfields
         */
        readonly tooltipFields?: Array<CfnDashboard.TooltipItemProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FieldBasedTooltipProperty.TooltipTitleType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldbasedtooltip.html#cfn-quicksight-dashboard-fieldbasedtooltip-tooltiptitletype
         */
        readonly tooltipTitleType?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html
     */
    interface FieldLabelTypeProperty {
        /**
         * `CfnDashboard.FieldLabelTypeProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * `CfnDashboard.FieldLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldlabeltype.html#cfn-quicksight-dashboard-fieldlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html
     */
    interface FieldSeriesItemProperty {
        /**
         * `CfnDashboard.FieldSeriesItemProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * `CfnDashboard.FieldSeriesItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.FieldSeriesItemProperty.Settings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldseriesitem.html#cfn-quicksight-dashboard-fieldseriesitem-settings
         */
        readonly settings?: CfnDashboard.LineChartSeriesSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html
     */
    interface FieldSortProperty {
        /**
         * `CfnDashboard.FieldSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-direction
         */
        readonly direction: string;
        /**
         * `CfnDashboard.FieldSortProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsort.html#cfn-quicksight-dashboard-fieldsort-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html
     */
    interface FieldSortOptionsProperty {
        /**
         * `CfnDashboard.FieldSortOptionsProperty.ColumnSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-columnsort
         */
        readonly columnSort?: CfnDashboard.ColumnSortProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FieldSortOptionsProperty.FieldSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldsortoptions.html#cfn-quicksight-dashboard-fieldsortoptions-fieldsort
         */
        readonly fieldSort?: CfnDashboard.FieldSortProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html
     */
    interface FieldTooltipItemProperty {
        /**
         * `CfnDashboard.FieldTooltipItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.FieldTooltipItemProperty.Label`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-label
         */
        readonly label?: string;
        /**
         * `CfnDashboard.FieldTooltipItemProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fieldtooltipitem.html#cfn-quicksight-dashboard-fieldtooltipitem-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html
     */
    interface FilledMapAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.FilledMapAggregatedFieldWellsProperty.Geospatial`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapaggregatedfieldwells.html#cfn-quicksight-dashboard-filledmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html
     */
    interface FilledMapConditionalFormattingProperty {
        /**
         * `CfnDashboard.FilledMapConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformatting.html#cfn-quicksight-dashboard-filledmapconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions: Array<CfnDashboard.FilledMapConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html
     */
    interface FilledMapConditionalFormattingOptionProperty {
        /**
         * `CfnDashboard.FilledMapConditionalFormattingOptionProperty.Shape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconditionalformattingoption.html#cfn-quicksight-dashboard-filledmapconditionalformattingoption-shape
         */
        readonly shape: CfnDashboard.FilledMapShapeConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html
     */
    interface FilledMapConfigurationProperty {
        /**
         * `CfnDashboard.FilledMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.FilledMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapConfigurationProperty.MapStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnDashboard.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.FilledMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapConfigurationProperty.WindowOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapconfiguration.html#cfn-quicksight-dashboard-filledmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnDashboard.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html
     */
    interface FilledMapFieldWellsProperty {
        /**
         * `CfnDashboard.FilledMapFieldWellsProperty.FilledMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapfieldwells.html#cfn-quicksight-dashboard-filledmapfieldwells-filledmapaggregatedfieldwells
         */
        readonly filledMapAggregatedFieldWells?: CfnDashboard.FilledMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html
     */
    interface FilledMapShapeConditionalFormattingProperty {
        /**
         * `CfnDashboard.FilledMapShapeConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.FilledMapShapeConditionalFormattingProperty.Format`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapshapeconditionalformatting.html#cfn-quicksight-dashboard-filledmapshapeconditionalformatting-format
         */
        readonly format?: CfnDashboard.ShapeConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html
     */
    interface FilledMapSortConfigurationProperty {
        /**
         * `CfnDashboard.FilledMapSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapsortconfiguration.html#cfn-quicksight-dashboard-filledmapsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html
     */
    interface FilledMapVisualProperty {
        /**
         * `CfnDashboard.FilledMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.FilledMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnDashboard.FilledMapConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilledMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filledmapvisual.html#cfn-quicksight-dashboard-filledmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html
     */
    interface FilterProperty {
        /**
         * `CfnDashboard.FilterProperty.CategoryFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-categoryfilter
         */
        readonly categoryFilter?: CfnDashboard.CategoryFilterProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterProperty.NumericEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericequalityfilter
         */
        readonly numericEqualityFilter?: CfnDashboard.NumericEqualityFilterProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterProperty.NumericRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-numericrangefilter
         */
        readonly numericRangeFilter?: CfnDashboard.NumericRangeFilterProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterProperty.RelativeDatesFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-relativedatesfilter
         */
        readonly relativeDatesFilter?: CfnDashboard.RelativeDatesFilterProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterProperty.TimeEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timeequalityfilter
         */
        readonly timeEqualityFilter?: CfnDashboard.TimeEqualityFilterProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterProperty.TimeRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-timerangefilter
         */
        readonly timeRangeFilter?: CfnDashboard.TimeRangeFilterProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterProperty.TopBottomFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filter.html#cfn-quicksight-dashboard-filter-topbottomfilter
         */
        readonly topBottomFilter?: CfnDashboard.TopBottomFilterProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html
     */
    interface FilterControlProperty {
        /**
         * `CfnDashboard.FilterControlProperty.DateTimePicker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnDashboard.FilterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterControlProperty.Dropdown`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-dropdown
         */
        readonly dropdown?: CfnDashboard.FilterDropDownControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterControlProperty.List`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-list
         */
        readonly list?: CfnDashboard.FilterListControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterControlProperty.RelativeDateTime`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-relativedatetime
         */
        readonly relativeDateTime?: CfnDashboard.FilterRelativeDateTimeControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterControlProperty.Slider`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-slider
         */
        readonly slider?: CfnDashboard.FilterSliderControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterControlProperty.TextArea`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textarea
         */
        readonly textArea?: CfnDashboard.FilterTextAreaControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterControlProperty.TextField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtercontrol.html#cfn-quicksight-dashboard-filtercontrol-textfield
         */
        readonly textField?: CfnDashboard.FilterTextFieldControlProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html
     */
    interface FilterDateTimePickerControlProperty {
        /**
         * `CfnDashboard.FilterDateTimePickerControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterDateTimePickerControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnDashboard.FilterDateTimePickerControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnDashboard.FilterDateTimePickerControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-title
         */
        readonly title: string;
        /**
         * `CfnDashboard.FilterDateTimePickerControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdatetimepickercontrol.html#cfn-quicksight-dashboard-filterdatetimepickercontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html
     */
    interface FilterDropDownControlProperty {
        /**
         * `CfnDashboard.FilterDropDownControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnDashboard.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterDropDownControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterDropDownControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnDashboard.FilterDropDownControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnDashboard.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterDropDownControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnDashboard.FilterDropDownControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * `CfnDashboard.FilterDropDownControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterdropdowncontrol.html#cfn-quicksight-dashboard-filterdropdowncontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html
     */
    interface FilterGroupProperty {
        /**
         * `CfnDashboard.FilterGroupProperty.CrossDataset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-crossdataset
         */
        readonly crossDataset: string;
        /**
         * `CfnDashboard.FilterGroupProperty.FilterGroupId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filtergroupid
         */
        readonly filterGroupId: string;
        /**
         * `CfnDashboard.FilterGroupProperty.Filters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-filters
         */
        readonly filters: Array<CfnDashboard.FilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterGroupProperty.ScopeConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-scopeconfiguration
         */
        readonly scopeConfiguration: CfnDashboard.FilterScopeConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterGroupProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtergroup.html#cfn-quicksight-dashboard-filtergroup-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html
     */
    interface FilterListConfigurationProperty {
        /**
         * `CfnDashboard.FilterListConfigurationProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: string[];
        /**
         * `CfnDashboard.FilterListConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnDashboard.FilterListConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistconfiguration.html#cfn-quicksight-dashboard-filterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html
     */
    interface FilterListControlProperty {
        /**
         * `CfnDashboard.FilterListControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnDashboard.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterListControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.ListControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterListControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnDashboard.FilterListControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnDashboard.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterListControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnDashboard.FilterListControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-title
         */
        readonly title: string;
        /**
         * `CfnDashboard.FilterListControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterlistcontrol.html#cfn-quicksight-dashboard-filterlistcontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html
     */
    interface FilterOperationSelectedFieldsConfigurationProperty {
        /**
         * `CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfieldoptions
         */
        readonly selectedFieldOptions?: string;
        /**
         * `CfnDashboard.FilterOperationSelectedFieldsConfigurationProperty.SelectedFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-dashboard-filteroperationselectedfieldsconfiguration-selectedfields
         */
        readonly selectedFields?: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html
     */
    interface FilterOperationTargetVisualsConfigurationProperty {
        /**
         * `CfnDashboard.FilterOperationTargetVisualsConfigurationProperty.SameSheetTargetVisualConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-dashboard-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
         */
        readonly sameSheetTargetVisualConfiguration?: CfnDashboard.SameSheetTargetVisualConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html
     */
    interface FilterRelativeDateTimeControlProperty {
        /**
         * `CfnDashboard.FilterRelativeDateTimeControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterRelativeDateTimeControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnDashboard.FilterRelativeDateTimeControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnDashboard.FilterRelativeDateTimeControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterrelativedatetimecontrol.html#cfn-quicksight-dashboard-filterrelativedatetimecontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html
     */
    interface FilterScopeConfigurationProperty {
        /**
         * `CfnDashboard.FilterScopeConfigurationProperty.SelectedSheets`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterscopeconfiguration.html#cfn-quicksight-dashboard-filterscopeconfiguration-selectedsheets
         */
        readonly selectedSheets?: CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html
     */
    interface FilterSelectableValuesProperty {
        /**
         * `CfnDashboard.FilterSelectableValuesProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterselectablevalues.html#cfn-quicksight-dashboard-filterselectablevalues-values
         */
        readonly values?: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html
     */
    interface FilterSliderControlProperty {
        /**
         * `CfnDashboard.FilterSliderControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.SliderControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterSliderControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnDashboard.FilterSliderControlProperty.MaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * `CfnDashboard.FilterSliderControlProperty.MinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * `CfnDashboard.FilterSliderControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnDashboard.FilterSliderControlProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * `CfnDashboard.FilterSliderControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-title
         */
        readonly title: string;
        /**
         * `CfnDashboard.FilterSliderControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filterslidercontrol.html#cfn-quicksight-dashboard-filterslidercontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html
     */
    interface FilterTextAreaControlProperty {
        /**
         * `CfnDashboard.FilterTextAreaControlProperty.Delimiter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * `CfnDashboard.FilterTextAreaControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.TextAreaControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterTextAreaControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnDashboard.FilterTextAreaControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnDashboard.FilterTextAreaControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextareacontrol.html#cfn-quicksight-dashboard-filtertextareacontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html
     */
    interface FilterTextFieldControlProperty {
        /**
         * `CfnDashboard.FilterTextFieldControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.TextFieldControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FilterTextFieldControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnDashboard.FilterTextFieldControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnDashboard.FilterTextFieldControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-filtertextfieldcontrol.html#cfn-quicksight-dashboard-filtertextfieldcontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html
     */
    interface FontConfigurationProperty {
        /**
         * `CfnDashboard.FontConfigurationProperty.FontColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * `CfnDashboard.FontConfigurationProperty.FontDecoration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontdecoration
         */
        readonly fontDecoration?: string;
        /**
         * `CfnDashboard.FontConfigurationProperty.FontSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontsize
         */
        readonly fontSize?: CfnDashboard.FontSizeProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FontConfigurationProperty.FontStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontstyle
         */
        readonly fontStyle?: string;
        /**
         * `CfnDashboard.FontConfigurationProperty.FontWeight`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontconfiguration.html#cfn-quicksight-dashboard-fontconfiguration-fontweight
         */
        readonly fontWeight?: CfnDashboard.FontWeightProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html
     */
    interface FontSizeProperty {
        /**
         * `CfnDashboard.FontSizeProperty.Relative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontsize.html#cfn-quicksight-dashboard-fontsize-relative
         */
        readonly relative?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html
     */
    interface FontWeightProperty {
        /**
         * `CfnDashboard.FontWeightProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-fontweight.html#cfn-quicksight-dashboard-fontweight-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html
     */
    interface ForecastComputationProperty {
        /**
         * `CfnDashboard.ForecastComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.ForecastComputationProperty.CustomSeasonalityValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-customseasonalityvalue
         */
        readonly customSeasonalityValue?: number;
        /**
         * `CfnDashboard.ForecastComputationProperty.LowerBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * `CfnDashboard.ForecastComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.ForecastComputationProperty.PeriodsBackward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * `CfnDashboard.ForecastComputationProperty.PeriodsForward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * `CfnDashboard.ForecastComputationProperty.PredictionInterval`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * `CfnDashboard.ForecastComputationProperty.Seasonality`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-seasonality
         */
        readonly seasonality?: string;
        /**
         * `CfnDashboard.ForecastComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-time
         */
        readonly time: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ForecastComputationProperty.UpperBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-upperboundary
         */
        readonly upperBoundary?: number;
        /**
         * `CfnDashboard.ForecastComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastcomputation.html#cfn-quicksight-dashboard-forecastcomputation-value
         */
        readonly value?: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html
     */
    interface ForecastConfigurationProperty {
        /**
         * `CfnDashboard.ForecastConfigurationProperty.ForecastProperties`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-forecastproperties
         */
        readonly forecastProperties?: CfnDashboard.TimeBasedForecastPropertiesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ForecastConfigurationProperty.Scenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastconfiguration.html#cfn-quicksight-dashboard-forecastconfiguration-scenario
         */
        readonly scenario?: CfnDashboard.ForecastScenarioProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html
     */
    interface ForecastScenarioProperty {
        /**
         * `CfnDashboard.ForecastScenarioProperty.WhatIfPointScenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifpointscenario
         */
        readonly whatIfPointScenario?: CfnDashboard.WhatIfPointScenarioProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ForecastScenarioProperty.WhatIfRangeScenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-forecastscenario.html#cfn-quicksight-dashboard-forecastscenario-whatifrangescenario
         */
        readonly whatIfRangeScenario?: CfnDashboard.WhatIfRangeScenarioProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html
     */
    interface FormatConfigurationProperty {
        /**
         * `CfnDashboard.FormatConfigurationProperty.DateTimeFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-datetimeformatconfiguration
         */
        readonly dateTimeFormatConfiguration?: CfnDashboard.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FormatConfigurationProperty.NumberFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-numberformatconfiguration
         */
        readonly numberFormatConfiguration?: CfnDashboard.NumberFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FormatConfigurationProperty.StringFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-formatconfiguration.html#cfn-quicksight-dashboard-formatconfiguration-stringformatconfiguration
         */
        readonly stringFormatConfiguration?: CfnDashboard.StringFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html
     */
    interface FreeFormLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty.ScreenCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html
     */
    interface FreeFormLayoutConfigurationProperty {
        /**
         * `CfnDashboard.FreeFormLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnDashboard.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FreeFormLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutconfiguration.html#cfn-quicksight-dashboard-freeformlayoutconfiguration-elements
         */
        readonly elements: Array<CfnDashboard.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html
     */
    interface FreeFormLayoutElementProperty {
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.BackgroundStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-backgroundstyle
         */
        readonly backgroundStyle?: CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.BorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-borderstyle
         */
        readonly borderStyle?: CfnDashboard.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.ElementId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.ElementType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-height
         */
        readonly height: string;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.LoadingAnimation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-loadinganimation
         */
        readonly loadingAnimation?: CfnDashboard.LoadingAnimationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.RenderingRules`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-renderingrules
         */
        readonly renderingRules?: Array<CfnDashboard.SheetElementRenderingRuleProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.SelectedBorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-selectedborderstyle
         */
        readonly selectedBorderStyle?: CfnDashboard.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-width
         */
        readonly width: string;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.XAxisLocation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-xaxislocation
         */
        readonly xAxisLocation: string;
        /**
         * `CfnDashboard.FreeFormLayoutElementProperty.YAxisLocation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelement.html#cfn-quicksight-dashboard-freeformlayoutelement-yaxislocation
         */
        readonly yAxisLocation: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html
     */
    interface FreeFormLayoutElementBackgroundStyleProperty {
        /**
         * `CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-color
         */
        readonly color?: string;
        /**
         * `CfnDashboard.FreeFormLayoutElementBackgroundStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-dashboard-freeformlayoutelementbackgroundstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html
     */
    interface FreeFormLayoutElementBorderStyleProperty {
        /**
         * `CfnDashboard.FreeFormLayoutElementBorderStyleProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-color
         */
        readonly color?: string;
        /**
         * `CfnDashboard.FreeFormLayoutElementBorderStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutelementborderstyle.html#cfn-quicksight-dashboard-freeformlayoutelementborderstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html
     */
    interface FreeFormLayoutScreenCanvasSizeOptionsProperty {
        /**
         * `CfnDashboard.FreeFormLayoutScreenCanvasSizeOptionsProperty.OptimizedViewPortWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html
     */
    interface FreeFormSectionLayoutConfigurationProperty {
        /**
         * `CfnDashboard.FreeFormSectionLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-freeformsectionlayoutconfiguration.html#cfn-quicksight-dashboard-freeformsectionlayoutconfiguration-elements
         */
        readonly elements: Array<CfnDashboard.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html
     */
    interface FunnelChartAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.FunnelChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartaggregatedfieldwells.html#cfn-quicksight-dashboard-funnelchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html
     */
    interface FunnelChartConfigurationProperty {
        /**
         * `CfnDashboard.FunnelChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartConfigurationProperty.DataLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-datalabeloptions
         */
        readonly dataLabelOptions?: CfnDashboard.FunnelChartDataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.FunnelChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.FunnelChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartconfiguration.html#cfn-quicksight-dashboard-funnelchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html
     */
    interface FunnelChartDataLabelOptionsProperty {
        /**
         * `CfnDashboard.FunnelChartDataLabelOptionsProperty.CategoryLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * `CfnDashboard.FunnelChartDataLabelOptionsProperty.LabelColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * `CfnDashboard.FunnelChartDataLabelOptionsProperty.LabelFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartDataLabelOptionsProperty.MeasureDataLabelStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measuredatalabelstyle
         */
        readonly measureDataLabelStyle?: string;
        /**
         * `CfnDashboard.FunnelChartDataLabelOptionsProperty.MeasureLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * `CfnDashboard.FunnelChartDataLabelOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-position
         */
        readonly position?: string;
        /**
         * `CfnDashboard.FunnelChartDataLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartdatalabeloptions.html#cfn-quicksight-dashboard-funnelchartdatalabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html
     */
    interface FunnelChartFieldWellsProperty {
        /**
         * `CfnDashboard.FunnelChartFieldWellsProperty.FunnelChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartfieldwells.html#cfn-quicksight-dashboard-funnelchartfieldwells-funnelchartaggregatedfieldwells
         */
        readonly funnelChartAggregatedFieldWells?: CfnDashboard.FunnelChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html
     */
    interface FunnelChartSortConfigurationProperty {
        /**
         * `CfnDashboard.FunnelChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartsortconfiguration.html#cfn-quicksight-dashboard-funnelchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html
     */
    interface FunnelChartVisualProperty {
        /**
         * `CfnDashboard.FunnelChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.FunnelChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.FunnelChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-funnelchartvisual.html#cfn-quicksight-dashboard-funnelchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html
     */
    interface GaugeChartArcConditionalFormattingProperty {
        /**
         * `CfnDashboard.GaugeChartArcConditionalFormattingProperty.ForegroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartarcconditionalformatting.html#cfn-quicksight-dashboard-gaugechartarcconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html
     */
    interface GaugeChartConditionalFormattingProperty {
        /**
         * `CfnDashboard.GaugeChartConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformatting.html#cfn-quicksight-dashboard-gaugechartconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnDashboard.GaugeChartConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html
     */
    interface GaugeChartConditionalFormattingOptionProperty {
        /**
         * `CfnDashboard.GaugeChartConditionalFormattingOptionProperty.Arc`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-arc
         */
        readonly arc?: CfnDashboard.GaugeChartArcConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartConditionalFormattingOptionProperty.PrimaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconditionalformattingoption.html#cfn-quicksight-dashboard-gaugechartconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html
     */
    interface GaugeChartConfigurationProperty {
        /**
         * `CfnDashboard.GaugeChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.GaugeChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartConfigurationProperty.GaugeChartOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-gaugechartoptions
         */
        readonly gaugeChartOptions?: CfnDashboard.GaugeChartOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartConfigurationProperty.TooltipOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-tooltipoptions
         */
        readonly tooltipOptions?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartconfiguration.html#cfn-quicksight-dashboard-gaugechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html
     */
    interface GaugeChartFieldWellsProperty {
        /**
         * `CfnDashboard.GaugeChartFieldWellsProperty.TargetValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-targetvalues
         */
        readonly targetValues?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartfieldwells.html#cfn-quicksight-dashboard-gaugechartfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html
     */
    interface GaugeChartOptionsProperty {
        /**
         * `CfnDashboard.GaugeChartOptionsProperty.Arc`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arc
         */
        readonly arc?: CfnDashboard.ArcConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartOptionsProperty.ArcAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-arcaxis
         */
        readonly arcAxis?: CfnDashboard.ArcAxisConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartOptionsProperty.Comparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-comparison
         */
        readonly comparison?: CfnDashboard.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartOptionsProperty.PrimaryValueDisplayType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * `CfnDashboard.GaugeChartOptionsProperty.PrimaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartoptions.html#cfn-quicksight-dashboard-gaugechartoptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html
     */
    interface GaugeChartPrimaryValueConditionalFormattingProperty {
        /**
         * `CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnDashboard.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartPrimaryValueConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-gaugechartprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html
     */
    interface GaugeChartVisualProperty {
        /**
         * `CfnDashboard.GaugeChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.GaugeChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnDashboard.GaugeChartConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GaugeChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gaugechartvisual.html#cfn-quicksight-dashboard-gaugechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html
     */
    interface GeospatialCoordinateBoundsProperty {
        /**
         * `CfnDashboard.GeospatialCoordinateBoundsProperty.East`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-east
         */
        readonly east: number;
        /**
         * `CfnDashboard.GeospatialCoordinateBoundsProperty.North`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-north
         */
        readonly north: number;
        /**
         * `CfnDashboard.GeospatialCoordinateBoundsProperty.South`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-south
         */
        readonly south: number;
        /**
         * `CfnDashboard.GeospatialCoordinateBoundsProperty.West`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialcoordinatebounds.html#cfn-quicksight-dashboard-geospatialcoordinatebounds-west
         */
        readonly west: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html
     */
    interface GeospatialMapAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.GeospatialMapAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapAggregatedFieldWellsProperty.Geospatial`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapaggregatedfieldwells.html#cfn-quicksight-dashboard-geospatialmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html
     */
    interface GeospatialMapConfigurationProperty {
        /**
         * `CfnDashboard.GeospatialMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.GeospatialMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapConfigurationProperty.MapStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnDashboard.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapConfigurationProperty.PointStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-pointstyleoptions
         */
        readonly pointStyleOptions?: CfnDashboard.GeospatialPointStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapConfigurationProperty.WindowOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapconfiguration.html#cfn-quicksight-dashboard-geospatialmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnDashboard.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html
     */
    interface GeospatialMapFieldWellsProperty {
        /**
         * `CfnDashboard.GeospatialMapFieldWellsProperty.GeospatialMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapfieldwells.html#cfn-quicksight-dashboard-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
         */
        readonly geospatialMapAggregatedFieldWells?: CfnDashboard.GeospatialMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html
     */
    interface GeospatialMapStyleOptionsProperty {
        /**
         * `CfnDashboard.GeospatialMapStyleOptionsProperty.BaseMapStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapstyleoptions.html#cfn-quicksight-dashboard-geospatialmapstyleoptions-basemapstyle
         */
        readonly baseMapStyle?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html
     */
    interface GeospatialMapVisualProperty {
        /**
         * `CfnDashboard.GeospatialMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.GeospatialMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialmapvisual.html#cfn-quicksight-dashboard-geospatialmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html
     */
    interface GeospatialPointStyleOptionsProperty {
        /**
         * `CfnDashboard.GeospatialPointStyleOptionsProperty.ClusterMarkerConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-clustermarkerconfiguration
         */
        readonly clusterMarkerConfiguration?: CfnDashboard.ClusterMarkerConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialPointStyleOptionsProperty.SelectedPointStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialpointstyleoptions.html#cfn-quicksight-dashboard-geospatialpointstyleoptions-selectedpointstyle
         */
        readonly selectedPointStyle?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html
     */
    interface GeospatialWindowOptionsProperty {
        /**
         * `CfnDashboard.GeospatialWindowOptionsProperty.Bounds`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-bounds
         */
        readonly bounds?: CfnDashboard.GeospatialCoordinateBoundsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GeospatialWindowOptionsProperty.MapZoomMode`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-geospatialwindowoptions.html#cfn-quicksight-dashboard-geospatialwindowoptions-mapzoommode
         */
        readonly mapZoomMode?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html
     */
    interface GlobalTableBorderOptionsProperty {
        /**
         * `CfnDashboard.GlobalTableBorderOptionsProperty.SideSpecificBorder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-sidespecificborder
         */
        readonly sideSpecificBorder?: CfnDashboard.TableSideBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GlobalTableBorderOptionsProperty.UniformBorder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-globaltableborderoptions.html#cfn-quicksight-dashboard-globaltableborderoptions-uniformborder
         */
        readonly uniformBorder?: CfnDashboard.TableBorderOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html
     */
    interface GradientColorProperty {
        /**
         * `CfnDashboard.GradientColorProperty.Stops`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientcolor.html#cfn-quicksight-dashboard-gradientcolor-stops
         */
        readonly stops?: Array<CfnDashboard.GradientStopProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html
     */
    interface GradientStopProperty {
        /**
         * `CfnDashboard.GradientStopProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-color
         */
        readonly color?: string;
        /**
         * `CfnDashboard.GradientStopProperty.DataValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-datavalue
         */
        readonly dataValue?: number;
        /**
         * `CfnDashboard.GradientStopProperty.GradientOffset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gradientstop.html#cfn-quicksight-dashboard-gradientstop-gradientoffset
         */
        readonly gradientOffset: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html
     */
    interface GridLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnDashboard.GridLayoutCanvasSizeOptionsProperty.ScreenCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html
     */
    interface GridLayoutConfigurationProperty {
        /**
         * `CfnDashboard.GridLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnDashboard.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GridLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutconfiguration.html#cfn-quicksight-dashboard-gridlayoutconfiguration-elements
         */
        readonly elements: Array<CfnDashboard.GridLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html
     */
    interface GridLayoutElementProperty {
        /**
         * `CfnDashboard.GridLayoutElementProperty.ColumnIndex`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnindex
         */
        readonly columnIndex?: number;
        /**
         * `CfnDashboard.GridLayoutElementProperty.ColumnSpan`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-columnspan
         */
        readonly columnSpan: number;
        /**
         * `CfnDashboard.GridLayoutElementProperty.ElementId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * `CfnDashboard.GridLayoutElementProperty.ElementType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * `CfnDashboard.GridLayoutElementProperty.RowIndex`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowindex
         */
        readonly rowIndex?: number;
        /**
         * `CfnDashboard.GridLayoutElementProperty.RowSpan`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutelement.html#cfn-quicksight-dashboard-gridlayoutelement-rowspan
         */
        readonly rowSpan: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html
     */
    interface GridLayoutScreenCanvasSizeOptionsProperty {
        /**
         * `CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty.OptimizedViewPortWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth?: string;
        /**
         * `CfnDashboard.GridLayoutScreenCanvasSizeOptionsProperty.ResizeOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-dashboard-gridlayoutscreencanvassizeoptions-resizeoption
         */
        readonly resizeOption: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html
     */
    interface GrowthRateComputationProperty {
        /**
         * `CfnDashboard.GrowthRateComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.GrowthRateComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.GrowthRateComputationProperty.PeriodSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-periodsize
         */
        readonly periodSize?: number;
        /**
         * `CfnDashboard.GrowthRateComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-time
         */
        readonly time: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.GrowthRateComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-growthratecomputation.html#cfn-quicksight-dashboard-growthratecomputation-value
         */
        readonly value?: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html
     */
    interface HeaderFooterSectionConfigurationProperty {
        /**
         * `CfnDashboard.HeaderFooterSectionConfigurationProperty.Layout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-layout
         */
        readonly layout: CfnDashboard.SectionLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeaderFooterSectionConfigurationProperty.SectionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * `CfnDashboard.HeaderFooterSectionConfigurationProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-headerfootersectionconfiguration.html#cfn-quicksight-dashboard-headerfootersectionconfiguration-style
         */
        readonly style?: CfnDashboard.SectionStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html
     */
    interface HeatMapAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.HeatMapAggregatedFieldWellsProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapAggregatedFieldWellsProperty.Rows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapaggregatedfieldwells.html#cfn-quicksight-dashboard-heatmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html
     */
    interface HeatMapConfigurationProperty {
        /**
         * `CfnDashboard.HeatMapConfigurationProperty.ColorScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-colorscale
         */
        readonly colorScale?: CfnDashboard.ColorScaleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapConfigurationProperty.ColumnLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-columnlabeloptions
         */
        readonly columnLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.HeatMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapConfigurationProperty.RowLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-rowlabeloptions
         */
        readonly rowLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.HeatMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapconfiguration.html#cfn-quicksight-dashboard-heatmapconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html
     */
    interface HeatMapFieldWellsProperty {
        /**
         * `CfnDashboard.HeatMapFieldWellsProperty.HeatMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapfieldwells.html#cfn-quicksight-dashboard-heatmapfieldwells-heatmapaggregatedfieldwells
         */
        readonly heatMapAggregatedFieldWells?: CfnDashboard.HeatMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html
     */
    interface HeatMapSortConfigurationProperty {
        /**
         * `CfnDashboard.HeatMapSortConfigurationProperty.HeatMapColumnItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
         */
        readonly heatMapColumnItemsLimitConfiguration?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapSortConfigurationProperty.HeatMapColumnSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmapcolumnsort
         */
        readonly heatMapColumnSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapSortConfigurationProperty.HeatMapRowItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
         */
        readonly heatMapRowItemsLimitConfiguration?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapSortConfigurationProperty.HeatMapRowSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapsortconfiguration.html#cfn-quicksight-dashboard-heatmapsortconfiguration-heatmaprowsort
         */
        readonly heatMapRowSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html
     */
    interface HeatMapVisualProperty {
        /**
         * `CfnDashboard.HeatMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.HeatMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HeatMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-heatmapvisual.html#cfn-quicksight-dashboard-heatmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html
     */
    interface HistogramAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.HistogramAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramaggregatedfieldwells.html#cfn-quicksight-dashboard-histogramaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html
     */
    interface HistogramBinOptionsProperty {
        /**
         * `CfnDashboard.HistogramBinOptionsProperty.BinCount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-bincount
         */
        readonly binCount?: CfnDashboard.BinCountOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramBinOptionsProperty.BinWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-binwidth
         */
        readonly binWidth?: CfnDashboard.BinWidthOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramBinOptionsProperty.SelectedBinType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-selectedbintype
         */
        readonly selectedBinType?: string;
        /**
         * `CfnDashboard.HistogramBinOptionsProperty.StartValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogrambinoptions.html#cfn-quicksight-dashboard-histogrambinoptions-startvalue
         */
        readonly startValue?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html
     */
    interface HistogramConfigurationProperty {
        /**
         * `CfnDashboard.HistogramConfigurationProperty.BinOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-binoptions
         */
        readonly binOptions?: CfnDashboard.HistogramBinOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.HistogramFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramConfigurationProperty.YAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramconfiguration.html#cfn-quicksight-dashboard-histogramconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html
     */
    interface HistogramFieldWellsProperty {
        /**
         * `CfnDashboard.HistogramFieldWellsProperty.HistogramAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramfieldwells.html#cfn-quicksight-dashboard-histogramfieldwells-histogramaggregatedfieldwells
         */
        readonly histogramAggregatedFieldWells?: CfnDashboard.HistogramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html
     */
    interface HistogramVisualProperty {
        /**
         * `CfnDashboard.HistogramVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.HistogramConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.HistogramVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-histogramvisual.html#cfn-quicksight-dashboard-histogramvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html
     */
    interface InsightConfigurationProperty {
        /**
         * `CfnDashboard.InsightConfigurationProperty.Computations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-computations
         */
        readonly computations?: Array<CfnDashboard.ComputationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.InsightConfigurationProperty.CustomNarrative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightconfiguration.html#cfn-quicksight-dashboard-insightconfiguration-customnarrative
         */
        readonly customNarrative?: CfnDashboard.CustomNarrativeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html
     */
    interface InsightVisualProperty {
        /**
         * `CfnDashboard.InsightVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.InsightVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnDashboard.InsightVisualProperty.InsightConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-insightconfiguration
         */
        readonly insightConfiguration?: CfnDashboard.InsightConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.InsightVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.InsightVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.InsightVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-insightvisual.html#cfn-quicksight-dashboard-insightvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html
     */
    interface IntegerDefaultValuesProperty {
        /**
         * `CfnDashboard.IntegerDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnDashboard.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.IntegerDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerdefaultvalues.html#cfn-quicksight-dashboard-integerdefaultvalues-staticvalues
         */
        readonly staticValues?: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * An integer parameter.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html
     */
    interface IntegerParameterProperty {
        /**
         * The name of the integer parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-name
         */
        readonly name: string;
        /**
         * The values for the integer parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameter.html#cfn-quicksight-dashboard-integerparameter-values
         */
        readonly values: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html
     */
    interface IntegerParameterDeclarationProperty {
        /**
         * `CfnDashboard.IntegerParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnDashboard.IntegerDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.IntegerParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnDashboard.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.IntegerParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnDashboard.IntegerParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnDashboard.IntegerParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integerparameterdeclaration.html#cfn-quicksight-dashboard-integerparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnDashboard.IntegerValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html
     */
    interface IntegerValueWhenUnsetConfigurationProperty {
        /**
         * `CfnDashboard.IntegerValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * `CfnDashboard.IntegerValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-integervaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-integervaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html
     */
    interface ItemsLimitConfigurationProperty {
        /**
         * `CfnDashboard.ItemsLimitConfigurationProperty.ItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-itemslimit
         */
        readonly itemsLimit?: number;
        /**
         * `CfnDashboard.ItemsLimitConfigurationProperty.OtherCategories`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-itemslimitconfiguration.html#cfn-quicksight-dashboard-itemslimitconfiguration-othercategories
         */
        readonly otherCategories?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html
     */
    interface KPIConditionalFormattingProperty {
        /**
         * `CfnDashboard.KPIConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformatting.html#cfn-quicksight-dashboard-kpiconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnDashboard.KPIConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html
     */
    interface KPIConditionalFormattingOptionProperty {
        /**
         * `CfnDashboard.KPIConditionalFormattingOptionProperty.PrimaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnDashboard.KPIPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIConditionalFormattingOptionProperty.ProgressBar`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconditionalformattingoption.html#cfn-quicksight-dashboard-kpiconditionalformattingoption-progressbar
         */
        readonly progressBar?: CfnDashboard.KPIProgressBarConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html
     */
    interface KPIConfigurationProperty {
        /**
         * `CfnDashboard.KPIConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.KPIFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIConfigurationProperty.KPIOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-kpioptions
         */
        readonly kpiOptions?: CfnDashboard.KPIOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiconfiguration.html#cfn-quicksight-dashboard-kpiconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.KPISortConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html
     */
    interface KPIFieldWellsProperty {
        /**
         * `CfnDashboard.KPIFieldWellsProperty.TargetValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-targetvalues
         */
        readonly targetValues?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIFieldWellsProperty.TrendGroups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-trendgroups
         */
        readonly trendGroups?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpifieldwells.html#cfn-quicksight-dashboard-kpifieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html
     */
    interface KPIOptionsProperty {
        /**
         * `CfnDashboard.KPIOptionsProperty.Comparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-comparison
         */
        readonly comparison?: CfnDashboard.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIOptionsProperty.PrimaryValueDisplayType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * `CfnDashboard.KPIOptionsProperty.PrimaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIOptionsProperty.ProgressBar`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-progressbar
         */
        readonly progressBar?: CfnDashboard.ProgressBarOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIOptionsProperty.SecondaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvalue
         */
        readonly secondaryValue?: CfnDashboard.SecondaryValueOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIOptionsProperty.SecondaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-secondaryvaluefontconfiguration
         */
        readonly secondaryValueFontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIOptionsProperty.TrendArrows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpioptions.html#cfn-quicksight-dashboard-kpioptions-trendarrows
         */
        readonly trendArrows?: CfnDashboard.TrendArrowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html
     */
    interface KPIPrimaryValueConditionalFormattingProperty {
        /**
         * `CfnDashboard.KPIPrimaryValueConditionalFormattingProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnDashboard.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIPrimaryValueConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-dashboard-kpiprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html
     */
    interface KPIProgressBarConditionalFormattingProperty {
        /**
         * `CfnDashboard.KPIProgressBarConditionalFormattingProperty.ForegroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpiprogressbarconditionalformatting.html#cfn-quicksight-dashboard-kpiprogressbarconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html
     */
    interface KPISortConfigurationProperty {
        /**
         * `CfnDashboard.KPISortConfigurationProperty.TrendGroupSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpisortconfiguration.html#cfn-quicksight-dashboard-kpisortconfiguration-trendgroupsort
         */
        readonly trendGroupSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html
     */
    interface KPIVisualProperty {
        /**
         * `CfnDashboard.KPIVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.KPIConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnDashboard.KPIConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.KPIVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-kpivisual.html#cfn-quicksight-dashboard-kpivisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html
     */
    interface LabelOptionsProperty {
        /**
         * `CfnDashboard.LabelOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnDashboard.LabelOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-labeloptions.html#cfn-quicksight-dashboard-labeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html
     */
    interface LayoutProperty {
        /**
         * `CfnDashboard.LayoutProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layout.html#cfn-quicksight-dashboard-layout-configuration
         */
        readonly configuration: CfnDashboard.LayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html
     */
    interface LayoutConfigurationProperty {
        /**
         * `CfnDashboard.LayoutConfigurationProperty.FreeFormLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-freeformlayout
         */
        readonly freeFormLayout?: CfnDashboard.FreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LayoutConfigurationProperty.GridLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnDashboard.GridLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LayoutConfigurationProperty.SectionBasedLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-layoutconfiguration.html#cfn-quicksight-dashboard-layoutconfiguration-sectionbasedlayout
         */
        readonly sectionBasedLayout?: CfnDashboard.SectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html
     */
    interface LegendOptionsProperty {
        /**
         * `CfnDashboard.LegendOptionsProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-height
         */
        readonly height?: string;
        /**
         * `CfnDashboard.LegendOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-position
         */
        readonly position?: string;
        /**
         * `CfnDashboard.LegendOptionsProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-title
         */
        readonly title?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LegendOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnDashboard.LegendOptionsProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-legendoptions.html#cfn-quicksight-dashboard-legendoptions-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html
     */
    interface LineChartAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.LineChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartaggregatedfieldwells.html#cfn-quicksight-dashboard-linechartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html
     */
    interface LineChartConfigurationProperty {
        /**
         * `CfnDashboard.LineChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnDashboard.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.DefaultSeriesSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-defaultseriessettings
         */
        readonly defaultSeriesSettings?: CfnDashboard.LineChartDefaultSeriesSettingsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.LineChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.ForecastConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-forecastconfigurations
         */
        readonly forecastConfigurations?: Array<CfnDashboard.ForecastConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnDashboard.LineSeriesAxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnDashboard.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.SecondaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnDashboard.LineSeriesAxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.SecondaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.Series`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-series
         */
        readonly series?: Array<CfnDashboard.SeriesItemProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnDashboard.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.LineChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-type
         */
        readonly type?: string;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartconfiguration.html#cfn-quicksight-dashboard-linechartconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html
     */
    interface LineChartDefaultSeriesSettingsProperty {
        /**
         * `CfnDashboard.LineChartDefaultSeriesSettingsProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * `CfnDashboard.LineChartDefaultSeriesSettingsProperty.LineStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: CfnDashboard.LineChartLineStyleSettingsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartDefaultSeriesSettingsProperty.MarkerStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartdefaultseriessettings.html#cfn-quicksight-dashboard-linechartdefaultseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: CfnDashboard.LineChartMarkerStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html
     */
    interface LineChartFieldWellsProperty {
        /**
         * `CfnDashboard.LineChartFieldWellsProperty.LineChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartfieldwells.html#cfn-quicksight-dashboard-linechartfieldwells-linechartaggregatedfieldwells
         */
        readonly lineChartAggregatedFieldWells?: CfnDashboard.LineChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html
     */
    interface LineChartLineStyleSettingsProperty {
        /**
         * `CfnDashboard.LineChartLineStyleSettingsProperty.LineInterpolation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-lineinterpolation
         */
        readonly lineInterpolation?: string;
        /**
         * `CfnDashboard.LineChartLineStyleSettingsProperty.LineStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linestyle
         */
        readonly lineStyle?: string;
        /**
         * `CfnDashboard.LineChartLineStyleSettingsProperty.LineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linevisibility
         */
        readonly lineVisibility?: string;
        /**
         * `CfnDashboard.LineChartLineStyleSettingsProperty.LineWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartlinestylesettings.html#cfn-quicksight-dashboard-linechartlinestylesettings-linewidth
         */
        readonly lineWidth?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html
     */
    interface LineChartMarkerStyleSettingsProperty {
        /**
         * `CfnDashboard.LineChartMarkerStyleSettingsProperty.MarkerColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markercolor
         */
        readonly markerColor?: string;
        /**
         * `CfnDashboard.LineChartMarkerStyleSettingsProperty.MarkerShape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markershape
         */
        readonly markerShape?: string;
        /**
         * `CfnDashboard.LineChartMarkerStyleSettingsProperty.MarkerSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markersize
         */
        readonly markerSize?: string;
        /**
         * `CfnDashboard.LineChartMarkerStyleSettingsProperty.MarkerVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartmarkerstylesettings.html#cfn-quicksight-dashboard-linechartmarkerstylesettings-markervisibility
         */
        readonly markerVisibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html
     */
    interface LineChartSeriesSettingsProperty {
        /**
         * `CfnDashboard.LineChartSeriesSettingsProperty.LineStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: CfnDashboard.LineChartLineStyleSettingsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartSeriesSettingsProperty.MarkerStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartseriessettings.html#cfn-quicksight-dashboard-linechartseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: CfnDashboard.LineChartMarkerStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html
     */
    interface LineChartSortConfigurationProperty {
        /**
         * `CfnDashboard.LineChartSortConfigurationProperty.CategoryItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categoryitemslimitconfiguration
         */
        readonly categoryItemsLimitConfiguration?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartSortConfigurationProperty.ColorItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-coloritemslimitconfiguration
         */
        readonly colorItemsLimitConfiguration?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartsortconfiguration.html#cfn-quicksight-dashboard-linechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html
     */
    interface LineChartVisualProperty {
        /**
         * `CfnDashboard.LineChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.LineChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-linechartvisual.html#cfn-quicksight-dashboard-linechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html
     */
    interface LineSeriesAxisDisplayOptionsProperty {
        /**
         * `CfnDashboard.LineSeriesAxisDisplayOptionsProperty.AxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-axisoptions
         */
        readonly axisOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.LineSeriesAxisDisplayOptionsProperty.MissingDataConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-lineseriesaxisdisplayoptions.html#cfn-quicksight-dashboard-lineseriesaxisdisplayoptions-missingdataconfigurations
         */
        readonly missingDataConfigurations?: Array<CfnDashboard.MissingDataConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html
     */
    interface ListControlDisplayOptionsProperty {
        /**
         * `CfnDashboard.ListControlDisplayOptionsProperty.SearchOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-searchoptions
         */
        readonly searchOptions?: CfnDashboard.ListControlSearchOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ListControlDisplayOptionsProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: CfnDashboard.ListControlSelectAllOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ListControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontroldisplayoptions.html#cfn-quicksight-dashboard-listcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html
     */
    interface ListControlSearchOptionsProperty {
        /**
         * `CfnDashboard.ListControlSearchOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolsearchoptions.html#cfn-quicksight-dashboard-listcontrolsearchoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html
     */
    interface ListControlSelectAllOptionsProperty {
        /**
         * `CfnDashboard.ListControlSelectAllOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-listcontrolselectalloptions.html#cfn-quicksight-dashboard-listcontrolselectalloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html
     */
    interface LoadingAnimationProperty {
        /**
         * `CfnDashboard.LoadingAnimationProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-loadinganimation.html#cfn-quicksight-dashboard-loadinganimation-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html
     */
    interface LocalNavigationConfigurationProperty {
        /**
         * `CfnDashboard.LocalNavigationConfigurationProperty.TargetSheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-localnavigationconfiguration.html#cfn-quicksight-dashboard-localnavigationconfiguration-targetsheetid
         */
        readonly targetSheetId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html
     */
    interface LongFormatTextProperty {
        /**
         * `CfnDashboard.LongFormatTextProperty.PlainText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * `CfnDashboard.LongFormatTextProperty.RichText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-longformattext.html#cfn-quicksight-dashboard-longformattext-richtext
         */
        readonly richText?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html
     */
    interface MappedDataSetParameterProperty {
        /**
         * `CfnDashboard.MappedDataSetParameterProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnDashboard.MappedDataSetParameterProperty.DataSetParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-mappeddatasetparameter.html#cfn-quicksight-dashboard-mappeddatasetparameter-datasetparametername
         */
        readonly dataSetParameterName: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html
     */
    interface MaximumLabelTypeProperty {
        /**
         * `CfnDashboard.MaximumLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumlabeltype.html#cfn-quicksight-dashboard-maximumlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html
     */
    interface MaximumMinimumComputationProperty {
        /**
         * `CfnDashboard.MaximumMinimumComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.MaximumMinimumComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.MaximumMinimumComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-time
         */
        readonly time: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.MaximumMinimumComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-type
         */
        readonly type: string;
        /**
         * `CfnDashboard.MaximumMinimumComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-maximumminimumcomputation.html#cfn-quicksight-dashboard-maximumminimumcomputation-value
         */
        readonly value?: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html
     */
    interface MeasureFieldProperty {
        /**
         * `CfnDashboard.MeasureFieldProperty.CalculatedMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-calculatedmeasurefield
         */
        readonly calculatedMeasureField?: CfnDashboard.CalculatedMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.MeasureFieldProperty.CategoricalMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-categoricalmeasurefield
         */
        readonly categoricalMeasureField?: CfnDashboard.CategoricalMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.MeasureFieldProperty.DateMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-datemeasurefield
         */
        readonly dateMeasureField?: CfnDashboard.DateMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.MeasureFieldProperty.NumericalMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-measurefield.html#cfn-quicksight-dashboard-measurefield-numericalmeasurefield
         */
        readonly numericalMeasureField?: CfnDashboard.NumericalMeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html
     */
    interface MetricComparisonComputationProperty {
        /**
         * `CfnDashboard.MetricComparisonComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.MetricComparisonComputationProperty.FromValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-fromvalue
         */
        readonly fromValue: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.MetricComparisonComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.MetricComparisonComputationProperty.TargetValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-targetvalue
         */
        readonly targetValue: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.MetricComparisonComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-metriccomparisoncomputation.html#cfn-quicksight-dashboard-metriccomparisoncomputation-time
         */
        readonly time: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html
     */
    interface MinimumLabelTypeProperty {
        /**
         * `CfnDashboard.MinimumLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-minimumlabeltype.html#cfn-quicksight-dashboard-minimumlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html
     */
    interface MissingDataConfigurationProperty {
        /**
         * `CfnDashboard.MissingDataConfigurationProperty.TreatmentOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-missingdataconfiguration.html#cfn-quicksight-dashboard-missingdataconfiguration-treatmentoption
         */
        readonly treatmentOption?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html
     */
    interface NegativeValueConfigurationProperty {
        /**
         * `CfnDashboard.NegativeValueConfigurationProperty.DisplayMode`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-negativevalueconfiguration.html#cfn-quicksight-dashboard-negativevalueconfiguration-displaymode
         */
        readonly displayMode: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html
     */
    interface NullValueFormatConfigurationProperty {
        /**
         * `CfnDashboard.NullValueFormatConfigurationProperty.NullString`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-nullvalueformatconfiguration.html#cfn-quicksight-dashboard-nullvalueformatconfiguration-nullstring
         */
        readonly nullString: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html
     */
    interface NumberDisplayFormatConfigurationProperty {
        /**
         * `CfnDashboard.NumberDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnDashboard.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumberDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnDashboard.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumberDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnDashboard.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumberDisplayFormatConfigurationProperty.NumberScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * `CfnDashboard.NumberDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnDashboard.NumberDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnDashboard.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumberDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberdisplayformatconfiguration.html#cfn-quicksight-dashboard-numberdisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html
     */
    interface NumberFormatConfigurationProperty {
        /**
         * `CfnDashboard.NumberFormatConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numberformatconfiguration.html#cfn-quicksight-dashboard-numberformatconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html
     */
    interface NumericAxisOptionsProperty {
        /**
         * `CfnDashboard.NumericAxisOptionsProperty.Range`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-range
         */
        readonly range?: CfnDashboard.AxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericAxisOptionsProperty.Scale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaxisoptions.html#cfn-quicksight-dashboard-numericaxisoptions-scale
         */
        readonly scale?: CfnDashboard.AxisScaleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html
     */
    interface NumericEqualityDrillDownFilterProperty {
        /**
         * `CfnDashboard.NumericEqualityDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericEqualityDrillDownFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalitydrilldownfilter.html#cfn-quicksight-dashboard-numericequalitydrilldownfilter-value
         */
        readonly value: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html
     */
    interface NumericEqualityFilterProperty {
        /**
         * `CfnDashboard.NumericEqualityFilterProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericEqualityFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericEqualityFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnDashboard.NumericEqualityFilterProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnDashboard.NumericEqualityFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnDashboard.NumericEqualityFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnDashboard.NumericEqualityFilterProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-selectalloptions
         */
        readonly selectAllOptions?: string;
        /**
         * `CfnDashboard.NumericEqualityFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericequalityfilter.html#cfn-quicksight-dashboard-numericequalityfilter-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html
     */
    interface NumericFormatConfigurationProperty {
        /**
         * `CfnDashboard.NumericFormatConfigurationProperty.CurrencyDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-currencydisplayformatconfiguration
         */
        readonly currencyDisplayFormatConfiguration?: CfnDashboard.CurrencyDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericFormatConfigurationProperty.NumberDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: CfnDashboard.NumberDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericFormatConfigurationProperty.PercentageDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericformatconfiguration.html#cfn-quicksight-dashboard-numericformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: CfnDashboard.PercentageDisplayFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html
     */
    interface NumericRangeFilterProperty {
        /**
         * `CfnDashboard.NumericRangeFilterProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericRangeFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericRangeFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnDashboard.NumericRangeFilterProperty.IncludeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericRangeFilterProperty.IncludeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericRangeFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnDashboard.NumericRangeFilterProperty.RangeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangemaximum
         */
        readonly rangeMaximum?: CfnDashboard.NumericRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericRangeFilterProperty.RangeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-rangeminimum
         */
        readonly rangeMinimum?: CfnDashboard.NumericRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericRangeFilterProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefilter.html#cfn-quicksight-dashboard-numericrangefilter-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html
     */
    interface NumericRangeFilterValueProperty {
        /**
         * `CfnDashboard.NumericRangeFilterValueProperty.Parameter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * `CfnDashboard.NumericRangeFilterValueProperty.StaticValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericrangefiltervalue.html#cfn-quicksight-dashboard-numericrangefiltervalue-staticvalue
         */
        readonly staticValue?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html
     */
    interface NumericSeparatorConfigurationProperty {
        /**
         * `CfnDashboard.NumericSeparatorConfigurationProperty.DecimalSeparator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-decimalseparator
         */
        readonly decimalSeparator?: string;
        /**
         * `CfnDashboard.NumericSeparatorConfigurationProperty.ThousandsSeparator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericseparatorconfiguration.html#cfn-quicksight-dashboard-numericseparatorconfiguration-thousandsseparator
         */
        readonly thousandsSeparator?: CfnDashboard.ThousandSeparatorOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html
     */
    interface NumericalAggregationFunctionProperty {
        /**
         * `CfnDashboard.NumericalAggregationFunctionProperty.PercentileAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-percentileaggregation
         */
        readonly percentileAggregation?: CfnDashboard.PercentileAggregationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericalAggregationFunctionProperty.SimpleNumericalAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalaggregationfunction.html#cfn-quicksight-dashboard-numericalaggregationfunction-simplenumericalaggregation
         */
        readonly simpleNumericalAggregation?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html
     */
    interface NumericalDimensionFieldProperty {
        /**
         * `CfnDashboard.NumericalDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericalDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.NumericalDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.NumberFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericalDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericaldimensionfield.html#cfn-quicksight-dashboard-numericaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html
     */
    interface NumericalMeasureFieldProperty {
        /**
         * `CfnDashboard.NumericalMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: CfnDashboard.NumericalAggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericalMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.NumericalMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.NumericalMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-numericalmeasurefield.html#cfn-quicksight-dashboard-numericalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.NumberFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html
     */
    interface PaginationConfigurationProperty {
        /**
         * `CfnDashboard.PaginationConfigurationProperty.PageNumber`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagenumber
         */
        readonly pageNumber: number;
        /**
         * `CfnDashboard.PaginationConfigurationProperty.PageSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paginationconfiguration.html#cfn-quicksight-dashboard-paginationconfiguration-pagesize
         */
        readonly pageSize: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html
     */
    interface PanelConfigurationProperty {
        /**
         * `CfnDashboard.PanelConfigurationProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * `CfnDashboard.PanelConfigurationProperty.BackgroundVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-backgroundvisibility
         */
        readonly backgroundVisibility?: string;
        /**
         * `CfnDashboard.PanelConfigurationProperty.BorderColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordercolor
         */
        readonly borderColor?: string;
        /**
         * `CfnDashboard.PanelConfigurationProperty.BorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderstyle
         */
        readonly borderStyle?: string;
        /**
         * `CfnDashboard.PanelConfigurationProperty.BorderThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-borderthickness
         */
        readonly borderThickness?: string;
        /**
         * `CfnDashboard.PanelConfigurationProperty.BorderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-bordervisibility
         */
        readonly borderVisibility?: string;
        /**
         * `CfnDashboard.PanelConfigurationProperty.GutterSpacing`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-gutterspacing
         */
        readonly gutterSpacing?: string;
        /**
         * `CfnDashboard.PanelConfigurationProperty.GutterVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-guttervisibility
         */
        readonly gutterVisibility?: string;
        /**
         * `CfnDashboard.PanelConfigurationProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-panelconfiguration.html#cfn-quicksight-dashboard-panelconfiguration-title
         */
        readonly title?: CfnDashboard.PanelTitleOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html
     */
    interface PanelTitleOptionsProperty {
        /**
         * `CfnDashboard.PanelTitleOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PanelTitleOptionsProperty.HorizontalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * `CfnDashboard.PanelTitleOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-paneltitleoptions.html#cfn-quicksight-dashboard-paneltitleoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html
     */
    interface ParameterControlProperty {
        /**
         * `CfnDashboard.ParameterControlProperty.DateTimePicker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnDashboard.ParameterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterControlProperty.Dropdown`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-dropdown
         */
        readonly dropdown?: CfnDashboard.ParameterDropDownControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterControlProperty.List`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-list
         */
        readonly list?: CfnDashboard.ParameterListControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterControlProperty.Slider`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-slider
         */
        readonly slider?: CfnDashboard.ParameterSliderControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterControlProperty.TextArea`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textarea
         */
        readonly textArea?: CfnDashboard.ParameterTextAreaControlProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterControlProperty.TextField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametercontrol.html#cfn-quicksight-dashboard-parametercontrol-textfield
         */
        readonly textField?: CfnDashboard.ParameterTextFieldControlProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html
     */
    interface ParameterDateTimePickerControlProperty {
        /**
         * `CfnDashboard.ParameterDateTimePickerControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterDateTimePickerControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnDashboard.ParameterDateTimePickerControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnDashboard.ParameterDateTimePickerControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdatetimepickercontrol.html#cfn-quicksight-dashboard-parameterdatetimepickercontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html
     */
    interface ParameterDeclarationProperty {
        /**
         * `CfnDashboard.ParameterDeclarationProperty.DateTimeParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-datetimeparameterdeclaration
         */
        readonly dateTimeParameterDeclaration?: CfnDashboard.DateTimeParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterDeclarationProperty.DecimalParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-decimalparameterdeclaration
         */
        readonly decimalParameterDeclaration?: CfnDashboard.DecimalParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterDeclarationProperty.IntegerParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-integerparameterdeclaration
         */
        readonly integerParameterDeclaration?: CfnDashboard.IntegerParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterDeclarationProperty.StringParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdeclaration.html#cfn-quicksight-dashboard-parameterdeclaration-stringparameterdeclaration
         */
        readonly stringParameterDeclaration?: CfnDashboard.StringParameterDeclarationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html
     */
    interface ParameterDropDownControlProperty {
        /**
         * `CfnDashboard.ParameterDropDownControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnDashboard.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterDropDownControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterDropDownControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnDashboard.ParameterDropDownControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnDashboard.ParameterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterDropDownControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnDashboard.ParameterDropDownControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * `CfnDashboard.ParameterDropDownControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterdropdowncontrol.html#cfn-quicksight-dashboard-parameterdropdowncontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html
     */
    interface ParameterListControlProperty {
        /**
         * `CfnDashboard.ParameterListControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnDashboard.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterListControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.ListControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterListControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnDashboard.ParameterListControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnDashboard.ParameterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterListControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnDashboard.ParameterListControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-title
         */
        readonly title: string;
        /**
         * `CfnDashboard.ParameterListControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterlistcontrol.html#cfn-quicksight-dashboard-parameterlistcontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html
     */
    interface ParameterSelectableValuesProperty {
        /**
         * `CfnDashboard.ParameterSelectableValuesProperty.LinkToDataSetColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-linktodatasetcolumn
         */
        readonly linkToDataSetColumn?: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterSelectableValuesProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterselectablevalues.html#cfn-quicksight-dashboard-parameterselectablevalues-values
         */
        readonly values?: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html
     */
    interface ParameterSliderControlProperty {
        /**
         * `CfnDashboard.ParameterSliderControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.SliderControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterSliderControlProperty.MaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * `CfnDashboard.ParameterSliderControlProperty.MinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * `CfnDashboard.ParameterSliderControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnDashboard.ParameterSliderControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnDashboard.ParameterSliderControlProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * `CfnDashboard.ParameterSliderControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameterslidercontrol.html#cfn-quicksight-dashboard-parameterslidercontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html
     */
    interface ParameterTextAreaControlProperty {
        /**
         * `CfnDashboard.ParameterTextAreaControlProperty.Delimiter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * `CfnDashboard.ParameterTextAreaControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.TextAreaControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterTextAreaControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnDashboard.ParameterTextAreaControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnDashboard.ParameterTextAreaControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextareacontrol.html#cfn-quicksight-dashboard-parametertextareacontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html
     */
    interface ParameterTextFieldControlProperty {
        /**
         * `CfnDashboard.ParameterTextFieldControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: CfnDashboard.TextFieldControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ParameterTextFieldControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnDashboard.ParameterTextFieldControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnDashboard.ParameterTextFieldControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parametertextfieldcontrol.html#cfn-quicksight-dashboard-parametertextfieldcontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnDashboard {
    /**
     * A list of Amazon QuickSight parameters and the list's override values.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html
     */
    interface ParametersProperty {
        /**
         * The parameters that have a data type of date-time.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-datetimeparameters
         */
        readonly dateTimeParameters?: Array<CfnDashboard.DateTimeParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of decimal.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-decimalparameters
         */
        readonly decimalParameters?: Array<CfnDashboard.DecimalParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of integer.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-integerparameters
         */
        readonly integerParameters?: Array<CfnDashboard.IntegerParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The parameters that have a data type of string.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-parameters.html#cfn-quicksight-dashboard-parameters-stringparameters
         */
        readonly stringParameters?: Array<CfnDashboard.StringParameterProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html
     */
    interface PercentVisibleRangeProperty {
        /**
         * `CfnDashboard.PercentVisibleRangeProperty.From`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-from
         */
        readonly from?: number;
        /**
         * `CfnDashboard.PercentVisibleRangeProperty.To`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentvisiblerange.html#cfn-quicksight-dashboard-percentvisiblerange-to
         */
        readonly to?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html
     */
    interface PercentageDisplayFormatConfigurationProperty {
        /**
         * `CfnDashboard.PercentageDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnDashboard.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PercentageDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnDashboard.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PercentageDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnDashboard.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PercentageDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnDashboard.PercentageDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnDashboard.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PercentageDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentagedisplayformatconfiguration.html#cfn-quicksight-dashboard-percentagedisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html
     */
    interface PercentileAggregationProperty {
        /**
         * `CfnDashboard.PercentileAggregationProperty.PercentileValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-percentileaggregation.html#cfn-quicksight-dashboard-percentileaggregation-percentilevalue
         */
        readonly percentileValue?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html
     */
    interface PeriodOverPeriodComputationProperty {
        /**
         * `CfnDashboard.PeriodOverPeriodComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.PeriodOverPeriodComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.PeriodOverPeriodComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-time
         */
        readonly time: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PeriodOverPeriodComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodoverperiodcomputation.html#cfn-quicksight-dashboard-periodoverperiodcomputation-value
         */
        readonly value?: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html
     */
    interface PeriodToDateComputationProperty {
        /**
         * `CfnDashboard.PeriodToDateComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.PeriodToDateComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.PeriodToDateComputationProperty.PeriodTimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-periodtimegranularity
         */
        readonly periodTimeGranularity?: string;
        /**
         * `CfnDashboard.PeriodToDateComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-time
         */
        readonly time: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PeriodToDateComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-periodtodatecomputation.html#cfn-quicksight-dashboard-periodtodatecomputation-value
         */
        readonly value?: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html
     */
    interface PieChartAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.PieChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartaggregatedfieldwells.html#cfn-quicksight-dashboard-piechartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html
     */
    interface PieChartConfigurationProperty {
        /**
         * `CfnDashboard.PieChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnDashboard.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.DonutOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-donutoptions
         */
        readonly donutOptions?: CfnDashboard.DonutOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.PieChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnDashboard.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.PieChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartconfiguration.html#cfn-quicksight-dashboard-piechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html
     */
    interface PieChartFieldWellsProperty {
        /**
         * `CfnDashboard.PieChartFieldWellsProperty.PieChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartfieldwells.html#cfn-quicksight-dashboard-piechartfieldwells-piechartaggregatedfieldwells
         */
        readonly pieChartAggregatedFieldWells?: CfnDashboard.PieChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html
     */
    interface PieChartSortConfigurationProperty {
        /**
         * `CfnDashboard.PieChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartsortconfiguration.html#cfn-quicksight-dashboard-piechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html
     */
    interface PieChartVisualProperty {
        /**
         * `CfnDashboard.PieChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.PieChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PieChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-piechartvisual.html#cfn-quicksight-dashboard-piechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html
     */
    interface PivotFieldSortOptionsProperty {
        /**
         * `CfnDashboard.PivotFieldSortOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.PivotFieldSortOptionsProperty.SortBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivotfieldsortoptions.html#cfn-quicksight-dashboard-pivotfieldsortoptions-sortby
         */
        readonly sortBy: CfnDashboard.PivotTableSortByProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html
     */
    interface PivotTableAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.PivotTableAggregatedFieldWellsProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableAggregatedFieldWellsProperty.Rows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableaggregatedfieldwells.html#cfn-quicksight-dashboard-pivottableaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html
     */
    interface PivotTableCellConditionalFormattingProperty {
        /**
         * `CfnDashboard.PivotTableCellConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.PivotTableCellConditionalFormattingProperty.Scope`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-scope
         */
        readonly scope?: CfnDashboard.PivotTableConditionalFormattingScopeProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableCellConditionalFormattingProperty.TextFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablecellconditionalformatting.html#cfn-quicksight-dashboard-pivottablecellconditionalformatting-textformat
         */
        readonly textFormat?: CfnDashboard.TextConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html
     */
    interface PivotTableConditionalFormattingProperty {
        /**
         * `CfnDashboard.PivotTableConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformatting.html#cfn-quicksight-dashboard-pivottableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnDashboard.PivotTableConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html
     */
    interface PivotTableConditionalFormattingOptionProperty {
        /**
         * `CfnDashboard.PivotTableConditionalFormattingOptionProperty.Cell`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingoption.html#cfn-quicksight-dashboard-pivottableconditionalformattingoption-cell
         */
        readonly cell?: CfnDashboard.PivotTableCellConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html
     */
    interface PivotTableConditionalFormattingScopeProperty {
        /**
         * `CfnDashboard.PivotTableConditionalFormattingScopeProperty.Role`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconditionalformattingscope.html#cfn-quicksight-dashboard-pivottableconditionalformattingscope-role
         */
        readonly role?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html
     */
    interface PivotTableConfigurationProperty {
        /**
         * `CfnDashboard.PivotTableConfigurationProperty.FieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldoptions
         */
        readonly fieldOptions?: CfnDashboard.PivotTableFieldOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.PivotTableFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableConfigurationProperty.PaginatedReportOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: CfnDashboard.PivotTablePaginatedReportOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.PivotTableSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableConfigurationProperty.TableOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-tableoptions
         */
        readonly tableOptions?: CfnDashboard.PivotTableOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableConfigurationProperty.TotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableconfiguration.html#cfn-quicksight-dashboard-pivottableconfiguration-totaloptions
         */
        readonly totalOptions?: CfnDashboard.PivotTableTotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html
     */
    interface PivotTableDataPathOptionProperty {
        /**
         * `CfnDashboard.PivotTableDataPathOptionProperty.DataPathList`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-datapathlist
         */
        readonly dataPathList: Array<CfnDashboard.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableDataPathOptionProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabledatapathoption.html#cfn-quicksight-dashboard-pivottabledatapathoption-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html
     */
    interface PivotTableFieldOptionProperty {
        /**
         * `CfnDashboard.PivotTableFieldOptionProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnDashboard.PivotTableFieldOptionProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.PivotTableFieldOptionProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoption.html#cfn-quicksight-dashboard-pivottablefieldoption-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html
     */
    interface PivotTableFieldOptionsProperty {
        /**
         * `CfnDashboard.PivotTableFieldOptionsProperty.DataPathOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-datapathoptions
         */
        readonly dataPathOptions?: Array<CfnDashboard.PivotTableDataPathOptionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableFieldOptionsProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldoptions.html#cfn-quicksight-dashboard-pivottablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<CfnDashboard.PivotTableFieldOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html
     */
    interface PivotTableFieldSubtotalOptionsProperty {
        /**
         * `CfnDashboard.PivotTableFieldSubtotalOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldsubtotaloptions.html#cfn-quicksight-dashboard-pivottablefieldsubtotaloptions-fieldid
         */
        readonly fieldId?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html
     */
    interface PivotTableFieldWellsProperty {
        /**
         * `CfnDashboard.PivotTableFieldWellsProperty.PivotTableAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablefieldwells.html#cfn-quicksight-dashboard-pivottablefieldwells-pivottableaggregatedfieldwells
         */
        readonly pivotTableAggregatedFieldWells?: CfnDashboard.PivotTableAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html
     */
    interface PivotTableOptionsProperty {
        /**
         * `CfnDashboard.PivotTableOptionsProperty.CellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-cellstyle
         */
        readonly cellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableOptionsProperty.ColumnHeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnheaderstyle
         */
        readonly columnHeaderStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableOptionsProperty.ColumnNamesVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-columnnamesvisibility
         */
        readonly columnNamesVisibility?: string;
        /**
         * `CfnDashboard.PivotTableOptionsProperty.MetricPlacement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-metricplacement
         */
        readonly metricPlacement?: string;
        /**
         * `CfnDashboard.PivotTableOptionsProperty.RowAlternateColorOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: CfnDashboard.RowAlternateColorOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableOptionsProperty.RowFieldNamesStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowfieldnamesstyle
         */
        readonly rowFieldNamesStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableOptionsProperty.RowHeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-rowheaderstyle
         */
        readonly rowHeaderStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableOptionsProperty.SingleMetricVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-singlemetricvisibility
         */
        readonly singleMetricVisibility?: string;
        /**
         * `CfnDashboard.PivotTableOptionsProperty.ToggleButtonsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottableoptions.html#cfn-quicksight-dashboard-pivottableoptions-togglebuttonsvisibility
         */
        readonly toggleButtonsVisibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html
     */
    interface PivotTablePaginatedReportOptionsProperty {
        /**
         * `CfnDashboard.PivotTablePaginatedReportOptionsProperty.OverflowColumnHeaderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * `CfnDashboard.PivotTablePaginatedReportOptionsProperty.VerticalOverflowVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablepaginatedreportoptions.html#cfn-quicksight-dashboard-pivottablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html
     */
    interface PivotTableSortByProperty {
        /**
         * `CfnDashboard.PivotTableSortByProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-column
         */
        readonly column?: CfnDashboard.ColumnSortProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableSortByProperty.DataPath`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-datapath
         */
        readonly dataPath?: CfnDashboard.DataPathSortProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableSortByProperty.Field`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortby.html#cfn-quicksight-dashboard-pivottablesortby-field
         */
        readonly field?: CfnDashboard.FieldSortProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html
     */
    interface PivotTableSortConfigurationProperty {
        /**
         * `CfnDashboard.PivotTableSortConfigurationProperty.FieldSortOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablesortconfiguration.html#cfn-quicksight-dashboard-pivottablesortconfiguration-fieldsortoptions
         */
        readonly fieldSortOptions?: Array<CfnDashboard.PivotFieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html
     */
    interface PivotTableTotalOptionsProperty {
        /**
         * `CfnDashboard.PivotTableTotalOptionsProperty.ColumnSubtotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columnsubtotaloptions
         */
        readonly columnSubtotalOptions?: CfnDashboard.SubtotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableTotalOptionsProperty.ColumnTotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-columntotaloptions
         */
        readonly columnTotalOptions?: CfnDashboard.PivotTotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableTotalOptionsProperty.RowSubtotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowsubtotaloptions
         */
        readonly rowSubtotalOptions?: CfnDashboard.SubtotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableTotalOptionsProperty.RowTotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottabletotaloptions.html#cfn-quicksight-dashboard-pivottabletotaloptions-rowtotaloptions
         */
        readonly rowTotalOptions?: CfnDashboard.PivotTotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html
     */
    interface PivotTableVisualProperty {
        /**
         * `CfnDashboard.PivotTableVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.PivotTableConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnDashboard.PivotTableConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTableVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottablevisual.html#cfn-quicksight-dashboard-pivottablevisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html
     */
    interface PivotTotalOptionsProperty {
        /**
         * `CfnDashboard.PivotTotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnDashboard.PivotTotalOptionsProperty.MetricHeaderCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTotalOptionsProperty.Placement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-placement
         */
        readonly placement?: string;
        /**
         * `CfnDashboard.PivotTotalOptionsProperty.ScrollStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * `CfnDashboard.PivotTotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.PivotTotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * `CfnDashboard.PivotTotalOptionsProperty.ValueCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-pivottotaloptions.html#cfn-quicksight-dashboard-pivottotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html
     */
    interface PredefinedHierarchyProperty {
        /**
         * `CfnDashboard.PredefinedHierarchyProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-columns
         */
        readonly columns: Array<CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PredefinedHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnDashboard.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.PredefinedHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-predefinedhierarchy.html#cfn-quicksight-dashboard-predefinedhierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html
     */
    interface ProgressBarOptionsProperty {
        /**
         * `CfnDashboard.ProgressBarOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-progressbaroptions.html#cfn-quicksight-dashboard-progressbaroptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html
     */
    interface RadarChartAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.RadarChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartAggregatedFieldWellsProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-color
         */
        readonly color?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartaggregatedfieldwells.html#cfn-quicksight-dashboard-radarchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html
     */
    interface RadarChartAreaStyleSettingsProperty {
        /**
         * `CfnDashboard.RadarChartAreaStyleSettingsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartareastylesettings.html#cfn-quicksight-dashboard-radarchartareastylesettings-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html
     */
    interface RadarChartConfigurationProperty {
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.AlternateBandColorsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandcolorsvisibility
         */
        readonly alternateBandColorsVisibility?: string;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.AlternateBandEvenColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandevencolor
         */
        readonly alternateBandEvenColor?: string;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.AlternateBandOddColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-alternatebandoddcolor
         */
        readonly alternateBandOddColor?: string;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.BaseSeriesSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-baseseriessettings
         */
        readonly baseSeriesSettings?: CfnDashboard.RadarChartSeriesSettingsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.ColorAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-coloraxis
         */
        readonly colorAxis?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.RadarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.Shape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-shape
         */
        readonly shape?: string;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.RadarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.StartAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-startangle
         */
        readonly startAngle?: number;
        /**
         * `CfnDashboard.RadarChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartconfiguration.html#cfn-quicksight-dashboard-radarchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html
     */
    interface RadarChartFieldWellsProperty {
        /**
         * `CfnDashboard.RadarChartFieldWellsProperty.RadarChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartfieldwells.html#cfn-quicksight-dashboard-radarchartfieldwells-radarchartaggregatedfieldwells
         */
        readonly radarChartAggregatedFieldWells?: CfnDashboard.RadarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html
     */
    interface RadarChartSeriesSettingsProperty {
        /**
         * `CfnDashboard.RadarChartSeriesSettingsProperty.AreaStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartseriessettings.html#cfn-quicksight-dashboard-radarchartseriessettings-areastylesettings
         */
        readonly areaStyleSettings?: CfnDashboard.RadarChartAreaStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html
     */
    interface RadarChartSortConfigurationProperty {
        /**
         * `CfnDashboard.RadarChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartsortconfiguration.html#cfn-quicksight-dashboard-radarchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html
     */
    interface RadarChartVisualProperty {
        /**
         * `CfnDashboard.RadarChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.RadarChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RadarChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-radarchartvisual.html#cfn-quicksight-dashboard-radarchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html
     */
    interface RangeEndsLabelTypeProperty {
        /**
         * `CfnDashboard.RangeEndsLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rangeendslabeltype.html#cfn-quicksight-dashboard-rangeendslabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html
     */
    interface ReferenceLineProperty {
        /**
         * `CfnDashboard.ReferenceLineProperty.DataConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-dataconfiguration
         */
        readonly dataConfiguration: CfnDashboard.ReferenceLineDataConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineProperty.LabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-labelconfiguration
         */
        readonly labelConfiguration?: CfnDashboard.ReferenceLineLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-status
         */
        readonly status?: string;
        /**
         * `CfnDashboard.ReferenceLineProperty.StyleConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referenceline.html#cfn-quicksight-dashboard-referenceline-styleconfiguration
         */
        readonly styleConfiguration?: CfnDashboard.ReferenceLineStyleConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html
     */
    interface ReferenceLineCustomLabelConfigurationProperty {
        /**
         * `CfnDashboard.ReferenceLineCustomLabelConfigurationProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinecustomlabelconfiguration.html#cfn-quicksight-dashboard-referencelinecustomlabelconfiguration-customlabel
         */
        readonly customLabel: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html
     */
    interface ReferenceLineDataConfigurationProperty {
        /**
         * `CfnDashboard.ReferenceLineDataConfigurationProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * `CfnDashboard.ReferenceLineDataConfigurationProperty.DynamicConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-dynamicconfiguration
         */
        readonly dynamicConfiguration?: CfnDashboard.ReferenceLineDynamicDataConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineDataConfigurationProperty.StaticConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedataconfiguration.html#cfn-quicksight-dashboard-referencelinedataconfiguration-staticconfiguration
         */
        readonly staticConfiguration?: CfnDashboard.ReferenceLineStaticDataConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html
     */
    interface ReferenceLineDynamicDataConfigurationProperty {
        /**
         * `CfnDashboard.ReferenceLineDynamicDataConfigurationProperty.Calculation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-calculation
         */
        readonly calculation: CfnDashboard.NumericalAggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineDynamicDataConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineDynamicDataConfigurationProperty.MeasureAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinedynamicdataconfiguration.html#cfn-quicksight-dashboard-referencelinedynamicdataconfiguration-measureaggregationfunction
         */
        readonly measureAggregationFunction: CfnDashboard.AggregationFunctionProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html
     */
    interface ReferenceLineLabelConfigurationProperty {
        /**
         * `CfnDashboard.ReferenceLineLabelConfigurationProperty.CustomLabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-customlabelconfiguration
         */
        readonly customLabelConfiguration?: CfnDashboard.ReferenceLineCustomLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineLabelConfigurationProperty.FontColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * `CfnDashboard.ReferenceLineLabelConfigurationProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineLabelConfigurationProperty.HorizontalPosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-horizontalposition
         */
        readonly horizontalPosition?: string;
        /**
         * `CfnDashboard.ReferenceLineLabelConfigurationProperty.ValueLabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-valuelabelconfiguration
         */
        readonly valueLabelConfiguration?: CfnDashboard.ReferenceLineValueLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineLabelConfigurationProperty.VerticalPosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinelabelconfiguration.html#cfn-quicksight-dashboard-referencelinelabelconfiguration-verticalposition
         */
        readonly verticalPosition?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html
     */
    interface ReferenceLineStaticDataConfigurationProperty {
        /**
         * `CfnDashboard.ReferenceLineStaticDataConfigurationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestaticdataconfiguration.html#cfn-quicksight-dashboard-referencelinestaticdataconfiguration-value
         */
        readonly value: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html
     */
    interface ReferenceLineStyleConfigurationProperty {
        /**
         * `CfnDashboard.ReferenceLineStyleConfigurationProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-color
         */
        readonly color?: string;
        /**
         * `CfnDashboard.ReferenceLineStyleConfigurationProperty.Pattern`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinestyleconfiguration.html#cfn-quicksight-dashboard-referencelinestyleconfiguration-pattern
         */
        readonly pattern?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html
     */
    interface ReferenceLineValueLabelConfigurationProperty {
        /**
         * `CfnDashboard.ReferenceLineValueLabelConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.NumericFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ReferenceLineValueLabelConfigurationProperty.RelativePosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-referencelinevaluelabelconfiguration.html#cfn-quicksight-dashboard-referencelinevaluelabelconfiguration-relativeposition
         */
        readonly relativePosition?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html
     */
    interface RelativeDateTimeControlDisplayOptionsProperty {
        /**
         * `CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnDashboard.RelativeDateTimeControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatetimecontroldisplayoptions.html#cfn-quicksight-dashboard-relativedatetimecontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html
     */
    interface RelativeDatesFilterProperty {
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.AnchorDateConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-anchordateconfiguration
         */
        readonly anchorDateConfiguration: CfnDashboard.AnchorDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.ExcludePeriodConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnDashboard.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.MinimumGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-minimumgranularity
         */
        readonly minimumGranularity?: string;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.RelativeDateType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatetype
         */
        readonly relativeDateType: string;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.RelativeDateValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-relativedatevalue
         */
        readonly relativeDateValue?: number;
        /**
         * `CfnDashboard.RelativeDatesFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-relativedatesfilter.html#cfn-quicksight-dashboard-relativedatesfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
}
export declare namespace CfnDashboard {
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-actions
         */
        readonly actions: string[];
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-principal
         */
        readonly principal: string;
        /**
         * `CfnDashboard.ResourcePermissionProperty.Resource`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-resourcepermission.html#cfn-quicksight-dashboard-resourcepermission-resource
         */
        readonly resource?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html
     */
    interface RollingDateConfigurationProperty {
        /**
         * `CfnDashboard.RollingDateConfigurationProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-datasetidentifier
         */
        readonly dataSetIdentifier?: string;
        /**
         * `CfnDashboard.RollingDateConfigurationProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rollingdateconfiguration.html#cfn-quicksight-dashboard-rollingdateconfiguration-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html
     */
    interface RowAlternateColorOptionsProperty {
        /**
         * `CfnDashboard.RowAlternateColorOptionsProperty.RowAlternateColors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-rowalternatecolors
         */
        readonly rowAlternateColors?: string[];
        /**
         * `CfnDashboard.RowAlternateColorOptionsProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-rowalternatecoloroptions.html#cfn-quicksight-dashboard-rowalternatecoloroptions-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html
     */
    interface SameSheetTargetVisualConfigurationProperty {
        /**
         * `CfnDashboard.SameSheetTargetVisualConfigurationProperty.TargetVisualOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisualoptions
         */
        readonly targetVisualOptions?: string;
        /**
         * `CfnDashboard.SameSheetTargetVisualConfigurationProperty.TargetVisuals`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-samesheettargetvisualconfiguration.html#cfn-quicksight-dashboard-samesheettargetvisualconfiguration-targetvisuals
         */
        readonly targetVisuals?: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html
     */
    interface SankeyDiagramAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty.Destination`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-destination
         */
        readonly destination?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty.Source`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-source
         */
        readonly source?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty.Weight`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-dashboard-sankeydiagramaggregatedfieldwells-weight
         */
        readonly weight?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html
     */
    interface SankeyDiagramChartConfigurationProperty {
        /**
         * `CfnDashboard.SankeyDiagramChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.SankeyDiagramFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramchartconfiguration.html#cfn-quicksight-dashboard-sankeydiagramchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.SankeyDiagramSortConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html
     */
    interface SankeyDiagramFieldWellsProperty {
        /**
         * `CfnDashboard.SankeyDiagramFieldWellsProperty.SankeyDiagramAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramfieldwells.html#cfn-quicksight-dashboard-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
         */
        readonly sankeyDiagramAggregatedFieldWells?: CfnDashboard.SankeyDiagramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html
     */
    interface SankeyDiagramSortConfigurationProperty {
        /**
         * `CfnDashboard.SankeyDiagramSortConfigurationProperty.DestinationItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-destinationitemslimit
         */
        readonly destinationItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramSortConfigurationProperty.SourceItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-sourceitemslimit
         */
        readonly sourceItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramSortConfigurationProperty.WeightSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramsortconfiguration.html#cfn-quicksight-dashboard-sankeydiagramsortconfiguration-weightsort
         */
        readonly weightSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html
     */
    interface SankeyDiagramVisualProperty {
        /**
         * `CfnDashboard.SankeyDiagramVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.SankeyDiagramChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SankeyDiagramVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sankeydiagramvisual.html#cfn-quicksight-dashboard-sankeydiagramvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html
     */
    interface ScatterPlotCategoricallyAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-category
         */
        readonly category?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-size
         */
        readonly size?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty.XAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty.YAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotcategoricallyaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html
     */
    interface ScatterPlotConfigurationProperty {
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.ScatterPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.YAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotConfigurationProperty.YAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotconfiguration.html#cfn-quicksight-dashboard-scatterplotconfiguration-yaxislabeloptions
         */
        readonly yAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html
     */
    interface ScatterPlotFieldWellsProperty {
        /**
         * `CfnDashboard.ScatterPlotFieldWellsProperty.ScatterPlotCategoricallyAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
         */
        readonly scatterPlotCategoricallyAggregatedFieldWells?: CfnDashboard.ScatterPlotCategoricallyAggregatedFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotFieldWellsProperty.ScatterPlotUnaggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotfieldwells.html#cfn-quicksight-dashboard-scatterplotfieldwells-scatterplotunaggregatedfieldwells
         */
        readonly scatterPlotUnaggregatedFieldWells?: CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html
     */
    interface ScatterPlotUnaggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-size
         */
        readonly size?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty.XAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotUnaggregatedFieldWellsProperty.YAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotunaggregatedfieldwells.html#cfn-quicksight-dashboard-scatterplotunaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html
     */
    interface ScatterPlotVisualProperty {
        /**
         * `CfnDashboard.ScatterPlotVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.ScatterPlotConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.ScatterPlotVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scatterplotvisual.html#cfn-quicksight-dashboard-scatterplotvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html
     */
    interface ScrollBarOptionsProperty {
        /**
         * `CfnDashboard.ScrollBarOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnDashboard.ScrollBarOptionsProperty.VisibleRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-scrollbaroptions.html#cfn-quicksight-dashboard-scrollbaroptions-visiblerange
         */
        readonly visibleRange?: CfnDashboard.VisibleRangeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html
     */
    interface SecondaryValueOptionsProperty {
        /**
         * `CfnDashboard.SecondaryValueOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-secondaryvalueoptions.html#cfn-quicksight-dashboard-secondaryvalueoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html
     */
    interface SectionAfterPageBreakProperty {
        /**
         * `CfnDashboard.SectionAfterPageBreakProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionafterpagebreak.html#cfn-quicksight-dashboard-sectionafterpagebreak-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html
     */
    interface SectionBasedLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty.PaperCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
         */
        readonly paperCanvasSizeOptions?: CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html
     */
    interface SectionBasedLayoutConfigurationProperty {
        /**
         * `CfnDashboard.SectionBasedLayoutConfigurationProperty.BodySections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-bodysections
         */
        readonly bodySections: Array<CfnDashboard.BodySectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SectionBasedLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnDashboard.SectionBasedLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SectionBasedLayoutConfigurationProperty.FooterSections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-footersections
         */
        readonly footerSections: Array<CfnDashboard.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SectionBasedLayoutConfigurationProperty.HeaderSections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutconfiguration.html#cfn-quicksight-dashboard-sectionbasedlayoutconfiguration-headersections
         */
        readonly headerSections: Array<CfnDashboard.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html
     */
    interface SectionBasedLayoutPaperCanvasSizeOptionsProperty {
        /**
         * `CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperMargin`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papermargin
         */
        readonly paperMargin?: CfnDashboard.SpacingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperOrientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-paperorientation
         */
        readonly paperOrientation?: string;
        /**
         * `CfnDashboard.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-dashboard-sectionbasedlayoutpapercanvassizeoptions-papersize
         */
        readonly paperSize?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html
     */
    interface SectionLayoutConfigurationProperty {
        /**
         * `CfnDashboard.SectionLayoutConfigurationProperty.FreeFormLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionlayoutconfiguration.html#cfn-quicksight-dashboard-sectionlayoutconfiguration-freeformlayout
         */
        readonly freeFormLayout: CfnDashboard.FreeFormSectionLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html
     */
    interface SectionPageBreakConfigurationProperty {
        /**
         * `CfnDashboard.SectionPageBreakConfigurationProperty.After`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionpagebreakconfiguration.html#cfn-quicksight-dashboard-sectionpagebreakconfiguration-after
         */
        readonly after?: CfnDashboard.SectionAfterPageBreakProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html
     */
    interface SectionStyleProperty {
        /**
         * `CfnDashboard.SectionStyleProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-height
         */
        readonly height?: string;
        /**
         * `CfnDashboard.SectionStyleProperty.Padding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sectionstyle.html#cfn-quicksight-dashboard-sectionstyle-padding
         */
        readonly padding?: CfnDashboard.SpacingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html
     */
    interface SelectedSheetsFilterScopeConfigurationProperty {
        /**
         * `CfnDashboard.SelectedSheetsFilterScopeConfigurationProperty.SheetVisualScopingConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-dashboard-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
         */
        readonly sheetVisualScopingConfigurations?: Array<CfnDashboard.SheetVisualScopingConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html
     */
    interface SeriesItemProperty {
        /**
         * `CfnDashboard.SeriesItemProperty.DataFieldSeriesItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-datafieldseriesitem
         */
        readonly dataFieldSeriesItem?: CfnDashboard.DataFieldSeriesItemProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SeriesItemProperty.FieldSeriesItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-seriesitem.html#cfn-quicksight-dashboard-seriesitem-fieldseriesitem
         */
        readonly fieldSeriesItem?: CfnDashboard.FieldSeriesItemProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html
     */
    interface SetParameterValueConfigurationProperty {
        /**
         * `CfnDashboard.SetParameterValueConfigurationProperty.DestinationParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-destinationparametername
         */
        readonly destinationParameterName: string;
        /**
         * `CfnDashboard.SetParameterValueConfigurationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-setparametervalueconfiguration.html#cfn-quicksight-dashboard-setparametervalueconfiguration-value
         */
        readonly value: CfnDashboard.DestinationParameterValueConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html
     */
    interface ShapeConditionalFormatProperty {
        /**
         * `CfnDashboard.ShapeConditionalFormatProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shapeconditionalformat.html#cfn-quicksight-dashboard-shapeconditionalformat-backgroundcolor
         */
        readonly backgroundColor: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight. Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html
     */
    interface SheetProperty {
        /**
         * The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-name
         */
        readonly name?: string;
        /**
         * The unique identifier associated with a sheet.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheet.html#cfn-quicksight-dashboard-sheet-sheetid
         */
        readonly sheetId?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html
     */
    interface SheetControlLayoutProperty {
        /**
         * `CfnDashboard.SheetControlLayoutProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayout.html#cfn-quicksight-dashboard-sheetcontrollayout-configuration
         */
        readonly configuration: CfnDashboard.SheetControlLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html
     */
    interface SheetControlLayoutConfigurationProperty {
        /**
         * `CfnDashboard.SheetControlLayoutConfigurationProperty.GridLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrollayoutconfiguration.html#cfn-quicksight-dashboard-sheetcontrollayoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnDashboard.GridLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * Sheet controls option.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html
     */
    interface SheetControlsOptionProperty {
        /**
         * Visibility state.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetcontrolsoption.html#cfn-quicksight-dashboard-sheetcontrolsoption-visibilitystate
         */
        readonly visibilityState?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html
     */
    interface SheetDefinitionProperty {
        /**
         * `CfnDashboard.SheetDefinitionProperty.ContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-contenttype
         */
        readonly contentType?: string;
        /**
         * `CfnDashboard.SheetDefinitionProperty.Description`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-description
         */
        readonly description?: string;
        /**
         * `CfnDashboard.SheetDefinitionProperty.FilterControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-filtercontrols
         */
        readonly filterControls?: Array<CfnDashboard.FilterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SheetDefinitionProperty.Layouts`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-layouts
         */
        readonly layouts?: Array<CfnDashboard.LayoutProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SheetDefinitionProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.SheetDefinitionProperty.ParameterControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-parametercontrols
         */
        readonly parameterControls?: Array<CfnDashboard.ParameterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SheetDefinitionProperty.SheetControlLayouts`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetcontrollayouts
         */
        readonly sheetControlLayouts?: Array<CfnDashboard.SheetControlLayoutProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SheetDefinitionProperty.SheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-sheetid
         */
        readonly sheetId: string;
        /**
         * `CfnDashboard.SheetDefinitionProperty.TextBoxes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-textboxes
         */
        readonly textBoxes?: Array<CfnDashboard.SheetTextBoxProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SheetDefinitionProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-title
         */
        readonly title?: string;
        /**
         * `CfnDashboard.SheetDefinitionProperty.Visuals`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetdefinition.html#cfn-quicksight-dashboard-sheetdefinition-visuals
         */
        readonly visuals?: Array<CfnDashboard.VisualProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html
     */
    interface SheetElementConfigurationOverridesProperty {
        /**
         * `CfnDashboard.SheetElementConfigurationOverridesProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementconfigurationoverrides.html#cfn-quicksight-dashboard-sheetelementconfigurationoverrides-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html
     */
    interface SheetElementRenderingRuleProperty {
        /**
         * `CfnDashboard.SheetElementRenderingRuleProperty.ConfigurationOverrides`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-configurationoverrides
         */
        readonly configurationOverrides: CfnDashboard.SheetElementConfigurationOverridesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SheetElementRenderingRuleProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetelementrenderingrule.html#cfn-quicksight-dashboard-sheetelementrenderingrule-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html
     */
    interface SheetLayoutElementMaximizationOptionProperty {
        /**
         * `CfnDashboard.SheetLayoutElementMaximizationOptionProperty.AvailabilityStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetlayoutelementmaximizationoption.html#cfn-quicksight-dashboard-sheetlayoutelementmaximizationoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html
     */
    interface SheetTextBoxProperty {
        /**
         * `CfnDashboard.SheetTextBoxProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-content
         */
        readonly content?: string;
        /**
         * `CfnDashboard.SheetTextBoxProperty.SheetTextBoxId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheettextbox.html#cfn-quicksight-dashboard-sheettextbox-sheettextboxid
         */
        readonly sheetTextBoxId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html
     */
    interface SheetVisualScopingConfigurationProperty {
        /**
         * `CfnDashboard.SheetVisualScopingConfigurationProperty.Scope`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-scope
         */
        readonly scope: string;
        /**
         * `CfnDashboard.SheetVisualScopingConfigurationProperty.SheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-sheetid
         */
        readonly sheetId: string;
        /**
         * `CfnDashboard.SheetVisualScopingConfigurationProperty.VisualIds`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-sheetvisualscopingconfiguration.html#cfn-quicksight-dashboard-sheetvisualscopingconfiguration-visualids
         */
        readonly visualIds?: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html
     */
    interface ShortFormatTextProperty {
        /**
         * `CfnDashboard.ShortFormatTextProperty.PlainText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * `CfnDashboard.ShortFormatTextProperty.RichText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-shortformattext.html#cfn-quicksight-dashboard-shortformattext-richtext
         */
        readonly richText?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html
     */
    interface SimpleClusterMarkerProperty {
        /**
         * `CfnDashboard.SimpleClusterMarkerProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-simpleclustermarker.html#cfn-quicksight-dashboard-simpleclustermarker-color
         */
        readonly color?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html
     */
    interface SliderControlDisplayOptionsProperty {
        /**
         * `CfnDashboard.SliderControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-slidercontroldisplayoptions.html#cfn-quicksight-dashboard-slidercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html
     */
    interface SmallMultiplesOptionsProperty {
        /**
         * `CfnDashboard.SmallMultiplesOptionsProperty.MaxVisibleColumns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblecolumns
         */
        readonly maxVisibleColumns?: number;
        /**
         * `CfnDashboard.SmallMultiplesOptionsProperty.MaxVisibleRows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-maxvisiblerows
         */
        readonly maxVisibleRows?: number;
        /**
         * `CfnDashboard.SmallMultiplesOptionsProperty.PanelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-smallmultiplesoptions.html#cfn-quicksight-dashboard-smallmultiplesoptions-panelconfiguration
         */
        readonly panelConfiguration?: CfnDashboard.PanelConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html
     */
    interface SpacingProperty {
        /**
         * `CfnDashboard.SpacingProperty.Bottom`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-bottom
         */
        readonly bottom?: string;
        /**
         * `CfnDashboard.SpacingProperty.Left`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-left
         */
        readonly left?: string;
        /**
         * `CfnDashboard.SpacingProperty.Right`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-right
         */
        readonly right?: string;
        /**
         * `CfnDashboard.SpacingProperty.Top`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-spacing.html#cfn-quicksight-dashboard-spacing-top
         */
        readonly top?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html
     */
    interface StringDefaultValuesProperty {
        /**
         * `CfnDashboard.StringDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnDashboard.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.StringDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringdefaultvalues.html#cfn-quicksight-dashboard-stringdefaultvalues-staticvalues
         */
        readonly staticValues?: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html
     */
    interface StringFormatConfigurationProperty {
        /**
         * `CfnDashboard.StringFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnDashboard.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.StringFormatConfigurationProperty.NumericFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringformatconfiguration.html#cfn-quicksight-dashboard-stringformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: CfnDashboard.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     * A string parameter.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html
     */
    interface StringParameterProperty {
        /**
         * A display name for a string parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-name
         */
        readonly name: string;
        /**
         * The values of a string parameter.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameter.html#cfn-quicksight-dashboard-stringparameter-values
         */
        readonly values: string[];
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html
     */
    interface StringParameterDeclarationProperty {
        /**
         * `CfnDashboard.StringParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnDashboard.StringDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.StringParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnDashboard.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.StringParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnDashboard.StringParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnDashboard.StringParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringparameterdeclaration.html#cfn-quicksight-dashboard-stringparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnDashboard.StringValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html
     */
    interface StringValueWhenUnsetConfigurationProperty {
        /**
         * `CfnDashboard.StringValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * `CfnDashboard.StringValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-stringvaluewhenunsetconfiguration.html#cfn-quicksight-dashboard-stringvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html
     */
    interface SubtotalOptionsProperty {
        /**
         * `CfnDashboard.SubtotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnDashboard.SubtotalOptionsProperty.FieldLevel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldlevel
         */
        readonly fieldLevel?: string;
        /**
         * `CfnDashboard.SubtotalOptionsProperty.FieldLevelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-fieldleveloptions
         */
        readonly fieldLevelOptions?: Array<CfnDashboard.PivotTableFieldSubtotalOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.SubtotalOptionsProperty.MetricHeaderCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SubtotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.SubtotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * `CfnDashboard.SubtotalOptionsProperty.ValueCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-subtotaloptions.html#cfn-quicksight-dashboard-subtotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html
     */
    interface TableAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.TableAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.TableAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableaggregatedfieldwells.html#cfn-quicksight-dashboard-tableaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html
     */
    interface TableBorderOptionsProperty {
        /**
         * `CfnDashboard.TableBorderOptionsProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-color
         */
        readonly color?: string;
        /**
         * `CfnDashboard.TableBorderOptionsProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-style
         */
        readonly style?: string;
        /**
         * `CfnDashboard.TableBorderOptionsProperty.Thickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableborderoptions.html#cfn-quicksight-dashboard-tableborderoptions-thickness
         */
        readonly thickness?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html
     */
    interface TableCellConditionalFormattingProperty {
        /**
         * `CfnDashboard.TableCellConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.TableCellConditionalFormattingProperty.TextFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellconditionalformatting.html#cfn-quicksight-dashboard-tablecellconditionalformatting-textformat
         */
        readonly textFormat?: CfnDashboard.TextConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html
     */
    interface TableCellImageSizingConfigurationProperty {
        /**
         * `CfnDashboard.TableCellImageSizingConfigurationProperty.TableCellImageScalingConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellimagesizingconfiguration.html#cfn-quicksight-dashboard-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
         */
        readonly tableCellImageScalingConfiguration?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html
     */
    interface TableCellStyleProperty {
        /**
         * `CfnDashboard.TableCellStyleProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * `CfnDashboard.TableCellStyleProperty.Border`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-border
         */
        readonly border?: CfnDashboard.GlobalTableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableCellStyleProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-fontconfiguration
         */
        readonly fontConfiguration?: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableCellStyleProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-height
         */
        readonly height?: number;
        /**
         * `CfnDashboard.TableCellStyleProperty.HorizontalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * `CfnDashboard.TableCellStyleProperty.TextWrap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-textwrap
         */
        readonly textWrap?: string;
        /**
         * `CfnDashboard.TableCellStyleProperty.VerticalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-verticaltextalignment
         */
        readonly verticalTextAlignment?: string;
        /**
         * `CfnDashboard.TableCellStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablecellstyle.html#cfn-quicksight-dashboard-tablecellstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html
     */
    interface TableConditionalFormattingProperty {
        /**
         * `CfnDashboard.TableConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformatting.html#cfn-quicksight-dashboard-tableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnDashboard.TableConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html
     */
    interface TableConditionalFormattingOptionProperty {
        /**
         * `CfnDashboard.TableConditionalFormattingOptionProperty.Cell`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-cell
         */
        readonly cell?: CfnDashboard.TableCellConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableConditionalFormattingOptionProperty.Row`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconditionalformattingoption.html#cfn-quicksight-dashboard-tableconditionalformattingoption-row
         */
        readonly row?: CfnDashboard.TableRowConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html
     */
    interface TableConfigurationProperty {
        /**
         * `CfnDashboard.TableConfigurationProperty.FieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldoptions
         */
        readonly fieldOptions?: CfnDashboard.TableFieldOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.TableFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableConfigurationProperty.PaginatedReportOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: CfnDashboard.TablePaginatedReportOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.TableSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableConfigurationProperty.TableInlineVisualizations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableinlinevisualizations
         */
        readonly tableInlineVisualizations?: Array<CfnDashboard.TableInlineVisualizationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.TableConfigurationProperty.TableOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-tableoptions
         */
        readonly tableOptions?: CfnDashboard.TableOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableConfigurationProperty.TotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableconfiguration.html#cfn-quicksight-dashboard-tableconfiguration-totaloptions
         */
        readonly totalOptions?: CfnDashboard.TotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html
     */
    interface TableFieldCustomIconContentProperty {
        /**
         * `CfnDashboard.TableFieldCustomIconContentProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomiconcontent.html#cfn-quicksight-dashboard-tablefieldcustomiconcontent-icon
         */
        readonly icon?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html
     */
    interface TableFieldCustomTextContentProperty {
        /**
         * `CfnDashboard.TableFieldCustomTextContentProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-fontconfiguration
         */
        readonly fontConfiguration: CfnDashboard.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableFieldCustomTextContentProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldcustomtextcontent.html#cfn-quicksight-dashboard-tablefieldcustomtextcontent-value
         */
        readonly value?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html
     */
    interface TableFieldImageConfigurationProperty {
        /**
         * `CfnDashboard.TableFieldImageConfigurationProperty.SizingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldimageconfiguration.html#cfn-quicksight-dashboard-tablefieldimageconfiguration-sizingoptions
         */
        readonly sizingOptions?: CfnDashboard.TableCellImageSizingConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html
     */
    interface TableFieldLinkConfigurationProperty {
        /**
         * `CfnDashboard.TableFieldLinkConfigurationProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-content
         */
        readonly content: CfnDashboard.TableFieldLinkContentConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableFieldLinkConfigurationProperty.Target`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkconfiguration-target
         */
        readonly target: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html
     */
    interface TableFieldLinkContentConfigurationProperty {
        /**
         * `CfnDashboard.TableFieldLinkContentConfigurationProperty.CustomIconContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customiconcontent
         */
        readonly customIconContent?: CfnDashboard.TableFieldCustomIconContentProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableFieldLinkContentConfigurationProperty.CustomTextContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldlinkcontentconfiguration.html#cfn-quicksight-dashboard-tablefieldlinkcontentconfiguration-customtextcontent
         */
        readonly customTextContent?: CfnDashboard.TableFieldCustomTextContentProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html
     */
    interface TableFieldOptionProperty {
        /**
         * `CfnDashboard.TableFieldOptionProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnDashboard.TableFieldOptionProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.TableFieldOptionProperty.URLStyling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-urlstyling
         */
        readonly urlStyling?: CfnDashboard.TableFieldURLConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableFieldOptionProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnDashboard.TableFieldOptionProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoption.html#cfn-quicksight-dashboard-tablefieldoption-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html
     */
    interface TableFieldOptionsProperty {
        /**
         * `CfnDashboard.TableFieldOptionsProperty.Order`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-order
         */
        readonly order?: string[];
        /**
         * `CfnDashboard.TableFieldOptionsProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldoptions.html#cfn-quicksight-dashboard-tablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<CfnDashboard.TableFieldOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html
     */
    interface TableFieldURLConfigurationProperty {
        /**
         * `CfnDashboard.TableFieldURLConfigurationProperty.ImageConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-imageconfiguration
         */
        readonly imageConfiguration?: CfnDashboard.TableFieldImageConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableFieldURLConfigurationProperty.LinkConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldurlconfiguration.html#cfn-quicksight-dashboard-tablefieldurlconfiguration-linkconfiguration
         */
        readonly linkConfiguration?: CfnDashboard.TableFieldLinkConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html
     */
    interface TableFieldWellsProperty {
        /**
         * `CfnDashboard.TableFieldWellsProperty.TableAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableaggregatedfieldwells
         */
        readonly tableAggregatedFieldWells?: CfnDashboard.TableAggregatedFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableFieldWellsProperty.TableUnaggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablefieldwells.html#cfn-quicksight-dashboard-tablefieldwells-tableunaggregatedfieldwells
         */
        readonly tableUnaggregatedFieldWells?: CfnDashboard.TableUnaggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html
     */
    interface TableInlineVisualizationProperty {
        /**
         * `CfnDashboard.TableInlineVisualizationProperty.DataBars`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableinlinevisualization.html#cfn-quicksight-dashboard-tableinlinevisualization-databars
         */
        readonly dataBars?: CfnDashboard.DataBarsOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html
     */
    interface TableOptionsProperty {
        /**
         * `CfnDashboard.TableOptionsProperty.CellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-cellstyle
         */
        readonly cellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableOptionsProperty.HeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-headerstyle
         */
        readonly headerStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableOptionsProperty.Orientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-orientation
         */
        readonly orientation?: string;
        /**
         * `CfnDashboard.TableOptionsProperty.RowAlternateColorOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableoptions.html#cfn-quicksight-dashboard-tableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: CfnDashboard.RowAlternateColorOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html
     */
    interface TablePaginatedReportOptionsProperty {
        /**
         * `CfnDashboard.TablePaginatedReportOptionsProperty.OverflowColumnHeaderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * `CfnDashboard.TablePaginatedReportOptionsProperty.VerticalOverflowVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablepaginatedreportoptions.html#cfn-quicksight-dashboard-tablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html
     */
    interface TableRowConditionalFormattingProperty {
        /**
         * `CfnDashboard.TableRowConditionalFormattingProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-backgroundcolor
         */
        readonly backgroundColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableRowConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablerowconditionalformatting.html#cfn-quicksight-dashboard-tablerowconditionalformatting-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html
     */
    interface TableSideBorderOptionsProperty {
        /**
         * `CfnDashboard.TableSideBorderOptionsProperty.Bottom`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-bottom
         */
        readonly bottom?: CfnDashboard.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableSideBorderOptionsProperty.InnerHorizontal`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innerhorizontal
         */
        readonly innerHorizontal?: CfnDashboard.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableSideBorderOptionsProperty.InnerVertical`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-innervertical
         */
        readonly innerVertical?: CfnDashboard.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableSideBorderOptionsProperty.Left`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-left
         */
        readonly left?: CfnDashboard.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableSideBorderOptionsProperty.Right`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-right
         */
        readonly right?: CfnDashboard.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableSideBorderOptionsProperty.Top`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesideborderoptions.html#cfn-quicksight-dashboard-tablesideborderoptions-top
         */
        readonly top?: CfnDashboard.TableBorderOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html
     */
    interface TableSortConfigurationProperty {
        /**
         * `CfnDashboard.TableSortConfigurationProperty.PaginationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: CfnDashboard.PaginationConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableSortConfigurationProperty.RowSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablesortconfiguration.html#cfn-quicksight-dashboard-tablesortconfiguration-rowsort
         */
        readonly rowSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html
     */
    interface TableUnaggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.TableUnaggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tableunaggregatedfieldwells.html#cfn-quicksight-dashboard-tableunaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.UnaggregatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html
     */
    interface TableVisualProperty {
        /**
         * `CfnDashboard.TableVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.TableVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.TableConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnDashboard.TableConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TableVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tablevisual.html#cfn-quicksight-dashboard-tablevisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html
     */
    interface TextAreaControlDisplayOptionsProperty {
        /**
         * `CfnDashboard.TextAreaControlDisplayOptionsProperty.PlaceholderOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: CfnDashboard.TextControlPlaceholderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TextAreaControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textareacontroldisplayoptions.html#cfn-quicksight-dashboard-textareacontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html
     */
    interface TextConditionalFormatProperty {
        /**
         * `CfnDashboard.TextConditionalFormatProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-backgroundcolor
         */
        readonly backgroundColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TextConditionalFormatProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-icon
         */
        readonly icon?: CfnDashboard.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TextConditionalFormatProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textconditionalformat.html#cfn-quicksight-dashboard-textconditionalformat-textcolor
         */
        readonly textColor?: CfnDashboard.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html
     */
    interface TextControlPlaceholderOptionsProperty {
        /**
         * `CfnDashboard.TextControlPlaceholderOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textcontrolplaceholderoptions.html#cfn-quicksight-dashboard-textcontrolplaceholderoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html
     */
    interface TextFieldControlDisplayOptionsProperty {
        /**
         * `CfnDashboard.TextFieldControlDisplayOptionsProperty.PlaceholderOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: CfnDashboard.TextControlPlaceholderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TextFieldControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-textfieldcontroldisplayoptions.html#cfn-quicksight-dashboard-textfieldcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnDashboard.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html
     */
    interface ThousandSeparatorOptionsProperty {
        /**
         * `CfnDashboard.ThousandSeparatorOptionsProperty.Symbol`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-symbol
         */
        readonly symbol?: string;
        /**
         * `CfnDashboard.ThousandSeparatorOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-thousandseparatoroptions.html#cfn-quicksight-dashboard-thousandseparatoroptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html
     */
    interface TimeBasedForecastPropertiesProperty {
        /**
         * `CfnDashboard.TimeBasedForecastPropertiesProperty.LowerBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * `CfnDashboard.TimeBasedForecastPropertiesProperty.PeriodsBackward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * `CfnDashboard.TimeBasedForecastPropertiesProperty.PeriodsForward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * `CfnDashboard.TimeBasedForecastPropertiesProperty.PredictionInterval`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * `CfnDashboard.TimeBasedForecastPropertiesProperty.Seasonality`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-seasonality
         */
        readonly seasonality?: number;
        /**
         * `CfnDashboard.TimeBasedForecastPropertiesProperty.UpperBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timebasedforecastproperties.html#cfn-quicksight-dashboard-timebasedforecastproperties-upperboundary
         */
        readonly upperBoundary?: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html
     */
    interface TimeEqualityFilterProperty {
        /**
         * `CfnDashboard.TimeEqualityFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeEqualityFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnDashboard.TimeEqualityFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnDashboard.TimeEqualityFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * `CfnDashboard.TimeEqualityFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timeequalityfilter.html#cfn-quicksight-dashboard-timeequalityfilter-value
         */
        readonly value?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html
     */
    interface TimeRangeDrillDownFilterProperty {
        /**
         * `CfnDashboard.TimeRangeDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeRangeDrillDownFilterProperty.RangeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangemaximum
         */
        readonly rangeMaximum: string;
        /**
         * `CfnDashboard.TimeRangeDrillDownFilterProperty.RangeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-rangeminimum
         */
        readonly rangeMinimum: string;
        /**
         * `CfnDashboard.TimeRangeDrillDownFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangedrilldownfilter.html#cfn-quicksight-dashboard-timerangedrilldownfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html
     */
    interface TimeRangeFilterProperty {
        /**
         * `CfnDashboard.TimeRangeFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeRangeFilterProperty.ExcludePeriodConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnDashboard.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeRangeFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnDashboard.TimeRangeFilterProperty.IncludeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeRangeFilterProperty.IncludeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeRangeFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnDashboard.TimeRangeFilterProperty.RangeMaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangemaximumvalue
         */
        readonly rangeMaximumValue?: CfnDashboard.TimeRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeRangeFilterProperty.RangeMinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-rangeminimumvalue
         */
        readonly rangeMinimumValue?: CfnDashboard.TimeRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeRangeFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefilter.html#cfn-quicksight-dashboard-timerangefilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html
     */
    interface TimeRangeFilterValueProperty {
        /**
         * `CfnDashboard.TimeRangeFilterValueProperty.Parameter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * `CfnDashboard.TimeRangeFilterValueProperty.RollingDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-rollingdate
         */
        readonly rollingDate?: CfnDashboard.RollingDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TimeRangeFilterValueProperty.StaticValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-timerangefiltervalue.html#cfn-quicksight-dashboard-timerangefiltervalue-staticvalue
         */
        readonly staticValue?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html
     */
    interface TooltipItemProperty {
        /**
         * `CfnDashboard.TooltipItemProperty.ColumnTooltipItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-columntooltipitem
         */
        readonly columnTooltipItem?: CfnDashboard.ColumnTooltipItemProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TooltipItemProperty.FieldTooltipItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipitem.html#cfn-quicksight-dashboard-tooltipitem-fieldtooltipitem
         */
        readonly fieldTooltipItem?: CfnDashboard.FieldTooltipItemProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html
     */
    interface TooltipOptionsProperty {
        /**
         * `CfnDashboard.TooltipOptionsProperty.FieldBasedTooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-fieldbasedtooltip
         */
        readonly fieldBasedTooltip?: CfnDashboard.FieldBasedTooltipProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TooltipOptionsProperty.SelectedTooltipType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-selectedtooltiptype
         */
        readonly selectedTooltipType?: string;
        /**
         * `CfnDashboard.TooltipOptionsProperty.TooltipVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-tooltipoptions.html#cfn-quicksight-dashboard-tooltipoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html
     */
    interface TopBottomFilterProperty {
        /**
         * `CfnDashboard.TopBottomFilterProperty.AggregationSortConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-aggregationsortconfigurations
         */
        readonly aggregationSortConfigurations: Array<CfnDashboard.AggregationSortConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.TopBottomFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TopBottomFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnDashboard.TopBottomFilterProperty.Limit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-limit
         */
        readonly limit?: number;
        /**
         * `CfnDashboard.TopBottomFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnDashboard.TopBottomFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomfilter.html#cfn-quicksight-dashboard-topbottomfilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html
     */
    interface TopBottomMoversComputationProperty {
        /**
         * `CfnDashboard.TopBottomMoversComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-category
         */
        readonly category: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TopBottomMoversComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.TopBottomMoversComputationProperty.MoverSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-moversize
         */
        readonly moverSize?: number;
        /**
         * `CfnDashboard.TopBottomMoversComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.TopBottomMoversComputationProperty.SortOrder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-sortorder
         */
        readonly sortOrder?: string;
        /**
         * `CfnDashboard.TopBottomMoversComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-time
         */
        readonly time: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TopBottomMoversComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-type
         */
        readonly type: string;
        /**
         * `CfnDashboard.TopBottomMoversComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottommoverscomputation.html#cfn-quicksight-dashboard-topbottommoverscomputation-value
         */
        readonly value?: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html
     */
    interface TopBottomRankedComputationProperty {
        /**
         * `CfnDashboard.TopBottomRankedComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-category
         */
        readonly category: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TopBottomRankedComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.TopBottomRankedComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.TopBottomRankedComputationProperty.ResultSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-resultsize
         */
        readonly resultSize?: number;
        /**
         * `CfnDashboard.TopBottomRankedComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-type
         */
        readonly type: string;
        /**
         * `CfnDashboard.TopBottomRankedComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-topbottomrankedcomputation.html#cfn-quicksight-dashboard-topbottomrankedcomputation-value
         */
        readonly value?: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html
     */
    interface TotalAggregationComputationProperty {
        /**
         * `CfnDashboard.TotalAggregationComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.TotalAggregationComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnDashboard.TotalAggregationComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totalaggregationcomputation.html#cfn-quicksight-dashboard-totalaggregationcomputation-value
         */
        readonly value: CfnDashboard.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html
     */
    interface TotalOptionsProperty {
        /**
         * `CfnDashboard.TotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnDashboard.TotalOptionsProperty.Placement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-placement
         */
        readonly placement?: string;
        /**
         * `CfnDashboard.TotalOptionsProperty.ScrollStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * `CfnDashboard.TotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnDashboard.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-totaloptions.html#cfn-quicksight-dashboard-totaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html
     */
    interface TreeMapAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.TreeMapAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapAggregatedFieldWellsProperty.Groups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-groups
         */
        readonly groups?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapAggregatedFieldWellsProperty.Sizes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapaggregatedfieldwells.html#cfn-quicksight-dashboard-treemapaggregatedfieldwells-sizes
         */
        readonly sizes?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html
     */
    interface TreeMapConfigurationProperty {
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.ColorScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-colorscale
         */
        readonly colorScale?: CfnDashboard.ColorScaleProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.TreeMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.GroupLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-grouplabeloptions
         */
        readonly groupLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.SizeLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sizelabeloptions
         */
        readonly sizeLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.TreeMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapconfiguration.html#cfn-quicksight-dashboard-treemapconfiguration-tooltip
         */
        readonly tooltip?: CfnDashboard.TooltipOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html
     */
    interface TreeMapFieldWellsProperty {
        /**
         * `CfnDashboard.TreeMapFieldWellsProperty.TreeMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapfieldwells.html#cfn-quicksight-dashboard-treemapfieldwells-treemapaggregatedfieldwells
         */
        readonly treeMapAggregatedFieldWells?: CfnDashboard.TreeMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html
     */
    interface TreeMapSortConfigurationProperty {
        /**
         * `CfnDashboard.TreeMapSortConfigurationProperty.TreeMapGroupItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapgroupitemslimitconfiguration
         */
        readonly treeMapGroupItemsLimitConfiguration?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapSortConfigurationProperty.TreeMapSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapsortconfiguration.html#cfn-quicksight-dashboard-treemapsortconfiguration-treemapsort
         */
        readonly treeMapSort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html
     */
    interface TreeMapVisualProperty {
        /**
         * `CfnDashboard.TreeMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.TreeMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.TreeMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-treemapvisual.html#cfn-quicksight-dashboard-treemapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html
     */
    interface TrendArrowOptionsProperty {
        /**
         * `CfnDashboard.TrendArrowOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-trendarrowoptions.html#cfn-quicksight-dashboard-trendarrowoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html
     */
    interface UnaggregatedFieldProperty {
        /**
         * `CfnDashboard.UnaggregatedFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-column
         */
        readonly column: CfnDashboard.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.UnaggregatedFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnDashboard.UnaggregatedFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-unaggregatedfield.html#cfn-quicksight-dashboard-unaggregatedfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnDashboard.FormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html
     */
    interface UniqueValuesComputationProperty {
        /**
         * `CfnDashboard.UniqueValuesComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-category
         */
        readonly category: CfnDashboard.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.UniqueValuesComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnDashboard.UniqueValuesComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-uniquevaluescomputation.html#cfn-quicksight-dashboard-uniquevaluescomputation-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html
     */
    interface VisibleRangeOptionsProperty {
        /**
         * `CfnDashboard.VisibleRangeOptionsProperty.PercentRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visiblerangeoptions.html#cfn-quicksight-dashboard-visiblerangeoptions-percentrange
         */
        readonly percentRange?: CfnDashboard.PercentVisibleRangeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html
     */
    interface VisualProperty {
        /**
         * `CfnDashboard.VisualProperty.BarChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-barchartvisual
         */
        readonly barChartVisual?: CfnDashboard.BarChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.BoxPlotVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-boxplotvisual
         */
        readonly boxPlotVisual?: CfnDashboard.BoxPlotVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.ComboChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-combochartvisual
         */
        readonly comboChartVisual?: CfnDashboard.ComboChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.CustomContentVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-customcontentvisual
         */
        readonly customContentVisual?: CfnDashboard.CustomContentVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.EmptyVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-emptyvisual
         */
        readonly emptyVisual?: CfnDashboard.EmptyVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.FilledMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-filledmapvisual
         */
        readonly filledMapVisual?: CfnDashboard.FilledMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.FunnelChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-funnelchartvisual
         */
        readonly funnelChartVisual?: CfnDashboard.FunnelChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.GaugeChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-gaugechartvisual
         */
        readonly gaugeChartVisual?: CfnDashboard.GaugeChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.GeospatialMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-geospatialmapvisual
         */
        readonly geospatialMapVisual?: CfnDashboard.GeospatialMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.HeatMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-heatmapvisual
         */
        readonly heatMapVisual?: CfnDashboard.HeatMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.HistogramVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-histogramvisual
         */
        readonly histogramVisual?: CfnDashboard.HistogramVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.InsightVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-insightvisual
         */
        readonly insightVisual?: CfnDashboard.InsightVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.KPIVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-kpivisual
         */
        readonly kpiVisual?: CfnDashboard.KPIVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.LineChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-linechartvisual
         */
        readonly lineChartVisual?: CfnDashboard.LineChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.PieChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-piechartvisual
         */
        readonly pieChartVisual?: CfnDashboard.PieChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.PivotTableVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-pivottablevisual
         */
        readonly pivotTableVisual?: CfnDashboard.PivotTableVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.RadarChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-radarchartvisual
         */
        readonly radarChartVisual?: CfnDashboard.RadarChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.SankeyDiagramVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-sankeydiagramvisual
         */
        readonly sankeyDiagramVisual?: CfnDashboard.SankeyDiagramVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.ScatterPlotVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-scatterplotvisual
         */
        readonly scatterPlotVisual?: CfnDashboard.ScatterPlotVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.TableVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-tablevisual
         */
        readonly tableVisual?: CfnDashboard.TableVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.TreeMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-treemapvisual
         */
        readonly treeMapVisual?: CfnDashboard.TreeMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.WaterfallVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-waterfallvisual
         */
        readonly waterfallVisual?: CfnDashboard.WaterfallVisualProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualProperty.WordCloudVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visual.html#cfn-quicksight-dashboard-visual-wordcloudvisual
         */
        readonly wordCloudVisual?: CfnDashboard.WordCloudVisualProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html
     */
    interface VisualAxisSortOptionProperty {
        /**
         * `CfnDashboard.VisualAxisSortOptionProperty.AvailabilityStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualaxissortoption.html#cfn-quicksight-dashboard-visualaxissortoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html
     */
    interface VisualCustomActionProperty {
        /**
         * `CfnDashboard.VisualCustomActionProperty.ActionOperations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-actionoperations
         */
        readonly actionOperations: Array<CfnDashboard.VisualCustomActionOperationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualCustomActionProperty.CustomActionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-customactionid
         */
        readonly customActionId: string;
        /**
         * `CfnDashboard.VisualCustomActionProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-name
         */
        readonly name: string;
        /**
         * `CfnDashboard.VisualCustomActionProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-status
         */
        readonly status?: string;
        /**
         * `CfnDashboard.VisualCustomActionProperty.Trigger`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomaction.html#cfn-quicksight-dashboard-visualcustomaction-trigger
         */
        readonly trigger: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html
     */
    interface VisualCustomActionOperationProperty {
        /**
         * `CfnDashboard.VisualCustomActionOperationProperty.FilterOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-filteroperation
         */
        readonly filterOperation?: CfnDashboard.CustomActionFilterOperationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualCustomActionOperationProperty.NavigationOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-navigationoperation
         */
        readonly navigationOperation?: CfnDashboard.CustomActionNavigationOperationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualCustomActionOperationProperty.SetParametersOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-setparametersoperation
         */
        readonly setParametersOperation?: CfnDashboard.CustomActionSetParametersOperationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualCustomActionOperationProperty.URLOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualcustomactionoperation.html#cfn-quicksight-dashboard-visualcustomactionoperation-urloperation
         */
        readonly urlOperation?: CfnDashboard.CustomActionURLOperationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html
     */
    interface VisualMenuOptionProperty {
        /**
         * `CfnDashboard.VisualMenuOptionProperty.AvailabilityStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualmenuoption.html#cfn-quicksight-dashboard-visualmenuoption-availabilitystatus
         */
        readonly availabilityStatus?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html
     */
    interface VisualPaletteProperty {
        /**
         * `CfnDashboard.VisualPaletteProperty.ChartColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-chartcolor
         */
        readonly chartColor?: string;
        /**
         * `CfnDashboard.VisualPaletteProperty.ColorMap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualpalette.html#cfn-quicksight-dashboard-visualpalette-colormap
         */
        readonly colorMap?: Array<CfnDashboard.DataPathColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html
     */
    interface VisualSubtitleLabelOptionsProperty {
        /**
         * `CfnDashboard.VisualSubtitleLabelOptionsProperty.FormatText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-formattext
         */
        readonly formatText?: CfnDashboard.LongFormatTextProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualSubtitleLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualsubtitlelabeloptions.html#cfn-quicksight-dashboard-visualsubtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html
     */
    interface VisualTitleLabelOptionsProperty {
        /**
         * `CfnDashboard.VisualTitleLabelOptionsProperty.FormatText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-formattext
         */
        readonly formatText?: CfnDashboard.ShortFormatTextProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.VisualTitleLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-visualtitlelabeloptions.html#cfn-quicksight-dashboard-visualtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html
     */
    interface WaterfallChartAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.WaterfallChartAggregatedFieldWellsProperty.Breakdowns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-breakdowns
         */
        readonly breakdowns?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartAggregatedFieldWellsProperty.Categories`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-categories
         */
        readonly categories?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartaggregatedfieldwells.html#cfn-quicksight-dashboard-waterfallchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html
     */
    interface WaterfallChartConfigurationProperty {
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.CategoryAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxisdisplayoptions
         */
        readonly categoryAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.CategoryAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-categoryaxislabeloptions
         */
        readonly categoryAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnDashboard.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.WaterfallChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-legend
         */
        readonly legend?: CfnDashboard.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnDashboard.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.WaterfallChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnDashboard.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartConfigurationProperty.WaterfallChartOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartconfiguration.html#cfn-quicksight-dashboard-waterfallchartconfiguration-waterfallchartoptions
         */
        readonly waterfallChartOptions?: CfnDashboard.WaterfallChartOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html
     */
    interface WaterfallChartFieldWellsProperty {
        /**
         * `CfnDashboard.WaterfallChartFieldWellsProperty.WaterfallChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartfieldwells.html#cfn-quicksight-dashboard-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
         */
        readonly waterfallChartAggregatedFieldWells?: CfnDashboard.WaterfallChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html
     */
    interface WaterfallChartOptionsProperty {
        /**
         * `CfnDashboard.WaterfallChartOptionsProperty.TotalBarLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartoptions.html#cfn-quicksight-dashboard-waterfallchartoptions-totalbarlabel
         */
        readonly totalBarLabel?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html
     */
    interface WaterfallChartSortConfigurationProperty {
        /**
         * `CfnDashboard.WaterfallChartSortConfigurationProperty.BreakdownItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-breakdownitemslimit
         */
        readonly breakdownItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallchartsortconfiguration.html#cfn-quicksight-dashboard-waterfallchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html
     */
    interface WaterfallVisualProperty {
        /**
         * `CfnDashboard.WaterfallVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.WaterfallChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WaterfallVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-waterfallvisual.html#cfn-quicksight-dashboard-waterfallvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html
     */
    interface WhatIfPointScenarioProperty {
        /**
         * `CfnDashboard.WhatIfPointScenarioProperty.Date`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-date
         */
        readonly date: string;
        /**
         * `CfnDashboard.WhatIfPointScenarioProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifpointscenario.html#cfn-quicksight-dashboard-whatifpointscenario-value
         */
        readonly value: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html
     */
    interface WhatIfRangeScenarioProperty {
        /**
         * `CfnDashboard.WhatIfRangeScenarioProperty.EndDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-enddate
         */
        readonly endDate: string;
        /**
         * `CfnDashboard.WhatIfRangeScenarioProperty.StartDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-startdate
         */
        readonly startDate: string;
        /**
         * `CfnDashboard.WhatIfRangeScenarioProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-whatifrangescenario.html#cfn-quicksight-dashboard-whatifrangescenario-value
         */
        readonly value: number;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html
     */
    interface WordCloudAggregatedFieldWellsProperty {
        /**
         * `CfnDashboard.WordCloudAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnDashboard.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudAggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudaggregatedfieldwells.html#cfn-quicksight-dashboard-wordcloudaggregatedfieldwells-size
         */
        readonly size?: Array<CfnDashboard.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html
     */
    interface WordCloudChartConfigurationProperty {
        /**
         * `CfnDashboard.WordCloudChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnDashboard.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnDashboard.WordCloudFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnDashboard.WordCloudSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudChartConfigurationProperty.WordCloudOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudchartconfiguration.html#cfn-quicksight-dashboard-wordcloudchartconfiguration-wordcloudoptions
         */
        readonly wordCloudOptions?: CfnDashboard.WordCloudOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html
     */
    interface WordCloudFieldWellsProperty {
        /**
         * `CfnDashboard.WordCloudFieldWellsProperty.WordCloudAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudfieldwells.html#cfn-quicksight-dashboard-wordcloudfieldwells-wordcloudaggregatedfieldwells
         */
        readonly wordCloudAggregatedFieldWells?: CfnDashboard.WordCloudAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html
     */
    interface WordCloudOptionsProperty {
        /**
         * `CfnDashboard.WordCloudOptionsProperty.CloudLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-cloudlayout
         */
        readonly cloudLayout?: string;
        /**
         * `CfnDashboard.WordCloudOptionsProperty.MaximumStringLength`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-maximumstringlength
         */
        readonly maximumStringLength?: number;
        /**
         * `CfnDashboard.WordCloudOptionsProperty.WordCasing`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordcasing
         */
        readonly wordCasing?: string;
        /**
         * `CfnDashboard.WordCloudOptionsProperty.WordOrientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordorientation
         */
        readonly wordOrientation?: string;
        /**
         * `CfnDashboard.WordCloudOptionsProperty.WordPadding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordpadding
         */
        readonly wordPadding?: string;
        /**
         * `CfnDashboard.WordCloudOptionsProperty.WordScaling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudoptions.html#cfn-quicksight-dashboard-wordcloudoptions-wordscaling
         */
        readonly wordScaling?: string;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html
     */
    interface WordCloudSortConfigurationProperty {
        /**
         * `CfnDashboard.WordCloudSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnDashboard.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudsortconfiguration.html#cfn-quicksight-dashboard-wordcloudsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnDashboard.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDashboard {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html
     */
    interface WordCloudVisualProperty {
        /**
         * `CfnDashboard.WordCloudVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-actions
         */
        readonly actions?: Array<CfnDashboard.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnDashboard.WordCloudChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnDashboard.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-subtitle
         */
        readonly subtitle?: CfnDashboard.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-title
         */
        readonly title?: CfnDashboard.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnDashboard.WordCloudVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dashboard-wordcloudvisual.html#cfn-quicksight-dashboard-wordcloudvisual-visualid
         */
        readonly visualId: string;
    }
}
/**
 * Properties for defining a `CfnDataSet`
 *
 * @struct
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
 */
export interface CfnDataSetProps {
    /**
     * The AWS account ID.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-awsaccountid
     */
    readonly awsAccountId?: string;
    /**
     * Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columngroups
     */
    readonly columnGroups?: Array<CfnDataSet.ColumnGroupProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * A set of one or more definitions of a `ColumnLevelPermissionRule` .
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columnlevelpermissionrules
     */
    readonly columnLevelPermissionRules?: Array<CfnDataSet.ColumnLevelPermissionRuleProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetid
     */
    readonly dataSetId?: string;
    /**
     * The usage configuration to apply to child datasets that reference this dataset as a source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetusageconfiguration
     */
    readonly dataSetUsageConfiguration?: CfnDataSet.DataSetUsageConfigurationProperty | cdk.IResolvable;
    /**
     * The folder that contains fields and nested subfolders for your dataset.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-fieldfolders
     */
    readonly fieldFolders?: {
        [key: string]: (CfnDataSet.FieldFolderProperty | cdk.IResolvable);
    } | cdk.IResolvable;
    /**
     * Indicates whether you want to import the data into SPICE.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-importmode
     */
    readonly importMode?: string;
    /**
     * The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-ingestionwaitpolicy
     */
    readonly ingestionWaitPolicy?: CfnDataSet.IngestionWaitPolicyProperty | cdk.IResolvable;
    /**
     * Configures the combination and transformation of the data from the physical tables.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-logicaltablemap
     */
    readonly logicalTableMap?: {
        [key: string]: (CfnDataSet.LogicalTableProperty | cdk.IResolvable);
    } | cdk.IResolvable;
    /**
     * The display name for the dataset.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-name
     */
    readonly name?: string;
    /**
     * A list of resource permissions on the dataset.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-permissions
     */
    readonly permissions?: Array<CfnDataSet.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * Declares the physical tables that are available in the underlying data sources.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-physicaltablemap
     */
    readonly physicalTableMap?: {
        [key: string]: (CfnDataSet.PhysicalTableProperty | cdk.IResolvable);
    } | cdk.IResolvable;
    /**
     * The row-level security configuration for the data that you want to create.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset
     */
    readonly rowLevelPermissionDataSet?: CfnDataSet.RowLevelPermissionDataSetProperty | cdk.IResolvable;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-tags
     */
    readonly tags?: cdk.CfnTag[];
}
/**
 * A CloudFormation `AWS::QuickSight::DataSet`
 *
 * Creates a dataset. This operation doesn't support datasets that include uploaded files as a source.
 *
 * @cloudformationResource AWS::QuickSight::DataSet
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html
 */
export declare class CfnDataSet extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "AWS::QuickSight::DataSet";
    /**
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDataSet;
    /**
     * The Amazon Resource Name (ARN) of the dataset.
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     *
     * @cloudformationAttribute ConsumedSpiceCapacityInBytes
     */
    readonly attrConsumedSpiceCapacityInBytes: cdk.IResolvable;
    /**
     * The time this dataset version was created.
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time this dataset version was last updated.
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     *
     * @cloudformationAttribute OutputColumns
     */
    readonly attrOutputColumns: cdk.IResolvable;
    /**
     * The AWS account ID.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-awsaccountid
     */
    awsAccountId: string | undefined;
    /**
     * Groupings of columns that work together in certain Amazon QuickSight features. Currently, only geospatial hierarchy is supported.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columngroups
     */
    columnGroups: Array<CfnDataSet.ColumnGroupProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * A set of one or more definitions of a `ColumnLevelPermissionRule` .
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-columnlevelpermissionrules
     */
    columnLevelPermissionRules: Array<CfnDataSet.ColumnLevelPermissionRuleProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * An ID for the dataset that you want to create. This ID is unique per AWS Region for each AWS account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetid
     */
    dataSetId: string | undefined;
    /**
     * The usage configuration to apply to child datasets that reference this dataset as a source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-datasetusageconfiguration
     */
    dataSetUsageConfiguration: CfnDataSet.DataSetUsageConfigurationProperty | cdk.IResolvable | undefined;
    /**
     * The folder that contains fields and nested subfolders for your dataset.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-fieldfolders
     */
    fieldFolders: {
        [key: string]: (CfnDataSet.FieldFolderProperty | cdk.IResolvable);
    } | cdk.IResolvable | undefined;
    /**
     * Indicates whether you want to import the data into SPICE.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-importmode
     */
    importMode: string | undefined;
    /**
     * The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-ingestionwaitpolicy
     */
    ingestionWaitPolicy: CfnDataSet.IngestionWaitPolicyProperty | cdk.IResolvable | undefined;
    /**
     * Configures the combination and transformation of the data from the physical tables.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-logicaltablemap
     */
    logicalTableMap: {
        [key: string]: (CfnDataSet.LogicalTableProperty | cdk.IResolvable);
    } | cdk.IResolvable | undefined;
    /**
     * The display name for the dataset.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-name
     */
    name: string | undefined;
    /**
     * A list of resource permissions on the dataset.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-permissions
     */
    permissions: Array<CfnDataSet.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * Declares the physical tables that are available in the underlying data sources.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-physicaltablemap
     */
    physicalTableMap: {
        [key: string]: (CfnDataSet.PhysicalTableProperty | cdk.IResolvable);
    } | cdk.IResolvable | undefined;
    /**
     * The row-level security configuration for the data that you want to create.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset
     */
    rowLevelPermissionDataSet: CfnDataSet.RowLevelPermissionDataSetProperty | cdk.IResolvable | undefined;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the dataset.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-dataset.html#cfn-quicksight-dataset-tags
     */
    readonly tags: cdk.TagManager;
    /**
     * Create a new `AWS::QuickSight::DataSet`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnDataSetProps);
    /**
     * Examines the CloudFormation resource and discloses attributes.
     *
     * @param inspector - tree inspector to collect and process attributes
     *
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected get cfnProperties(): {
        [key: string]: any;
    };
    protected renderProperties(props: {
        [key: string]: any;
    }): {
        [key: string]: any;
    };
}
export declare namespace CfnDataSet {
    /**
     * A calculated column for a dataset.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html
     */
    interface CalculatedColumnProperty {
        /**
         * A unique ID to identify a calculated column. During a dataset update, if the column ID of a calculated column matches that of an existing calculated column, Amazon QuickSight preserves the existing calculated column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnid
         */
        readonly columnId: string;
        /**
         * Column name.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-columnname
         */
        readonly columnName: string;
        /**
         * An expression that defines the calculated column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-calculatedcolumn.html#cfn-quicksight-dataset-calculatedcolumn-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * A transform operation that casts a column to a different type.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html
     */
    interface CastColumnTypeOperationProperty {
        /**
         * Column name.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-columnname
         */
        readonly columnName: string;
        /**
         * When casting a column from string to datetime type, you can supply a string in a format supported by Amazon QuickSight to denote the source data format.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-format
         */
        readonly format?: string;
        /**
         * New column data type.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-castcolumntypeoperation.html#cfn-quicksight-dataset-castcolumntypeoperation-newcolumntype
         */
        readonly newColumnType: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * Metadata that contains a description for a column.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html
     */
    interface ColumnDescriptionProperty {
        /**
         * The text of a description for a column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columndescription.html#cfn-quicksight-dataset-columndescription-text
         */
        readonly text?: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * Groupings of columns that work together in certain Amazon QuickSight features. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html
     */
    interface ColumnGroupProperty {
        /**
         * Geospatial column group that denotes a hierarchy.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columngroup.html#cfn-quicksight-dataset-columngroup-geospatialcolumngroup
         */
        readonly geoSpatialColumnGroup?: CfnDataSet.GeoSpatialColumnGroupProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * A rule defined to grant access on one or more restricted columns. Each dataset can have multiple rules. To create a restricted column, you add it to one or more rules. Each rule must contain at least one column and at least one user or group. To be able to see a restricted column, a user or group needs to be added to a rule for that column.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html
     */
    interface ColumnLevelPermissionRuleProperty {
        /**
         * An array of column names.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-columnnames
         */
        readonly columnNames?: string[];
        /**
         * An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columnlevelpermissionrule.html#cfn-quicksight-dataset-columnlevelpermissionrule-principals
         */
        readonly principals?: string[];
    }
}
export declare namespace CfnDataSet {
    /**
     * A tag for a column in a `[TagColumnOperation](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_TagColumnOperation.html)` structure. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html
     */
    interface ColumnTagProperty {
        /**
         * A description for a column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columndescription
         */
        readonly columnDescription?: CfnDataSet.ColumnDescriptionProperty | cdk.IResolvable;
        /**
         * A geospatial role for a column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-columntag.html#cfn-quicksight-dataset-columntag-columngeographicrole
         */
        readonly columnGeographicRole?: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * A transform operation that creates calculated columns. Columns created in one such operation form a lexical closure.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html
     */
    interface CreateColumnsOperationProperty {
        /**
         * Calculated columns to create.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-createcolumnsoperation.html#cfn-quicksight-dataset-createcolumnsoperation-columns
         */
        readonly columns: Array<CfnDataSet.CalculatedColumnProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * A physical table type built from the results of the custom SQL query.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html
     */
    interface CustomSqlProperty {
        /**
         * The column schema from the SQL query result set.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-columns
         */
        readonly columns: Array<CfnDataSet.InputColumnProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The Amazon Resource Name (ARN) of the data source.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-datasourcearn
         */
        readonly dataSourceArn: string;
        /**
         * A display name for the SQL query result.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-name
         */
        readonly name: string;
        /**
         * The SQL query.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-customsql.html#cfn-quicksight-dataset-customsql-sqlquery
         */
        readonly sqlQuery: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * The usage configuration to apply to child datasets that reference this dataset as a source.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html
     */
    interface DataSetUsageConfigurationProperty {
        /**
         * An option that controls whether a child dataset of a direct query can use this dataset as a source.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasdirectquerysource
         */
        readonly disableUseAsDirectQuerySource?: boolean | cdk.IResolvable;
        /**
         * An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-datasetusageconfiguration.html#cfn-quicksight-dataset-datasetusageconfiguration-disableuseasimportedsource
         */
        readonly disableUseAsImportedSource?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * A FieldFolder element is a folder that contains fields and nested subfolders.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html
     */
    interface FieldFolderProperty {
        /**
         * A folder has a list of columns. A column can only be in one folder.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-columns
         */
        readonly columns?: string[];
        /**
         * The description for a field folder.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-fieldfolder.html#cfn-quicksight-dataset-fieldfolder-description
         */
        readonly description?: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * A transform operation that filters rows based on a condition.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html
     */
    interface FilterOperationProperty {
        /**
         * An expression that must evaluate to a Boolean value. Rows for which the expression evaluates to true are kept in the dataset.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-filteroperation.html#cfn-quicksight-dataset-filteroperation-conditionexpression
         */
        readonly conditionExpression: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * Geospatial column group that denotes a hierarchy.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html
     */
    interface GeoSpatialColumnGroupProperty {
        /**
         * Columns in this hierarchy.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-columns
         */
        readonly columns: string[];
        /**
         * Country code.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-countrycode
         */
        readonly countryCode?: string;
        /**
         * A display name for the hierarchy.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-geospatialcolumngroup.html#cfn-quicksight-dataset-geospatialcolumngroup-name
         */
        readonly name: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * The wait policy to use when creating or updating a Dataset. The default is to wait for SPICE ingestion to finish with timeout of 36 hours.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html
     */
    interface IngestionWaitPolicyProperty {
        /**
         * The maximum time (in hours) to wait for Ingestion to complete. Default timeout is 36 hours. Applicable only when `DataSetImportMode` mode is set to SPICE and `WaitForSpiceIngestion` is set to true.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-ingestionwaittimeinhours
         */
        readonly ingestionWaitTimeInHours?: number;
        /**
         * Wait for SPICE ingestion to finish to mark dataset creation or update as successful. Default (true). Applicable only when `DataSetImportMode` mode is set to SPICE.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-ingestionwaitpolicy.html#cfn-quicksight-dataset-ingestionwaitpolicy-waitforspiceingestion
         */
        readonly waitForSpiceIngestion?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * Metadata for a column that is used as the input of a transform operation.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html
     */
    interface InputColumnProperty {
        /**
         * The name of this column in the underlying data source.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-name
         */
        readonly name: string;
        /**
         * The data type of the column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-inputcolumn.html#cfn-quicksight-dataset-inputcolumn-type
         */
        readonly type: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * The instructions associated with a join.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html
     */
    interface JoinInstructionProperty {
        /**
         * Join key properties of the left operand.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftjoinkeyproperties
         */
        readonly leftJoinKeyProperties?: CfnDataSet.JoinKeyPropertiesProperty | cdk.IResolvable;
        /**
         * The operand on the left side of a join.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-leftoperand
         */
        readonly leftOperand: string;
        /**
         * The join instructions provided in the `ON` clause of a join.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-onclause
         */
        readonly onClause: string;
        /**
         * Join key properties of the right operand.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightjoinkeyproperties
         */
        readonly rightJoinKeyProperties?: CfnDataSet.JoinKeyPropertiesProperty | cdk.IResolvable;
        /**
         * The operand on the right side of a join.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-rightoperand
         */
        readonly rightOperand: string;
        /**
         * The type of join that it is.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joininstruction.html#cfn-quicksight-dataset-joininstruction-type
         */
        readonly type: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * Properties associated with the columns participating in a join.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html
     */
    interface JoinKeyPropertiesProperty {
        /**
         * A value that indicates that a row in a table is uniquely identified by the columns in a join key. This is used by Amazon QuickSight to optimize query performance.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-joinkeyproperties.html#cfn-quicksight-dataset-joinkeyproperties-uniquekey
         */
        readonly uniqueKey?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * A *logical table* is a unit that joins and that data transformations operate on. A logical table has a source, which can be either a physical table or result of a join. When a logical table points to a physical table, the logical table acts as a mutable copy of that physical table through transform operations.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html
     */
    interface LogicalTableProperty {
        /**
         * A display name for the logical table.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-alias
         */
        readonly alias: string;
        /**
         * Transform operations that act on this logical table. For this structure to be valid, only one of the attributes can be non-null.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-datatransforms
         */
        readonly dataTransforms?: Array<CfnDataSet.TransformOperationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Source of this logical table.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltable.html#cfn-quicksight-dataset-logicaltable-source
         */
        readonly source: CfnDataSet.LogicalTableSourceProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * Information about the source of a logical table. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html
     */
    interface LogicalTableSourceProperty {
        /**
         * The Amazon Resource Number (ARN) of the parent dataset.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-datasetarn
         */
        readonly dataSetArn?: string;
        /**
         * Specifies the result of a join of two logical tables.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-joininstruction
         */
        readonly joinInstruction?: CfnDataSet.JoinInstructionProperty | cdk.IResolvable;
        /**
         * Physical table ID.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-logicaltablesource.html#cfn-quicksight-dataset-logicaltablesource-physicaltableid
         */
        readonly physicalTableId?: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * Output column.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html
     */
    interface OutputColumnProperty {
        /**
         * A description for a column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-description
         */
        readonly description?: string;
        /**
         * A display name for the dataset.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-name
         */
        readonly name?: string;
        /**
         * Type.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-outputcolumn.html#cfn-quicksight-dataset-outputcolumn-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * A view of a data source that contains information about the shape of the data in the underlying source. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html
     */
    interface PhysicalTableProperty {
        /**
         * A physical table type built from the results of the custom SQL query.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-customsql
         */
        readonly customSql?: CfnDataSet.CustomSqlProperty | cdk.IResolvable;
        /**
         * A physical table type for relational data sources.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-relationaltable
         */
        readonly relationalTable?: CfnDataSet.RelationalTableProperty | cdk.IResolvable;
        /**
         * A physical table type for as S3 data source.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-physicaltable.html#cfn-quicksight-dataset-physicaltable-s3source
         */
        readonly s3Source?: CfnDataSet.S3SourceProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * A transform operation that projects columns. Operations that come after a projection can only refer to projected columns.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html
     */
    interface ProjectOperationProperty {
        /**
         * Projected columns.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-projectoperation.html#cfn-quicksight-dataset-projectoperation-projectedcolumns
         */
        readonly projectedColumns: string[];
    }
}
export declare namespace CfnDataSet {
    /**
     * A physical table type for relational data sources.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html
     */
    interface RelationalTableProperty {
        /**
         * `CfnDataSet.RelationalTableProperty.Catalog`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-catalog
         */
        readonly catalog?: string;
        /**
         * The Amazon Resource Name (ARN) for the data source.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-datasourcearn
         */
        readonly dataSourceArn: string;
        /**
         * The column schema of the table.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-inputcolumns
         */
        readonly inputColumns: Array<CfnDataSet.InputColumnProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The name of the relational table.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-name
         */
        readonly name: string;
        /**
         * The schema name. This name applies to certain relational database engines.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-relationaltable.html#cfn-quicksight-dataset-relationaltable-schema
         */
        readonly schema?: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * A transform operation that renames a column.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html
     */
    interface RenameColumnOperationProperty {
        /**
         * The name of the column to be renamed.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-columnname
         */
        readonly columnName: string;
        /**
         * The new name for the column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-renamecolumnoperation.html#cfn-quicksight-dataset-renamecolumnoperation-newcolumnname
         */
        readonly newColumnName: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permisions on
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-actions
         */
        readonly actions: string[];
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-resourcepermission.html#cfn-quicksight-dataset-resourcepermission-principal
         */
        readonly principal: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * Information about a dataset that contains permissions for row-level security (RLS). The permissions dataset maps fields to users or groups. For more information, see [Using Row-Level Security (RLS) to Restrict Access to a Dataset](https://docs.aws.amazon.com/quicksight/latest/user/restrict-access-to-a-data-set-using-row-level-security.html) in the *Amazon QuickSight User Guide* .
     *
     * The option to deny permissions by setting `PermissionPolicy` to `DENY_ACCESS` is not supported for new RLS datasets.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html
     */
    interface RowLevelPermissionDataSetProperty {
        /**
         * The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-arn
         */
        readonly arn: string;
        /**
         * The user or group rules associated with the dataset that contains permissions for RLS.
         *
         * By default, `FormatVersion` is `VERSION_1` . When `FormatVersion` is `VERSION_1` , `UserName` and `GroupName` are required. When `FormatVersion` is `VERSION_2` , `UserARN` and `GroupARN` are required, and `Namespace` must not exist.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-formatversion
         */
        readonly formatVersion?: string;
        /**
         * The namespace associated with the dataset that contains permissions for RLS.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-namespace
         */
        readonly namespace?: string;
        /**
         * The type of permissions to use when interpreting the permissions for RLS. `DENY_ACCESS` is included for backward compatibility only.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-rowlevelpermissiondataset.html#cfn-quicksight-dataset-rowlevelpermissiondataset-permissionpolicy
         */
        readonly permissionPolicy: string;
    }
}
export declare namespace CfnDataSet {
    /**
     * A physical table type for an S3 data source.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html
     */
    interface S3SourceProperty {
        /**
         * The Amazon Resource Name (ARN) for the data source.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-datasourcearn
         */
        readonly dataSourceArn: string;
        /**
         * A physical table type for an S3 data source.
         *
         * > For files that aren't JSON, only `STRING` data types are supported in input columns.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-inputcolumns
         */
        readonly inputColumns: Array<CfnDataSet.InputColumnProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Information about the format for the S3 source file or files.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-s3source.html#cfn-quicksight-dataset-s3source-uploadsettings
         */
        readonly uploadSettings?: CfnDataSet.UploadSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * A transform operation that tags a column with additional information.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html
     */
    interface TagColumnOperationProperty {
        /**
         * The column that this operation acts on.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-columnname
         */
        readonly columnName: string;
        /**
         * The dataset column tag, currently only used for geospatial type tagging.
         *
         * > This is not tags for the AWS tagging feature.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-tagcolumnoperation.html#cfn-quicksight-dataset-tagcolumnoperation-tags
         */
        readonly tags: CfnDataSet.ColumnTagProperty[];
    }
}
export declare namespace CfnDataSet {
    /**
     * A data transformation on a logical table. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html
     */
    interface TransformOperationProperty {
        /**
         * A transform operation that casts a column to a different type.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-castcolumntypeoperation
         */
        readonly castColumnTypeOperation?: CfnDataSet.CastColumnTypeOperationProperty | cdk.IResolvable;
        /**
         * An operation that creates calculated columns. Columns created in one such operation form a lexical closure.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-createcolumnsoperation
         */
        readonly createColumnsOperation?: CfnDataSet.CreateColumnsOperationProperty | cdk.IResolvable;
        /**
         * An operation that filters rows based on some condition.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-filteroperation
         */
        readonly filterOperation?: CfnDataSet.FilterOperationProperty | cdk.IResolvable;
        /**
         * An operation that projects columns. Operations that come after a projection can only refer to projected columns.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-projectoperation
         */
        readonly projectOperation?: CfnDataSet.ProjectOperationProperty | cdk.IResolvable;
        /**
         * An operation that renames a column.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-renamecolumnoperation
         */
        readonly renameColumnOperation?: CfnDataSet.RenameColumnOperationProperty | cdk.IResolvable;
        /**
         * An operation that tags a column with additional information.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-transformoperation.html#cfn-quicksight-dataset-transformoperation-tagcolumnoperation
         */
        readonly tagColumnOperation?: CfnDataSet.TagColumnOperationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDataSet {
    /**
     * Information about the format for a source file or files.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html
     */
    interface UploadSettingsProperty {
        /**
         * Whether the file has a header row, or the files each have a header row.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-containsheader
         */
        readonly containsHeader?: boolean | cdk.IResolvable;
        /**
         * The delimiter between values in the file.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-delimiter
         */
        readonly delimiter?: string;
        /**
         * File format.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-format
         */
        readonly format?: string;
        /**
         * A row number to start reading data from.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-startfromrow
         */
        readonly startFromRow?: number;
        /**
         * Text qualifier.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-dataset-uploadsettings.html#cfn-quicksight-dataset-uploadsettings-textqualifier
         */
        readonly textQualifier?: string;
    }
}
/**
 * Properties for defining a `CfnDataSource`
 *
 * @struct
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
 */
export interface CfnDataSourceProps {
    /**
     * A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the `DataSourceParameters` structure that's in the request with the structures in the `AlternateDataSourceParameters` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the `AlternateDataSourceParameters` list is null, the `Credentials` originally used with this `DataSourceParameters` are automatically allowed.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-alternatedatasourceparameters
     */
    readonly alternateDataSourceParameters?: Array<CfnDataSource.DataSourceParametersProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The AWS account ID.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-awsaccountid
     */
    readonly awsAccountId?: string;
    /**
     * The credentials Amazon QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-credentials
     */
    readonly credentials?: CfnDataSource.DataSourceCredentialsProperty | cdk.IResolvable;
    /**
     * An ID for the data source. This ID is unique per AWS Region for each AWS account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceid
     */
    readonly dataSourceId?: string;
    /**
     * The parameters that Amazon QuickSight uses to connect to your underlying source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceparameters
     */
    readonly dataSourceParameters?: CfnDataSource.DataSourceParametersProperty | cdk.IResolvable;
    /**
     * Error information from the last update or the creation of the data source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-errorinfo
     */
    readonly errorInfo?: CfnDataSource.DataSourceErrorInfoProperty | cdk.IResolvable;
    /**
     * A display name for the data source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-name
     */
    readonly name?: string;
    /**
     * A list of resource permissions on the data source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-permissions
     */
    readonly permissions?: Array<CfnDataSource.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-sslproperties
     */
    readonly sslProperties?: CfnDataSource.SslPropertiesProperty | cdk.IResolvable;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-tags
     */
    readonly tags?: cdk.CfnTag[];
    /**
     * The type of the data source. To return a list of all data sources, use `ListDataSources` .
     *
     * Use `AMAZON_ELASTICSEARCH` for Amazon OpenSearch Service.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-type
     */
    readonly type?: string;
    /**
     * Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-vpcconnectionproperties
     */
    readonly vpcConnectionProperties?: CfnDataSource.VpcConnectionPropertiesProperty | cdk.IResolvable;
}
/**
 * A CloudFormation `AWS::QuickSight::DataSource`
 *
 * Creates a data source.
 *
 * @cloudformationResource AWS::QuickSight::DataSource
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html
 */
export declare class CfnDataSource extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "AWS::QuickSight::DataSource";
    /**
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDataSource;
    /**
     * The Amazon Resource Name (ARN) of the dataset.
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time that this data source was created.
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The last time that this data source was updated.
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * The HTTP status of the request.
     * @cloudformationAttribute Status
     */
    readonly attrStatus: string;
    /**
     * A set of alternate data source parameters that you want to share for the credentials stored with this data source. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the `DataSourceParameters` structure that's in the request with the structures in the `AlternateDataSourceParameters` allow list. If the structures are an exact match, the request is allowed to use the credentials from this existing data source. If the `AlternateDataSourceParameters` list is null, the `Credentials` originally used with this `DataSourceParameters` are automatically allowed.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-alternatedatasourceparameters
     */
    alternateDataSourceParameters: Array<CfnDataSource.DataSourceParametersProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * The AWS account ID.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-awsaccountid
     */
    awsAccountId: string | undefined;
    /**
     * The credentials Amazon QuickSight that uses to connect to your underlying source. Currently, only credentials based on user name and password are supported.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-credentials
     */
    credentials: CfnDataSource.DataSourceCredentialsProperty | cdk.IResolvable | undefined;
    /**
     * An ID for the data source. This ID is unique per AWS Region for each AWS account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceid
     */
    dataSourceId: string | undefined;
    /**
     * The parameters that Amazon QuickSight uses to connect to your underlying source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-datasourceparameters
     */
    dataSourceParameters: CfnDataSource.DataSourceParametersProperty | cdk.IResolvable | undefined;
    /**
     * Error information from the last update or the creation of the data source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-errorinfo
     */
    errorInfo: CfnDataSource.DataSourceErrorInfoProperty | cdk.IResolvable | undefined;
    /**
     * A display name for the data source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-name
     */
    name: string | undefined;
    /**
     * A list of resource permissions on the data source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-permissions
     */
    permissions: Array<CfnDataSource.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-sslproperties
     */
    sslProperties: CfnDataSource.SslPropertiesProperty | cdk.IResolvable | undefined;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the data source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-tags
     */
    readonly tags: cdk.TagManager;
    /**
     * The type of the data source. To return a list of all data sources, use `ListDataSources` .
     *
     * Use `AMAZON_ELASTICSEARCH` for Amazon OpenSearch Service.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-type
     */
    type: string | undefined;
    /**
     * Use this parameter only when you want Amazon QuickSight to use a VPC connection when connecting to your underlying source.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-datasource.html#cfn-quicksight-datasource-vpcconnectionproperties
     */
    vpcConnectionProperties: CfnDataSource.VpcConnectionPropertiesProperty | cdk.IResolvable | undefined;
    /**
     * Create a new `AWS::QuickSight::DataSource`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props?: CfnDataSourceProps);
    /**
     * Examines the CloudFormation resource and discloses attributes.
     *
     * @param inspector - tree inspector to collect and process attributes
     *
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected get cfnProperties(): {
        [key: string]: any;
    };
    protected renderProperties(props: {
        [key: string]: any;
    }): {
        [key: string]: any;
    };
}
export declare namespace CfnDataSource {
    /**
     * The parameters for OpenSearch.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html
     */
    interface AmazonElasticsearchParametersProperty {
        /**
         * The OpenSearch domain.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonelasticsearchparameters.html#cfn-quicksight-datasource-amazonelasticsearchparameters-domain
         */
        readonly domain: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for OpenSearch.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html
     */
    interface AmazonOpenSearchParametersProperty {
        /**
         * The OpenSearch domain.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-amazonopensearchparameters.html#cfn-quicksight-datasource-amazonopensearchparameters-domain
         */
        readonly domain: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * Parameters for Amazon Athena.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html
     */
    interface AthenaParametersProperty {
        /**
         * The workgroup that Amazon Athena uses.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-athenaparameters.html#cfn-quicksight-datasource-athenaparameters-workgroup
         */
        readonly workGroup?: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * Parameters for Amazon Aurora.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html
     */
    interface AuroraParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-auroraparameters.html#cfn-quicksight-datasource-auroraparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * Parameters for Amazon Aurora PostgreSQL-Compatible Edition.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html
     */
    interface AuroraPostgreSqlParametersProperty {
        /**
         * The Amazon Aurora PostgreSQL database to connect to.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-database
         */
        readonly database: string;
        /**
         * The Amazon Aurora PostgreSQL-Compatible host to connect to.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-host
         */
        readonly host: string;
        /**
         * The port that Amazon Aurora PostgreSQL is listening on.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-aurorapostgresqlparameters.html#cfn-quicksight-datasource-aurorapostgresqlparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * The combination of user name and password that are used as credentials.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html
     */
    interface CredentialPairProperty {
        /**
         * A set of alternate data source parameters that you want to share for these credentials. The credentials are applied in tandem with the data source parameters when you copy a data source by using a create or update request. The API operation compares the `DataSourceParameters` structure that's in the request with the structures in the `AlternateDataSourceParameters` allow list. If the structures are an exact match, the request is allowed to use the new data source with the existing credentials. If the `AlternateDataSourceParameters` list is null, the `DataSourceParameters` originally used with these `Credentials` is automatically allowed.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-alternatedatasourceparameters
         */
        readonly alternateDataSourceParameters?: Array<CfnDataSource.DataSourceParametersProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Password.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-password
         */
        readonly password: string;
        /**
         * User name.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-credentialpair.html#cfn-quicksight-datasource-credentialpair-username
         */
        readonly username: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * Data source credentials. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html
     */
    interface DataSourceCredentialsProperty {
        /**
         * The Amazon Resource Name (ARN) of a data source that has the credential pair that you want to use. When `CopySourceArn` is not null, the credential pair from the data source in the ARN is used as the credentials for the `DataSourceCredentials` structure.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-copysourcearn
         */
        readonly copySourceArn?: string;
        /**
         * Credential pair. For more information, see `[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)` .
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-credentialpair
         */
        readonly credentialPair?: CfnDataSource.CredentialPairProperty | cdk.IResolvable;
        /**
         * `CfnDataSource.DataSourceCredentialsProperty.SecretArn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourcecredentials.html#cfn-quicksight-datasource-datasourcecredentials-secretarn
         */
        readonly secretArn?: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * Error information for the data source creation or update.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html
     */
    interface DataSourceErrorInfoProperty {
        /**
         * Error message.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-message
         */
        readonly message?: string;
        /**
         * Error type.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceerrorinfo.html#cfn-quicksight-datasource-datasourceerrorinfo-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters that Amazon QuickSight uses to connect to your underlying data source. This is a variant type structure. For this structure to be valid, only one of the attributes can be non-null.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html
     */
    interface DataSourceParametersProperty {
        /**
         * The parameters for OpenSearch.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonelasticsearchparameters
         */
        readonly amazonElasticsearchParameters?: CfnDataSource.AmazonElasticsearchParametersProperty | cdk.IResolvable;
        /**
         * The parameters for OpenSearch.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-amazonopensearchparameters
         */
        readonly amazonOpenSearchParameters?: CfnDataSource.AmazonOpenSearchParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Amazon Athena.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-athenaparameters
         */
        readonly athenaParameters?: CfnDataSource.AthenaParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Amazon Aurora MySQL.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-auroraparameters
         */
        readonly auroraParameters?: CfnDataSource.AuroraParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Amazon Aurora.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-aurorapostgresqlparameters
         */
        readonly auroraPostgreSqlParameters?: CfnDataSource.AuroraPostgreSqlParametersProperty | cdk.IResolvable;
        /**
         * `CfnDataSource.DataSourceParametersProperty.DatabricksParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-databricksparameters
         */
        readonly databricksParameters?: CfnDataSource.DatabricksParametersProperty | cdk.IResolvable;
        /**
         * The parameters for MariaDB.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mariadbparameters
         */
        readonly mariaDbParameters?: CfnDataSource.MariaDbParametersProperty | cdk.IResolvable;
        /**
         * The parameters for MySQL.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-mysqlparameters
         */
        readonly mySqlParameters?: CfnDataSource.MySqlParametersProperty | cdk.IResolvable;
        /**
         * Oracle parameters.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-oracleparameters
         */
        readonly oracleParameters?: CfnDataSource.OracleParametersProperty | cdk.IResolvable;
        /**
         * The parameters for PostgreSQL.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-postgresqlparameters
         */
        readonly postgreSqlParameters?: CfnDataSource.PostgreSqlParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Presto.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-prestoparameters
         */
        readonly prestoParameters?: CfnDataSource.PrestoParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Amazon RDS.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-rdsparameters
         */
        readonly rdsParameters?: CfnDataSource.RdsParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Amazon Redshift.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-redshiftparameters
         */
        readonly redshiftParameters?: CfnDataSource.RedshiftParametersProperty | cdk.IResolvable;
        /**
         * The parameters for S3.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-s3parameters
         */
        readonly s3Parameters?: CfnDataSource.S3ParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Snowflake.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-snowflakeparameters
         */
        readonly snowflakeParameters?: CfnDataSource.SnowflakeParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Spark.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sparkparameters
         */
        readonly sparkParameters?: CfnDataSource.SparkParametersProperty | cdk.IResolvable;
        /**
         * The parameters for SQL Server.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-sqlserverparameters
         */
        readonly sqlServerParameters?: CfnDataSource.SqlServerParametersProperty | cdk.IResolvable;
        /**
         * The parameters for Teradata.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-datasourceparameters.html#cfn-quicksight-datasource-datasourceparameters-teradataparameters
         */
        readonly teradataParameters?: CfnDataSource.TeradataParametersProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDataSource {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html
     */
    interface DatabricksParametersProperty {
        /**
         * `CfnDataSource.DatabricksParametersProperty.Host`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-host
         */
        readonly host: string;
        /**
         * `CfnDataSource.DatabricksParametersProperty.Port`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-port
         */
        readonly port: number;
        /**
         * `CfnDataSource.DatabricksParametersProperty.SqlEndpointPath`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-databricksparameters.html#cfn-quicksight-datasource-databricksparameters-sqlendpointpath
         */
        readonly sqlEndpointPath: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * Amazon S3 manifest file location.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html
     */
    interface ManifestFileLocationProperty {
        /**
         * Amazon S3 bucket.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-bucket
         */
        readonly bucket: string;
        /**
         * Amazon S3 key that identifies an object.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-manifestfilelocation.html#cfn-quicksight-datasource-manifestfilelocation-key
         */
        readonly key: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for MariaDB.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html
     */
    interface MariaDbParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mariadbparameters.html#cfn-quicksight-datasource-mariadbparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for MySQL.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html
     */
    interface MySqlParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-mysqlparameters.html#cfn-quicksight-datasource-mysqlparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * Oracle parameters.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html
     */
    interface OracleParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-oracleparameters.html#cfn-quicksight-datasource-oracleparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for PostgreSQL.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html
     */
    interface PostgreSqlParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-postgresqlparameters.html#cfn-quicksight-datasource-postgresqlparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for Presto.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html
     */
    interface PrestoParametersProperty {
        /**
         * Catalog.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-catalog
         */
        readonly catalog: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-prestoparameters.html#cfn-quicksight-datasource-prestoparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for Amazon RDS.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html
     */
    interface RdsParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-database
         */
        readonly database: string;
        /**
         * Instance ID.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-rdsparameters.html#cfn-quicksight-datasource-rdsparameters-instanceid
         */
        readonly instanceId: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for Amazon Redshift. The `ClusterId` field can be blank if `Host` and `Port` are both set. The `Host` and `Port` fields can be blank if the `ClusterId` field is set.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html
     */
    interface RedshiftParametersProperty {
        /**
         * Cluster ID. This field can be blank if the `Host` and `Port` are provided.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-clusterid
         */
        readonly clusterId?: string;
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-database
         */
        readonly database: string;
        /**
         * Host. This field can be blank if `ClusterId` is provided.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-host
         */
        readonly host?: string;
        /**
         * Port. This field can be blank if the `ClusterId` is provided.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-redshiftparameters.html#cfn-quicksight-datasource-redshiftparameters-port
         */
        readonly port?: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-actions
         */
        readonly actions: string[];
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-resourcepermission.html#cfn-quicksight-datasource-resourcepermission-principal
         */
        readonly principal: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for S3.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html
     */
    interface S3ParametersProperty {
        /**
         * Location of the Amazon S3 manifest file. This is NULL if the manifest file was uploaded into Amazon QuickSight.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-s3parameters.html#cfn-quicksight-datasource-s3parameters-manifestfilelocation
         */
        readonly manifestFileLocation: CfnDataSource.ManifestFileLocationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for Snowflake.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html
     */
    interface SnowflakeParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-host
         */
        readonly host: string;
        /**
         * Warehouse.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-snowflakeparameters.html#cfn-quicksight-datasource-snowflakeparameters-warehouse
         */
        readonly warehouse: string;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for Spark.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html
     */
    interface SparkParametersProperty {
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sparkparameters.html#cfn-quicksight-datasource-sparkparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for SQL Server.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html
     */
    interface SqlServerParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sqlserverparameters.html#cfn-quicksight-datasource-sqlserverparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your underlying data source.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html
     */
    interface SslPropertiesProperty {
        /**
         * A Boolean option to control whether SSL should be disabled.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-sslproperties.html#cfn-quicksight-datasource-sslproperties-disablessl
         */
        readonly disableSsl?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnDataSource {
    /**
     * The parameters for Teradata.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html
     */
    interface TeradataParametersProperty {
        /**
         * Database.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-database
         */
        readonly database: string;
        /**
         * Host.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-host
         */
        readonly host: string;
        /**
         * Port.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-teradataparameters.html#cfn-quicksight-datasource-teradataparameters-port
         */
        readonly port: number;
    }
}
export declare namespace CfnDataSource {
    /**
     * VPC connection properties.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html
     */
    interface VpcConnectionPropertiesProperty {
        /**
         * The Amazon Resource Name (ARN) for the VPC connection.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-datasource-vpcconnectionproperties.html#cfn-quicksight-datasource-vpcconnectionproperties-vpcconnectionarn
         */
        readonly vpcConnectionArn: string;
    }
}
/**
 * Properties for defining a `CfnTemplate`
 *
 * @struct
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
 */
export interface CfnTemplateProps {
    /**
     * The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-awsaccountid
     */
    readonly awsAccountId: string;
    /**
     * An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-templateid
     */
    readonly templateId: string;
    /**
     * `AWS::QuickSight::Template.Definition`
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-definition
     */
    readonly definition?: CfnTemplate.TemplateVersionDefinitionProperty | cdk.IResolvable;
    /**
     * A display name for the template.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-name
     */
    readonly name?: string;
    /**
     * A list of resource permissions to be set on the template.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-permissions
     */
    readonly permissions?: Array<CfnTemplate.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * The entity that you are using as a source when you create the template. In `SourceEntity` , you specify the type of object you're using as source: `SourceTemplate` for a template or `SourceAnalysis` for an analysis. Both of these require an Amazon Resource Name (ARN). For `SourceTemplate` , specify the ARN of the source template. For `SourceAnalysis` , specify the ARN of the source analysis. The `SourceTemplate` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region .
     *
     * Use the `DataSetReferences` entity within `SourceTemplate` or `SourceAnalysis` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
     *
     * Either a `SourceEntity` or a `Definition` must be provided in order for the request to be valid.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-sourceentity
     */
    readonly sourceEntity?: CfnTemplate.TemplateSourceEntityProperty | cdk.IResolvable;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-tags
     */
    readonly tags?: cdk.CfnTag[];
    /**
     * A description of the current template version being created. This API operation creates the first version of the template. Every time `UpdateTemplate` is called, a new version is created. Each version of the template maintains a description of the version in the `VersionDescription` field.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-versiondescription
     */
    readonly versionDescription?: string;
}
/**
 * A CloudFormation `AWS::QuickSight::Template`
 *
 * Creates a template from an existing Amazon QuickSight analysis or template. You can use the resulting template to create a dashboard.
 *
 * A *template* is an entity in Amazon QuickSight that encapsulates the metadata required to create an analysis and that you can use to create s dashboard. A template adds a layer of abstraction by using placeholders to replace the dataset associated with the analysis. You can use templates to create dashboards by replacing dataset placeholders with datasets that follow the same schema that was used to create the source analysis and template.
 *
 * @cloudformationResource AWS::QuickSight::Template
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html
 */
export declare class CfnTemplate extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "AWS::QuickSight::Template";
    /**
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnTemplate;
    /**
     * The Amazon Resource Name (ARN) of the template.
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time this template was created.
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time this template was last updated.
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     *
     * @cloudformationAttribute Version.CreatedTime
     */
    readonly attrVersionCreatedTime: string;
    /**
     *
     * @cloudformationAttribute Version.DataSetConfigurations
     */
    readonly attrVersionDataSetConfigurations: cdk.IResolvable;
    /**
     *
     * @cloudformationAttribute Version.Description
     */
    readonly attrVersionDescription: string;
    /**
     *
     * @cloudformationAttribute Version.Errors
     */
    readonly attrVersionErrors: cdk.IResolvable;
    /**
     *
     * @cloudformationAttribute Version.Sheets
     */
    readonly attrVersionSheets: cdk.IResolvable;
    /**
     *
     * @cloudformationAttribute Version.SourceEntityArn
     */
    readonly attrVersionSourceEntityArn: string;
    /**
     *
     * @cloudformationAttribute Version.Status
     */
    readonly attrVersionStatus: string;
    /**
     *
     * @cloudformationAttribute Version.ThemeArn
     */
    readonly attrVersionThemeArn: string;
    /**
     *
     * @cloudformationAttribute Version.VersionNumber
     */
    readonly attrVersionVersionNumber: cdk.IResolvable;
    /**
     * The ID for the AWS account that the group is in. You use the ID for the AWS account that contains your Amazon QuickSight account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-awsaccountid
     */
    awsAccountId: string;
    /**
     * An ID for the template that you want to create. This template is unique per AWS Region ; in each AWS account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-templateid
     */
    templateId: string;
    /**
     * `AWS::QuickSight::Template.Definition`
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-definition
     */
    definition: CfnTemplate.TemplateVersionDefinitionProperty | cdk.IResolvable | undefined;
    /**
     * A display name for the template.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-name
     */
    name: string | undefined;
    /**
     * A list of resource permissions to be set on the template.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-permissions
     */
    permissions: Array<CfnTemplate.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * The entity that you are using as a source when you create the template. In `SourceEntity` , you specify the type of object you're using as source: `SourceTemplate` for a template or `SourceAnalysis` for an analysis. Both of these require an Amazon Resource Name (ARN). For `SourceTemplate` , specify the ARN of the source template. For `SourceAnalysis` , specify the ARN of the source analysis. The `SourceTemplate` ARN can contain any AWS account and any Amazon QuickSight-supported AWS Region .
     *
     * Use the `DataSetReferences` entity within `SourceTemplate` or `SourceAnalysis` to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder.
     *
     * Either a `SourceEntity` or a `Definition` must be provided in order for the request to be valid.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-sourceentity
     */
    sourceEntity: CfnTemplate.TemplateSourceEntityProperty | cdk.IResolvable | undefined;
    /**
     * Contains a map of the key-value pairs for the resource tag or tags assigned to the resource.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-tags
     */
    readonly tags: cdk.TagManager;
    /**
     * A description of the current template version being created. This API operation creates the first version of the template. Every time `UpdateTemplate` is called, a new version is created. Each version of the template maintains a description of the version in the `VersionDescription` field.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-template.html#cfn-quicksight-template-versiondescription
     */
    versionDescription: string | undefined;
    /**
     * Create a new `AWS::QuickSight::Template`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnTemplateProps);
    /**
     * Examines the CloudFormation resource and discloses attributes.
     *
     * @param inspector - tree inspector to collect and process attributes
     *
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected get cfnProperties(): {
        [key: string]: any;
    };
    protected renderProperties(props: {
        [key: string]: any;
    }): {
        [key: string]: any;
    };
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html
     */
    interface AggregationFunctionProperty {
        /**
         * `CfnTemplate.AggregationFunctionProperty.CategoricalAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-categoricalaggregationfunction
         */
        readonly categoricalAggregationFunction?: string;
        /**
         * `CfnTemplate.AggregationFunctionProperty.DateAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-dateaggregationfunction
         */
        readonly dateAggregationFunction?: string;
        /**
         * `CfnTemplate.AggregationFunctionProperty.NumericalAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationfunction.html#cfn-quicksight-template-aggregationfunction-numericalaggregationfunction
         */
        readonly numericalAggregationFunction?: CfnTemplate.NumericalAggregationFunctionProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html
     */
    interface AggregationSortConfigurationProperty {
        /**
         * `CfnTemplate.AggregationSortConfigurationProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-aggregationfunction
         */
        readonly aggregationFunction: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AggregationSortConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AggregationSortConfigurationProperty.SortDirection`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-aggregationsortconfiguration.html#cfn-quicksight-template-aggregationsortconfiguration-sortdirection
         */
        readonly sortDirection: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html
     */
    interface AnalysisDefaultsProperty {
        /**
         * `CfnTemplate.AnalysisDefaultsProperty.DefaultNewSheetConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-analysisdefaults.html#cfn-quicksight-template-analysisdefaults-defaultnewsheetconfiguration
         */
        readonly defaultNewSheetConfiguration: CfnTemplate.DefaultNewSheetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html
     */
    interface AnchorDateConfigurationProperty {
        /**
         * `CfnTemplate.AnchorDateConfigurationProperty.AnchorOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-anchoroption
         */
        readonly anchorOption?: string;
        /**
         * `CfnTemplate.AnchorDateConfigurationProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-anchordateconfiguration.html#cfn-quicksight-template-anchordateconfiguration-parametername
         */
        readonly parameterName?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html
     */
    interface ArcAxisConfigurationProperty {
        /**
         * `CfnTemplate.ArcAxisConfigurationProperty.Range`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-range
         */
        readonly range?: CfnTemplate.ArcAxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ArcAxisConfigurationProperty.ReserveRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisconfiguration.html#cfn-quicksight-template-arcaxisconfiguration-reserverange
         */
        readonly reserveRange?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html
     */
    interface ArcAxisDisplayRangeProperty {
        /**
         * `CfnTemplate.ArcAxisDisplayRangeProperty.Max`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-max
         */
        readonly max?: number;
        /**
         * `CfnTemplate.ArcAxisDisplayRangeProperty.Min`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcaxisdisplayrange.html#cfn-quicksight-template-arcaxisdisplayrange-min
         */
        readonly min?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html
     */
    interface ArcConfigurationProperty {
        /**
         * `CfnTemplate.ArcConfigurationProperty.ArcAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcangle
         */
        readonly arcAngle?: number;
        /**
         * `CfnTemplate.ArcConfigurationProperty.ArcThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcconfiguration.html#cfn-quicksight-template-arcconfiguration-arcthickness
         */
        readonly arcThickness?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html
     */
    interface ArcOptionsProperty {
        /**
         * `CfnTemplate.ArcOptionsProperty.ArcThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-arcoptions.html#cfn-quicksight-template-arcoptions-arcthickness
         */
        readonly arcThickness?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html
     */
    interface AxisDataOptionsProperty {
        /**
         * `CfnTemplate.AxisDataOptionsProperty.DateAxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-dateaxisoptions
         */
        readonly dateAxisOptions?: CfnTemplate.DateAxisOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AxisDataOptionsProperty.NumericAxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdataoptions.html#cfn-quicksight-template-axisdataoptions-numericaxisoptions
         */
        readonly numericAxisOptions?: CfnTemplate.NumericAxisOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html
     */
    interface AxisDisplayMinMaxRangeProperty {
        /**
         * `CfnTemplate.AxisDisplayMinMaxRangeProperty.Maximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-maximum
         */
        readonly maximum?: number;
        /**
         * `CfnTemplate.AxisDisplayMinMaxRangeProperty.Minimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayminmaxrange.html#cfn-quicksight-template-axisdisplayminmaxrange-minimum
         */
        readonly minimum?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html
     */
    interface AxisDisplayOptionsProperty {
        /**
         * `CfnTemplate.AxisDisplayOptionsProperty.AxisLineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axislinevisibility
         */
        readonly axisLineVisibility?: string;
        /**
         * `CfnTemplate.AxisDisplayOptionsProperty.AxisOffset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-axisoffset
         */
        readonly axisOffset?: string;
        /**
         * `CfnTemplate.AxisDisplayOptionsProperty.DataOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-dataoptions
         */
        readonly dataOptions?: CfnTemplate.AxisDataOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AxisDisplayOptionsProperty.GridLineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-gridlinevisibility
         */
        readonly gridLineVisibility?: string;
        /**
         * `CfnTemplate.AxisDisplayOptionsProperty.ScrollbarOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-scrollbaroptions
         */
        readonly scrollbarOptions?: CfnTemplate.ScrollBarOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AxisDisplayOptionsProperty.TickLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayoptions.html#cfn-quicksight-template-axisdisplayoptions-ticklabeloptions
         */
        readonly tickLabelOptions?: CfnTemplate.AxisTickLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html
     */
    interface AxisDisplayRangeProperty {
        /**
         * `CfnTemplate.AxisDisplayRangeProperty.DataDriven`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-datadriven
         */
        readonly dataDriven?: any | cdk.IResolvable;
        /**
         * `CfnTemplate.AxisDisplayRangeProperty.MinMax`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisdisplayrange.html#cfn-quicksight-template-axisdisplayrange-minmax
         */
        readonly minMax?: CfnTemplate.AxisDisplayMinMaxRangeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html
     */
    interface AxisLabelOptionsProperty {
        /**
         * `CfnTemplate.AxisLabelOptionsProperty.ApplyTo`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-applyto
         */
        readonly applyTo?: CfnTemplate.AxisLabelReferenceOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AxisLabelOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnTemplate.AxisLabelOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabeloptions.html#cfn-quicksight-template-axislabeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html
     */
    interface AxisLabelReferenceOptionsProperty {
        /**
         * `CfnTemplate.AxisLabelReferenceOptionsProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AxisLabelReferenceOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislabelreferenceoptions.html#cfn-quicksight-template-axislabelreferenceoptions-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html
     */
    interface AxisLinearScaleProperty {
        /**
         * `CfnTemplate.AxisLinearScaleProperty.StepCount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepcount
         */
        readonly stepCount?: number;
        /**
         * `CfnTemplate.AxisLinearScaleProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislinearscale.html#cfn-quicksight-template-axislinearscale-stepsize
         */
        readonly stepSize?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html
     */
    interface AxisLogarithmicScaleProperty {
        /**
         * `CfnTemplate.AxisLogarithmicScaleProperty.Base`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axislogarithmicscale.html#cfn-quicksight-template-axislogarithmicscale-base
         */
        readonly base?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html
     */
    interface AxisScaleProperty {
        /**
         * `CfnTemplate.AxisScaleProperty.Linear`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-linear
         */
        readonly linear?: CfnTemplate.AxisLinearScaleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AxisScaleProperty.Logarithmic`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisscale.html#cfn-quicksight-template-axisscale-logarithmic
         */
        readonly logarithmic?: CfnTemplate.AxisLogarithmicScaleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html
     */
    interface AxisTickLabelOptionsProperty {
        /**
         * `CfnTemplate.AxisTickLabelOptionsProperty.LabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-labeloptions
         */
        readonly labelOptions?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.AxisTickLabelOptionsProperty.RotationAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-axisticklabeloptions.html#cfn-quicksight-template-axisticklabeloptions-rotationangle
         */
        readonly rotationAngle?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html
     */
    interface BarChartAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.BarChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartaggregatedfieldwells.html#cfn-quicksight-template-barchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html
     */
    interface BarChartConfigurationProperty {
        /**
         * `CfnTemplate.BarChartConfigurationProperty.BarsArrangement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnTemplate.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.BarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.Orientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-orientation
         */
        readonly orientation?: string;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnTemplate.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnTemplate.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.BarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.ValueAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valueaxis
         */
        readonly valueAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartconfiguration.html#cfn-quicksight-template-barchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html
     */
    interface BarChartFieldWellsProperty {
        /**
         * `CfnTemplate.BarChartFieldWellsProperty.BarChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartfieldwells.html#cfn-quicksight-template-barchartfieldwells-barchartaggregatedfieldwells
         */
        readonly barChartAggregatedFieldWells?: CfnTemplate.BarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html
     */
    interface BarChartSortConfigurationProperty {
        /**
         * `CfnTemplate.BarChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartsortconfiguration.html#cfn-quicksight-template-barchartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html
     */
    interface BarChartVisualProperty {
        /**
         * `CfnTemplate.BarChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.BarChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BarChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-barchartvisual.html#cfn-quicksight-template-barchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html
     */
    interface BinCountOptionsProperty {
        /**
         * `CfnTemplate.BinCountOptionsProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bincountoptions.html#cfn-quicksight-template-bincountoptions-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html
     */
    interface BinWidthOptionsProperty {
        /**
         * `CfnTemplate.BinWidthOptionsProperty.BinCountLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-bincountlimit
         */
        readonly binCountLimit?: number;
        /**
         * `CfnTemplate.BinWidthOptionsProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-binwidthoptions.html#cfn-quicksight-template-binwidthoptions-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html
     */
    interface BodySectionConfigurationProperty {
        /**
         * `CfnTemplate.BodySectionConfigurationProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-content
         */
        readonly content: CfnTemplate.BodySectionContentProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BodySectionConfigurationProperty.PageBreakConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-pagebreakconfiguration
         */
        readonly pageBreakConfiguration?: CfnTemplate.SectionPageBreakConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BodySectionConfigurationProperty.SectionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * `CfnTemplate.BodySectionConfigurationProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectionconfiguration.html#cfn-quicksight-template-bodysectionconfiguration-style
         */
        readonly style?: CfnTemplate.SectionStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html
     */
    interface BodySectionContentProperty {
        /**
         * `CfnTemplate.BodySectionContentProperty.Layout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-bodysectioncontent.html#cfn-quicksight-template-bodysectioncontent-layout
         */
        readonly layout?: CfnTemplate.SectionLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html
     */
    interface BoxPlotAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.BoxPlotAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotaggregatedfieldwells.html#cfn-quicksight-template-boxplotaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html
     */
    interface BoxPlotChartConfigurationProperty {
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.BoxPlotOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-boxplotoptions
         */
        readonly boxPlotOptions?: CfnTemplate.BoxPlotOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.BoxPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnTemplate.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.BoxPlotSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotchartconfiguration.html#cfn-quicksight-template-boxplotchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html
     */
    interface BoxPlotFieldWellsProperty {
        /**
         * `CfnTemplate.BoxPlotFieldWellsProperty.BoxPlotAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotfieldwells.html#cfn-quicksight-template-boxplotfieldwells-boxplotaggregatedfieldwells
         */
        readonly boxPlotAggregatedFieldWells?: CfnTemplate.BoxPlotAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html
     */
    interface BoxPlotOptionsProperty {
        /**
         * `CfnTemplate.BoxPlotOptionsProperty.AllDataPointsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-alldatapointsvisibility
         */
        readonly allDataPointsVisibility?: string;
        /**
         * `CfnTemplate.BoxPlotOptionsProperty.OutlierVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-outliervisibility
         */
        readonly outlierVisibility?: string;
        /**
         * `CfnTemplate.BoxPlotOptionsProperty.StyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotoptions.html#cfn-quicksight-template-boxplotoptions-styleoptions
         */
        readonly styleOptions?: CfnTemplate.BoxPlotStyleOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html
     */
    interface BoxPlotSortConfigurationProperty {
        /**
         * `CfnTemplate.BoxPlotSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotSortConfigurationProperty.PaginationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotsortconfiguration.html#cfn-quicksight-template-boxplotsortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: CfnTemplate.PaginationConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html
     */
    interface BoxPlotStyleOptionsProperty {
        /**
         * `CfnTemplate.BoxPlotStyleOptionsProperty.FillStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotstyleoptions.html#cfn-quicksight-template-boxplotstyleoptions-fillstyle
         */
        readonly fillStyle?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html
     */
    interface BoxPlotVisualProperty {
        /**
         * `CfnTemplate.BoxPlotVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.BoxPlotChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.BoxPlotVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-boxplotvisual.html#cfn-quicksight-template-boxplotvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html
     */
    interface CalculatedFieldProperty {
        /**
         * `CfnTemplate.CalculatedFieldProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnTemplate.CalculatedFieldProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-expression
         */
        readonly expression: string;
        /**
         * `CfnTemplate.CalculatedFieldProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedfield.html#cfn-quicksight-template-calculatedfield-name
         */
        readonly name: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html
     */
    interface CalculatedMeasureFieldProperty {
        /**
         * `CfnTemplate.CalculatedMeasureFieldProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-expression
         */
        readonly expression: string;
        /**
         * `CfnTemplate.CalculatedMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-calculatedmeasurefield.html#cfn-quicksight-template-calculatedmeasurefield-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html
     */
    interface CascadingControlConfigurationProperty {
        /**
         * `CfnTemplate.CascadingControlConfigurationProperty.SourceControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolconfiguration.html#cfn-quicksight-template-cascadingcontrolconfiguration-sourcecontrols
         */
        readonly sourceControls?: Array<CfnTemplate.CascadingControlSourceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html
     */
    interface CascadingControlSourceProperty {
        /**
         * `CfnTemplate.CascadingControlSourceProperty.ColumnToMatch`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-columntomatch
         */
        readonly columnToMatch?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CascadingControlSourceProperty.SourceSheetControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-cascadingcontrolsource.html#cfn-quicksight-template-cascadingcontrolsource-sourcesheetcontrolid
         */
        readonly sourceSheetControlId?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html
     */
    interface CategoricalDimensionFieldProperty {
        /**
         * `CfnTemplate.CategoricalDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CategoricalDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.CategoricalDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.StringFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CategoricalDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricaldimensionfield.html#cfn-quicksight-template-categoricaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html
     */
    interface CategoricalMeasureFieldProperty {
        /**
         * `CfnTemplate.CategoricalMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * `CfnTemplate.CategoricalMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CategoricalMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.CategoricalMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoricalmeasurefield.html#cfn-quicksight-template-categoricalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.StringFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html
     */
    interface CategoryDrillDownFilterProperty {
        /**
         * `CfnTemplate.CategoryDrillDownFilterProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-categoryvalues
         */
        readonly categoryValues: string[];
        /**
         * `CfnTemplate.CategoryDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categorydrilldownfilter.html#cfn-quicksight-template-categorydrilldownfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html
     */
    interface CategoryFilterProperty {
        /**
         * `CfnTemplate.CategoryFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CategoryFilterProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-configuration
         */
        readonly configuration: CfnTemplate.CategoryFilterConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CategoryFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilter.html#cfn-quicksight-template-categoryfilter-filterid
         */
        readonly filterId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html
     */
    interface CategoryFilterConfigurationProperty {
        /**
         * `CfnTemplate.CategoryFilterConfigurationProperty.CustomFilterConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterconfiguration
         */
        readonly customFilterConfiguration?: CfnTemplate.CustomFilterConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CategoryFilterConfigurationProperty.CustomFilterListConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-customfilterlistconfiguration
         */
        readonly customFilterListConfiguration?: CfnTemplate.CustomFilterListConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CategoryFilterConfigurationProperty.FilterListConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-categoryfilterconfiguration.html#cfn-quicksight-template-categoryfilterconfiguration-filterlistconfiguration
         */
        readonly filterListConfiguration?: CfnTemplate.FilterListConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html
     */
    interface ChartAxisLabelOptionsProperty {
        /**
         * `CfnTemplate.ChartAxisLabelOptionsProperty.AxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-axislabeloptions
         */
        readonly axisLabelOptions?: Array<CfnTemplate.AxisLabelOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ChartAxisLabelOptionsProperty.SortIconVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-sorticonvisibility
         */
        readonly sortIconVisibility?: string;
        /**
         * `CfnTemplate.ChartAxisLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-chartaxislabeloptions.html#cfn-quicksight-template-chartaxislabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html
     */
    interface ClusterMarkerProperty {
        /**
         * `CfnTemplate.ClusterMarkerProperty.SimpleClusterMarker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarker.html#cfn-quicksight-template-clustermarker-simpleclustermarker
         */
        readonly simpleClusterMarker?: CfnTemplate.SimpleClusterMarkerProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html
     */
    interface ClusterMarkerConfigurationProperty {
        /**
         * `CfnTemplate.ClusterMarkerConfigurationProperty.ClusterMarker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-clustermarkerconfiguration.html#cfn-quicksight-template-clustermarkerconfiguration-clustermarker
         */
        readonly clusterMarker?: CfnTemplate.ClusterMarkerProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html
     */
    interface ColorScaleProperty {
        /**
         * `CfnTemplate.ColorScaleProperty.ColorFillType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colorfilltype
         */
        readonly colorFillType: string;
        /**
         * `CfnTemplate.ColorScaleProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-colors
         */
        readonly colors: Array<CfnTemplate.DataColorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ColorScaleProperty.NullValueColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorscale.html#cfn-quicksight-template-colorscale-nullvaluecolor
         */
        readonly nullValueColor?: CfnTemplate.DataColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html
     */
    interface ColorsConfigurationProperty {
        /**
         * `CfnTemplate.ColorsConfigurationProperty.CustomColors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-colorsconfiguration.html#cfn-quicksight-template-colorsconfiguration-customcolors
         */
        readonly customColors?: Array<CfnTemplate.CustomColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html
     */
    interface ColumnConfigurationProperty {
        /**
         * `CfnTemplate.ColumnConfigurationProperty.ColorsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-colorsconfiguration
         */
        readonly colorsConfiguration?: CfnTemplate.ColorsConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ColumnConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ColumnConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.FormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ColumnConfigurationProperty.Role`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnconfiguration.html#cfn-quicksight-template-columnconfiguration-role
         */
        readonly role?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * A structure describing the name, data type, and geographic role of the columns.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html
     */
    interface ColumnGroupColumnSchemaProperty {
        /**
         * The name of the column group's column schema.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupcolumnschema.html#cfn-quicksight-template-columngroupcolumnschema-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * The column group schema.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html
     */
    interface ColumnGroupSchemaProperty {
        /**
         * A structure containing the list of schemas for column group columns.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-columngroupcolumnschemalist
         */
        readonly columnGroupColumnSchemaList?: Array<CfnTemplate.ColumnGroupColumnSchemaProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The name of the column group schema.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columngroupschema.html#cfn-quicksight-template-columngroupschema-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html
     */
    interface ColumnHierarchyProperty {
        /**
         * `CfnTemplate.ColumnHierarchyProperty.DateTimeHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-datetimehierarchy
         */
        readonly dateTimeHierarchy?: CfnTemplate.DateTimeHierarchyProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ColumnHierarchyProperty.ExplicitHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-explicithierarchy
         */
        readonly explicitHierarchy?: CfnTemplate.ExplicitHierarchyProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ColumnHierarchyProperty.PredefinedHierarchy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnhierarchy.html#cfn-quicksight-template-columnhierarchy-predefinedhierarchy
         */
        readonly predefinedHierarchy?: CfnTemplate.PredefinedHierarchyProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html
     */
    interface ColumnIdentifierProperty {
        /**
         * `CfnTemplate.ColumnIdentifierProperty.ColumnName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-columnname
         */
        readonly columnName: string;
        /**
         * `CfnTemplate.ColumnIdentifierProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnidentifier.html#cfn-quicksight-template-columnidentifier-datasetidentifier
         */
        readonly dataSetIdentifier: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * The column schema.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html
     */
    interface ColumnSchemaProperty {
        /**
         * The data type of the column schema.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-datatype
         */
        readonly dataType?: string;
        /**
         * The geographic role of the column schema.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-geographicrole
         */
        readonly geographicRole?: string;
        /**
         * The name of the column schema.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnschema.html#cfn-quicksight-template-columnschema-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html
     */
    interface ColumnSortProperty {
        /**
         * `CfnTemplate.ColumnSortProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-aggregationfunction
         */
        readonly aggregationFunction?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ColumnSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-direction
         */
        readonly direction: string;
        /**
         * `CfnTemplate.ColumnSortProperty.SortBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columnsort.html#cfn-quicksight-template-columnsort-sortby
         */
        readonly sortBy: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html
     */
    interface ColumnTooltipItemProperty {
        /**
         * `CfnTemplate.ColumnTooltipItemProperty.Aggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-aggregation
         */
        readonly aggregation?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ColumnTooltipItemProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ColumnTooltipItemProperty.Label`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-label
         */
        readonly label?: string;
        /**
         * `CfnTemplate.ColumnTooltipItemProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-columntooltipitem.html#cfn-quicksight-template-columntooltipitem-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html
     */
    interface ComboChartAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.ComboChartAggregatedFieldWellsProperty.BarValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-barvalues
         */
        readonly barValues?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartAggregatedFieldWellsProperty.LineValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartaggregatedfieldwells.html#cfn-quicksight-template-combochartaggregatedfieldwells-linevalues
         */
        readonly lineValues?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html
     */
    interface ComboChartConfigurationProperty {
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.BarDataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-bardatalabels
         */
        readonly barDataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.BarsArrangement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-barsarrangement
         */
        readonly barsArrangement?: string;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.ComboChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.LineDataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-linedatalabels
         */
        readonly lineDataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnTemplate.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.SecondaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.SecondaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.ComboChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartconfiguration.html#cfn-quicksight-template-combochartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html
     */
    interface ComboChartFieldWellsProperty {
        /**
         * `CfnTemplate.ComboChartFieldWellsProperty.ComboChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartfieldwells.html#cfn-quicksight-template-combochartfieldwells-combochartaggregatedfieldwells
         */
        readonly comboChartAggregatedFieldWells?: CfnTemplate.ComboChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html
     */
    interface ComboChartSortConfigurationProperty {
        /**
         * `CfnTemplate.ComboChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartsortconfiguration.html#cfn-quicksight-template-combochartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html
     */
    interface ComboChartVisualProperty {
        /**
         * `CfnTemplate.ComboChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.ComboChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComboChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-combochartvisual.html#cfn-quicksight-template-combochartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html
     */
    interface ComparisonConfigurationProperty {
        /**
         * `CfnTemplate.ComparisonConfigurationProperty.ComparisonFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonformat
         */
        readonly comparisonFormat?: CfnTemplate.ComparisonFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComparisonConfigurationProperty.ComparisonMethod`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonconfiguration.html#cfn-quicksight-template-comparisonconfiguration-comparisonmethod
         */
        readonly comparisonMethod?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html
     */
    interface ComparisonFormatConfigurationProperty {
        /**
         * `CfnTemplate.ComparisonFormatConfigurationProperty.NumberDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: CfnTemplate.NumberDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComparisonFormatConfigurationProperty.PercentageDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-comparisonformatconfiguration.html#cfn-quicksight-template-comparisonformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: CfnTemplate.PercentageDisplayFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html
     */
    interface ComputationProperty {
        /**
         * `CfnTemplate.ComputationProperty.Forecast`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-forecast
         */
        readonly forecast?: CfnTemplate.ForecastComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.GrowthRate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-growthrate
         */
        readonly growthRate?: CfnTemplate.GrowthRateComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.MaximumMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-maximumminimum
         */
        readonly maximumMinimum?: CfnTemplate.MaximumMinimumComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.MetricComparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-metriccomparison
         */
        readonly metricComparison?: CfnTemplate.MetricComparisonComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.PeriodOverPeriod`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodoverperiod
         */
        readonly periodOverPeriod?: CfnTemplate.PeriodOverPeriodComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.PeriodToDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-periodtodate
         */
        readonly periodToDate?: CfnTemplate.PeriodToDateComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.TopBottomMovers`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottommovers
         */
        readonly topBottomMovers?: CfnTemplate.TopBottomMoversComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.TopBottomRanked`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-topbottomranked
         */
        readonly topBottomRanked?: CfnTemplate.TopBottomRankedComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.TotalAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-totalaggregation
         */
        readonly totalAggregation?: CfnTemplate.TotalAggregationComputationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ComputationProperty.UniqueValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-computation.html#cfn-quicksight-template-computation-uniquevalues
         */
        readonly uniqueValues?: CfnTemplate.UniqueValuesComputationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html
     */
    interface ConditionalFormattingColorProperty {
        /**
         * `CfnTemplate.ConditionalFormattingColorProperty.Gradient`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-gradient
         */
        readonly gradient?: CfnTemplate.ConditionalFormattingGradientColorProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ConditionalFormattingColorProperty.Solid`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcolor.html#cfn-quicksight-template-conditionalformattingcolor-solid
         */
        readonly solid?: CfnTemplate.ConditionalFormattingSolidColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html
     */
    interface ConditionalFormattingCustomIconConditionProperty {
        /**
         * `CfnTemplate.ConditionalFormattingCustomIconConditionProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-color
         */
        readonly color?: string;
        /**
         * `CfnTemplate.ConditionalFormattingCustomIconConditionProperty.DisplayConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-displayconfiguration
         */
        readonly displayConfiguration?: CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ConditionalFormattingCustomIconConditionProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-expression
         */
        readonly expression: string;
        /**
         * `CfnTemplate.ConditionalFormattingCustomIconConditionProperty.IconOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconcondition.html#cfn-quicksight-template-conditionalformattingcustomiconcondition-iconoptions
         */
        readonly iconOptions: CfnTemplate.ConditionalFormattingCustomIconOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html
     */
    interface ConditionalFormattingCustomIconOptionsProperty {
        /**
         * `CfnTemplate.ConditionalFormattingCustomIconOptionsProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-icon
         */
        readonly icon?: string;
        /**
         * `CfnTemplate.ConditionalFormattingCustomIconOptionsProperty.UnicodeIcon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingcustomiconoptions.html#cfn-quicksight-template-conditionalformattingcustomiconoptions-unicodeicon
         */
        readonly unicodeIcon?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html
     */
    interface ConditionalFormattingGradientColorProperty {
        /**
         * `CfnTemplate.ConditionalFormattingGradientColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-color
         */
        readonly color: CfnTemplate.GradientColorProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ConditionalFormattingGradientColorProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattinggradientcolor.html#cfn-quicksight-template-conditionalformattinggradientcolor-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html
     */
    interface ConditionalFormattingIconProperty {
        /**
         * `CfnTemplate.ConditionalFormattingIconProperty.CustomCondition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-customcondition
         */
        readonly customCondition?: CfnTemplate.ConditionalFormattingCustomIconConditionProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ConditionalFormattingIconProperty.IconSet`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicon.html#cfn-quicksight-template-conditionalformattingicon-iconset
         */
        readonly iconSet?: CfnTemplate.ConditionalFormattingIconSetProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html
     */
    interface ConditionalFormattingIconDisplayConfigurationProperty {
        /**
         * `CfnTemplate.ConditionalFormattingIconDisplayConfigurationProperty.IconDisplayOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingicondisplayconfiguration.html#cfn-quicksight-template-conditionalformattingicondisplayconfiguration-icondisplayoption
         */
        readonly iconDisplayOption?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html
     */
    interface ConditionalFormattingIconSetProperty {
        /**
         * `CfnTemplate.ConditionalFormattingIconSetProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-expression
         */
        readonly expression: string;
        /**
         * `CfnTemplate.ConditionalFormattingIconSetProperty.IconSetType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingiconset.html#cfn-quicksight-template-conditionalformattingiconset-iconsettype
         */
        readonly iconSetType?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html
     */
    interface ConditionalFormattingSolidColorProperty {
        /**
         * `CfnTemplate.ConditionalFormattingSolidColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-color
         */
        readonly color?: string;
        /**
         * `CfnTemplate.ConditionalFormattingSolidColorProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-conditionalformattingsolidcolor.html#cfn-quicksight-template-conditionalformattingsolidcolor-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html
     */
    interface ContributionAnalysisDefaultProperty {
        /**
         * `CfnTemplate.ContributionAnalysisDefaultProperty.ContributorDimensions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-contributordimensions
         */
        readonly contributorDimensions: Array<CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ContributionAnalysisDefaultProperty.MeasureFieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-contributionanalysisdefault.html#cfn-quicksight-template-contributionanalysisdefault-measurefieldid
         */
        readonly measureFieldId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html
     */
    interface CurrencyDisplayFormatConfigurationProperty {
        /**
         * `CfnTemplate.CurrencyDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnTemplate.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CurrencyDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnTemplate.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CurrencyDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnTemplate.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CurrencyDisplayFormatConfigurationProperty.NumberScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * `CfnTemplate.CurrencyDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnTemplate.CurrencyDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnTemplate.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CurrencyDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
        /**
         * `CfnTemplate.CurrencyDisplayFormatConfigurationProperty.Symbol`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-currencydisplayformatconfiguration.html#cfn-quicksight-template-currencydisplayformatconfiguration-symbol
         */
        readonly symbol?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html
     */
    interface CustomActionFilterOperationProperty {
        /**
         * `CfnTemplate.CustomActionFilterOperationProperty.SelectedFieldsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-selectedfieldsconfiguration
         */
        readonly selectedFieldsConfiguration: CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CustomActionFilterOperationProperty.TargetVisualsConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionfilteroperation.html#cfn-quicksight-template-customactionfilteroperation-targetvisualsconfiguration
         */
        readonly targetVisualsConfiguration: CfnTemplate.FilterOperationTargetVisualsConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html
     */
    interface CustomActionNavigationOperationProperty {
        /**
         * `CfnTemplate.CustomActionNavigationOperationProperty.LocalNavigationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionnavigationoperation.html#cfn-quicksight-template-customactionnavigationoperation-localnavigationconfiguration
         */
        readonly localNavigationConfiguration?: CfnTemplate.LocalNavigationConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html
     */
    interface CustomActionSetParametersOperationProperty {
        /**
         * `CfnTemplate.CustomActionSetParametersOperationProperty.ParameterValueConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionsetparametersoperation.html#cfn-quicksight-template-customactionsetparametersoperation-parametervalueconfigurations
         */
        readonly parameterValueConfigurations: Array<CfnTemplate.SetParameterValueConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html
     */
    interface CustomActionURLOperationProperty {
        /**
         * `CfnTemplate.CustomActionURLOperationProperty.URLTarget`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltarget
         */
        readonly urlTarget: string;
        /**
         * `CfnTemplate.CustomActionURLOperationProperty.URLTemplate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customactionurloperation.html#cfn-quicksight-template-customactionurloperation-urltemplate
         */
        readonly urlTemplate: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html
     */
    interface CustomColorProperty {
        /**
         * `CfnTemplate.CustomColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-color
         */
        readonly color: string;
        /**
         * `CfnTemplate.CustomColorProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnTemplate.CustomColorProperty.SpecialValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcolor.html#cfn-quicksight-template-customcolor-specialvalue
         */
        readonly specialValue?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html
     */
    interface CustomContentConfigurationProperty {
        /**
         * `CfnTemplate.CustomContentConfigurationProperty.ContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenttype
         */
        readonly contentType?: string;
        /**
         * `CfnTemplate.CustomContentConfigurationProperty.ContentUrl`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-contenturl
         */
        readonly contentUrl?: string;
        /**
         * `CfnTemplate.CustomContentConfigurationProperty.ImageScaling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentconfiguration.html#cfn-quicksight-template-customcontentconfiguration-imagescaling
         */
        readonly imageScaling?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html
     */
    interface CustomContentVisualProperty {
        /**
         * `CfnTemplate.CustomContentVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.CustomContentVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.CustomContentConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CustomContentVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnTemplate.CustomContentVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CustomContentVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CustomContentVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customcontentvisual.html#cfn-quicksight-template-customcontentvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html
     */
    interface CustomFilterConfigurationProperty {
        /**
         * `CfnTemplate.CustomFilterConfigurationProperty.CategoryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-categoryvalue
         */
        readonly categoryValue?: string;
        /**
         * `CfnTemplate.CustomFilterConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnTemplate.CustomFilterConfigurationProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnTemplate.CustomFilterConfigurationProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnTemplate.CustomFilterConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterconfiguration.html#cfn-quicksight-template-customfilterconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html
     */
    interface CustomFilterListConfigurationProperty {
        /**
         * `CfnTemplate.CustomFilterListConfigurationProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: string[];
        /**
         * `CfnTemplate.CustomFilterListConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnTemplate.CustomFilterListConfigurationProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnTemplate.CustomFilterListConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customfilterlistconfiguration.html#cfn-quicksight-template-customfilterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html
     */
    interface CustomNarrativeOptionsProperty {
        /**
         * `CfnTemplate.CustomNarrativeOptionsProperty.Narrative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customnarrativeoptions.html#cfn-quicksight-template-customnarrativeoptions-narrative
         */
        readonly narrative: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html
     */
    interface CustomParameterValuesProperty {
        /**
         * `CfnTemplate.CustomParameterValuesProperty.DateTimeValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-datetimevalues
         */
        readonly dateTimeValues?: string[];
        /**
         * `CfnTemplate.CustomParameterValuesProperty.DecimalValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-decimalvalues
         */
        readonly decimalValues?: number[] | cdk.IResolvable;
        /**
         * `CfnTemplate.CustomParameterValuesProperty.IntegerValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-integervalues
         */
        readonly integerValues?: number[] | cdk.IResolvable;
        /**
         * `CfnTemplate.CustomParameterValuesProperty.StringValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customparametervalues.html#cfn-quicksight-template-customparametervalues-stringvalues
         */
        readonly stringValues?: string[];
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html
     */
    interface CustomValuesConfigurationProperty {
        /**
         * `CfnTemplate.CustomValuesConfigurationProperty.CustomValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-customvalues
         */
        readonly customValues: CfnTemplate.CustomParameterValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.CustomValuesConfigurationProperty.IncludeNullValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-customvaluesconfiguration.html#cfn-quicksight-template-customvaluesconfiguration-includenullvalue
         */
        readonly includeNullValue?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html
     */
    interface DataBarsOptionsProperty {
        /**
         * `CfnTemplate.DataBarsOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.DataBarsOptionsProperty.NegativeColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-negativecolor
         */
        readonly negativeColor?: string;
        /**
         * `CfnTemplate.DataBarsOptionsProperty.PositiveColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-databarsoptions.html#cfn-quicksight-template-databarsoptions-positivecolor
         */
        readonly positiveColor?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html
     */
    interface DataColorProperty {
        /**
         * `CfnTemplate.DataColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-color
         */
        readonly color?: string;
        /**
         * `CfnTemplate.DataColorProperty.DataValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datacolor.html#cfn-quicksight-template-datacolor-datavalue
         */
        readonly dataValue?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html
     */
    interface DataFieldSeriesItemProperty {
        /**
         * `CfnTemplate.DataFieldSeriesItemProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * `CfnTemplate.DataFieldSeriesItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.DataFieldSeriesItemProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnTemplate.DataFieldSeriesItemProperty.Settings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datafieldseriesitem.html#cfn-quicksight-template-datafieldseriesitem-settings
         */
        readonly settings?: CfnTemplate.LineChartSeriesSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html
     */
    interface DataLabelOptionsProperty {
        /**
         * `CfnTemplate.DataLabelOptionsProperty.CategoryLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * `CfnTemplate.DataLabelOptionsProperty.DataLabelTypes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-datalabeltypes
         */
        readonly dataLabelTypes?: Array<CfnTemplate.DataLabelTypeProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.DataLabelOptionsProperty.LabelColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * `CfnTemplate.DataLabelOptionsProperty.LabelContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelcontent
         */
        readonly labelContent?: string;
        /**
         * `CfnTemplate.DataLabelOptionsProperty.LabelFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DataLabelOptionsProperty.MeasureLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * `CfnTemplate.DataLabelOptionsProperty.Overlap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-overlap
         */
        readonly overlap?: string;
        /**
         * `CfnTemplate.DataLabelOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-position
         */
        readonly position?: string;
        /**
         * `CfnTemplate.DataLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeloptions.html#cfn-quicksight-template-datalabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html
     */
    interface DataLabelTypeProperty {
        /**
         * `CfnTemplate.DataLabelTypeProperty.DataPathLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-datapathlabeltype
         */
        readonly dataPathLabelType?: CfnTemplate.DataPathLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DataLabelTypeProperty.FieldLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-fieldlabeltype
         */
        readonly fieldLabelType?: CfnTemplate.FieldLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DataLabelTypeProperty.MaximumLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-maximumlabeltype
         */
        readonly maximumLabelType?: CfnTemplate.MaximumLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DataLabelTypeProperty.MinimumLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-minimumlabeltype
         */
        readonly minimumLabelType?: CfnTemplate.MinimumLabelTypeProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DataLabelTypeProperty.RangeEndsLabelType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datalabeltype.html#cfn-quicksight-template-datalabeltype-rangeendslabeltype
         */
        readonly rangeEndsLabelType?: CfnTemplate.RangeEndsLabelTypeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html
     */
    interface DataPathColorProperty {
        /**
         * `CfnTemplate.DataPathColorProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-color
         */
        readonly color: string;
        /**
         * `CfnTemplate.DataPathColorProperty.Element`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-element
         */
        readonly element: CfnTemplate.DataPathValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DataPathColorProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathcolor.html#cfn-quicksight-template-datapathcolor-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html
     */
    interface DataPathLabelTypeProperty {
        /**
         * `CfnTemplate.DataPathLabelTypeProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * `CfnTemplate.DataPathLabelTypeProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-fieldvalue
         */
        readonly fieldValue?: string;
        /**
         * `CfnTemplate.DataPathLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathlabeltype.html#cfn-quicksight-template-datapathlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html
     */
    interface DataPathSortProperty {
        /**
         * `CfnTemplate.DataPathSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-direction
         */
        readonly direction: string;
        /**
         * `CfnTemplate.DataPathSortProperty.SortPaths`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathsort.html#cfn-quicksight-template-datapathsort-sortpaths
         */
        readonly sortPaths: Array<CfnTemplate.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html
     */
    interface DataPathValueProperty {
        /**
         * `CfnTemplate.DataPathValueProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.DataPathValueProperty.FieldValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datapathvalue.html#cfn-quicksight-template-datapathvalue-fieldvalue
         */
        readonly fieldValue: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * Dataset configuration.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html
     */
    interface DataSetConfigurationProperty {
        /**
         * A structure containing the list of column group schemas.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-columngroupschemalist
         */
        readonly columnGroupSchemaList?: Array<CfnTemplate.ColumnGroupSchemaProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * Dataset schema.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-datasetschema
         */
        readonly dataSetSchema?: CfnTemplate.DataSetSchemaProperty | cdk.IResolvable;
        /**
         * Placeholder.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetconfiguration.html#cfn-quicksight-template-datasetconfiguration-placeholder
         */
        readonly placeholder?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * Dataset reference.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html
     */
    interface DataSetReferenceProperty {
        /**
         * Dataset Amazon Resource Name (ARN).
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetarn
         */
        readonly dataSetArn: string;
        /**
         * Dataset placeholder.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetreference.html#cfn-quicksight-template-datasetreference-datasetplaceholder
         */
        readonly dataSetPlaceholder: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * Dataset schema.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html
     */
    interface DataSetSchemaProperty {
        /**
         * A structure containing the list of column schemas.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datasetschema.html#cfn-quicksight-template-datasetschema-columnschemalist
         */
        readonly columnSchemaList?: Array<CfnTemplate.ColumnSchemaProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html
     */
    interface DateAxisOptionsProperty {
        /**
         * `CfnTemplate.DateAxisOptionsProperty.MissingDateVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dateaxisoptions.html#cfn-quicksight-template-dateaxisoptions-missingdatevisibility
         */
        readonly missingDateVisibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html
     */
    interface DateDimensionFieldProperty {
        /**
         * `CfnTemplate.DateDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DateDimensionFieldProperty.DateGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-dategranularity
         */
        readonly dateGranularity?: string;
        /**
         * `CfnTemplate.DateDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.DateDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DateDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datedimensionfield.html#cfn-quicksight-template-datedimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html
     */
    interface DateMeasureFieldProperty {
        /**
         * `CfnTemplate.DateMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: string;
        /**
         * `CfnTemplate.DateMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DateMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.DateMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datemeasurefield.html#cfn-quicksight-template-datemeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.DateTimeFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html
     */
    interface DateTimeDefaultValuesProperty {
        /**
         * `CfnTemplate.DateTimeDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnTemplate.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DateTimeDefaultValuesProperty.RollingDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-rollingdate
         */
        readonly rollingDate?: CfnTemplate.RollingDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DateTimeDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimedefaultvalues.html#cfn-quicksight-template-datetimedefaultvalues-staticvalues
         */
        readonly staticValues?: string[];
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html
     */
    interface DateTimeFormatConfigurationProperty {
        /**
         * `CfnTemplate.DateTimeFormatConfigurationProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnTemplate.DateTimeFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnTemplate.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DateTimeFormatConfigurationProperty.NumericFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeformatconfiguration.html#cfn-quicksight-template-datetimeformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: CfnTemplate.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html
     */
    interface DateTimeHierarchyProperty {
        /**
         * `CfnTemplate.DateTimeHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnTemplate.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.DateTimeHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimehierarchy.html#cfn-quicksight-template-datetimehierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html
     */
    interface DateTimeParameterDeclarationProperty {
        /**
         * `CfnTemplate.DateTimeParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnTemplate.DateTimeDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DateTimeParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnTemplate.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.DateTimeParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnTemplate.DateTimeParameterDeclarationProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * `CfnTemplate.DateTimeParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimeparameterdeclaration.html#cfn-quicksight-template-datetimeparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html
     */
    interface DateTimePickerControlDisplayOptionsProperty {
        /**
         * `CfnTemplate.DateTimePickerControlDisplayOptionsProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnTemplate.DateTimePickerControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimepickercontroldisplayoptions.html#cfn-quicksight-template-datetimepickercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html
     */
    interface DateTimeValueWhenUnsetConfigurationProperty {
        /**
         * `CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * `CfnTemplate.DateTimeValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-datetimevaluewhenunsetconfiguration.html#cfn-quicksight-template-datetimevaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html
     */
    interface DecimalDefaultValuesProperty {
        /**
         * `CfnTemplate.DecimalDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnTemplate.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DecimalDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimaldefaultvalues.html#cfn-quicksight-template-decimaldefaultvalues-staticvalues
         */
        readonly staticValues?: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html
     */
    interface DecimalParameterDeclarationProperty {
        /**
         * `CfnTemplate.DecimalParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnTemplate.DecimalDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DecimalParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnTemplate.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.DecimalParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnTemplate.DecimalParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnTemplate.DecimalParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalparameterdeclaration.html#cfn-quicksight-template-decimalparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnTemplate.DecimalValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html
     */
    interface DecimalPlacesConfigurationProperty {
        /**
         * `CfnTemplate.DecimalPlacesConfigurationProperty.DecimalPlaces`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalplacesconfiguration.html#cfn-quicksight-template-decimalplacesconfiguration-decimalplaces
         */
        readonly decimalPlaces: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html
     */
    interface DecimalValueWhenUnsetConfigurationProperty {
        /**
         * `CfnTemplate.DecimalValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * `CfnTemplate.DecimalValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-decimalvaluewhenunsetconfiguration.html#cfn-quicksight-template-decimalvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html
     */
    interface DefaultFreeFormLayoutConfigurationProperty {
        /**
         * `CfnTemplate.DefaultFreeFormLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultfreeformlayoutconfiguration.html#cfn-quicksight-template-defaultfreeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html
     */
    interface DefaultGridLayoutConfigurationProperty {
        /**
         * `CfnTemplate.DefaultGridLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultgridlayoutconfiguration.html#cfn-quicksight-template-defaultgridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnTemplate.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html
     */
    interface DefaultInteractiveLayoutConfigurationProperty {
        /**
         * `CfnTemplate.DefaultInteractiveLayoutConfigurationProperty.FreeForm`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-freeform
         */
        readonly freeForm?: CfnTemplate.DefaultFreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DefaultInteractiveLayoutConfigurationProperty.Grid`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultinteractivelayoutconfiguration.html#cfn-quicksight-template-defaultinteractivelayoutconfiguration-grid
         */
        readonly grid?: CfnTemplate.DefaultGridLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html
     */
    interface DefaultNewSheetConfigurationProperty {
        /**
         * `CfnTemplate.DefaultNewSheetConfigurationProperty.InteractiveLayoutConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-interactivelayoutconfiguration
         */
        readonly interactiveLayoutConfiguration?: CfnTemplate.DefaultInteractiveLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DefaultNewSheetConfigurationProperty.PaginatedLayoutConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-paginatedlayoutconfiguration
         */
        readonly paginatedLayoutConfiguration?: CfnTemplate.DefaultPaginatedLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DefaultNewSheetConfigurationProperty.SheetContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultnewsheetconfiguration.html#cfn-quicksight-template-defaultnewsheetconfiguration-sheetcontenttype
         */
        readonly sheetContentType?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html
     */
    interface DefaultPaginatedLayoutConfigurationProperty {
        /**
         * `CfnTemplate.DefaultPaginatedLayoutConfigurationProperty.SectionBased`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultpaginatedlayoutconfiguration.html#cfn-quicksight-template-defaultpaginatedlayoutconfiguration-sectionbased
         */
        readonly sectionBased?: CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html
     */
    interface DefaultSectionBasedLayoutConfigurationProperty {
        /**
         * `CfnTemplate.DefaultSectionBasedLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-defaultsectionbasedlayoutconfiguration.html#cfn-quicksight-template-defaultsectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html
     */
    interface DestinationParameterValueConfigurationProperty {
        /**
         * `CfnTemplate.DestinationParameterValueConfigurationProperty.CustomValuesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-customvaluesconfiguration
         */
        readonly customValuesConfiguration?: CfnTemplate.CustomValuesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DestinationParameterValueConfigurationProperty.SelectAllValueOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-selectallvalueoptions
         */
        readonly selectAllValueOptions?: string;
        /**
         * `CfnTemplate.DestinationParameterValueConfigurationProperty.SourceField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourcefield
         */
        readonly sourceField?: string;
        /**
         * `CfnTemplate.DestinationParameterValueConfigurationProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-destinationparametervalueconfiguration.html#cfn-quicksight-template-destinationparametervalueconfiguration-sourceparametername
         */
        readonly sourceParameterName?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html
     */
    interface DimensionFieldProperty {
        /**
         * `CfnTemplate.DimensionFieldProperty.CategoricalDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-categoricaldimensionfield
         */
        readonly categoricalDimensionField?: CfnTemplate.CategoricalDimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DimensionFieldProperty.DateDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-datedimensionfield
         */
        readonly dateDimensionField?: CfnTemplate.DateDimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DimensionFieldProperty.NumericalDimensionField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dimensionfield.html#cfn-quicksight-template-dimensionfield-numericaldimensionfield
         */
        readonly numericalDimensionField?: CfnTemplate.NumericalDimensionFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html
     */
    interface DonutCenterOptionsProperty {
        /**
         * `CfnTemplate.DonutCenterOptionsProperty.LabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutcenteroptions.html#cfn-quicksight-template-donutcenteroptions-labelvisibility
         */
        readonly labelVisibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html
     */
    interface DonutOptionsProperty {
        /**
         * `CfnTemplate.DonutOptionsProperty.ArcOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-arcoptions
         */
        readonly arcOptions?: CfnTemplate.ArcOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DonutOptionsProperty.DonutCenterOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-donutoptions.html#cfn-quicksight-template-donutoptions-donutcenteroptions
         */
        readonly donutCenterOptions?: CfnTemplate.DonutCenterOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html
     */
    interface DrillDownFilterProperty {
        /**
         * `CfnTemplate.DrillDownFilterProperty.CategoryFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-categoryfilter
         */
        readonly categoryFilter?: CfnTemplate.CategoryDrillDownFilterProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DrillDownFilterProperty.NumericEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-numericequalityfilter
         */
        readonly numericEqualityFilter?: CfnTemplate.NumericEqualityDrillDownFilterProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DrillDownFilterProperty.TimeRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-drilldownfilter.html#cfn-quicksight-template-drilldownfilter-timerangefilter
         */
        readonly timeRangeFilter?: CfnTemplate.TimeRangeDrillDownFilterProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html
     */
    interface DropDownControlDisplayOptionsProperty {
        /**
         * `CfnTemplate.DropDownControlDisplayOptionsProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: CfnTemplate.ListControlSelectAllOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DropDownControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dropdowncontroldisplayoptions.html#cfn-quicksight-template-dropdowncontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html
     */
    interface DynamicDefaultValueProperty {
        /**
         * `CfnTemplate.DynamicDefaultValueProperty.DefaultValueColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-defaultvaluecolumn
         */
        readonly defaultValueColumn: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DynamicDefaultValueProperty.GroupNameColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-groupnamecolumn
         */
        readonly groupNameColumn?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.DynamicDefaultValueProperty.UserNameColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-dynamicdefaultvalue.html#cfn-quicksight-template-dynamicdefaultvalue-usernamecolumn
         */
        readonly userNameColumn?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html
     */
    interface EmptyVisualProperty {
        /**
         * `CfnTemplate.EmptyVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.EmptyVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnTemplate.EmptyVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-emptyvisual.html#cfn-quicksight-template-emptyvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html
     */
    interface EntityProperty {
        /**
         * `CfnTemplate.EntityProperty.Path`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-entity.html#cfn-quicksight-template-entity-path
         */
        readonly path?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html
     */
    interface ExcludePeriodConfigurationProperty {
        /**
         * `CfnTemplate.ExcludePeriodConfigurationProperty.Amount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-amount
         */
        readonly amount: number;
        /**
         * `CfnTemplate.ExcludePeriodConfigurationProperty.Granularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-granularity
         */
        readonly granularity: string;
        /**
         * `CfnTemplate.ExcludePeriodConfigurationProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-excludeperiodconfiguration.html#cfn-quicksight-template-excludeperiodconfiguration-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html
     */
    interface ExplicitHierarchyProperty {
        /**
         * `CfnTemplate.ExplicitHierarchyProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-columns
         */
        readonly columns: Array<CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ExplicitHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnTemplate.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ExplicitHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-explicithierarchy.html#cfn-quicksight-template-explicithierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html
     */
    interface FieldBasedTooltipProperty {
        /**
         * `CfnTemplate.FieldBasedTooltipProperty.AggregationVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-aggregationvisibility
         */
        readonly aggregationVisibility?: string;
        /**
         * `CfnTemplate.FieldBasedTooltipProperty.TooltipFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltipfields
         */
        readonly tooltipFields?: Array<CfnTemplate.TooltipItemProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FieldBasedTooltipProperty.TooltipTitleType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldbasedtooltip.html#cfn-quicksight-template-fieldbasedtooltip-tooltiptitletype
         */
        readonly tooltipTitleType?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html
     */
    interface FieldLabelTypeProperty {
        /**
         * `CfnTemplate.FieldLabelTypeProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-fieldid
         */
        readonly fieldId?: string;
        /**
         * `CfnTemplate.FieldLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldlabeltype.html#cfn-quicksight-template-fieldlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html
     */
    interface FieldSeriesItemProperty {
        /**
         * `CfnTemplate.FieldSeriesItemProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-axisbinding
         */
        readonly axisBinding: string;
        /**
         * `CfnTemplate.FieldSeriesItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.FieldSeriesItemProperty.Settings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldseriesitem.html#cfn-quicksight-template-fieldseriesitem-settings
         */
        readonly settings?: CfnTemplate.LineChartSeriesSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html
     */
    interface FieldSortProperty {
        /**
         * `CfnTemplate.FieldSortProperty.Direction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-direction
         */
        readonly direction: string;
        /**
         * `CfnTemplate.FieldSortProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsort.html#cfn-quicksight-template-fieldsort-fieldid
         */
        readonly fieldId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html
     */
    interface FieldSortOptionsProperty {
        /**
         * `CfnTemplate.FieldSortOptionsProperty.ColumnSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-columnsort
         */
        readonly columnSort?: CfnTemplate.ColumnSortProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FieldSortOptionsProperty.FieldSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldsortoptions.html#cfn-quicksight-template-fieldsortoptions-fieldsort
         */
        readonly fieldSort?: CfnTemplate.FieldSortProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html
     */
    interface FieldTooltipItemProperty {
        /**
         * `CfnTemplate.FieldTooltipItemProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.FieldTooltipItemProperty.Label`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-label
         */
        readonly label?: string;
        /**
         * `CfnTemplate.FieldTooltipItemProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fieldtooltipitem.html#cfn-quicksight-template-fieldtooltipitem-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html
     */
    interface FilledMapAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.FilledMapAggregatedFieldWellsProperty.Geospatial`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapaggregatedfieldwells.html#cfn-quicksight-template-filledmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html
     */
    interface FilledMapConditionalFormattingProperty {
        /**
         * `CfnTemplate.FilledMapConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformatting.html#cfn-quicksight-template-filledmapconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions: Array<CfnTemplate.FilledMapConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html
     */
    interface FilledMapConditionalFormattingOptionProperty {
        /**
         * `CfnTemplate.FilledMapConditionalFormattingOptionProperty.Shape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconditionalformattingoption.html#cfn-quicksight-template-filledmapconditionalformattingoption-shape
         */
        readonly shape: CfnTemplate.FilledMapShapeConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html
     */
    interface FilledMapConfigurationProperty {
        /**
         * `CfnTemplate.FilledMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.FilledMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapConfigurationProperty.MapStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnTemplate.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.FilledMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapConfigurationProperty.WindowOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapconfiguration.html#cfn-quicksight-template-filledmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnTemplate.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html
     */
    interface FilledMapFieldWellsProperty {
        /**
         * `CfnTemplate.FilledMapFieldWellsProperty.FilledMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapfieldwells.html#cfn-quicksight-template-filledmapfieldwells-filledmapaggregatedfieldwells
         */
        readonly filledMapAggregatedFieldWells?: CfnTemplate.FilledMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html
     */
    interface FilledMapShapeConditionalFormattingProperty {
        /**
         * `CfnTemplate.FilledMapShapeConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.FilledMapShapeConditionalFormattingProperty.Format`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapshapeconditionalformatting.html#cfn-quicksight-template-filledmapshapeconditionalformatting-format
         */
        readonly format?: CfnTemplate.ShapeConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html
     */
    interface FilledMapSortConfigurationProperty {
        /**
         * `CfnTemplate.FilledMapSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapsortconfiguration.html#cfn-quicksight-template-filledmapsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html
     */
    interface FilledMapVisualProperty {
        /**
         * `CfnTemplate.FilledMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.FilledMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnTemplate.FilledMapConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilledMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filledmapvisual.html#cfn-quicksight-template-filledmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html
     */
    interface FilterProperty {
        /**
         * `CfnTemplate.FilterProperty.CategoryFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-categoryfilter
         */
        readonly categoryFilter?: CfnTemplate.CategoryFilterProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterProperty.NumericEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericequalityfilter
         */
        readonly numericEqualityFilter?: CfnTemplate.NumericEqualityFilterProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterProperty.NumericRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-numericrangefilter
         */
        readonly numericRangeFilter?: CfnTemplate.NumericRangeFilterProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterProperty.RelativeDatesFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-relativedatesfilter
         */
        readonly relativeDatesFilter?: CfnTemplate.RelativeDatesFilterProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterProperty.TimeEqualityFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timeequalityfilter
         */
        readonly timeEqualityFilter?: CfnTemplate.TimeEqualityFilterProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterProperty.TimeRangeFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-timerangefilter
         */
        readonly timeRangeFilter?: CfnTemplate.TimeRangeFilterProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterProperty.TopBottomFilter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filter.html#cfn-quicksight-template-filter-topbottomfilter
         */
        readonly topBottomFilter?: CfnTemplate.TopBottomFilterProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html
     */
    interface FilterControlProperty {
        /**
         * `CfnTemplate.FilterControlProperty.DateTimePicker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnTemplate.FilterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterControlProperty.Dropdown`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-dropdown
         */
        readonly dropdown?: CfnTemplate.FilterDropDownControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterControlProperty.List`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-list
         */
        readonly list?: CfnTemplate.FilterListControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterControlProperty.RelativeDateTime`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-relativedatetime
         */
        readonly relativeDateTime?: CfnTemplate.FilterRelativeDateTimeControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterControlProperty.Slider`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-slider
         */
        readonly slider?: CfnTemplate.FilterSliderControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterControlProperty.TextArea`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textarea
         */
        readonly textArea?: CfnTemplate.FilterTextAreaControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterControlProperty.TextField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtercontrol.html#cfn-quicksight-template-filtercontrol-textfield
         */
        readonly textField?: CfnTemplate.FilterTextFieldControlProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html
     */
    interface FilterDateTimePickerControlProperty {
        /**
         * `CfnTemplate.FilterDateTimePickerControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterDateTimePickerControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnTemplate.FilterDateTimePickerControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnTemplate.FilterDateTimePickerControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-title
         */
        readonly title: string;
        /**
         * `CfnTemplate.FilterDateTimePickerControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdatetimepickercontrol.html#cfn-quicksight-template-filterdatetimepickercontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html
     */
    interface FilterDropDownControlProperty {
        /**
         * `CfnTemplate.FilterDropDownControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnTemplate.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterDropDownControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterDropDownControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnTemplate.FilterDropDownControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnTemplate.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterDropDownControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnTemplate.FilterDropDownControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * `CfnTemplate.FilterDropDownControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterdropdowncontrol.html#cfn-quicksight-template-filterdropdowncontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html
     */
    interface FilterGroupProperty {
        /**
         * `CfnTemplate.FilterGroupProperty.CrossDataset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-crossdataset
         */
        readonly crossDataset: string;
        /**
         * `CfnTemplate.FilterGroupProperty.FilterGroupId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filtergroupid
         */
        readonly filterGroupId: string;
        /**
         * `CfnTemplate.FilterGroupProperty.Filters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-filters
         */
        readonly filters: Array<CfnTemplate.FilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterGroupProperty.ScopeConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-scopeconfiguration
         */
        readonly scopeConfiguration: CfnTemplate.FilterScopeConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterGroupProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtergroup.html#cfn-quicksight-template-filtergroup-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html
     */
    interface FilterListConfigurationProperty {
        /**
         * `CfnTemplate.FilterListConfigurationProperty.CategoryValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-categoryvalues
         */
        readonly categoryValues?: string[];
        /**
         * `CfnTemplate.FilterListConfigurationProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnTemplate.FilterListConfigurationProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistconfiguration.html#cfn-quicksight-template-filterlistconfiguration-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html
     */
    interface FilterListControlProperty {
        /**
         * `CfnTemplate.FilterListControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnTemplate.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterListControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.ListControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterListControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnTemplate.FilterListControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnTemplate.FilterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterListControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnTemplate.FilterListControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-title
         */
        readonly title: string;
        /**
         * `CfnTemplate.FilterListControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterlistcontrol.html#cfn-quicksight-template-filterlistcontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html
     */
    interface FilterOperationSelectedFieldsConfigurationProperty {
        /**
         * `CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfieldoptions
         */
        readonly selectedFieldOptions?: string;
        /**
         * `CfnTemplate.FilterOperationSelectedFieldsConfigurationProperty.SelectedFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationselectedfieldsconfiguration.html#cfn-quicksight-template-filteroperationselectedfieldsconfiguration-selectedfields
         */
        readonly selectedFields?: string[];
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html
     */
    interface FilterOperationTargetVisualsConfigurationProperty {
        /**
         * `CfnTemplate.FilterOperationTargetVisualsConfigurationProperty.SameSheetTargetVisualConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filteroperationtargetvisualsconfiguration.html#cfn-quicksight-template-filteroperationtargetvisualsconfiguration-samesheettargetvisualconfiguration
         */
        readonly sameSheetTargetVisualConfiguration?: CfnTemplate.SameSheetTargetVisualConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html
     */
    interface FilterRelativeDateTimeControlProperty {
        /**
         * `CfnTemplate.FilterRelativeDateTimeControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterRelativeDateTimeControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnTemplate.FilterRelativeDateTimeControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnTemplate.FilterRelativeDateTimeControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterrelativedatetimecontrol.html#cfn-quicksight-template-filterrelativedatetimecontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html
     */
    interface FilterScopeConfigurationProperty {
        /**
         * `CfnTemplate.FilterScopeConfigurationProperty.SelectedSheets`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterscopeconfiguration.html#cfn-quicksight-template-filterscopeconfiguration-selectedsheets
         */
        readonly selectedSheets?: CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html
     */
    interface FilterSelectableValuesProperty {
        /**
         * `CfnTemplate.FilterSelectableValuesProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterselectablevalues.html#cfn-quicksight-template-filterselectablevalues-values
         */
        readonly values?: string[];
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html
     */
    interface FilterSliderControlProperty {
        /**
         * `CfnTemplate.FilterSliderControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.SliderControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterSliderControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnTemplate.FilterSliderControlProperty.MaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * `CfnTemplate.FilterSliderControlProperty.MinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * `CfnTemplate.FilterSliderControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnTemplate.FilterSliderControlProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * `CfnTemplate.FilterSliderControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-title
         */
        readonly title: string;
        /**
         * `CfnTemplate.FilterSliderControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filterslidercontrol.html#cfn-quicksight-template-filterslidercontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html
     */
    interface FilterTextAreaControlProperty {
        /**
         * `CfnTemplate.FilterTextAreaControlProperty.Delimiter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * `CfnTemplate.FilterTextAreaControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.TextAreaControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterTextAreaControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnTemplate.FilterTextAreaControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnTemplate.FilterTextAreaControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextareacontrol.html#cfn-quicksight-template-filtertextareacontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html
     */
    interface FilterTextFieldControlProperty {
        /**
         * `CfnTemplate.FilterTextFieldControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.TextFieldControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FilterTextFieldControlProperty.FilterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-filtercontrolid
         */
        readonly filterControlId: string;
        /**
         * `CfnTemplate.FilterTextFieldControlProperty.SourceFilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-sourcefilterid
         */
        readonly sourceFilterId: string;
        /**
         * `CfnTemplate.FilterTextFieldControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-filtertextfieldcontrol.html#cfn-quicksight-template-filtertextfieldcontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html
     */
    interface FontConfigurationProperty {
        /**
         * `CfnTemplate.FontConfigurationProperty.FontColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * `CfnTemplate.FontConfigurationProperty.FontDecoration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontdecoration
         */
        readonly fontDecoration?: string;
        /**
         * `CfnTemplate.FontConfigurationProperty.FontSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontsize
         */
        readonly fontSize?: CfnTemplate.FontSizeProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FontConfigurationProperty.FontStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontstyle
         */
        readonly fontStyle?: string;
        /**
         * `CfnTemplate.FontConfigurationProperty.FontWeight`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontconfiguration.html#cfn-quicksight-template-fontconfiguration-fontweight
         */
        readonly fontWeight?: CfnTemplate.FontWeightProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html
     */
    interface FontSizeProperty {
        /**
         * `CfnTemplate.FontSizeProperty.Relative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontsize.html#cfn-quicksight-template-fontsize-relative
         */
        readonly relative?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html
     */
    interface FontWeightProperty {
        /**
         * `CfnTemplate.FontWeightProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-fontweight.html#cfn-quicksight-template-fontweight-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html
     */
    interface ForecastComputationProperty {
        /**
         * `CfnTemplate.ForecastComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.ForecastComputationProperty.CustomSeasonalityValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-customseasonalityvalue
         */
        readonly customSeasonalityValue?: number;
        /**
         * `CfnTemplate.ForecastComputationProperty.LowerBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * `CfnTemplate.ForecastComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.ForecastComputationProperty.PeriodsBackward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * `CfnTemplate.ForecastComputationProperty.PeriodsForward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * `CfnTemplate.ForecastComputationProperty.PredictionInterval`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * `CfnTemplate.ForecastComputationProperty.Seasonality`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-seasonality
         */
        readonly seasonality?: string;
        /**
         * `CfnTemplate.ForecastComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-time
         */
        readonly time: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ForecastComputationProperty.UpperBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-upperboundary
         */
        readonly upperBoundary?: number;
        /**
         * `CfnTemplate.ForecastComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastcomputation.html#cfn-quicksight-template-forecastcomputation-value
         */
        readonly value?: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html
     */
    interface ForecastConfigurationProperty {
        /**
         * `CfnTemplate.ForecastConfigurationProperty.ForecastProperties`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-forecastproperties
         */
        readonly forecastProperties?: CfnTemplate.TimeBasedForecastPropertiesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ForecastConfigurationProperty.Scenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastconfiguration.html#cfn-quicksight-template-forecastconfiguration-scenario
         */
        readonly scenario?: CfnTemplate.ForecastScenarioProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html
     */
    interface ForecastScenarioProperty {
        /**
         * `CfnTemplate.ForecastScenarioProperty.WhatIfPointScenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifpointscenario
         */
        readonly whatIfPointScenario?: CfnTemplate.WhatIfPointScenarioProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ForecastScenarioProperty.WhatIfRangeScenario`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-forecastscenario.html#cfn-quicksight-template-forecastscenario-whatifrangescenario
         */
        readonly whatIfRangeScenario?: CfnTemplate.WhatIfRangeScenarioProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html
     */
    interface FormatConfigurationProperty {
        /**
         * `CfnTemplate.FormatConfigurationProperty.DateTimeFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-datetimeformatconfiguration
         */
        readonly dateTimeFormatConfiguration?: CfnTemplate.DateTimeFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FormatConfigurationProperty.NumberFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-numberformatconfiguration
         */
        readonly numberFormatConfiguration?: CfnTemplate.NumberFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FormatConfigurationProperty.StringFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-formatconfiguration.html#cfn-quicksight-template-formatconfiguration-stringformatconfiguration
         */
        readonly stringFormatConfiguration?: CfnTemplate.StringFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html
     */
    interface FreeFormLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty.ScreenCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutcanvassizeoptions.html#cfn-quicksight-template-freeformlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html
     */
    interface FreeFormLayoutConfigurationProperty {
        /**
         * `CfnTemplate.FreeFormLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnTemplate.FreeFormLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FreeFormLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutconfiguration.html#cfn-quicksight-template-freeformlayoutconfiguration-elements
         */
        readonly elements: Array<CfnTemplate.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html
     */
    interface FreeFormLayoutElementProperty {
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.BackgroundStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-backgroundstyle
         */
        readonly backgroundStyle?: CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.BorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-borderstyle
         */
        readonly borderStyle?: CfnTemplate.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.ElementId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.ElementType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-height
         */
        readonly height: string;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.LoadingAnimation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-loadinganimation
         */
        readonly loadingAnimation?: CfnTemplate.LoadingAnimationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.RenderingRules`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-renderingrules
         */
        readonly renderingRules?: Array<CfnTemplate.SheetElementRenderingRuleProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.SelectedBorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-selectedborderstyle
         */
        readonly selectedBorderStyle?: CfnTemplate.FreeFormLayoutElementBorderStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-width
         */
        readonly width: string;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.XAxisLocation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-xaxislocation
         */
        readonly xAxisLocation: string;
        /**
         * `CfnTemplate.FreeFormLayoutElementProperty.YAxisLocation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelement.html#cfn-quicksight-template-freeformlayoutelement-yaxislocation
         */
        readonly yAxisLocation: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html
     */
    interface FreeFormLayoutElementBackgroundStyleProperty {
        /**
         * `CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-color
         */
        readonly color?: string;
        /**
         * `CfnTemplate.FreeFormLayoutElementBackgroundStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementbackgroundstyle.html#cfn-quicksight-template-freeformlayoutelementbackgroundstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html
     */
    interface FreeFormLayoutElementBorderStyleProperty {
        /**
         * `CfnTemplate.FreeFormLayoutElementBorderStyleProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-color
         */
        readonly color?: string;
        /**
         * `CfnTemplate.FreeFormLayoutElementBorderStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutelementborderstyle.html#cfn-quicksight-template-freeformlayoutelementborderstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html
     */
    interface FreeFormLayoutScreenCanvasSizeOptionsProperty {
        /**
         * `CfnTemplate.FreeFormLayoutScreenCanvasSizeOptionsProperty.OptimizedViewPortWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformlayoutscreencanvassizeoptions.html#cfn-quicksight-template-freeformlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html
     */
    interface FreeFormSectionLayoutConfigurationProperty {
        /**
         * `CfnTemplate.FreeFormSectionLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-freeformsectionlayoutconfiguration.html#cfn-quicksight-template-freeformsectionlayoutconfiguration-elements
         */
        readonly elements: Array<CfnTemplate.FreeFormLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html
     */
    interface FunnelChartAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.FunnelChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartaggregatedfieldwells.html#cfn-quicksight-template-funnelchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html
     */
    interface FunnelChartConfigurationProperty {
        /**
         * `CfnTemplate.FunnelChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartConfigurationProperty.DataLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-datalabeloptions
         */
        readonly dataLabelOptions?: CfnTemplate.FunnelChartDataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.FunnelChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.FunnelChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartconfiguration.html#cfn-quicksight-template-funnelchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html
     */
    interface FunnelChartDataLabelOptionsProperty {
        /**
         * `CfnTemplate.FunnelChartDataLabelOptionsProperty.CategoryLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-categorylabelvisibility
         */
        readonly categoryLabelVisibility?: string;
        /**
         * `CfnTemplate.FunnelChartDataLabelOptionsProperty.LabelColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelcolor
         */
        readonly labelColor?: string;
        /**
         * `CfnTemplate.FunnelChartDataLabelOptionsProperty.LabelFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-labelfontconfiguration
         */
        readonly labelFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartDataLabelOptionsProperty.MeasureDataLabelStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measuredatalabelstyle
         */
        readonly measureDataLabelStyle?: string;
        /**
         * `CfnTemplate.FunnelChartDataLabelOptionsProperty.MeasureLabelVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-measurelabelvisibility
         */
        readonly measureLabelVisibility?: string;
        /**
         * `CfnTemplate.FunnelChartDataLabelOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-position
         */
        readonly position?: string;
        /**
         * `CfnTemplate.FunnelChartDataLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartdatalabeloptions.html#cfn-quicksight-template-funnelchartdatalabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html
     */
    interface FunnelChartFieldWellsProperty {
        /**
         * `CfnTemplate.FunnelChartFieldWellsProperty.FunnelChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartfieldwells.html#cfn-quicksight-template-funnelchartfieldwells-funnelchartaggregatedfieldwells
         */
        readonly funnelChartAggregatedFieldWells?: CfnTemplate.FunnelChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html
     */
    interface FunnelChartSortConfigurationProperty {
        /**
         * `CfnTemplate.FunnelChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartsortconfiguration.html#cfn-quicksight-template-funnelchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html
     */
    interface FunnelChartVisualProperty {
        /**
         * `CfnTemplate.FunnelChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.FunnelChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.FunnelChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-funnelchartvisual.html#cfn-quicksight-template-funnelchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html
     */
    interface GaugeChartArcConditionalFormattingProperty {
        /**
         * `CfnTemplate.GaugeChartArcConditionalFormattingProperty.ForegroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartarcconditionalformatting.html#cfn-quicksight-template-gaugechartarcconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html
     */
    interface GaugeChartConditionalFormattingProperty {
        /**
         * `CfnTemplate.GaugeChartConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformatting.html#cfn-quicksight-template-gaugechartconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnTemplate.GaugeChartConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html
     */
    interface GaugeChartConditionalFormattingOptionProperty {
        /**
         * `CfnTemplate.GaugeChartConditionalFormattingOptionProperty.Arc`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-arc
         */
        readonly arc?: CfnTemplate.GaugeChartArcConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartConditionalFormattingOptionProperty.PrimaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconditionalformattingoption.html#cfn-quicksight-template-gaugechartconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html
     */
    interface GaugeChartConfigurationProperty {
        /**
         * `CfnTemplate.GaugeChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.GaugeChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartConfigurationProperty.GaugeChartOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-gaugechartoptions
         */
        readonly gaugeChartOptions?: CfnTemplate.GaugeChartOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartConfigurationProperty.TooltipOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-tooltipoptions
         */
        readonly tooltipOptions?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartconfiguration.html#cfn-quicksight-template-gaugechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html
     */
    interface GaugeChartFieldWellsProperty {
        /**
         * `CfnTemplate.GaugeChartFieldWellsProperty.TargetValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-targetvalues
         */
        readonly targetValues?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartfieldwells.html#cfn-quicksight-template-gaugechartfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html
     */
    interface GaugeChartOptionsProperty {
        /**
         * `CfnTemplate.GaugeChartOptionsProperty.Arc`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arc
         */
        readonly arc?: CfnTemplate.ArcConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartOptionsProperty.ArcAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-arcaxis
         */
        readonly arcAxis?: CfnTemplate.ArcAxisConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartOptionsProperty.Comparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-comparison
         */
        readonly comparison?: CfnTemplate.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartOptionsProperty.PrimaryValueDisplayType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * `CfnTemplate.GaugeChartOptionsProperty.PrimaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartoptions.html#cfn-quicksight-template-gaugechartoptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html
     */
    interface GaugeChartPrimaryValueConditionalFormattingProperty {
        /**
         * `CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnTemplate.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartPrimaryValueConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartprimaryvalueconditionalformatting.html#cfn-quicksight-template-gaugechartprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html
     */
    interface GaugeChartVisualProperty {
        /**
         * `CfnTemplate.GaugeChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.GaugeChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnTemplate.GaugeChartConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GaugeChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gaugechartvisual.html#cfn-quicksight-template-gaugechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html
     */
    interface GeospatialCoordinateBoundsProperty {
        /**
         * `CfnTemplate.GeospatialCoordinateBoundsProperty.East`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-east
         */
        readonly east: number;
        /**
         * `CfnTemplate.GeospatialCoordinateBoundsProperty.North`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-north
         */
        readonly north: number;
        /**
         * `CfnTemplate.GeospatialCoordinateBoundsProperty.South`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-south
         */
        readonly south: number;
        /**
         * `CfnTemplate.GeospatialCoordinateBoundsProperty.West`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialcoordinatebounds.html#cfn-quicksight-template-geospatialcoordinatebounds-west
         */
        readonly west: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html
     */
    interface GeospatialMapAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.GeospatialMapAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapAggregatedFieldWellsProperty.Geospatial`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-geospatial
         */
        readonly geospatial?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapaggregatedfieldwells.html#cfn-quicksight-template-geospatialmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html
     */
    interface GeospatialMapConfigurationProperty {
        /**
         * `CfnTemplate.GeospatialMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.GeospatialMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapConfigurationProperty.MapStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-mapstyleoptions
         */
        readonly mapStyleOptions?: CfnTemplate.GeospatialMapStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapConfigurationProperty.PointStyleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-pointstyleoptions
         */
        readonly pointStyleOptions?: CfnTemplate.GeospatialPointStyleOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapConfigurationProperty.WindowOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapconfiguration.html#cfn-quicksight-template-geospatialmapconfiguration-windowoptions
         */
        readonly windowOptions?: CfnTemplate.GeospatialWindowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html
     */
    interface GeospatialMapFieldWellsProperty {
        /**
         * `CfnTemplate.GeospatialMapFieldWellsProperty.GeospatialMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapfieldwells.html#cfn-quicksight-template-geospatialmapfieldwells-geospatialmapaggregatedfieldwells
         */
        readonly geospatialMapAggregatedFieldWells?: CfnTemplate.GeospatialMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html
     */
    interface GeospatialMapStyleOptionsProperty {
        /**
         * `CfnTemplate.GeospatialMapStyleOptionsProperty.BaseMapStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapstyleoptions.html#cfn-quicksight-template-geospatialmapstyleoptions-basemapstyle
         */
        readonly baseMapStyle?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html
     */
    interface GeospatialMapVisualProperty {
        /**
         * `CfnTemplate.GeospatialMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.GeospatialMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialmapvisual.html#cfn-quicksight-template-geospatialmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html
     */
    interface GeospatialPointStyleOptionsProperty {
        /**
         * `CfnTemplate.GeospatialPointStyleOptionsProperty.ClusterMarkerConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-clustermarkerconfiguration
         */
        readonly clusterMarkerConfiguration?: CfnTemplate.ClusterMarkerConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialPointStyleOptionsProperty.SelectedPointStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialpointstyleoptions.html#cfn-quicksight-template-geospatialpointstyleoptions-selectedpointstyle
         */
        readonly selectedPointStyle?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html
     */
    interface GeospatialWindowOptionsProperty {
        /**
         * `CfnTemplate.GeospatialWindowOptionsProperty.Bounds`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-bounds
         */
        readonly bounds?: CfnTemplate.GeospatialCoordinateBoundsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GeospatialWindowOptionsProperty.MapZoomMode`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-geospatialwindowoptions.html#cfn-quicksight-template-geospatialwindowoptions-mapzoommode
         */
        readonly mapZoomMode?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html
     */
    interface GlobalTableBorderOptionsProperty {
        /**
         * `CfnTemplate.GlobalTableBorderOptionsProperty.SideSpecificBorder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-sidespecificborder
         */
        readonly sideSpecificBorder?: CfnTemplate.TableSideBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GlobalTableBorderOptionsProperty.UniformBorder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-globaltableborderoptions.html#cfn-quicksight-template-globaltableborderoptions-uniformborder
         */
        readonly uniformBorder?: CfnTemplate.TableBorderOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html
     */
    interface GradientColorProperty {
        /**
         * `CfnTemplate.GradientColorProperty.Stops`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientcolor.html#cfn-quicksight-template-gradientcolor-stops
         */
        readonly stops?: Array<CfnTemplate.GradientStopProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html
     */
    interface GradientStopProperty {
        /**
         * `CfnTemplate.GradientStopProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-color
         */
        readonly color?: string;
        /**
         * `CfnTemplate.GradientStopProperty.DataValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-datavalue
         */
        readonly dataValue?: number;
        /**
         * `CfnTemplate.GradientStopProperty.GradientOffset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gradientstop.html#cfn-quicksight-template-gradientstop-gradientoffset
         */
        readonly gradientOffset: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html
     */
    interface GridLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnTemplate.GridLayoutCanvasSizeOptionsProperty.ScreenCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutcanvassizeoptions.html#cfn-quicksight-template-gridlayoutcanvassizeoptions-screencanvassizeoptions
         */
        readonly screenCanvasSizeOptions?: CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html
     */
    interface GridLayoutConfigurationProperty {
        /**
         * `CfnTemplate.GridLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions?: CfnTemplate.GridLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GridLayoutConfigurationProperty.Elements`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutconfiguration.html#cfn-quicksight-template-gridlayoutconfiguration-elements
         */
        readonly elements: Array<CfnTemplate.GridLayoutElementProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html
     */
    interface GridLayoutElementProperty {
        /**
         * `CfnTemplate.GridLayoutElementProperty.ColumnIndex`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnindex
         */
        readonly columnIndex?: number;
        /**
         * `CfnTemplate.GridLayoutElementProperty.ColumnSpan`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-columnspan
         */
        readonly columnSpan: number;
        /**
         * `CfnTemplate.GridLayoutElementProperty.ElementId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementid
         */
        readonly elementId: string;
        /**
         * `CfnTemplate.GridLayoutElementProperty.ElementType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-elementtype
         */
        readonly elementType: string;
        /**
         * `CfnTemplate.GridLayoutElementProperty.RowIndex`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowindex
         */
        readonly rowIndex?: number;
        /**
         * `CfnTemplate.GridLayoutElementProperty.RowSpan`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutelement.html#cfn-quicksight-template-gridlayoutelement-rowspan
         */
        readonly rowSpan: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html
     */
    interface GridLayoutScreenCanvasSizeOptionsProperty {
        /**
         * `CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty.OptimizedViewPortWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-optimizedviewportwidth
         */
        readonly optimizedViewPortWidth?: string;
        /**
         * `CfnTemplate.GridLayoutScreenCanvasSizeOptionsProperty.ResizeOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-gridlayoutscreencanvassizeoptions.html#cfn-quicksight-template-gridlayoutscreencanvassizeoptions-resizeoption
         */
        readonly resizeOption: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html
     */
    interface GrowthRateComputationProperty {
        /**
         * `CfnTemplate.GrowthRateComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.GrowthRateComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.GrowthRateComputationProperty.PeriodSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-periodsize
         */
        readonly periodSize?: number;
        /**
         * `CfnTemplate.GrowthRateComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-time
         */
        readonly time: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.GrowthRateComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-growthratecomputation.html#cfn-quicksight-template-growthratecomputation-value
         */
        readonly value?: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html
     */
    interface HeaderFooterSectionConfigurationProperty {
        /**
         * `CfnTemplate.HeaderFooterSectionConfigurationProperty.Layout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-layout
         */
        readonly layout: CfnTemplate.SectionLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeaderFooterSectionConfigurationProperty.SectionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-sectionid
         */
        readonly sectionId: string;
        /**
         * `CfnTemplate.HeaderFooterSectionConfigurationProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-headerfootersectionconfiguration.html#cfn-quicksight-template-headerfootersectionconfiguration-style
         */
        readonly style?: CfnTemplate.SectionStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html
     */
    interface HeatMapAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.HeatMapAggregatedFieldWellsProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapAggregatedFieldWellsProperty.Rows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapaggregatedfieldwells.html#cfn-quicksight-template-heatmapaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html
     */
    interface HeatMapConfigurationProperty {
        /**
         * `CfnTemplate.HeatMapConfigurationProperty.ColorScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-colorscale
         */
        readonly colorScale?: CfnTemplate.ColorScaleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapConfigurationProperty.ColumnLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-columnlabeloptions
         */
        readonly columnLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.HeatMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapConfigurationProperty.RowLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-rowlabeloptions
         */
        readonly rowLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.HeatMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapconfiguration.html#cfn-quicksight-template-heatmapconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html
     */
    interface HeatMapFieldWellsProperty {
        /**
         * `CfnTemplate.HeatMapFieldWellsProperty.HeatMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapfieldwells.html#cfn-quicksight-template-heatmapfieldwells-heatmapaggregatedfieldwells
         */
        readonly heatMapAggregatedFieldWells?: CfnTemplate.HeatMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html
     */
    interface HeatMapSortConfigurationProperty {
        /**
         * `CfnTemplate.HeatMapSortConfigurationProperty.HeatMapColumnItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnitemslimitconfiguration
         */
        readonly heatMapColumnItemsLimitConfiguration?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapSortConfigurationProperty.HeatMapColumnSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmapcolumnsort
         */
        readonly heatMapColumnSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapSortConfigurationProperty.HeatMapRowItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowitemslimitconfiguration
         */
        readonly heatMapRowItemsLimitConfiguration?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapSortConfigurationProperty.HeatMapRowSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapsortconfiguration.html#cfn-quicksight-template-heatmapsortconfiguration-heatmaprowsort
         */
        readonly heatMapRowSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html
     */
    interface HeatMapVisualProperty {
        /**
         * `CfnTemplate.HeatMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.HeatMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HeatMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-heatmapvisual.html#cfn-quicksight-template-heatmapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html
     */
    interface HistogramAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.HistogramAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramaggregatedfieldwells.html#cfn-quicksight-template-histogramaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html
     */
    interface HistogramBinOptionsProperty {
        /**
         * `CfnTemplate.HistogramBinOptionsProperty.BinCount`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-bincount
         */
        readonly binCount?: CfnTemplate.BinCountOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramBinOptionsProperty.BinWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-binwidth
         */
        readonly binWidth?: CfnTemplate.BinWidthOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramBinOptionsProperty.SelectedBinType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-selectedbintype
         */
        readonly selectedBinType?: string;
        /**
         * `CfnTemplate.HistogramBinOptionsProperty.StartValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogrambinoptions.html#cfn-quicksight-template-histogrambinoptions-startvalue
         */
        readonly startValue?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html
     */
    interface HistogramConfigurationProperty {
        /**
         * `CfnTemplate.HistogramConfigurationProperty.BinOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-binoptions
         */
        readonly binOptions?: CfnTemplate.HistogramBinOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.HistogramFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramConfigurationProperty.YAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramconfiguration.html#cfn-quicksight-template-histogramconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html
     */
    interface HistogramFieldWellsProperty {
        /**
         * `CfnTemplate.HistogramFieldWellsProperty.HistogramAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramfieldwells.html#cfn-quicksight-template-histogramfieldwells-histogramaggregatedfieldwells
         */
        readonly histogramAggregatedFieldWells?: CfnTemplate.HistogramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html
     */
    interface HistogramVisualProperty {
        /**
         * `CfnTemplate.HistogramVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.HistogramConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.HistogramVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-histogramvisual.html#cfn-quicksight-template-histogramvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html
     */
    interface InsightConfigurationProperty {
        /**
         * `CfnTemplate.InsightConfigurationProperty.Computations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-computations
         */
        readonly computations?: Array<CfnTemplate.ComputationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.InsightConfigurationProperty.CustomNarrative`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightconfiguration.html#cfn-quicksight-template-insightconfiguration-customnarrative
         */
        readonly customNarrative?: CfnTemplate.CustomNarrativeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html
     */
    interface InsightVisualProperty {
        /**
         * `CfnTemplate.InsightVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.InsightVisualProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnTemplate.InsightVisualProperty.InsightConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-insightconfiguration
         */
        readonly insightConfiguration?: CfnTemplate.InsightConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.InsightVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.InsightVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.InsightVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-insightvisual.html#cfn-quicksight-template-insightvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html
     */
    interface IntegerDefaultValuesProperty {
        /**
         * `CfnTemplate.IntegerDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnTemplate.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.IntegerDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerdefaultvalues.html#cfn-quicksight-template-integerdefaultvalues-staticvalues
         */
        readonly staticValues?: number[] | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html
     */
    interface IntegerParameterDeclarationProperty {
        /**
         * `CfnTemplate.IntegerParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnTemplate.IntegerDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.IntegerParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnTemplate.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.IntegerParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnTemplate.IntegerParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnTemplate.IntegerParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integerparameterdeclaration.html#cfn-quicksight-template-integerparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnTemplate.IntegerValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html
     */
    interface IntegerValueWhenUnsetConfigurationProperty {
        /**
         * `CfnTemplate.IntegerValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: number;
        /**
         * `CfnTemplate.IntegerValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-integervaluewhenunsetconfiguration.html#cfn-quicksight-template-integervaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html
     */
    interface ItemsLimitConfigurationProperty {
        /**
         * `CfnTemplate.ItemsLimitConfigurationProperty.ItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-itemslimit
         */
        readonly itemsLimit?: number;
        /**
         * `CfnTemplate.ItemsLimitConfigurationProperty.OtherCategories`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-itemslimitconfiguration.html#cfn-quicksight-template-itemslimitconfiguration-othercategories
         */
        readonly otherCategories?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html
     */
    interface KPIConditionalFormattingProperty {
        /**
         * `CfnTemplate.KPIConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformatting.html#cfn-quicksight-template-kpiconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnTemplate.KPIConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html
     */
    interface KPIConditionalFormattingOptionProperty {
        /**
         * `CfnTemplate.KPIConditionalFormattingOptionProperty.PrimaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-primaryvalue
         */
        readonly primaryValue?: CfnTemplate.KPIPrimaryValueConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIConditionalFormattingOptionProperty.ProgressBar`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconditionalformattingoption.html#cfn-quicksight-template-kpiconditionalformattingoption-progressbar
         */
        readonly progressBar?: CfnTemplate.KPIProgressBarConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html
     */
    interface KPIConfigurationProperty {
        /**
         * `CfnTemplate.KPIConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.KPIFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIConfigurationProperty.KPIOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-kpioptions
         */
        readonly kpiOptions?: CfnTemplate.KPIOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiconfiguration.html#cfn-quicksight-template-kpiconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.KPISortConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html
     */
    interface KPIFieldWellsProperty {
        /**
         * `CfnTemplate.KPIFieldWellsProperty.TargetValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-targetvalues
         */
        readonly targetValues?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIFieldWellsProperty.TrendGroups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-trendgroups
         */
        readonly trendGroups?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpifieldwells.html#cfn-quicksight-template-kpifieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html
     */
    interface KPIOptionsProperty {
        /**
         * `CfnTemplate.KPIOptionsProperty.Comparison`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-comparison
         */
        readonly comparison?: CfnTemplate.ComparisonConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIOptionsProperty.PrimaryValueDisplayType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluedisplaytype
         */
        readonly primaryValueDisplayType?: string;
        /**
         * `CfnTemplate.KPIOptionsProperty.PrimaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-primaryvaluefontconfiguration
         */
        readonly primaryValueFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIOptionsProperty.ProgressBar`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-progressbar
         */
        readonly progressBar?: CfnTemplate.ProgressBarOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIOptionsProperty.SecondaryValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvalue
         */
        readonly secondaryValue?: CfnTemplate.SecondaryValueOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIOptionsProperty.SecondaryValueFontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-secondaryvaluefontconfiguration
         */
        readonly secondaryValueFontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIOptionsProperty.TrendArrows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpioptions.html#cfn-quicksight-template-kpioptions-trendarrows
         */
        readonly trendArrows?: CfnTemplate.TrendArrowOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html
     */
    interface KPIPrimaryValueConditionalFormattingProperty {
        /**
         * `CfnTemplate.KPIPrimaryValueConditionalFormattingProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-icon
         */
        readonly icon?: CfnTemplate.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIPrimaryValueConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprimaryvalueconditionalformatting.html#cfn-quicksight-template-kpiprimaryvalueconditionalformatting-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html
     */
    interface KPIProgressBarConditionalFormattingProperty {
        /**
         * `CfnTemplate.KPIProgressBarConditionalFormattingProperty.ForegroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpiprogressbarconditionalformatting.html#cfn-quicksight-template-kpiprogressbarconditionalformatting-foregroundcolor
         */
        readonly foregroundColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html
     */
    interface KPISortConfigurationProperty {
        /**
         * `CfnTemplate.KPISortConfigurationProperty.TrendGroupSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpisortconfiguration.html#cfn-quicksight-template-kpisortconfiguration-trendgroupsort
         */
        readonly trendGroupSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html
     */
    interface KPIVisualProperty {
        /**
         * `CfnTemplate.KPIVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.KPIConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnTemplate.KPIConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.KPIVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-kpivisual.html#cfn-quicksight-template-kpivisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html
     */
    interface LabelOptionsProperty {
        /**
         * `CfnTemplate.LabelOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnTemplate.LabelOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-labeloptions.html#cfn-quicksight-template-labeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html
     */
    interface LayoutProperty {
        /**
         * `CfnTemplate.LayoutProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layout.html#cfn-quicksight-template-layout-configuration
         */
        readonly configuration: CfnTemplate.LayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html
     */
    interface LayoutConfigurationProperty {
        /**
         * `CfnTemplate.LayoutConfigurationProperty.FreeFormLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-freeformlayout
         */
        readonly freeFormLayout?: CfnTemplate.FreeFormLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LayoutConfigurationProperty.GridLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnTemplate.GridLayoutConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LayoutConfigurationProperty.SectionBasedLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-layoutconfiguration.html#cfn-quicksight-template-layoutconfiguration-sectionbasedlayout
         */
        readonly sectionBasedLayout?: CfnTemplate.SectionBasedLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html
     */
    interface LegendOptionsProperty {
        /**
         * `CfnTemplate.LegendOptionsProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-height
         */
        readonly height?: string;
        /**
         * `CfnTemplate.LegendOptionsProperty.Position`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-position
         */
        readonly position?: string;
        /**
         * `CfnTemplate.LegendOptionsProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-title
         */
        readonly title?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LegendOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnTemplate.LegendOptionsProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-legendoptions.html#cfn-quicksight-template-legendoptions-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html
     */
    interface LineChartAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.LineChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartaggregatedfieldwells.html#cfn-quicksight-template-linechartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html
     */
    interface LineChartConfigurationProperty {
        /**
         * `CfnTemplate.LineChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnTemplate.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.DefaultSeriesSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-defaultseriessettings
         */
        readonly defaultSeriesSettings?: CfnTemplate.LineChartDefaultSeriesSettingsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.LineChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.ForecastConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-forecastconfigurations
         */
        readonly forecastConfigurations?: Array<CfnTemplate.ForecastConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnTemplate.LineSeriesAxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.ReferenceLines`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-referencelines
         */
        readonly referenceLines?: Array<CfnTemplate.ReferenceLineProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.SecondaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxisdisplayoptions
         */
        readonly secondaryYAxisDisplayOptions?: CfnTemplate.LineSeriesAxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.SecondaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-secondaryyaxislabeloptions
         */
        readonly secondaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.Series`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-series
         */
        readonly series?: Array<CfnTemplate.SeriesItemProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnTemplate.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.LineChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-type
         */
        readonly type?: string;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartconfiguration.html#cfn-quicksight-template-linechartconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html
     */
    interface LineChartDefaultSeriesSettingsProperty {
        /**
         * `CfnTemplate.LineChartDefaultSeriesSettingsProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * `CfnTemplate.LineChartDefaultSeriesSettingsProperty.LineStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: CfnTemplate.LineChartLineStyleSettingsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartDefaultSeriesSettingsProperty.MarkerStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartdefaultseriessettings.html#cfn-quicksight-template-linechartdefaultseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: CfnTemplate.LineChartMarkerStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html
     */
    interface LineChartFieldWellsProperty {
        /**
         * `CfnTemplate.LineChartFieldWellsProperty.LineChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartfieldwells.html#cfn-quicksight-template-linechartfieldwells-linechartaggregatedfieldwells
         */
        readonly lineChartAggregatedFieldWells?: CfnTemplate.LineChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html
     */
    interface LineChartLineStyleSettingsProperty {
        /**
         * `CfnTemplate.LineChartLineStyleSettingsProperty.LineInterpolation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-lineinterpolation
         */
        readonly lineInterpolation?: string;
        /**
         * `CfnTemplate.LineChartLineStyleSettingsProperty.LineStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linestyle
         */
        readonly lineStyle?: string;
        /**
         * `CfnTemplate.LineChartLineStyleSettingsProperty.LineVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linevisibility
         */
        readonly lineVisibility?: string;
        /**
         * `CfnTemplate.LineChartLineStyleSettingsProperty.LineWidth`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartlinestylesettings.html#cfn-quicksight-template-linechartlinestylesettings-linewidth
         */
        readonly lineWidth?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html
     */
    interface LineChartMarkerStyleSettingsProperty {
        /**
         * `CfnTemplate.LineChartMarkerStyleSettingsProperty.MarkerColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markercolor
         */
        readonly markerColor?: string;
        /**
         * `CfnTemplate.LineChartMarkerStyleSettingsProperty.MarkerShape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markershape
         */
        readonly markerShape?: string;
        /**
         * `CfnTemplate.LineChartMarkerStyleSettingsProperty.MarkerSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markersize
         */
        readonly markerSize?: string;
        /**
         * `CfnTemplate.LineChartMarkerStyleSettingsProperty.MarkerVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartmarkerstylesettings.html#cfn-quicksight-template-linechartmarkerstylesettings-markervisibility
         */
        readonly markerVisibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html
     */
    interface LineChartSeriesSettingsProperty {
        /**
         * `CfnTemplate.LineChartSeriesSettingsProperty.LineStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-linestylesettings
         */
        readonly lineStyleSettings?: CfnTemplate.LineChartLineStyleSettingsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartSeriesSettingsProperty.MarkerStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartseriessettings.html#cfn-quicksight-template-linechartseriessettings-markerstylesettings
         */
        readonly markerStyleSettings?: CfnTemplate.LineChartMarkerStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html
     */
    interface LineChartSortConfigurationProperty {
        /**
         * `CfnTemplate.LineChartSortConfigurationProperty.CategoryItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categoryitemslimitconfiguration
         */
        readonly categoryItemsLimitConfiguration?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartSortConfigurationProperty.ColorItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-coloritemslimitconfiguration
         */
        readonly colorItemsLimitConfiguration?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartsortconfiguration.html#cfn-quicksight-template-linechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html
     */
    interface LineChartVisualProperty {
        /**
         * `CfnTemplate.LineChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.LineChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-linechartvisual.html#cfn-quicksight-template-linechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html
     */
    interface LineSeriesAxisDisplayOptionsProperty {
        /**
         * `CfnTemplate.LineSeriesAxisDisplayOptionsProperty.AxisOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-axisoptions
         */
        readonly axisOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.LineSeriesAxisDisplayOptionsProperty.MissingDataConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-lineseriesaxisdisplayoptions.html#cfn-quicksight-template-lineseriesaxisdisplayoptions-missingdataconfigurations
         */
        readonly missingDataConfigurations?: Array<CfnTemplate.MissingDataConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html
     */
    interface ListControlDisplayOptionsProperty {
        /**
         * `CfnTemplate.ListControlDisplayOptionsProperty.SearchOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-searchoptions
         */
        readonly searchOptions?: CfnTemplate.ListControlSearchOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ListControlDisplayOptionsProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-selectalloptions
         */
        readonly selectAllOptions?: CfnTemplate.ListControlSelectAllOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ListControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontroldisplayoptions.html#cfn-quicksight-template-listcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html
     */
    interface ListControlSearchOptionsProperty {
        /**
         * `CfnTemplate.ListControlSearchOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolsearchoptions.html#cfn-quicksight-template-listcontrolsearchoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html
     */
    interface ListControlSelectAllOptionsProperty {
        /**
         * `CfnTemplate.ListControlSelectAllOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-listcontrolselectalloptions.html#cfn-quicksight-template-listcontrolselectalloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html
     */
    interface LoadingAnimationProperty {
        /**
         * `CfnTemplate.LoadingAnimationProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-loadinganimation.html#cfn-quicksight-template-loadinganimation-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html
     */
    interface LocalNavigationConfigurationProperty {
        /**
         * `CfnTemplate.LocalNavigationConfigurationProperty.TargetSheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-localnavigationconfiguration.html#cfn-quicksight-template-localnavigationconfiguration-targetsheetid
         */
        readonly targetSheetId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html
     */
    interface LongFormatTextProperty {
        /**
         * `CfnTemplate.LongFormatTextProperty.PlainText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * `CfnTemplate.LongFormatTextProperty.RichText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-longformattext.html#cfn-quicksight-template-longformattext-richtext
         */
        readonly richText?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html
     */
    interface MappedDataSetParameterProperty {
        /**
         * `CfnTemplate.MappedDataSetParameterProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetidentifier
         */
        readonly dataSetIdentifier: string;
        /**
         * `CfnTemplate.MappedDataSetParameterProperty.DataSetParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-mappeddatasetparameter.html#cfn-quicksight-template-mappeddatasetparameter-datasetparametername
         */
        readonly dataSetParameterName: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html
     */
    interface MaximumLabelTypeProperty {
        /**
         * `CfnTemplate.MaximumLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumlabeltype.html#cfn-quicksight-template-maximumlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html
     */
    interface MaximumMinimumComputationProperty {
        /**
         * `CfnTemplate.MaximumMinimumComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.MaximumMinimumComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.MaximumMinimumComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-time
         */
        readonly time: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.MaximumMinimumComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-type
         */
        readonly type: string;
        /**
         * `CfnTemplate.MaximumMinimumComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-maximumminimumcomputation.html#cfn-quicksight-template-maximumminimumcomputation-value
         */
        readonly value?: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html
     */
    interface MeasureFieldProperty {
        /**
         * `CfnTemplate.MeasureFieldProperty.CalculatedMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-calculatedmeasurefield
         */
        readonly calculatedMeasureField?: CfnTemplate.CalculatedMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.MeasureFieldProperty.CategoricalMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-categoricalmeasurefield
         */
        readonly categoricalMeasureField?: CfnTemplate.CategoricalMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.MeasureFieldProperty.DateMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-datemeasurefield
         */
        readonly dateMeasureField?: CfnTemplate.DateMeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.MeasureFieldProperty.NumericalMeasureField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-measurefield.html#cfn-quicksight-template-measurefield-numericalmeasurefield
         */
        readonly numericalMeasureField?: CfnTemplate.NumericalMeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html
     */
    interface MetricComparisonComputationProperty {
        /**
         * `CfnTemplate.MetricComparisonComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.MetricComparisonComputationProperty.FromValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-fromvalue
         */
        readonly fromValue: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.MetricComparisonComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.MetricComparisonComputationProperty.TargetValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-targetvalue
         */
        readonly targetValue: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.MetricComparisonComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-metriccomparisoncomputation.html#cfn-quicksight-template-metriccomparisoncomputation-time
         */
        readonly time: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html
     */
    interface MinimumLabelTypeProperty {
        /**
         * `CfnTemplate.MinimumLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-minimumlabeltype.html#cfn-quicksight-template-minimumlabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html
     */
    interface MissingDataConfigurationProperty {
        /**
         * `CfnTemplate.MissingDataConfigurationProperty.TreatmentOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-missingdataconfiguration.html#cfn-quicksight-template-missingdataconfiguration-treatmentoption
         */
        readonly treatmentOption?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html
     */
    interface NegativeValueConfigurationProperty {
        /**
         * `CfnTemplate.NegativeValueConfigurationProperty.DisplayMode`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-negativevalueconfiguration.html#cfn-quicksight-template-negativevalueconfiguration-displaymode
         */
        readonly displayMode: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html
     */
    interface NullValueFormatConfigurationProperty {
        /**
         * `CfnTemplate.NullValueFormatConfigurationProperty.NullString`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-nullvalueformatconfiguration.html#cfn-quicksight-template-nullvalueformatconfiguration-nullstring
         */
        readonly nullString: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html
     */
    interface NumberDisplayFormatConfigurationProperty {
        /**
         * `CfnTemplate.NumberDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnTemplate.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumberDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnTemplate.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumberDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnTemplate.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumberDisplayFormatConfigurationProperty.NumberScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-numberscale
         */
        readonly numberScale?: string;
        /**
         * `CfnTemplate.NumberDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnTemplate.NumberDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnTemplate.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumberDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberdisplayformatconfiguration.html#cfn-quicksight-template-numberdisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html
     */
    interface NumberFormatConfigurationProperty {
        /**
         * `CfnTemplate.NumberFormatConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numberformatconfiguration.html#cfn-quicksight-template-numberformatconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html
     */
    interface NumericAxisOptionsProperty {
        /**
         * `CfnTemplate.NumericAxisOptionsProperty.Range`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-range
         */
        readonly range?: CfnTemplate.AxisDisplayRangeProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericAxisOptionsProperty.Scale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaxisoptions.html#cfn-quicksight-template-numericaxisoptions-scale
         */
        readonly scale?: CfnTemplate.AxisScaleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html
     */
    interface NumericEqualityDrillDownFilterProperty {
        /**
         * `CfnTemplate.NumericEqualityDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericEqualityDrillDownFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalitydrilldownfilter.html#cfn-quicksight-template-numericequalitydrilldownfilter-value
         */
        readonly value: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html
     */
    interface NumericEqualityFilterProperty {
        /**
         * `CfnTemplate.NumericEqualityFilterProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericEqualityFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericEqualityFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnTemplate.NumericEqualityFilterProperty.MatchOperator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-matchoperator
         */
        readonly matchOperator: string;
        /**
         * `CfnTemplate.NumericEqualityFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnTemplate.NumericEqualityFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnTemplate.NumericEqualityFilterProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-selectalloptions
         */
        readonly selectAllOptions?: string;
        /**
         * `CfnTemplate.NumericEqualityFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericequalityfilter.html#cfn-quicksight-template-numericequalityfilter-value
         */
        readonly value?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html
     */
    interface NumericFormatConfigurationProperty {
        /**
         * `CfnTemplate.NumericFormatConfigurationProperty.CurrencyDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-currencydisplayformatconfiguration
         */
        readonly currencyDisplayFormatConfiguration?: CfnTemplate.CurrencyDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericFormatConfigurationProperty.NumberDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-numberdisplayformatconfiguration
         */
        readonly numberDisplayFormatConfiguration?: CfnTemplate.NumberDisplayFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericFormatConfigurationProperty.PercentageDisplayFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericformatconfiguration.html#cfn-quicksight-template-numericformatconfiguration-percentagedisplayformatconfiguration
         */
        readonly percentageDisplayFormatConfiguration?: CfnTemplate.PercentageDisplayFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html
     */
    interface NumericRangeFilterProperty {
        /**
         * `CfnTemplate.NumericRangeFilterProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-aggregationfunction
         */
        readonly aggregationFunction?: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericRangeFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericRangeFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnTemplate.NumericRangeFilterProperty.IncludeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericRangeFilterProperty.IncludeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericRangeFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnTemplate.NumericRangeFilterProperty.RangeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangemaximum
         */
        readonly rangeMaximum?: CfnTemplate.NumericRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericRangeFilterProperty.RangeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-rangeminimum
         */
        readonly rangeMinimum?: CfnTemplate.NumericRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericRangeFilterProperty.SelectAllOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefilter.html#cfn-quicksight-template-numericrangefilter-selectalloptions
         */
        readonly selectAllOptions?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html
     */
    interface NumericRangeFilterValueProperty {
        /**
         * `CfnTemplate.NumericRangeFilterValueProperty.Parameter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * `CfnTemplate.NumericRangeFilterValueProperty.StaticValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericrangefiltervalue.html#cfn-quicksight-template-numericrangefiltervalue-staticvalue
         */
        readonly staticValue?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html
     */
    interface NumericSeparatorConfigurationProperty {
        /**
         * `CfnTemplate.NumericSeparatorConfigurationProperty.DecimalSeparator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-decimalseparator
         */
        readonly decimalSeparator?: string;
        /**
         * `CfnTemplate.NumericSeparatorConfigurationProperty.ThousandsSeparator`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericseparatorconfiguration.html#cfn-quicksight-template-numericseparatorconfiguration-thousandsseparator
         */
        readonly thousandsSeparator?: CfnTemplate.ThousandSeparatorOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html
     */
    interface NumericalAggregationFunctionProperty {
        /**
         * `CfnTemplate.NumericalAggregationFunctionProperty.PercentileAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-percentileaggregation
         */
        readonly percentileAggregation?: CfnTemplate.PercentileAggregationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericalAggregationFunctionProperty.SimpleNumericalAggregation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalaggregationfunction.html#cfn-quicksight-template-numericalaggregationfunction-simplenumericalaggregation
         */
        readonly simpleNumericalAggregation?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html
     */
    interface NumericalDimensionFieldProperty {
        /**
         * `CfnTemplate.NumericalDimensionFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericalDimensionFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.NumericalDimensionFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.NumberFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericalDimensionFieldProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericaldimensionfield.html#cfn-quicksight-template-numericaldimensionfield-hierarchyid
         */
        readonly hierarchyId?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html
     */
    interface NumericalMeasureFieldProperty {
        /**
         * `CfnTemplate.NumericalMeasureFieldProperty.AggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-aggregationfunction
         */
        readonly aggregationFunction?: CfnTemplate.NumericalAggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericalMeasureFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.NumericalMeasureFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.NumericalMeasureFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-numericalmeasurefield.html#cfn-quicksight-template-numericalmeasurefield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.NumberFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html
     */
    interface PaginationConfigurationProperty {
        /**
         * `CfnTemplate.PaginationConfigurationProperty.PageNumber`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagenumber
         */
        readonly pageNumber: number;
        /**
         * `CfnTemplate.PaginationConfigurationProperty.PageSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paginationconfiguration.html#cfn-quicksight-template-paginationconfiguration-pagesize
         */
        readonly pageSize: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html
     */
    interface PanelConfigurationProperty {
        /**
         * `CfnTemplate.PanelConfigurationProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * `CfnTemplate.PanelConfigurationProperty.BackgroundVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-backgroundvisibility
         */
        readonly backgroundVisibility?: string;
        /**
         * `CfnTemplate.PanelConfigurationProperty.BorderColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordercolor
         */
        readonly borderColor?: string;
        /**
         * `CfnTemplate.PanelConfigurationProperty.BorderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderstyle
         */
        readonly borderStyle?: string;
        /**
         * `CfnTemplate.PanelConfigurationProperty.BorderThickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-borderthickness
         */
        readonly borderThickness?: string;
        /**
         * `CfnTemplate.PanelConfigurationProperty.BorderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-bordervisibility
         */
        readonly borderVisibility?: string;
        /**
         * `CfnTemplate.PanelConfigurationProperty.GutterSpacing`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-gutterspacing
         */
        readonly gutterSpacing?: string;
        /**
         * `CfnTemplate.PanelConfigurationProperty.GutterVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-guttervisibility
         */
        readonly gutterVisibility?: string;
        /**
         * `CfnTemplate.PanelConfigurationProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-panelconfiguration.html#cfn-quicksight-template-panelconfiguration-title
         */
        readonly title?: CfnTemplate.PanelTitleOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html
     */
    interface PanelTitleOptionsProperty {
        /**
         * `CfnTemplate.PanelTitleOptionsProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PanelTitleOptionsProperty.HorizontalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * `CfnTemplate.PanelTitleOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-paneltitleoptions.html#cfn-quicksight-template-paneltitleoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html
     */
    interface ParameterControlProperty {
        /**
         * `CfnTemplate.ParameterControlProperty.DateTimePicker`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-datetimepicker
         */
        readonly dateTimePicker?: CfnTemplate.ParameterDateTimePickerControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterControlProperty.Dropdown`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-dropdown
         */
        readonly dropdown?: CfnTemplate.ParameterDropDownControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterControlProperty.List`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-list
         */
        readonly list?: CfnTemplate.ParameterListControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterControlProperty.Slider`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-slider
         */
        readonly slider?: CfnTemplate.ParameterSliderControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterControlProperty.TextArea`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textarea
         */
        readonly textArea?: CfnTemplate.ParameterTextAreaControlProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterControlProperty.TextField`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametercontrol.html#cfn-quicksight-template-parametercontrol-textfield
         */
        readonly textField?: CfnTemplate.ParameterTextFieldControlProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html
     */
    interface ParameterDateTimePickerControlProperty {
        /**
         * `CfnTemplate.ParameterDateTimePickerControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.DateTimePickerControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterDateTimePickerControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnTemplate.ParameterDateTimePickerControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnTemplate.ParameterDateTimePickerControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdatetimepickercontrol.html#cfn-quicksight-template-parameterdatetimepickercontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html
     */
    interface ParameterDeclarationProperty {
        /**
         * `CfnTemplate.ParameterDeclarationProperty.DateTimeParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-datetimeparameterdeclaration
         */
        readonly dateTimeParameterDeclaration?: CfnTemplate.DateTimeParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterDeclarationProperty.DecimalParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-decimalparameterdeclaration
         */
        readonly decimalParameterDeclaration?: CfnTemplate.DecimalParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterDeclarationProperty.IntegerParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-integerparameterdeclaration
         */
        readonly integerParameterDeclaration?: CfnTemplate.IntegerParameterDeclarationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterDeclarationProperty.StringParameterDeclaration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdeclaration.html#cfn-quicksight-template-parameterdeclaration-stringparameterdeclaration
         */
        readonly stringParameterDeclaration?: CfnTemplate.StringParameterDeclarationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html
     */
    interface ParameterDropDownControlProperty {
        /**
         * `CfnTemplate.ParameterDropDownControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnTemplate.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterDropDownControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.DropDownControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterDropDownControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnTemplate.ParameterDropDownControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-selectablevalues
         */
        readonly selectableValues?: CfnTemplate.ParameterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterDropDownControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnTemplate.ParameterDropDownControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-title
         */
        readonly title: string;
        /**
         * `CfnTemplate.ParameterDropDownControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterdropdowncontrol.html#cfn-quicksight-template-parameterdropdowncontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html
     */
    interface ParameterListControlProperty {
        /**
         * `CfnTemplate.ParameterListControlProperty.CascadingControlConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-cascadingcontrolconfiguration
         */
        readonly cascadingControlConfiguration?: CfnTemplate.CascadingControlConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterListControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.ListControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterListControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnTemplate.ParameterListControlProperty.SelectableValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-selectablevalues
         */
        readonly selectableValues?: CfnTemplate.ParameterSelectableValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterListControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnTemplate.ParameterListControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-title
         */
        readonly title: string;
        /**
         * `CfnTemplate.ParameterListControlProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterlistcontrol.html#cfn-quicksight-template-parameterlistcontrol-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html
     */
    interface ParameterSelectableValuesProperty {
        /**
         * `CfnTemplate.ParameterSelectableValuesProperty.LinkToDataSetColumn`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-linktodatasetcolumn
         */
        readonly linkToDataSetColumn?: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterSelectableValuesProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterselectablevalues.html#cfn-quicksight-template-parameterselectablevalues-values
         */
        readonly values?: string[];
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html
     */
    interface ParameterSliderControlProperty {
        /**
         * `CfnTemplate.ParameterSliderControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.SliderControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterSliderControlProperty.MaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-maximumvalue
         */
        readonly maximumValue: number;
        /**
         * `CfnTemplate.ParameterSliderControlProperty.MinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-minimumvalue
         */
        readonly minimumValue: number;
        /**
         * `CfnTemplate.ParameterSliderControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnTemplate.ParameterSliderControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnTemplate.ParameterSliderControlProperty.StepSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-stepsize
         */
        readonly stepSize: number;
        /**
         * `CfnTemplate.ParameterSliderControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parameterslidercontrol.html#cfn-quicksight-template-parameterslidercontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html
     */
    interface ParameterTextAreaControlProperty {
        /**
         * `CfnTemplate.ParameterTextAreaControlProperty.Delimiter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-delimiter
         */
        readonly delimiter?: string;
        /**
         * `CfnTemplate.ParameterTextAreaControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.TextAreaControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterTextAreaControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnTemplate.ParameterTextAreaControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnTemplate.ParameterTextAreaControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextareacontrol.html#cfn-quicksight-template-parametertextareacontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html
     */
    interface ParameterTextFieldControlProperty {
        /**
         * `CfnTemplate.ParameterTextFieldControlProperty.DisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-displayoptions
         */
        readonly displayOptions?: CfnTemplate.TextFieldControlDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ParameterTextFieldControlProperty.ParameterControlId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-parametercontrolid
         */
        readonly parameterControlId: string;
        /**
         * `CfnTemplate.ParameterTextFieldControlProperty.SourceParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-sourceparametername
         */
        readonly sourceParameterName: string;
        /**
         * `CfnTemplate.ParameterTextFieldControlProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-parametertextfieldcontrol.html#cfn-quicksight-template-parametertextfieldcontrol-title
         */
        readonly title: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html
     */
    interface PercentVisibleRangeProperty {
        /**
         * `CfnTemplate.PercentVisibleRangeProperty.From`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-from
         */
        readonly from?: number;
        /**
         * `CfnTemplate.PercentVisibleRangeProperty.To`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentvisiblerange.html#cfn-quicksight-template-percentvisiblerange-to
         */
        readonly to?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html
     */
    interface PercentageDisplayFormatConfigurationProperty {
        /**
         * `CfnTemplate.PercentageDisplayFormatConfigurationProperty.DecimalPlacesConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-decimalplacesconfiguration
         */
        readonly decimalPlacesConfiguration?: CfnTemplate.DecimalPlacesConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PercentageDisplayFormatConfigurationProperty.NegativeValueConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-negativevalueconfiguration
         */
        readonly negativeValueConfiguration?: CfnTemplate.NegativeValueConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PercentageDisplayFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnTemplate.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PercentageDisplayFormatConfigurationProperty.Prefix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-prefix
         */
        readonly prefix?: string;
        /**
         * `CfnTemplate.PercentageDisplayFormatConfigurationProperty.SeparatorConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-separatorconfiguration
         */
        readonly separatorConfiguration?: CfnTemplate.NumericSeparatorConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PercentageDisplayFormatConfigurationProperty.Suffix`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentagedisplayformatconfiguration.html#cfn-quicksight-template-percentagedisplayformatconfiguration-suffix
         */
        readonly suffix?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html
     */
    interface PercentileAggregationProperty {
        /**
         * `CfnTemplate.PercentileAggregationProperty.PercentileValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-percentileaggregation.html#cfn-quicksight-template-percentileaggregation-percentilevalue
         */
        readonly percentileValue?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html
     */
    interface PeriodOverPeriodComputationProperty {
        /**
         * `CfnTemplate.PeriodOverPeriodComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.PeriodOverPeriodComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.PeriodOverPeriodComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-time
         */
        readonly time: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PeriodOverPeriodComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodoverperiodcomputation.html#cfn-quicksight-template-periodoverperiodcomputation-value
         */
        readonly value?: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html
     */
    interface PeriodToDateComputationProperty {
        /**
         * `CfnTemplate.PeriodToDateComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.PeriodToDateComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.PeriodToDateComputationProperty.PeriodTimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-periodtimegranularity
         */
        readonly periodTimeGranularity?: string;
        /**
         * `CfnTemplate.PeriodToDateComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-time
         */
        readonly time: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PeriodToDateComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-periodtodatecomputation.html#cfn-quicksight-template-periodtodatecomputation-value
         */
        readonly value?: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html
     */
    interface PieChartAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.PieChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartAggregatedFieldWellsProperty.SmallMultiples`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-smallmultiples
         */
        readonly smallMultiples?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartaggregatedfieldwells.html#cfn-quicksight-template-piechartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html
     */
    interface PieChartConfigurationProperty {
        /**
         * `CfnTemplate.PieChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.ContributionAnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-contributionanalysisdefaults
         */
        readonly contributionAnalysisDefaults?: Array<CfnTemplate.ContributionAnalysisDefaultProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.DonutOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-donutoptions
         */
        readonly donutOptions?: CfnTemplate.DonutOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.PieChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.SmallMultiplesOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-smallmultiplesoptions
         */
        readonly smallMultiplesOptions?: CfnTemplate.SmallMultiplesOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.PieChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.ValueLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-valuelabeloptions
         */
        readonly valueLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartconfiguration.html#cfn-quicksight-template-piechartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html
     */
    interface PieChartFieldWellsProperty {
        /**
         * `CfnTemplate.PieChartFieldWellsProperty.PieChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartfieldwells.html#cfn-quicksight-template-piechartfieldwells-piechartaggregatedfieldwells
         */
        readonly pieChartAggregatedFieldWells?: CfnTemplate.PieChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html
     */
    interface PieChartSortConfigurationProperty {
        /**
         * `CfnTemplate.PieChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartSortConfigurationProperty.SmallMultiplesLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultipleslimitconfiguration
         */
        readonly smallMultiplesLimitConfiguration?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartSortConfigurationProperty.SmallMultiplesSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartsortconfiguration.html#cfn-quicksight-template-piechartsortconfiguration-smallmultiplessort
         */
        readonly smallMultiplesSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html
     */
    interface PieChartVisualProperty {
        /**
         * `CfnTemplate.PieChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.PieChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PieChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-piechartvisual.html#cfn-quicksight-template-piechartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html
     */
    interface PivotFieldSortOptionsProperty {
        /**
         * `CfnTemplate.PivotFieldSortOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.PivotFieldSortOptionsProperty.SortBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivotfieldsortoptions.html#cfn-quicksight-template-pivotfieldsortoptions-sortby
         */
        readonly sortBy: CfnTemplate.PivotTableSortByProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html
     */
    interface PivotTableAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.PivotTableAggregatedFieldWellsProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-columns
         */
        readonly columns?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableAggregatedFieldWellsProperty.Rows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-rows
         */
        readonly rows?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableaggregatedfieldwells.html#cfn-quicksight-template-pivottableaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html
     */
    interface PivotTableCellConditionalFormattingProperty {
        /**
         * `CfnTemplate.PivotTableCellConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.PivotTableCellConditionalFormattingProperty.Scope`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-scope
         */
        readonly scope?: CfnTemplate.PivotTableConditionalFormattingScopeProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableCellConditionalFormattingProperty.TextFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablecellconditionalformatting.html#cfn-quicksight-template-pivottablecellconditionalformatting-textformat
         */
        readonly textFormat?: CfnTemplate.TextConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html
     */
    interface PivotTableConditionalFormattingProperty {
        /**
         * `CfnTemplate.PivotTableConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformatting.html#cfn-quicksight-template-pivottableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnTemplate.PivotTableConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html
     */
    interface PivotTableConditionalFormattingOptionProperty {
        /**
         * `CfnTemplate.PivotTableConditionalFormattingOptionProperty.Cell`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingoption.html#cfn-quicksight-template-pivottableconditionalformattingoption-cell
         */
        readonly cell?: CfnTemplate.PivotTableCellConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html
     */
    interface PivotTableConditionalFormattingScopeProperty {
        /**
         * `CfnTemplate.PivotTableConditionalFormattingScopeProperty.Role`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconditionalformattingscope.html#cfn-quicksight-template-pivottableconditionalformattingscope-role
         */
        readonly role?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html
     */
    interface PivotTableConfigurationProperty {
        /**
         * `CfnTemplate.PivotTableConfigurationProperty.FieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldoptions
         */
        readonly fieldOptions?: CfnTemplate.PivotTableFieldOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.PivotTableFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableConfigurationProperty.PaginatedReportOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: CfnTemplate.PivotTablePaginatedReportOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.PivotTableSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableConfigurationProperty.TableOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-tableoptions
         */
        readonly tableOptions?: CfnTemplate.PivotTableOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableConfigurationProperty.TotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableconfiguration.html#cfn-quicksight-template-pivottableconfiguration-totaloptions
         */
        readonly totalOptions?: CfnTemplate.PivotTableTotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html
     */
    interface PivotTableDataPathOptionProperty {
        /**
         * `CfnTemplate.PivotTableDataPathOptionProperty.DataPathList`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-datapathlist
         */
        readonly dataPathList: Array<CfnTemplate.DataPathValueProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableDataPathOptionProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabledatapathoption.html#cfn-quicksight-template-pivottabledatapathoption-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html
     */
    interface PivotTableFieldOptionProperty {
        /**
         * `CfnTemplate.PivotTableFieldOptionProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnTemplate.PivotTableFieldOptionProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.PivotTableFieldOptionProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoption.html#cfn-quicksight-template-pivottablefieldoption-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html
     */
    interface PivotTableFieldOptionsProperty {
        /**
         * `CfnTemplate.PivotTableFieldOptionsProperty.DataPathOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-datapathoptions
         */
        readonly dataPathOptions?: Array<CfnTemplate.PivotTableDataPathOptionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableFieldOptionsProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldoptions.html#cfn-quicksight-template-pivottablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<CfnTemplate.PivotTableFieldOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html
     */
    interface PivotTableFieldSubtotalOptionsProperty {
        /**
         * `CfnTemplate.PivotTableFieldSubtotalOptionsProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldsubtotaloptions.html#cfn-quicksight-template-pivottablefieldsubtotaloptions-fieldid
         */
        readonly fieldId?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html
     */
    interface PivotTableFieldWellsProperty {
        /**
         * `CfnTemplate.PivotTableFieldWellsProperty.PivotTableAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablefieldwells.html#cfn-quicksight-template-pivottablefieldwells-pivottableaggregatedfieldwells
         */
        readonly pivotTableAggregatedFieldWells?: CfnTemplate.PivotTableAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html
     */
    interface PivotTableOptionsProperty {
        /**
         * `CfnTemplate.PivotTableOptionsProperty.CellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-cellstyle
         */
        readonly cellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableOptionsProperty.ColumnHeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnheaderstyle
         */
        readonly columnHeaderStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableOptionsProperty.ColumnNamesVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-columnnamesvisibility
         */
        readonly columnNamesVisibility?: string;
        /**
         * `CfnTemplate.PivotTableOptionsProperty.MetricPlacement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-metricplacement
         */
        readonly metricPlacement?: string;
        /**
         * `CfnTemplate.PivotTableOptionsProperty.RowAlternateColorOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: CfnTemplate.RowAlternateColorOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableOptionsProperty.RowFieldNamesStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowfieldnamesstyle
         */
        readonly rowFieldNamesStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableOptionsProperty.RowHeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-rowheaderstyle
         */
        readonly rowHeaderStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableOptionsProperty.SingleMetricVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-singlemetricvisibility
         */
        readonly singleMetricVisibility?: string;
        /**
         * `CfnTemplate.PivotTableOptionsProperty.ToggleButtonsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottableoptions.html#cfn-quicksight-template-pivottableoptions-togglebuttonsvisibility
         */
        readonly toggleButtonsVisibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html
     */
    interface PivotTablePaginatedReportOptionsProperty {
        /**
         * `CfnTemplate.PivotTablePaginatedReportOptionsProperty.OverflowColumnHeaderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * `CfnTemplate.PivotTablePaginatedReportOptionsProperty.VerticalOverflowVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablepaginatedreportoptions.html#cfn-quicksight-template-pivottablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html
     */
    interface PivotTableSortByProperty {
        /**
         * `CfnTemplate.PivotTableSortByProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-column
         */
        readonly column?: CfnTemplate.ColumnSortProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableSortByProperty.DataPath`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-datapath
         */
        readonly dataPath?: CfnTemplate.DataPathSortProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableSortByProperty.Field`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortby.html#cfn-quicksight-template-pivottablesortby-field
         */
        readonly field?: CfnTemplate.FieldSortProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html
     */
    interface PivotTableSortConfigurationProperty {
        /**
         * `CfnTemplate.PivotTableSortConfigurationProperty.FieldSortOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablesortconfiguration.html#cfn-quicksight-template-pivottablesortconfiguration-fieldsortoptions
         */
        readonly fieldSortOptions?: Array<CfnTemplate.PivotFieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html
     */
    interface PivotTableTotalOptionsProperty {
        /**
         * `CfnTemplate.PivotTableTotalOptionsProperty.ColumnSubtotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columnsubtotaloptions
         */
        readonly columnSubtotalOptions?: CfnTemplate.SubtotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableTotalOptionsProperty.ColumnTotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-columntotaloptions
         */
        readonly columnTotalOptions?: CfnTemplate.PivotTotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableTotalOptionsProperty.RowSubtotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowsubtotaloptions
         */
        readonly rowSubtotalOptions?: CfnTemplate.SubtotalOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableTotalOptionsProperty.RowTotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottabletotaloptions.html#cfn-quicksight-template-pivottabletotaloptions-rowtotaloptions
         */
        readonly rowTotalOptions?: CfnTemplate.PivotTotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html
     */
    interface PivotTableVisualProperty {
        /**
         * `CfnTemplate.PivotTableVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.PivotTableConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnTemplate.PivotTableConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTableVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottablevisual.html#cfn-quicksight-template-pivottablevisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html
     */
    interface PivotTotalOptionsProperty {
        /**
         * `CfnTemplate.PivotTotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnTemplate.PivotTotalOptionsProperty.MetricHeaderCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTotalOptionsProperty.Placement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-placement
         */
        readonly placement?: string;
        /**
         * `CfnTemplate.PivotTotalOptionsProperty.ScrollStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * `CfnTemplate.PivotTotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.PivotTotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * `CfnTemplate.PivotTotalOptionsProperty.ValueCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-pivottotaloptions.html#cfn-quicksight-template-pivottotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html
     */
    interface PredefinedHierarchyProperty {
        /**
         * `CfnTemplate.PredefinedHierarchyProperty.Columns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-columns
         */
        readonly columns: Array<CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PredefinedHierarchyProperty.DrillDownFilters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-drilldownfilters
         */
        readonly drillDownFilters?: Array<CfnTemplate.DrillDownFilterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.PredefinedHierarchyProperty.HierarchyId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-predefinedhierarchy.html#cfn-quicksight-template-predefinedhierarchy-hierarchyid
         */
        readonly hierarchyId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html
     */
    interface ProgressBarOptionsProperty {
        /**
         * `CfnTemplate.ProgressBarOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-progressbaroptions.html#cfn-quicksight-template-progressbaroptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html
     */
    interface RadarChartAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.RadarChartAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartAggregatedFieldWellsProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-color
         */
        readonly color?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartaggregatedfieldwells.html#cfn-quicksight-template-radarchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html
     */
    interface RadarChartAreaStyleSettingsProperty {
        /**
         * `CfnTemplate.RadarChartAreaStyleSettingsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartareastylesettings.html#cfn-quicksight-template-radarchartareastylesettings-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html
     */
    interface RadarChartConfigurationProperty {
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.AlternateBandColorsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandcolorsvisibility
         */
        readonly alternateBandColorsVisibility?: string;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.AlternateBandEvenColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandevencolor
         */
        readonly alternateBandEvenColor?: string;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.AlternateBandOddColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-alternatebandoddcolor
         */
        readonly alternateBandOddColor?: string;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.BaseSeriesSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-baseseriessettings
         */
        readonly baseSeriesSettings?: CfnTemplate.RadarChartSeriesSettingsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.CategoryAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categoryaxis
         */
        readonly categoryAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.ColorAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-coloraxis
         */
        readonly colorAxis?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.RadarChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.Shape`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-shape
         */
        readonly shape?: string;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.RadarChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.StartAngle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-startangle
         */
        readonly startAngle?: number;
        /**
         * `CfnTemplate.RadarChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartconfiguration.html#cfn-quicksight-template-radarchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html
     */
    interface RadarChartFieldWellsProperty {
        /**
         * `CfnTemplate.RadarChartFieldWellsProperty.RadarChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartfieldwells.html#cfn-quicksight-template-radarchartfieldwells-radarchartaggregatedfieldwells
         */
        readonly radarChartAggregatedFieldWells?: CfnTemplate.RadarChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html
     */
    interface RadarChartSeriesSettingsProperty {
        /**
         * `CfnTemplate.RadarChartSeriesSettingsProperty.AreaStyleSettings`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartseriessettings.html#cfn-quicksight-template-radarchartseriessettings-areastylesettings
         */
        readonly areaStyleSettings?: CfnTemplate.RadarChartAreaStyleSettingsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html
     */
    interface RadarChartSortConfigurationProperty {
        /**
         * `CfnTemplate.RadarChartSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartSortConfigurationProperty.ColorItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-coloritemslimit
         */
        readonly colorItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartSortConfigurationProperty.ColorSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartsortconfiguration.html#cfn-quicksight-template-radarchartsortconfiguration-colorsort
         */
        readonly colorSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html
     */
    interface RadarChartVisualProperty {
        /**
         * `CfnTemplate.RadarChartVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.RadarChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RadarChartVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-radarchartvisual.html#cfn-quicksight-template-radarchartvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html
     */
    interface RangeEndsLabelTypeProperty {
        /**
         * `CfnTemplate.RangeEndsLabelTypeProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rangeendslabeltype.html#cfn-quicksight-template-rangeendslabeltype-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html
     */
    interface ReferenceLineProperty {
        /**
         * `CfnTemplate.ReferenceLineProperty.DataConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-dataconfiguration
         */
        readonly dataConfiguration: CfnTemplate.ReferenceLineDataConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineProperty.LabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-labelconfiguration
         */
        readonly labelConfiguration?: CfnTemplate.ReferenceLineLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-status
         */
        readonly status?: string;
        /**
         * `CfnTemplate.ReferenceLineProperty.StyleConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referenceline.html#cfn-quicksight-template-referenceline-styleconfiguration
         */
        readonly styleConfiguration?: CfnTemplate.ReferenceLineStyleConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html
     */
    interface ReferenceLineCustomLabelConfigurationProperty {
        /**
         * `CfnTemplate.ReferenceLineCustomLabelConfigurationProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinecustomlabelconfiguration.html#cfn-quicksight-template-referencelinecustomlabelconfiguration-customlabel
         */
        readonly customLabel: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html
     */
    interface ReferenceLineDataConfigurationProperty {
        /**
         * `CfnTemplate.ReferenceLineDataConfigurationProperty.AxisBinding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-axisbinding
         */
        readonly axisBinding?: string;
        /**
         * `CfnTemplate.ReferenceLineDataConfigurationProperty.DynamicConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-dynamicconfiguration
         */
        readonly dynamicConfiguration?: CfnTemplate.ReferenceLineDynamicDataConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineDataConfigurationProperty.StaticConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedataconfiguration.html#cfn-quicksight-template-referencelinedataconfiguration-staticconfiguration
         */
        readonly staticConfiguration?: CfnTemplate.ReferenceLineStaticDataConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html
     */
    interface ReferenceLineDynamicDataConfigurationProperty {
        /**
         * `CfnTemplate.ReferenceLineDynamicDataConfigurationProperty.Calculation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-calculation
         */
        readonly calculation: CfnTemplate.NumericalAggregationFunctionProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineDynamicDataConfigurationProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineDynamicDataConfigurationProperty.MeasureAggregationFunction`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinedynamicdataconfiguration.html#cfn-quicksight-template-referencelinedynamicdataconfiguration-measureaggregationfunction
         */
        readonly measureAggregationFunction: CfnTemplate.AggregationFunctionProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html
     */
    interface ReferenceLineLabelConfigurationProperty {
        /**
         * `CfnTemplate.ReferenceLineLabelConfigurationProperty.CustomLabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-customlabelconfiguration
         */
        readonly customLabelConfiguration?: CfnTemplate.ReferenceLineCustomLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineLabelConfigurationProperty.FontColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontcolor
         */
        readonly fontColor?: string;
        /**
         * `CfnTemplate.ReferenceLineLabelConfigurationProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineLabelConfigurationProperty.HorizontalPosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-horizontalposition
         */
        readonly horizontalPosition?: string;
        /**
         * `CfnTemplate.ReferenceLineLabelConfigurationProperty.ValueLabelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-valuelabelconfiguration
         */
        readonly valueLabelConfiguration?: CfnTemplate.ReferenceLineValueLabelConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineLabelConfigurationProperty.VerticalPosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinelabelconfiguration.html#cfn-quicksight-template-referencelinelabelconfiguration-verticalposition
         */
        readonly verticalPosition?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html
     */
    interface ReferenceLineStaticDataConfigurationProperty {
        /**
         * `CfnTemplate.ReferenceLineStaticDataConfigurationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestaticdataconfiguration.html#cfn-quicksight-template-referencelinestaticdataconfiguration-value
         */
        readonly value: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html
     */
    interface ReferenceLineStyleConfigurationProperty {
        /**
         * `CfnTemplate.ReferenceLineStyleConfigurationProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-color
         */
        readonly color?: string;
        /**
         * `CfnTemplate.ReferenceLineStyleConfigurationProperty.Pattern`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinestyleconfiguration.html#cfn-quicksight-template-referencelinestyleconfiguration-pattern
         */
        readonly pattern?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html
     */
    interface ReferenceLineValueLabelConfigurationProperty {
        /**
         * `CfnTemplate.ReferenceLineValueLabelConfigurationProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.NumericFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ReferenceLineValueLabelConfigurationProperty.RelativePosition`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-referencelinevaluelabelconfiguration.html#cfn-quicksight-template-referencelinevaluelabelconfiguration-relativeposition
         */
        readonly relativePosition?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html
     */
    interface RelativeDateTimeControlDisplayOptionsProperty {
        /**
         * `CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty.DateTimeFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-datetimeformat
         */
        readonly dateTimeFormat?: string;
        /**
         * `CfnTemplate.RelativeDateTimeControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatetimecontroldisplayoptions.html#cfn-quicksight-template-relativedatetimecontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html
     */
    interface RelativeDatesFilterProperty {
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.AnchorDateConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-anchordateconfiguration
         */
        readonly anchorDateConfiguration: CfnTemplate.AnchorDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.ExcludePeriodConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnTemplate.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.MinimumGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-minimumgranularity
         */
        readonly minimumGranularity?: string;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.RelativeDateType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatetype
         */
        readonly relativeDateType: string;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.RelativeDateValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-relativedatevalue
         */
        readonly relativeDateValue?: number;
        /**
         * `CfnTemplate.RelativeDatesFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-relativedatesfilter.html#cfn-quicksight-template-relativedatesfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-actions
         */
        readonly actions: string[];
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-principal
         */
        readonly principal: string;
        /**
         * `CfnTemplate.ResourcePermissionProperty.Resource`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-resourcepermission.html#cfn-quicksight-template-resourcepermission-resource
         */
        readonly resource?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html
     */
    interface RollingDateConfigurationProperty {
        /**
         * `CfnTemplate.RollingDateConfigurationProperty.DataSetIdentifier`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-datasetidentifier
         */
        readonly dataSetIdentifier?: string;
        /**
         * `CfnTemplate.RollingDateConfigurationProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rollingdateconfiguration.html#cfn-quicksight-template-rollingdateconfiguration-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html
     */
    interface RowAlternateColorOptionsProperty {
        /**
         * `CfnTemplate.RowAlternateColorOptionsProperty.RowAlternateColors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-rowalternatecolors
         */
        readonly rowAlternateColors?: string[];
        /**
         * `CfnTemplate.RowAlternateColorOptionsProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-rowalternatecoloroptions.html#cfn-quicksight-template-rowalternatecoloroptions-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html
     */
    interface SameSheetTargetVisualConfigurationProperty {
        /**
         * `CfnTemplate.SameSheetTargetVisualConfigurationProperty.TargetVisualOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisualoptions
         */
        readonly targetVisualOptions?: string;
        /**
         * `CfnTemplate.SameSheetTargetVisualConfigurationProperty.TargetVisuals`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-samesheettargetvisualconfiguration.html#cfn-quicksight-template-samesheettargetvisualconfiguration-targetvisuals
         */
        readonly targetVisuals?: string[];
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html
     */
    interface SankeyDiagramAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty.Destination`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-destination
         */
        readonly destination?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty.Source`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-source
         */
        readonly source?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty.Weight`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramaggregatedfieldwells.html#cfn-quicksight-template-sankeydiagramaggregatedfieldwells-weight
         */
        readonly weight?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html
     */
    interface SankeyDiagramChartConfigurationProperty {
        /**
         * `CfnTemplate.SankeyDiagramChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.SankeyDiagramFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramchartconfiguration.html#cfn-quicksight-template-sankeydiagramchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.SankeyDiagramSortConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html
     */
    interface SankeyDiagramFieldWellsProperty {
        /**
         * `CfnTemplate.SankeyDiagramFieldWellsProperty.SankeyDiagramAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramfieldwells.html#cfn-quicksight-template-sankeydiagramfieldwells-sankeydiagramaggregatedfieldwells
         */
        readonly sankeyDiagramAggregatedFieldWells?: CfnTemplate.SankeyDiagramAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html
     */
    interface SankeyDiagramSortConfigurationProperty {
        /**
         * `CfnTemplate.SankeyDiagramSortConfigurationProperty.DestinationItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-destinationitemslimit
         */
        readonly destinationItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramSortConfigurationProperty.SourceItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-sourceitemslimit
         */
        readonly sourceItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramSortConfigurationProperty.WeightSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramsortconfiguration.html#cfn-quicksight-template-sankeydiagramsortconfiguration-weightsort
         */
        readonly weightSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html
     */
    interface SankeyDiagramVisualProperty {
        /**
         * `CfnTemplate.SankeyDiagramVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.SankeyDiagramChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SankeyDiagramVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sankeydiagramvisual.html#cfn-quicksight-template-sankeydiagramvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html
     */
    interface ScatterPlotCategoricallyAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-category
         */
        readonly category?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-size
         */
        readonly size?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty.XAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty.YAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotcategoricallyaggregatedfieldwells.html#cfn-quicksight-template-scatterplotcategoricallyaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html
     */
    interface ScatterPlotConfigurationProperty {
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.ScatterPlotFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.XAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxisdisplayoptions
         */
        readonly xAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.XAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-xaxislabeloptions
         */
        readonly xAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.YAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxisdisplayoptions
         */
        readonly yAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotConfigurationProperty.YAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotconfiguration.html#cfn-quicksight-template-scatterplotconfiguration-yaxislabeloptions
         */
        readonly yAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html
     */
    interface ScatterPlotFieldWellsProperty {
        /**
         * `CfnTemplate.ScatterPlotFieldWellsProperty.ScatterPlotCategoricallyAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotcategoricallyaggregatedfieldwells
         */
        readonly scatterPlotCategoricallyAggregatedFieldWells?: CfnTemplate.ScatterPlotCategoricallyAggregatedFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotFieldWellsProperty.ScatterPlotUnaggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotfieldwells.html#cfn-quicksight-template-scatterplotfieldwells-scatterplotunaggregatedfieldwells
         */
        readonly scatterPlotUnaggregatedFieldWells?: CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html
     */
    interface ScatterPlotUnaggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-size
         */
        readonly size?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty.XAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-xaxis
         */
        readonly xAxis?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotUnaggregatedFieldWellsProperty.YAxis`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotunaggregatedfieldwells.html#cfn-quicksight-template-scatterplotunaggregatedfieldwells-yaxis
         */
        readonly yAxis?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html
     */
    interface ScatterPlotVisualProperty {
        /**
         * `CfnTemplate.ScatterPlotVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.ScatterPlotConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.ScatterPlotVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scatterplotvisual.html#cfn-quicksight-template-scatterplotvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html
     */
    interface ScrollBarOptionsProperty {
        /**
         * `CfnTemplate.ScrollBarOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnTemplate.ScrollBarOptionsProperty.VisibleRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-scrollbaroptions.html#cfn-quicksight-template-scrollbaroptions-visiblerange
         */
        readonly visibleRange?: CfnTemplate.VisibleRangeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html
     */
    interface SecondaryValueOptionsProperty {
        /**
         * `CfnTemplate.SecondaryValueOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-secondaryvalueoptions.html#cfn-quicksight-template-secondaryvalueoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html
     */
    interface SectionAfterPageBreakProperty {
        /**
         * `CfnTemplate.SectionAfterPageBreakProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionafterpagebreak.html#cfn-quicksight-template-sectionafterpagebreak-status
         */
        readonly status?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html
     */
    interface SectionBasedLayoutCanvasSizeOptionsProperty {
        /**
         * `CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty.PaperCanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutcanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutcanvassizeoptions-papercanvassizeoptions
         */
        readonly paperCanvasSizeOptions?: CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html
     */
    interface SectionBasedLayoutConfigurationProperty {
        /**
         * `CfnTemplate.SectionBasedLayoutConfigurationProperty.BodySections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-bodysections
         */
        readonly bodySections: Array<CfnTemplate.BodySectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SectionBasedLayoutConfigurationProperty.CanvasSizeOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-canvassizeoptions
         */
        readonly canvasSizeOptions: CfnTemplate.SectionBasedLayoutCanvasSizeOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SectionBasedLayoutConfigurationProperty.FooterSections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-footersections
         */
        readonly footerSections: Array<CfnTemplate.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SectionBasedLayoutConfigurationProperty.HeaderSections`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutconfiguration.html#cfn-quicksight-template-sectionbasedlayoutconfiguration-headersections
         */
        readonly headerSections: Array<CfnTemplate.HeaderFooterSectionConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html
     */
    interface SectionBasedLayoutPaperCanvasSizeOptionsProperty {
        /**
         * `CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperMargin`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papermargin
         */
        readonly paperMargin?: CfnTemplate.SpacingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperOrientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-paperorientation
         */
        readonly paperOrientation?: string;
        /**
         * `CfnTemplate.SectionBasedLayoutPaperCanvasSizeOptionsProperty.PaperSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionbasedlayoutpapercanvassizeoptions.html#cfn-quicksight-template-sectionbasedlayoutpapercanvassizeoptions-papersize
         */
        readonly paperSize?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html
     */
    interface SectionLayoutConfigurationProperty {
        /**
         * `CfnTemplate.SectionLayoutConfigurationProperty.FreeFormLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionlayoutconfiguration.html#cfn-quicksight-template-sectionlayoutconfiguration-freeformlayout
         */
        readonly freeFormLayout: CfnTemplate.FreeFormSectionLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html
     */
    interface SectionPageBreakConfigurationProperty {
        /**
         * `CfnTemplate.SectionPageBreakConfigurationProperty.After`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionpagebreakconfiguration.html#cfn-quicksight-template-sectionpagebreakconfiguration-after
         */
        readonly after?: CfnTemplate.SectionAfterPageBreakProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html
     */
    interface SectionStyleProperty {
        /**
         * `CfnTemplate.SectionStyleProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-height
         */
        readonly height?: string;
        /**
         * `CfnTemplate.SectionStyleProperty.Padding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sectionstyle.html#cfn-quicksight-template-sectionstyle-padding
         */
        readonly padding?: CfnTemplate.SpacingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html
     */
    interface SelectedSheetsFilterScopeConfigurationProperty {
        /**
         * `CfnTemplate.SelectedSheetsFilterScopeConfigurationProperty.SheetVisualScopingConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-selectedsheetsfilterscopeconfiguration.html#cfn-quicksight-template-selectedsheetsfilterscopeconfiguration-sheetvisualscopingconfigurations
         */
        readonly sheetVisualScopingConfigurations?: Array<CfnTemplate.SheetVisualScopingConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html
     */
    interface SeriesItemProperty {
        /**
         * `CfnTemplate.SeriesItemProperty.DataFieldSeriesItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-datafieldseriesitem
         */
        readonly dataFieldSeriesItem?: CfnTemplate.DataFieldSeriesItemProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SeriesItemProperty.FieldSeriesItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-seriesitem.html#cfn-quicksight-template-seriesitem-fieldseriesitem
         */
        readonly fieldSeriesItem?: CfnTemplate.FieldSeriesItemProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html
     */
    interface SetParameterValueConfigurationProperty {
        /**
         * `CfnTemplate.SetParameterValueConfigurationProperty.DestinationParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-destinationparametername
         */
        readonly destinationParameterName: string;
        /**
         * `CfnTemplate.SetParameterValueConfigurationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-setparametervalueconfiguration.html#cfn-quicksight-template-setparametervalueconfiguration-value
         */
        readonly value: CfnTemplate.DestinationParameterValueConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html
     */
    interface ShapeConditionalFormatProperty {
        /**
         * `CfnTemplate.ShapeConditionalFormatProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shapeconditionalformat.html#cfn-quicksight-template-shapeconditionalformat-backgroundcolor
         */
        readonly backgroundColor: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     * A *sheet* , which is an object that contains a set of visuals that are viewed together on one page in Amazon QuickSight. Every analysis and dashboard contains at least one sheet. Each sheet contains at least one visualization widget, for example a chart, pivot table, or narrative insight. Sheets can be associated with other components, such as controls, filters, and so on.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html
     */
    interface SheetProperty {
        /**
         * The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-name
         */
        readonly name?: string;
        /**
         * The unique identifier associated with a sheet.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheet.html#cfn-quicksight-template-sheet-sheetid
         */
        readonly sheetId?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html
     */
    interface SheetControlLayoutProperty {
        /**
         * `CfnTemplate.SheetControlLayoutProperty.Configuration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayout.html#cfn-quicksight-template-sheetcontrollayout-configuration
         */
        readonly configuration: CfnTemplate.SheetControlLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html
     */
    interface SheetControlLayoutConfigurationProperty {
        /**
         * `CfnTemplate.SheetControlLayoutConfigurationProperty.GridLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetcontrollayoutconfiguration.html#cfn-quicksight-template-sheetcontrollayoutconfiguration-gridlayout
         */
        readonly gridLayout?: CfnTemplate.GridLayoutConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html
     */
    interface SheetDefinitionProperty {
        /**
         * `CfnTemplate.SheetDefinitionProperty.ContentType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-contenttype
         */
        readonly contentType?: string;
        /**
         * `CfnTemplate.SheetDefinitionProperty.Description`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-description
         */
        readonly description?: string;
        /**
         * `CfnTemplate.SheetDefinitionProperty.FilterControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-filtercontrols
         */
        readonly filterControls?: Array<CfnTemplate.FilterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SheetDefinitionProperty.Layouts`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-layouts
         */
        readonly layouts?: Array<CfnTemplate.LayoutProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SheetDefinitionProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.SheetDefinitionProperty.ParameterControls`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-parametercontrols
         */
        readonly parameterControls?: Array<CfnTemplate.ParameterControlProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SheetDefinitionProperty.SheetControlLayouts`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetcontrollayouts
         */
        readonly sheetControlLayouts?: Array<CfnTemplate.SheetControlLayoutProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SheetDefinitionProperty.SheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-sheetid
         */
        readonly sheetId: string;
        /**
         * `CfnTemplate.SheetDefinitionProperty.TextBoxes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-textboxes
         */
        readonly textBoxes?: Array<CfnTemplate.SheetTextBoxProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SheetDefinitionProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-title
         */
        readonly title?: string;
        /**
         * `CfnTemplate.SheetDefinitionProperty.Visuals`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetdefinition.html#cfn-quicksight-template-sheetdefinition-visuals
         */
        readonly visuals?: Array<CfnTemplate.VisualProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html
     */
    interface SheetElementConfigurationOverridesProperty {
        /**
         * `CfnTemplate.SheetElementConfigurationOverridesProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementconfigurationoverrides.html#cfn-quicksight-template-sheetelementconfigurationoverrides-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html
     */
    interface SheetElementRenderingRuleProperty {
        /**
         * `CfnTemplate.SheetElementRenderingRuleProperty.ConfigurationOverrides`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-configurationoverrides
         */
        readonly configurationOverrides: CfnTemplate.SheetElementConfigurationOverridesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SheetElementRenderingRuleProperty.Expression`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetelementrenderingrule.html#cfn-quicksight-template-sheetelementrenderingrule-expression
         */
        readonly expression: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html
     */
    interface SheetTextBoxProperty {
        /**
         * `CfnTemplate.SheetTextBoxProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-content
         */
        readonly content?: string;
        /**
         * `CfnTemplate.SheetTextBoxProperty.SheetTextBoxId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheettextbox.html#cfn-quicksight-template-sheettextbox-sheettextboxid
         */
        readonly sheetTextBoxId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html
     */
    interface SheetVisualScopingConfigurationProperty {
        /**
         * `CfnTemplate.SheetVisualScopingConfigurationProperty.Scope`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-scope
         */
        readonly scope: string;
        /**
         * `CfnTemplate.SheetVisualScopingConfigurationProperty.SheetId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-sheetid
         */
        readonly sheetId: string;
        /**
         * `CfnTemplate.SheetVisualScopingConfigurationProperty.VisualIds`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-sheetvisualscopingconfiguration.html#cfn-quicksight-template-sheetvisualscopingconfiguration-visualids
         */
        readonly visualIds?: string[];
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html
     */
    interface ShortFormatTextProperty {
        /**
         * `CfnTemplate.ShortFormatTextProperty.PlainText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-plaintext
         */
        readonly plainText?: string;
        /**
         * `CfnTemplate.ShortFormatTextProperty.RichText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-shortformattext.html#cfn-quicksight-template-shortformattext-richtext
         */
        readonly richText?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html
     */
    interface SimpleClusterMarkerProperty {
        /**
         * `CfnTemplate.SimpleClusterMarkerProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-simpleclustermarker.html#cfn-quicksight-template-simpleclustermarker-color
         */
        readonly color?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html
     */
    interface SliderControlDisplayOptionsProperty {
        /**
         * `CfnTemplate.SliderControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-slidercontroldisplayoptions.html#cfn-quicksight-template-slidercontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html
     */
    interface SmallMultiplesOptionsProperty {
        /**
         * `CfnTemplate.SmallMultiplesOptionsProperty.MaxVisibleColumns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblecolumns
         */
        readonly maxVisibleColumns?: number;
        /**
         * `CfnTemplate.SmallMultiplesOptionsProperty.MaxVisibleRows`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-maxvisiblerows
         */
        readonly maxVisibleRows?: number;
        /**
         * `CfnTemplate.SmallMultiplesOptionsProperty.PanelConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-smallmultiplesoptions.html#cfn-quicksight-template-smallmultiplesoptions-panelconfiguration
         */
        readonly panelConfiguration?: CfnTemplate.PanelConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html
     */
    interface SpacingProperty {
        /**
         * `CfnTemplate.SpacingProperty.Bottom`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-bottom
         */
        readonly bottom?: string;
        /**
         * `CfnTemplate.SpacingProperty.Left`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-left
         */
        readonly left?: string;
        /**
         * `CfnTemplate.SpacingProperty.Right`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-right
         */
        readonly right?: string;
        /**
         * `CfnTemplate.SpacingProperty.Top`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-spacing.html#cfn-quicksight-template-spacing-top
         */
        readonly top?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html
     */
    interface StringDefaultValuesProperty {
        /**
         * `CfnTemplate.StringDefaultValuesProperty.DynamicValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-dynamicvalue
         */
        readonly dynamicValue?: CfnTemplate.DynamicDefaultValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.StringDefaultValuesProperty.StaticValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringdefaultvalues.html#cfn-quicksight-template-stringdefaultvalues-staticvalues
         */
        readonly staticValues?: string[];
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html
     */
    interface StringFormatConfigurationProperty {
        /**
         * `CfnTemplate.StringFormatConfigurationProperty.NullValueFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-nullvalueformatconfiguration
         */
        readonly nullValueFormatConfiguration?: CfnTemplate.NullValueFormatConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.StringFormatConfigurationProperty.NumericFormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringformatconfiguration.html#cfn-quicksight-template-stringformatconfiguration-numericformatconfiguration
         */
        readonly numericFormatConfiguration?: CfnTemplate.NumericFormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html
     */
    interface StringParameterDeclarationProperty {
        /**
         * `CfnTemplate.StringParameterDeclarationProperty.DefaultValues`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-defaultvalues
         */
        readonly defaultValues?: CfnTemplate.StringDefaultValuesProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.StringParameterDeclarationProperty.MappedDataSetParameters`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-mappeddatasetparameters
         */
        readonly mappedDataSetParameters?: Array<CfnTemplate.MappedDataSetParameterProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.StringParameterDeclarationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-name
         */
        readonly name: string;
        /**
         * `CfnTemplate.StringParameterDeclarationProperty.ParameterValueType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-parametervaluetype
         */
        readonly parameterValueType: string;
        /**
         * `CfnTemplate.StringParameterDeclarationProperty.ValueWhenUnset`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringparameterdeclaration.html#cfn-quicksight-template-stringparameterdeclaration-valuewhenunset
         */
        readonly valueWhenUnset?: CfnTemplate.StringValueWhenUnsetConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html
     */
    interface StringValueWhenUnsetConfigurationProperty {
        /**
         * `CfnTemplate.StringValueWhenUnsetConfigurationProperty.CustomValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-customvalue
         */
        readonly customValue?: string;
        /**
         * `CfnTemplate.StringValueWhenUnsetConfigurationProperty.ValueWhenUnsetOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-stringvaluewhenunsetconfiguration.html#cfn-quicksight-template-stringvaluewhenunsetconfiguration-valuewhenunsetoption
         */
        readonly valueWhenUnsetOption?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html
     */
    interface SubtotalOptionsProperty {
        /**
         * `CfnTemplate.SubtotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnTemplate.SubtotalOptionsProperty.FieldLevel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldlevel
         */
        readonly fieldLevel?: string;
        /**
         * `CfnTemplate.SubtotalOptionsProperty.FieldLevelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-fieldleveloptions
         */
        readonly fieldLevelOptions?: Array<CfnTemplate.PivotTableFieldSubtotalOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.SubtotalOptionsProperty.MetricHeaderCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-metricheadercellstyle
         */
        readonly metricHeaderCellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SubtotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.SubtotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
        /**
         * `CfnTemplate.SubtotalOptionsProperty.ValueCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-subtotaloptions.html#cfn-quicksight-template-subtotaloptions-valuecellstyle
         */
        readonly valueCellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html
     */
    interface TableAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.TableAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TableAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableaggregatedfieldwells.html#cfn-quicksight-template-tableaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html
     */
    interface TableBorderOptionsProperty {
        /**
         * `CfnTemplate.TableBorderOptionsProperty.Color`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-color
         */
        readonly color?: string;
        /**
         * `CfnTemplate.TableBorderOptionsProperty.Style`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-style
         */
        readonly style?: string;
        /**
         * `CfnTemplate.TableBorderOptionsProperty.Thickness`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableborderoptions.html#cfn-quicksight-template-tableborderoptions-thickness
         */
        readonly thickness?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html
     */
    interface TableCellConditionalFormattingProperty {
        /**
         * `CfnTemplate.TableCellConditionalFormattingProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.TableCellConditionalFormattingProperty.TextFormat`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellconditionalformatting.html#cfn-quicksight-template-tablecellconditionalformatting-textformat
         */
        readonly textFormat?: CfnTemplate.TextConditionalFormatProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html
     */
    interface TableCellImageSizingConfigurationProperty {
        /**
         * `CfnTemplate.TableCellImageSizingConfigurationProperty.TableCellImageScalingConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellimagesizingconfiguration.html#cfn-quicksight-template-tablecellimagesizingconfiguration-tablecellimagescalingconfiguration
         */
        readonly tableCellImageScalingConfiguration?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html
     */
    interface TableCellStyleProperty {
        /**
         * `CfnTemplate.TableCellStyleProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-backgroundcolor
         */
        readonly backgroundColor?: string;
        /**
         * `CfnTemplate.TableCellStyleProperty.Border`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-border
         */
        readonly border?: CfnTemplate.GlobalTableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableCellStyleProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-fontconfiguration
         */
        readonly fontConfiguration?: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableCellStyleProperty.Height`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-height
         */
        readonly height?: number;
        /**
         * `CfnTemplate.TableCellStyleProperty.HorizontalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-horizontaltextalignment
         */
        readonly horizontalTextAlignment?: string;
        /**
         * `CfnTemplate.TableCellStyleProperty.TextWrap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-textwrap
         */
        readonly textWrap?: string;
        /**
         * `CfnTemplate.TableCellStyleProperty.VerticalTextAlignment`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-verticaltextalignment
         */
        readonly verticalTextAlignment?: string;
        /**
         * `CfnTemplate.TableCellStyleProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablecellstyle.html#cfn-quicksight-template-tablecellstyle-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html
     */
    interface TableConditionalFormattingProperty {
        /**
         * `CfnTemplate.TableConditionalFormattingProperty.ConditionalFormattingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformatting.html#cfn-quicksight-template-tableconditionalformatting-conditionalformattingoptions
         */
        readonly conditionalFormattingOptions?: Array<CfnTemplate.TableConditionalFormattingOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html
     */
    interface TableConditionalFormattingOptionProperty {
        /**
         * `CfnTemplate.TableConditionalFormattingOptionProperty.Cell`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-cell
         */
        readonly cell?: CfnTemplate.TableCellConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableConditionalFormattingOptionProperty.Row`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconditionalformattingoption.html#cfn-quicksight-template-tableconditionalformattingoption-row
         */
        readonly row?: CfnTemplate.TableRowConditionalFormattingProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html
     */
    interface TableConfigurationProperty {
        /**
         * `CfnTemplate.TableConfigurationProperty.FieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldoptions
         */
        readonly fieldOptions?: CfnTemplate.TableFieldOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.TableFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableConfigurationProperty.PaginatedReportOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-paginatedreportoptions
         */
        readonly paginatedReportOptions?: CfnTemplate.TablePaginatedReportOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.TableSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableConfigurationProperty.TableInlineVisualizations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableinlinevisualizations
         */
        readonly tableInlineVisualizations?: Array<CfnTemplate.TableInlineVisualizationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TableConfigurationProperty.TableOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-tableoptions
         */
        readonly tableOptions?: CfnTemplate.TableOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableConfigurationProperty.TotalOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableconfiguration.html#cfn-quicksight-template-tableconfiguration-totaloptions
         */
        readonly totalOptions?: CfnTemplate.TotalOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html
     */
    interface TableFieldCustomIconContentProperty {
        /**
         * `CfnTemplate.TableFieldCustomIconContentProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomiconcontent.html#cfn-quicksight-template-tablefieldcustomiconcontent-icon
         */
        readonly icon?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html
     */
    interface TableFieldCustomTextContentProperty {
        /**
         * `CfnTemplate.TableFieldCustomTextContentProperty.FontConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-fontconfiguration
         */
        readonly fontConfiguration: CfnTemplate.FontConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableFieldCustomTextContentProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldcustomtextcontent.html#cfn-quicksight-template-tablefieldcustomtextcontent-value
         */
        readonly value?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html
     */
    interface TableFieldImageConfigurationProperty {
        /**
         * `CfnTemplate.TableFieldImageConfigurationProperty.SizingOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldimageconfiguration.html#cfn-quicksight-template-tablefieldimageconfiguration-sizingoptions
         */
        readonly sizingOptions?: CfnTemplate.TableCellImageSizingConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html
     */
    interface TableFieldLinkConfigurationProperty {
        /**
         * `CfnTemplate.TableFieldLinkConfigurationProperty.Content`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-content
         */
        readonly content: CfnTemplate.TableFieldLinkContentConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableFieldLinkConfigurationProperty.Target`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkconfiguration.html#cfn-quicksight-template-tablefieldlinkconfiguration-target
         */
        readonly target: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html
     */
    interface TableFieldLinkContentConfigurationProperty {
        /**
         * `CfnTemplate.TableFieldLinkContentConfigurationProperty.CustomIconContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customiconcontent
         */
        readonly customIconContent?: CfnTemplate.TableFieldCustomIconContentProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableFieldLinkContentConfigurationProperty.CustomTextContent`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldlinkcontentconfiguration.html#cfn-quicksight-template-tablefieldlinkcontentconfiguration-customtextcontent
         */
        readonly customTextContent?: CfnTemplate.TableFieldCustomTextContentProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html
     */
    interface TableFieldOptionProperty {
        /**
         * `CfnTemplate.TableFieldOptionProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnTemplate.TableFieldOptionProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.TableFieldOptionProperty.URLStyling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-urlstyling
         */
        readonly urlStyling?: CfnTemplate.TableFieldURLConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableFieldOptionProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-visibility
         */
        readonly visibility?: string;
        /**
         * `CfnTemplate.TableFieldOptionProperty.Width`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoption.html#cfn-quicksight-template-tablefieldoption-width
         */
        readonly width?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html
     */
    interface TableFieldOptionsProperty {
        /**
         * `CfnTemplate.TableFieldOptionsProperty.Order`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-order
         */
        readonly order?: string[];
        /**
         * `CfnTemplate.TableFieldOptionsProperty.SelectedFieldOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldoptions.html#cfn-quicksight-template-tablefieldoptions-selectedfieldoptions
         */
        readonly selectedFieldOptions?: Array<CfnTemplate.TableFieldOptionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html
     */
    interface TableFieldURLConfigurationProperty {
        /**
         * `CfnTemplate.TableFieldURLConfigurationProperty.ImageConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-imageconfiguration
         */
        readonly imageConfiguration?: CfnTemplate.TableFieldImageConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableFieldURLConfigurationProperty.LinkConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldurlconfiguration.html#cfn-quicksight-template-tablefieldurlconfiguration-linkconfiguration
         */
        readonly linkConfiguration?: CfnTemplate.TableFieldLinkConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html
     */
    interface TableFieldWellsProperty {
        /**
         * `CfnTemplate.TableFieldWellsProperty.TableAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableaggregatedfieldwells
         */
        readonly tableAggregatedFieldWells?: CfnTemplate.TableAggregatedFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableFieldWellsProperty.TableUnaggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablefieldwells.html#cfn-quicksight-template-tablefieldwells-tableunaggregatedfieldwells
         */
        readonly tableUnaggregatedFieldWells?: CfnTemplate.TableUnaggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html
     */
    interface TableInlineVisualizationProperty {
        /**
         * `CfnTemplate.TableInlineVisualizationProperty.DataBars`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableinlinevisualization.html#cfn-quicksight-template-tableinlinevisualization-databars
         */
        readonly dataBars?: CfnTemplate.DataBarsOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html
     */
    interface TableOptionsProperty {
        /**
         * `CfnTemplate.TableOptionsProperty.CellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-cellstyle
         */
        readonly cellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableOptionsProperty.HeaderStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-headerstyle
         */
        readonly headerStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableOptionsProperty.Orientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-orientation
         */
        readonly orientation?: string;
        /**
         * `CfnTemplate.TableOptionsProperty.RowAlternateColorOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableoptions.html#cfn-quicksight-template-tableoptions-rowalternatecoloroptions
         */
        readonly rowAlternateColorOptions?: CfnTemplate.RowAlternateColorOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html
     */
    interface TablePaginatedReportOptionsProperty {
        /**
         * `CfnTemplate.TablePaginatedReportOptionsProperty.OverflowColumnHeaderVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-overflowcolumnheadervisibility
         */
        readonly overflowColumnHeaderVisibility?: string;
        /**
         * `CfnTemplate.TablePaginatedReportOptionsProperty.VerticalOverflowVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablepaginatedreportoptions.html#cfn-quicksight-template-tablepaginatedreportoptions-verticaloverflowvisibility
         */
        readonly verticalOverflowVisibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html
     */
    interface TableRowConditionalFormattingProperty {
        /**
         * `CfnTemplate.TableRowConditionalFormattingProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-backgroundcolor
         */
        readonly backgroundColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableRowConditionalFormattingProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablerowconditionalformatting.html#cfn-quicksight-template-tablerowconditionalformatting-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html
     */
    interface TableSideBorderOptionsProperty {
        /**
         * `CfnTemplate.TableSideBorderOptionsProperty.Bottom`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-bottom
         */
        readonly bottom?: CfnTemplate.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableSideBorderOptionsProperty.InnerHorizontal`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innerhorizontal
         */
        readonly innerHorizontal?: CfnTemplate.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableSideBorderOptionsProperty.InnerVertical`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-innervertical
         */
        readonly innerVertical?: CfnTemplate.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableSideBorderOptionsProperty.Left`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-left
         */
        readonly left?: CfnTemplate.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableSideBorderOptionsProperty.Right`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-right
         */
        readonly right?: CfnTemplate.TableBorderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableSideBorderOptionsProperty.Top`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesideborderoptions.html#cfn-quicksight-template-tablesideborderoptions-top
         */
        readonly top?: CfnTemplate.TableBorderOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html
     */
    interface TableSortConfigurationProperty {
        /**
         * `CfnTemplate.TableSortConfigurationProperty.PaginationConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-paginationconfiguration
         */
        readonly paginationConfiguration?: CfnTemplate.PaginationConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableSortConfigurationProperty.RowSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablesortconfiguration.html#cfn-quicksight-template-tablesortconfiguration-rowsort
         */
        readonly rowSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html
     */
    interface TableUnaggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.TableUnaggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tableunaggregatedfieldwells.html#cfn-quicksight-template-tableunaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.UnaggregatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html
     */
    interface TableVisualProperty {
        /**
         * `CfnTemplate.TableVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TableVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.TableConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableVisualProperty.ConditionalFormatting`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-conditionalformatting
         */
        readonly conditionalFormatting?: CfnTemplate.TableConditionalFormattingProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TableVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tablevisual.html#cfn-quicksight-template-tablevisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * List of errors that occurred when the template version creation failed.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html
     */
    interface TemplateErrorProperty {
        /**
         * Description of the error type.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-message
         */
        readonly message?: string;
        /**
         * Type of error.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-type
         */
        readonly type?: string;
        /**
         * `CfnTemplate.TemplateErrorProperty.ViolatedEntities`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateerror.html#cfn-quicksight-template-templateerror-violatedentities
         */
        readonly violatedEntities?: Array<CfnTemplate.EntityProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     * The source analysis of the template.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html
     */
    interface TemplateSourceAnalysisProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-arn
         */
        readonly arn: string;
        /**
         * A structure containing information about the dataset references used as placeholders in the template.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceanalysis.html#cfn-quicksight-template-templatesourceanalysis-datasetreferences
         */
        readonly dataSetReferences: Array<CfnTemplate.DataSetReferenceProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     * The source entity of the template.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html
     */
    interface TemplateSourceEntityProperty {
        /**
         * The source analysis, if it is based on an analysis.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourceanalysis
         */
        readonly sourceAnalysis?: CfnTemplate.TemplateSourceAnalysisProperty | cdk.IResolvable;
        /**
         * The source template, if it is based on an template.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourceentity.html#cfn-quicksight-template-templatesourceentity-sourcetemplate
         */
        readonly sourceTemplate?: CfnTemplate.TemplateSourceTemplateProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     * The source template of the template.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html
     */
    interface TemplateSourceTemplateProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templatesourcetemplate.html#cfn-quicksight-template-templatesourcetemplate-arn
         */
        readonly arn: string;
    }
}
export declare namespace CfnTemplate {
    /**
     * A version of a template.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html
     */
    interface TemplateVersionProperty {
        /**
         * The time that this template version was created.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-createdtime
         */
        readonly createdTime?: string;
        /**
         * Schema of the dataset identified by the placeholder. Any dashboard created from this template should be bound to new datasets matching the same schema described through this API operation.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-datasetconfigurations
         */
        readonly dataSetConfigurations?: Array<CfnTemplate.DataSetConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The description of the template.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-description
         */
        readonly description?: string;
        /**
         * Errors associated with this template version.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-errors
         */
        readonly errors?: Array<CfnTemplate.TemplateErrorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * A list of the associated sheets with the unique identifier and name of each sheet.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sheets
         */
        readonly sheets?: Array<CfnTemplate.SheetProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The Amazon Resource Name (ARN) of an analysis or template that was used to create this template.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-sourceentityarn
         */
        readonly sourceEntityArn?: string;
        /**
         * The status that is associated with the template.
         *
         * - `CREATION_IN_PROGRESS`
         * - `CREATION_SUCCESSFUL`
         * - `CREATION_FAILED`
         * - `UPDATE_IN_PROGRESS`
         * - `UPDATE_SUCCESSFUL`
         * - `UPDATE_FAILED`
         * - `DELETED`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-status
         */
        readonly status?: string;
        /**
         * The ARN of the theme associated with this version of the template.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-themearn
         */
        readonly themeArn?: string;
        /**
         * The version number of the template version.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversion.html#cfn-quicksight-template-templateversion-versionnumber
         */
        readonly versionNumber?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html
     */
    interface TemplateVersionDefinitionProperty {
        /**
         * `CfnTemplate.TemplateVersionDefinitionProperty.AnalysisDefaults`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-analysisdefaults
         */
        readonly analysisDefaults?: CfnTemplate.AnalysisDefaultsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TemplateVersionDefinitionProperty.CalculatedFields`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-calculatedfields
         */
        readonly calculatedFields?: Array<CfnTemplate.CalculatedFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TemplateVersionDefinitionProperty.ColumnConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-columnconfigurations
         */
        readonly columnConfigurations?: Array<CfnTemplate.ColumnConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TemplateVersionDefinitionProperty.DataSetConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-datasetconfigurations
         */
        readonly dataSetConfigurations: Array<CfnTemplate.DataSetConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TemplateVersionDefinitionProperty.FilterGroups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-filtergroups
         */
        readonly filterGroups?: Array<CfnTemplate.FilterGroupProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TemplateVersionDefinitionProperty.ParameterDeclarations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-parameterdeclarations
         */
        readonly parameterDeclarations?: Array<CfnTemplate.ParameterDeclarationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TemplateVersionDefinitionProperty.Sheets`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-templateversiondefinition.html#cfn-quicksight-template-templateversiondefinition-sheets
         */
        readonly sheets?: Array<CfnTemplate.SheetDefinitionProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html
     */
    interface TextAreaControlDisplayOptionsProperty {
        /**
         * `CfnTemplate.TextAreaControlDisplayOptionsProperty.PlaceholderOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: CfnTemplate.TextControlPlaceholderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TextAreaControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textareacontroldisplayoptions.html#cfn-quicksight-template-textareacontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html
     */
    interface TextConditionalFormatProperty {
        /**
         * `CfnTemplate.TextConditionalFormatProperty.BackgroundColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-backgroundcolor
         */
        readonly backgroundColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TextConditionalFormatProperty.Icon`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-icon
         */
        readonly icon?: CfnTemplate.ConditionalFormattingIconProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TextConditionalFormatProperty.TextColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textconditionalformat.html#cfn-quicksight-template-textconditionalformat-textcolor
         */
        readonly textColor?: CfnTemplate.ConditionalFormattingColorProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html
     */
    interface TextControlPlaceholderOptionsProperty {
        /**
         * `CfnTemplate.TextControlPlaceholderOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textcontrolplaceholderoptions.html#cfn-quicksight-template-textcontrolplaceholderoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html
     */
    interface TextFieldControlDisplayOptionsProperty {
        /**
         * `CfnTemplate.TextFieldControlDisplayOptionsProperty.PlaceholderOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-placeholderoptions
         */
        readonly placeholderOptions?: CfnTemplate.TextControlPlaceholderOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TextFieldControlDisplayOptionsProperty.TitleOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-textfieldcontroldisplayoptions.html#cfn-quicksight-template-textfieldcontroldisplayoptions-titleoptions
         */
        readonly titleOptions?: CfnTemplate.LabelOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html
     */
    interface ThousandSeparatorOptionsProperty {
        /**
         * `CfnTemplate.ThousandSeparatorOptionsProperty.Symbol`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-symbol
         */
        readonly symbol?: string;
        /**
         * `CfnTemplate.ThousandSeparatorOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-thousandseparatoroptions.html#cfn-quicksight-template-thousandseparatoroptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html
     */
    interface TimeBasedForecastPropertiesProperty {
        /**
         * `CfnTemplate.TimeBasedForecastPropertiesProperty.LowerBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-lowerboundary
         */
        readonly lowerBoundary?: number;
        /**
         * `CfnTemplate.TimeBasedForecastPropertiesProperty.PeriodsBackward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsbackward
         */
        readonly periodsBackward?: number;
        /**
         * `CfnTemplate.TimeBasedForecastPropertiesProperty.PeriodsForward`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-periodsforward
         */
        readonly periodsForward?: number;
        /**
         * `CfnTemplate.TimeBasedForecastPropertiesProperty.PredictionInterval`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-predictioninterval
         */
        readonly predictionInterval?: number;
        /**
         * `CfnTemplate.TimeBasedForecastPropertiesProperty.Seasonality`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-seasonality
         */
        readonly seasonality?: number;
        /**
         * `CfnTemplate.TimeBasedForecastPropertiesProperty.UpperBoundary`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timebasedforecastproperties.html#cfn-quicksight-template-timebasedforecastproperties-upperboundary
         */
        readonly upperBoundary?: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html
     */
    interface TimeEqualityFilterProperty {
        /**
         * `CfnTemplate.TimeEqualityFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeEqualityFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnTemplate.TimeEqualityFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnTemplate.TimeEqualityFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-timegranularity
         */
        readonly timeGranularity?: string;
        /**
         * `CfnTemplate.TimeEqualityFilterProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timeequalityfilter.html#cfn-quicksight-template-timeequalityfilter-value
         */
        readonly value?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html
     */
    interface TimeRangeDrillDownFilterProperty {
        /**
         * `CfnTemplate.TimeRangeDrillDownFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeRangeDrillDownFilterProperty.RangeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangemaximum
         */
        readonly rangeMaximum: string;
        /**
         * `CfnTemplate.TimeRangeDrillDownFilterProperty.RangeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-rangeminimum
         */
        readonly rangeMinimum: string;
        /**
         * `CfnTemplate.TimeRangeDrillDownFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangedrilldownfilter.html#cfn-quicksight-template-timerangedrilldownfilter-timegranularity
         */
        readonly timeGranularity: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html
     */
    interface TimeRangeFilterProperty {
        /**
         * `CfnTemplate.TimeRangeFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeRangeFilterProperty.ExcludePeriodConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-excludeperiodconfiguration
         */
        readonly excludePeriodConfiguration?: CfnTemplate.ExcludePeriodConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeRangeFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnTemplate.TimeRangeFilterProperty.IncludeMaximum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includemaximum
         */
        readonly includeMaximum?: boolean | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeRangeFilterProperty.IncludeMinimum`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-includeminimum
         */
        readonly includeMinimum?: boolean | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeRangeFilterProperty.NullOption`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-nulloption
         */
        readonly nullOption: string;
        /**
         * `CfnTemplate.TimeRangeFilterProperty.RangeMaximumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangemaximumvalue
         */
        readonly rangeMaximumValue?: CfnTemplate.TimeRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeRangeFilterProperty.RangeMinimumValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-rangeminimumvalue
         */
        readonly rangeMinimumValue?: CfnTemplate.TimeRangeFilterValueProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeRangeFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefilter.html#cfn-quicksight-template-timerangefilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html
     */
    interface TimeRangeFilterValueProperty {
        /**
         * `CfnTemplate.TimeRangeFilterValueProperty.Parameter`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-parameter
         */
        readonly parameter?: string;
        /**
         * `CfnTemplate.TimeRangeFilterValueProperty.RollingDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-rollingdate
         */
        readonly rollingDate?: CfnTemplate.RollingDateConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TimeRangeFilterValueProperty.StaticValue`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-timerangefiltervalue.html#cfn-quicksight-template-timerangefiltervalue-staticvalue
         */
        readonly staticValue?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html
     */
    interface TooltipItemProperty {
        /**
         * `CfnTemplate.TooltipItemProperty.ColumnTooltipItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-columntooltipitem
         */
        readonly columnTooltipItem?: CfnTemplate.ColumnTooltipItemProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TooltipItemProperty.FieldTooltipItem`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipitem.html#cfn-quicksight-template-tooltipitem-fieldtooltipitem
         */
        readonly fieldTooltipItem?: CfnTemplate.FieldTooltipItemProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html
     */
    interface TooltipOptionsProperty {
        /**
         * `CfnTemplate.TooltipOptionsProperty.FieldBasedTooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-fieldbasedtooltip
         */
        readonly fieldBasedTooltip?: CfnTemplate.FieldBasedTooltipProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TooltipOptionsProperty.SelectedTooltipType`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-selectedtooltiptype
         */
        readonly selectedTooltipType?: string;
        /**
         * `CfnTemplate.TooltipOptionsProperty.TooltipVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-tooltipoptions.html#cfn-quicksight-template-tooltipoptions-tooltipvisibility
         */
        readonly tooltipVisibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html
     */
    interface TopBottomFilterProperty {
        /**
         * `CfnTemplate.TopBottomFilterProperty.AggregationSortConfigurations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-aggregationsortconfigurations
         */
        readonly aggregationSortConfigurations: Array<CfnTemplate.AggregationSortConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TopBottomFilterProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TopBottomFilterProperty.FilterId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-filterid
         */
        readonly filterId: string;
        /**
         * `CfnTemplate.TopBottomFilterProperty.Limit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-limit
         */
        readonly limit?: number;
        /**
         * `CfnTemplate.TopBottomFilterProperty.ParameterName`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-parametername
         */
        readonly parameterName?: string;
        /**
         * `CfnTemplate.TopBottomFilterProperty.TimeGranularity`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomfilter.html#cfn-quicksight-template-topbottomfilter-timegranularity
         */
        readonly timeGranularity?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html
     */
    interface TopBottomMoversComputationProperty {
        /**
         * `CfnTemplate.TopBottomMoversComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-category
         */
        readonly category: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TopBottomMoversComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.TopBottomMoversComputationProperty.MoverSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-moversize
         */
        readonly moverSize?: number;
        /**
         * `CfnTemplate.TopBottomMoversComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.TopBottomMoversComputationProperty.SortOrder`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-sortorder
         */
        readonly sortOrder?: string;
        /**
         * `CfnTemplate.TopBottomMoversComputationProperty.Time`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-time
         */
        readonly time: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TopBottomMoversComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-type
         */
        readonly type: string;
        /**
         * `CfnTemplate.TopBottomMoversComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottommoverscomputation.html#cfn-quicksight-template-topbottommoverscomputation-value
         */
        readonly value?: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html
     */
    interface TopBottomRankedComputationProperty {
        /**
         * `CfnTemplate.TopBottomRankedComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-category
         */
        readonly category: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TopBottomRankedComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.TopBottomRankedComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.TopBottomRankedComputationProperty.ResultSize`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-resultsize
         */
        readonly resultSize?: number;
        /**
         * `CfnTemplate.TopBottomRankedComputationProperty.Type`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-type
         */
        readonly type: string;
        /**
         * `CfnTemplate.TopBottomRankedComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-topbottomrankedcomputation.html#cfn-quicksight-template-topbottomrankedcomputation-value
         */
        readonly value?: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html
     */
    interface TotalAggregationComputationProperty {
        /**
         * `CfnTemplate.TotalAggregationComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.TotalAggregationComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-name
         */
        readonly name?: string;
        /**
         * `CfnTemplate.TotalAggregationComputationProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totalaggregationcomputation.html#cfn-quicksight-template-totalaggregationcomputation-value
         */
        readonly value: CfnTemplate.MeasureFieldProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html
     */
    interface TotalOptionsProperty {
        /**
         * `CfnTemplate.TotalOptionsProperty.CustomLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-customlabel
         */
        readonly customLabel?: string;
        /**
         * `CfnTemplate.TotalOptionsProperty.Placement`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-placement
         */
        readonly placement?: string;
        /**
         * `CfnTemplate.TotalOptionsProperty.ScrollStatus`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-scrollstatus
         */
        readonly scrollStatus?: string;
        /**
         * `CfnTemplate.TotalOptionsProperty.TotalCellStyle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalcellstyle
         */
        readonly totalCellStyle?: CfnTemplate.TableCellStyleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TotalOptionsProperty.TotalsVisibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-totaloptions.html#cfn-quicksight-template-totaloptions-totalsvisibility
         */
        readonly totalsVisibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html
     */
    interface TreeMapAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.TreeMapAggregatedFieldWellsProperty.Colors`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-colors
         */
        readonly colors?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapAggregatedFieldWellsProperty.Groups`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-groups
         */
        readonly groups?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapAggregatedFieldWellsProperty.Sizes`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapaggregatedfieldwells.html#cfn-quicksight-template-treemapaggregatedfieldwells-sizes
         */
        readonly sizes?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html
     */
    interface TreeMapConfigurationProperty {
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.ColorLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorlabeloptions
         */
        readonly colorLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.ColorScale`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-colorscale
         */
        readonly colorScale?: CfnTemplate.ColorScaleProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.TreeMapFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.GroupLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-grouplabeloptions
         */
        readonly groupLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.SizeLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sizelabeloptions
         */
        readonly sizeLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.TreeMapSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapConfigurationProperty.Tooltip`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapconfiguration.html#cfn-quicksight-template-treemapconfiguration-tooltip
         */
        readonly tooltip?: CfnTemplate.TooltipOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html
     */
    interface TreeMapFieldWellsProperty {
        /**
         * `CfnTemplate.TreeMapFieldWellsProperty.TreeMapAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapfieldwells.html#cfn-quicksight-template-treemapfieldwells-treemapaggregatedfieldwells
         */
        readonly treeMapAggregatedFieldWells?: CfnTemplate.TreeMapAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html
     */
    interface TreeMapSortConfigurationProperty {
        /**
         * `CfnTemplate.TreeMapSortConfigurationProperty.TreeMapGroupItemsLimitConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapgroupitemslimitconfiguration
         */
        readonly treeMapGroupItemsLimitConfiguration?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapSortConfigurationProperty.TreeMapSort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapsortconfiguration.html#cfn-quicksight-template-treemapsortconfiguration-treemapsort
         */
        readonly treeMapSort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html
     */
    interface TreeMapVisualProperty {
        /**
         * `CfnTemplate.TreeMapVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.TreeMapConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.TreeMapVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-treemapvisual.html#cfn-quicksight-template-treemapvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html
     */
    interface TrendArrowOptionsProperty {
        /**
         * `CfnTemplate.TrendArrowOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-trendarrowoptions.html#cfn-quicksight-template-trendarrowoptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html
     */
    interface UnaggregatedFieldProperty {
        /**
         * `CfnTemplate.UnaggregatedFieldProperty.Column`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-column
         */
        readonly column: CfnTemplate.ColumnIdentifierProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.UnaggregatedFieldProperty.FieldId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-fieldid
         */
        readonly fieldId: string;
        /**
         * `CfnTemplate.UnaggregatedFieldProperty.FormatConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-unaggregatedfield.html#cfn-quicksight-template-unaggregatedfield-formatconfiguration
         */
        readonly formatConfiguration?: CfnTemplate.FormatConfigurationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html
     */
    interface UniqueValuesComputationProperty {
        /**
         * `CfnTemplate.UniqueValuesComputationProperty.Category`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-category
         */
        readonly category: CfnTemplate.DimensionFieldProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.UniqueValuesComputationProperty.ComputationId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-computationid
         */
        readonly computationId: string;
        /**
         * `CfnTemplate.UniqueValuesComputationProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-uniquevaluescomputation.html#cfn-quicksight-template-uniquevaluescomputation-name
         */
        readonly name?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html
     */
    interface VisibleRangeOptionsProperty {
        /**
         * `CfnTemplate.VisibleRangeOptionsProperty.PercentRange`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visiblerangeoptions.html#cfn-quicksight-template-visiblerangeoptions-percentrange
         */
        readonly percentRange?: CfnTemplate.PercentVisibleRangeProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html
     */
    interface VisualProperty {
        /**
         * `CfnTemplate.VisualProperty.BarChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-barchartvisual
         */
        readonly barChartVisual?: CfnTemplate.BarChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.BoxPlotVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-boxplotvisual
         */
        readonly boxPlotVisual?: CfnTemplate.BoxPlotVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.ComboChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-combochartvisual
         */
        readonly comboChartVisual?: CfnTemplate.ComboChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.CustomContentVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-customcontentvisual
         */
        readonly customContentVisual?: CfnTemplate.CustomContentVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.EmptyVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-emptyvisual
         */
        readonly emptyVisual?: CfnTemplate.EmptyVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.FilledMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-filledmapvisual
         */
        readonly filledMapVisual?: CfnTemplate.FilledMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.FunnelChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-funnelchartvisual
         */
        readonly funnelChartVisual?: CfnTemplate.FunnelChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.GaugeChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-gaugechartvisual
         */
        readonly gaugeChartVisual?: CfnTemplate.GaugeChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.GeospatialMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-geospatialmapvisual
         */
        readonly geospatialMapVisual?: CfnTemplate.GeospatialMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.HeatMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-heatmapvisual
         */
        readonly heatMapVisual?: CfnTemplate.HeatMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.HistogramVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-histogramvisual
         */
        readonly histogramVisual?: CfnTemplate.HistogramVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.InsightVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-insightvisual
         */
        readonly insightVisual?: CfnTemplate.InsightVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.KPIVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-kpivisual
         */
        readonly kpiVisual?: CfnTemplate.KPIVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.LineChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-linechartvisual
         */
        readonly lineChartVisual?: CfnTemplate.LineChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.PieChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-piechartvisual
         */
        readonly pieChartVisual?: CfnTemplate.PieChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.PivotTableVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-pivottablevisual
         */
        readonly pivotTableVisual?: CfnTemplate.PivotTableVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.RadarChartVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-radarchartvisual
         */
        readonly radarChartVisual?: CfnTemplate.RadarChartVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.SankeyDiagramVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-sankeydiagramvisual
         */
        readonly sankeyDiagramVisual?: CfnTemplate.SankeyDiagramVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.ScatterPlotVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-scatterplotvisual
         */
        readonly scatterPlotVisual?: CfnTemplate.ScatterPlotVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.TableVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-tablevisual
         */
        readonly tableVisual?: CfnTemplate.TableVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.TreeMapVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-treemapvisual
         */
        readonly treeMapVisual?: CfnTemplate.TreeMapVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.WaterfallVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-waterfallvisual
         */
        readonly waterfallVisual?: CfnTemplate.WaterfallVisualProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualProperty.WordCloudVisual`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visual.html#cfn-quicksight-template-visual-wordcloudvisual
         */
        readonly wordCloudVisual?: CfnTemplate.WordCloudVisualProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html
     */
    interface VisualCustomActionProperty {
        /**
         * `CfnTemplate.VisualCustomActionProperty.ActionOperations`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-actionoperations
         */
        readonly actionOperations: Array<CfnTemplate.VisualCustomActionOperationProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualCustomActionProperty.CustomActionId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-customactionid
         */
        readonly customActionId: string;
        /**
         * `CfnTemplate.VisualCustomActionProperty.Name`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-name
         */
        readonly name: string;
        /**
         * `CfnTemplate.VisualCustomActionProperty.Status`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-status
         */
        readonly status?: string;
        /**
         * `CfnTemplate.VisualCustomActionProperty.Trigger`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomaction.html#cfn-quicksight-template-visualcustomaction-trigger
         */
        readonly trigger: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html
     */
    interface VisualCustomActionOperationProperty {
        /**
         * `CfnTemplate.VisualCustomActionOperationProperty.FilterOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-filteroperation
         */
        readonly filterOperation?: CfnTemplate.CustomActionFilterOperationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualCustomActionOperationProperty.NavigationOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-navigationoperation
         */
        readonly navigationOperation?: CfnTemplate.CustomActionNavigationOperationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualCustomActionOperationProperty.SetParametersOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-setparametersoperation
         */
        readonly setParametersOperation?: CfnTemplate.CustomActionSetParametersOperationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualCustomActionOperationProperty.URLOperation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualcustomactionoperation.html#cfn-quicksight-template-visualcustomactionoperation-urloperation
         */
        readonly urlOperation?: CfnTemplate.CustomActionURLOperationProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html
     */
    interface VisualPaletteProperty {
        /**
         * `CfnTemplate.VisualPaletteProperty.ChartColor`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-chartcolor
         */
        readonly chartColor?: string;
        /**
         * `CfnTemplate.VisualPaletteProperty.ColorMap`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualpalette.html#cfn-quicksight-template-visualpalette-colormap
         */
        readonly colorMap?: Array<CfnTemplate.DataPathColorProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html
     */
    interface VisualSubtitleLabelOptionsProperty {
        /**
         * `CfnTemplate.VisualSubtitleLabelOptionsProperty.FormatText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-formattext
         */
        readonly formatText?: CfnTemplate.LongFormatTextProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualSubtitleLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualsubtitlelabeloptions.html#cfn-quicksight-template-visualsubtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html
     */
    interface VisualTitleLabelOptionsProperty {
        /**
         * `CfnTemplate.VisualTitleLabelOptionsProperty.FormatText`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-formattext
         */
        readonly formatText?: CfnTemplate.ShortFormatTextProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.VisualTitleLabelOptionsProperty.Visibility`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-visualtitlelabeloptions.html#cfn-quicksight-template-visualtitlelabeloptions-visibility
         */
        readonly visibility?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html
     */
    interface WaterfallChartAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.WaterfallChartAggregatedFieldWellsProperty.Breakdowns`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-breakdowns
         */
        readonly breakdowns?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartAggregatedFieldWellsProperty.Categories`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-categories
         */
        readonly categories?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartAggregatedFieldWellsProperty.Values`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartaggregatedfieldwells.html#cfn-quicksight-template-waterfallchartaggregatedfieldwells-values
         */
        readonly values?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html
     */
    interface WaterfallChartConfigurationProperty {
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.CategoryAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxisdisplayoptions
         */
        readonly categoryAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.CategoryAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-categoryaxislabeloptions
         */
        readonly categoryAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.DataLabels`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-datalabels
         */
        readonly dataLabels?: CfnTemplate.DataLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.WaterfallChartFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.Legend`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-legend
         */
        readonly legend?: CfnTemplate.LegendOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.PrimaryYAxisDisplayOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxisdisplayoptions
         */
        readonly primaryYAxisDisplayOptions?: CfnTemplate.AxisDisplayOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.PrimaryYAxisLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-primaryyaxislabeloptions
         */
        readonly primaryYAxisLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.WaterfallChartSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.VisualPalette`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-visualpalette
         */
        readonly visualPalette?: CfnTemplate.VisualPaletteProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartConfigurationProperty.WaterfallChartOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartconfiguration.html#cfn-quicksight-template-waterfallchartconfiguration-waterfallchartoptions
         */
        readonly waterfallChartOptions?: CfnTemplate.WaterfallChartOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html
     */
    interface WaterfallChartFieldWellsProperty {
        /**
         * `CfnTemplate.WaterfallChartFieldWellsProperty.WaterfallChartAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartfieldwells.html#cfn-quicksight-template-waterfallchartfieldwells-waterfallchartaggregatedfieldwells
         */
        readonly waterfallChartAggregatedFieldWells?: CfnTemplate.WaterfallChartAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html
     */
    interface WaterfallChartOptionsProperty {
        /**
         * `CfnTemplate.WaterfallChartOptionsProperty.TotalBarLabel`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartoptions.html#cfn-quicksight-template-waterfallchartoptions-totalbarlabel
         */
        readonly totalBarLabel?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html
     */
    interface WaterfallChartSortConfigurationProperty {
        /**
         * `CfnTemplate.WaterfallChartSortConfigurationProperty.BreakdownItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-breakdownitemslimit
         */
        readonly breakdownItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallChartSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallchartsortconfiguration.html#cfn-quicksight-template-waterfallchartsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html
     */
    interface WaterfallVisualProperty {
        /**
         * `CfnTemplate.WaterfallVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.WaterfallChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WaterfallVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-waterfallvisual.html#cfn-quicksight-template-waterfallvisual-visualid
         */
        readonly visualId: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html
     */
    interface WhatIfPointScenarioProperty {
        /**
         * `CfnTemplate.WhatIfPointScenarioProperty.Date`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-date
         */
        readonly date: string;
        /**
         * `CfnTemplate.WhatIfPointScenarioProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifpointscenario.html#cfn-quicksight-template-whatifpointscenario-value
         */
        readonly value: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html
     */
    interface WhatIfRangeScenarioProperty {
        /**
         * `CfnTemplate.WhatIfRangeScenarioProperty.EndDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-enddate
         */
        readonly endDate: string;
        /**
         * `CfnTemplate.WhatIfRangeScenarioProperty.StartDate`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-startdate
         */
        readonly startDate: string;
        /**
         * `CfnTemplate.WhatIfRangeScenarioProperty.Value`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-whatifrangescenario.html#cfn-quicksight-template-whatifrangescenario-value
         */
        readonly value: number;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html
     */
    interface WordCloudAggregatedFieldWellsProperty {
        /**
         * `CfnTemplate.WordCloudAggregatedFieldWellsProperty.GroupBy`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-groupby
         */
        readonly groupBy?: Array<CfnTemplate.DimensionFieldProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudAggregatedFieldWellsProperty.Size`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudaggregatedfieldwells.html#cfn-quicksight-template-wordcloudaggregatedfieldwells-size
         */
        readonly size?: Array<CfnTemplate.MeasureFieldProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html
     */
    interface WordCloudChartConfigurationProperty {
        /**
         * `CfnTemplate.WordCloudChartConfigurationProperty.CategoryLabelOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-categorylabeloptions
         */
        readonly categoryLabelOptions?: CfnTemplate.ChartAxisLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudChartConfigurationProperty.FieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-fieldwells
         */
        readonly fieldWells?: CfnTemplate.WordCloudFieldWellsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudChartConfigurationProperty.SortConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-sortconfiguration
         */
        readonly sortConfiguration?: CfnTemplate.WordCloudSortConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudChartConfigurationProperty.WordCloudOptions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudchartconfiguration.html#cfn-quicksight-template-wordcloudchartconfiguration-wordcloudoptions
         */
        readonly wordCloudOptions?: CfnTemplate.WordCloudOptionsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html
     */
    interface WordCloudFieldWellsProperty {
        /**
         * `CfnTemplate.WordCloudFieldWellsProperty.WordCloudAggregatedFieldWells`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudfieldwells.html#cfn-quicksight-template-wordcloudfieldwells-wordcloudaggregatedfieldwells
         */
        readonly wordCloudAggregatedFieldWells?: CfnTemplate.WordCloudAggregatedFieldWellsProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html
     */
    interface WordCloudOptionsProperty {
        /**
         * `CfnTemplate.WordCloudOptionsProperty.CloudLayout`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-cloudlayout
         */
        readonly cloudLayout?: string;
        /**
         * `CfnTemplate.WordCloudOptionsProperty.MaximumStringLength`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-maximumstringlength
         */
        readonly maximumStringLength?: number;
        /**
         * `CfnTemplate.WordCloudOptionsProperty.WordCasing`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordcasing
         */
        readonly wordCasing?: string;
        /**
         * `CfnTemplate.WordCloudOptionsProperty.WordOrientation`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordorientation
         */
        readonly wordOrientation?: string;
        /**
         * `CfnTemplate.WordCloudOptionsProperty.WordPadding`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordpadding
         */
        readonly wordPadding?: string;
        /**
         * `CfnTemplate.WordCloudOptionsProperty.WordScaling`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudoptions.html#cfn-quicksight-template-wordcloudoptions-wordscaling
         */
        readonly wordScaling?: string;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html
     */
    interface WordCloudSortConfigurationProperty {
        /**
         * `CfnTemplate.WordCloudSortConfigurationProperty.CategoryItemsLimit`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categoryitemslimit
         */
        readonly categoryItemsLimit?: CfnTemplate.ItemsLimitConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudSortConfigurationProperty.CategorySort`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudsortconfiguration.html#cfn-quicksight-template-wordcloudsortconfiguration-categorysort
         */
        readonly categorySort?: Array<CfnTemplate.FieldSortOptionsProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTemplate {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html
     */
    interface WordCloudVisualProperty {
        /**
         * `CfnTemplate.WordCloudVisualProperty.Actions`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-actions
         */
        readonly actions?: Array<CfnTemplate.VisualCustomActionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudVisualProperty.ChartConfiguration`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-chartconfiguration
         */
        readonly chartConfiguration?: CfnTemplate.WordCloudChartConfigurationProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudVisualProperty.ColumnHierarchies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-columnhierarchies
         */
        readonly columnHierarchies?: Array<CfnTemplate.ColumnHierarchyProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudVisualProperty.Subtitle`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-subtitle
         */
        readonly subtitle?: CfnTemplate.VisualSubtitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudVisualProperty.Title`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-title
         */
        readonly title?: CfnTemplate.VisualTitleLabelOptionsProperty | cdk.IResolvable;
        /**
         * `CfnTemplate.WordCloudVisualProperty.VisualId`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-template-wordcloudvisual.html#cfn-quicksight-template-wordcloudvisual-visualid
         */
        readonly visualId: string;
    }
}
/**
 * Properties for defining a `CfnTheme`
 *
 * @struct
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
 */
export interface CfnThemeProps {
    /**
     * The ID of the AWS account where you want to store the new theme.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-awsaccountid
     */
    readonly awsAccountId: string;
    /**
     * An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-themeid
     */
    readonly themeId: string;
    /**
     * The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use `ListThemes` or choose *Themes* from within an analysis.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-basethemeid
     */
    readonly baseThemeId?: string;
    /**
     * The theme configuration, which contains the theme display properties.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-configuration
     */
    readonly configuration?: CfnTheme.ThemeConfigurationProperty | cdk.IResolvable;
    /**
     * A display name for the theme.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-name
     */
    readonly name?: string;
    /**
     * A valid grouping of resource permissions to apply to the new theme.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-permissions
     */
    readonly permissions?: Array<CfnTheme.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-tags
     */
    readonly tags?: cdk.CfnTag[];
    /**
     * A description of the first version of the theme that you're creating. Every time `UpdateTheme` is called, a new version is created. Each version of the theme has a description of the version in the `VersionDescription` field.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-versiondescription
     */
    readonly versionDescription?: string;
}
/**
 * A CloudFormation `AWS::QuickSight::Theme`
 *
 * Creates a theme.
 *
 * A *theme* is set of configuration options for color and layout. Themes apply to analyses and dashboards. For more information, see [Using Themes in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html) in the *Amazon QuickSight User Guide* .
 *
 * @cloudformationResource AWS::QuickSight::Theme
 * @stability external
 *
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html
 */
export declare class CfnTheme extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "AWS::QuickSight::Theme";
    /**
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnTheme;
    /**
     * The Amazon Resource Name (ARN) of the theme.
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The time the theme was created.
     * @cloudformationAttribute CreatedTime
     */
    readonly attrCreatedTime: string;
    /**
     * The time the theme was last updated.
     * @cloudformationAttribute LastUpdatedTime
     */
    readonly attrLastUpdatedTime: string;
    /**
     * Theme type.
     * @cloudformationAttribute Type
     */
    readonly attrType: string;
    /**
     *
     * @cloudformationAttribute Version.Arn
     */
    readonly attrVersionArn: string;
    /**
     *
     * @cloudformationAttribute Version.BaseThemeId
     */
    readonly attrVersionBaseThemeId: string;
    /**
     *
     * @cloudformationAttribute Version.CreatedTime
     */
    readonly attrVersionCreatedTime: string;
    /**
     *
     * @cloudformationAttribute Version.Description
     */
    readonly attrVersionDescription: string;
    /**
     *
     * @cloudformationAttribute Version.Errors
     */
    readonly attrVersionErrors: cdk.IResolvable;
    /**
     *
     * @cloudformationAttribute Version.Status
     */
    readonly attrVersionStatus: string;
    /**
     *
     * @cloudformationAttribute Version.VersionNumber
     */
    readonly attrVersionVersionNumber: cdk.IResolvable;
    /**
     * The ID of the AWS account where you want to store the new theme.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-awsaccountid
     */
    awsAccountId: string;
    /**
     * An ID for the theme that you want to create. The theme ID is unique per AWS Region in each AWS account.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-themeid
     */
    themeId: string;
    /**
     * The ID of the theme that a custom theme will inherit from. All themes inherit from one of the starting themes defined by Amazon QuickSight. For a list of the starting themes, use `ListThemes` or choose *Themes* from within an analysis.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-basethemeid
     */
    baseThemeId: string | undefined;
    /**
     * The theme configuration, which contains the theme display properties.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-configuration
     */
    configuration: CfnTheme.ThemeConfigurationProperty | cdk.IResolvable | undefined;
    /**
     * A display name for the theme.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-name
     */
    name: string | undefined;
    /**
     * A valid grouping of resource permissions to apply to the new theme.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-permissions
     */
    permissions: Array<CfnTheme.ResourcePermissionProperty | cdk.IResolvable> | cdk.IResolvable | undefined;
    /**
     * A map of the key-value pairs for the resource tag or tags that you want to add to the resource.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-tags
     */
    readonly tags: cdk.TagManager;
    /**
     * A description of the first version of the theme that you're creating. Every time `UpdateTheme` is called, a new version is created. Each version of the theme has a description of the version in the `VersionDescription` field.
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-quicksight-theme.html#cfn-quicksight-theme-versiondescription
     */
    versionDescription: string | undefined;
    /**
     * Create a new `AWS::QuickSight::Theme`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnThemeProps);
    /**
     * Examines the CloudFormation resource and discloses attributes.
     *
     * @param inspector - tree inspector to collect and process attributes
     *
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected get cfnProperties(): {
        [key: string]: any;
    };
    protected renderProperties(props: {
        [key: string]: any;
    }): {
        [key: string]: any;
    };
}
export declare namespace CfnTheme {
    /**
     * The display options for tile borders for visuals.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html
     */
    interface BorderStyleProperty {
        /**
         * The option to enable display of borders for visuals.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-borderstyle.html#cfn-quicksight-theme-borderstyle-show
         */
        readonly show?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnTheme {
    /**
     * The theme colors that are used for data colors in charts. The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with `#` , for example #37BFF5.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html
     */
    interface DataColorPaletteProperty {
        /**
         * The hexadecimal codes for the colors.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-colors
         */
        readonly colors?: string[];
        /**
         * The hexadecimal code of a color that applies to charts where a lack of data is highlighted.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-emptyfillcolor
         */
        readonly emptyFillColor?: string;
        /**
         * The minimum and maximum hexadecimal codes that describe a color gradient.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-datacolorpalette.html#cfn-quicksight-theme-datacolorpalette-minmaxgradient
         */
        readonly minMaxGradient?: string[];
    }
}
export declare namespace CfnTheme {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html
     */
    interface FontProperty {
        /**
         * `CfnTheme.FontProperty.FontFamily`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-font.html#cfn-quicksight-theme-font-fontfamily
         */
        readonly fontFamily?: string;
    }
}
export declare namespace CfnTheme {
    /**
     * The display options for gutter spacing between tiles on a sheet.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html
     */
    interface GutterStyleProperty {
        /**
         * This Boolean value controls whether to display a gutter space between sheet tiles.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-gutterstyle.html#cfn-quicksight-theme-gutterstyle-show
         */
        readonly show?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnTheme {
    /**
     * The display options for margins around the outside edge of sheets.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html
     */
    interface MarginStyleProperty {
        /**
         * This Boolean value controls whether to display sheet margins.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-marginstyle.html#cfn-quicksight-theme-marginstyle-show
         */
        readonly show?: boolean | cdk.IResolvable;
    }
}
export declare namespace CfnTheme {
    /**
     * Permission for the resource.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html
     */
    interface ResourcePermissionProperty {
        /**
         * The IAM action to grant or revoke permissions on.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-actions
         */
        readonly actions: string[];
        /**
         * The Amazon Resource Name (ARN) of the principal. This can be one of the following:
         *
         * - The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)
         * - The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)
         * - The ARN of an AWS account root: This is an IAM ARN rather than a Amazon QuickSight ARN. Use this option only to share resources (templates) across AWS accounts . (This is less common.)
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-resourcepermission.html#cfn-quicksight-theme-resourcepermission-principal
         */
        readonly principal: string;
    }
}
export declare namespace CfnTheme {
    /**
     * The theme display options for sheets.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html
     */
    interface SheetStyleProperty {
        /**
         * The display options for tiles.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tile
         */
        readonly tile?: CfnTheme.TileStyleProperty | cdk.IResolvable;
        /**
         * The layout options for tiles.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-sheetstyle.html#cfn-quicksight-theme-sheetstyle-tilelayout
         */
        readonly tileLayout?: CfnTheme.TileLayoutStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTheme {
    /**
     * The theme configuration. This configuration contains all of the display properties for a theme.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html
     */
    interface ThemeConfigurationProperty {
        /**
         * Color properties that apply to chart data colors.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-datacolorpalette
         */
        readonly dataColorPalette?: CfnTheme.DataColorPaletteProperty | cdk.IResolvable;
        /**
         * Display options related to sheets.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-sheet
         */
        readonly sheet?: CfnTheme.SheetStyleProperty | cdk.IResolvable;
        /**
         * `CfnTheme.ThemeConfigurationProperty.Typography`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-typography
         */
        readonly typography?: CfnTheme.TypographyProperty | cdk.IResolvable;
        /**
         * Color properties that apply to the UI and to charts, excluding the colors that apply to data.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeconfiguration.html#cfn-quicksight-theme-themeconfiguration-uicolorpalette
         */
        readonly uiColorPalette?: CfnTheme.UIColorPaletteProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTheme {
    /**
     * Theme error.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html
     */
    interface ThemeErrorProperty {
        /**
         * The error message.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-message
         */
        readonly message?: string;
        /**
         * The type of error.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeerror.html#cfn-quicksight-theme-themeerror-type
         */
        readonly type?: string;
    }
}
export declare namespace CfnTheme {
    /**
     * A version of a theme.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html
     */
    interface ThemeVersionProperty {
        /**
         * The Amazon Resource Name (ARN) of the resource.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-arn
         */
        readonly arn?: string;
        /**
         * The Amazon QuickSight-defined ID of the theme that a custom theme inherits from. All themes initially inherit from a default Amazon QuickSight theme.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-basethemeid
         */
        readonly baseThemeId?: string;
        /**
         * The theme configuration, which contains all the theme display properties.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-configuration
         */
        readonly configuration?: CfnTheme.ThemeConfigurationProperty | cdk.IResolvable;
        /**
         * The date and time that this theme version was created.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-createdtime
         */
        readonly createdTime?: string;
        /**
         * The description of the theme.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-description
         */
        readonly description?: string;
        /**
         * Errors associated with the theme.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-errors
         */
        readonly errors?: Array<CfnTheme.ThemeErrorProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The status of the theme version.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-status
         */
        readonly status?: string;
        /**
         * The version number of the theme.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-themeversion.html#cfn-quicksight-theme-themeversion-versionnumber
         */
        readonly versionNumber?: number;
    }
}
export declare namespace CfnTheme {
    /**
     * The display options for the layout of tiles on a sheet.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html
     */
    interface TileLayoutStyleProperty {
        /**
         * The gutter settings that apply between tiles.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-gutter
         */
        readonly gutter?: CfnTheme.GutterStyleProperty | cdk.IResolvable;
        /**
         * The margin settings that apply around the outside edge of sheets.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilelayoutstyle.html#cfn-quicksight-theme-tilelayoutstyle-margin
         */
        readonly margin?: CfnTheme.MarginStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTheme {
    /**
     * Display options related to tiles on a sheet.
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html
     */
    interface TileStyleProperty {
        /**
         * The border around a tile.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-tilestyle.html#cfn-quicksight-theme-tilestyle-border
         */
        readonly border?: CfnTheme.BorderStyleProperty | cdk.IResolvable;
    }
}
export declare namespace CfnTheme {
    /**
     *
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html
     */
    interface TypographyProperty {
        /**
         * `CfnTheme.TypographyProperty.FontFamilies`
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-typography.html#cfn-quicksight-theme-typography-fontfamilies
         */
        readonly fontFamilies?: Array<CfnTheme.FontProperty | cdk.IResolvable> | cdk.IResolvable;
    }
}
export declare namespace CfnTheme {
    /**
     * The theme colors that apply to UI and to charts, excluding data colors. The colors description is a hexadecimal color code that consists of six alphanumerical characters, prefixed with `#` , for example #37BFF5. For more information, see [Using Themes in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html) in the *Amazon QuickSight User Guide.*
     *
     * @struct
     * @stability external
     *
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html
     */
    interface UIColorPaletteProperty {
        /**
         * This color is that applies to selected states and buttons.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accent
         */
        readonly accent?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the accent color.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-accentforeground
         */
        readonly accentForeground?: string;
        /**
         * The color that applies to error messages.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-danger
         */
        readonly danger?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the error color.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dangerforeground
         */
        readonly dangerForeground?: string;
        /**
         * The color that applies to the names of fields that are identified as dimensions.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimension
         */
        readonly dimension?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the dimension color.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-dimensionforeground
         */
        readonly dimensionForeground?: string;
        /**
         * The color that applies to the names of fields that are identified as measures.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measure
         */
        readonly measure?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the measure color.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-measureforeground
         */
        readonly measureForeground?: string;
        /**
         * The background color that applies to visuals and other high emphasis UI.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primarybackground
         */
        readonly primaryBackground?: string;
        /**
         * The color of text and other foreground elements that appear over the primary background regions, such as grid lines, borders, table banding, icons, and so on.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-primaryforeground
         */
        readonly primaryForeground?: string;
        /**
         * The background color that applies to the sheet background and sheet controls.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondarybackground
         */
        readonly secondaryBackground?: string;
        /**
         * The foreground color that applies to any sheet title, sheet control text, or UI that appears over the secondary background.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-secondaryforeground
         */
        readonly secondaryForeground?: string;
        /**
         * The color that applies to success messages, for example the check mark for a successful download.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-success
         */
        readonly success?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the success color.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-successforeground
         */
        readonly successForeground?: string;
        /**
         * This color that applies to warning and informational messages.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warning
         */
        readonly warning?: string;
        /**
         * The foreground color that applies to any text or other elements that appear over the warning color.
         *
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-quicksight-theme-uicolorpalette.html#cfn-quicksight-theme-uicolorpalette-warningforeground
         */
        readonly warningForeground?: string;
    }
}
